@@ -1,7 +1,7 @@
 /*
  * check_netlist.cpp - checker for the Qucs netlist
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_netlist.cpp,v 1.82 2005/07/04 08:33:58 raimi Exp $
+ * $Id: check_netlist.cpp,v 1.92 2006/05/15 06:45:42 raimi Exp $
  *
  */
 
@@ -191,6 +191,8 @@ static struct special_t checker_specials[] = {
   { "BJT",    "Type",        { "npn", "pnp", NULL } },
   { "MOSFET", "Type",        { "nfet", "pfet", NULL } },
   { "SP",     "Noise",       { "yes", "no", NULL } },
+  { "SP",     "saveCVs",     { "yes", "no", NULL } },
+  { "SP",     "saveAll",     { "yes", "no", NULL } },
   { "SP",     "Type",        { "lin", "log", "list", "const", NULL } },
   { "AC",     "Type",        { "lin", "log", "list", "const", NULL } },
   { "AC",     "Noise",       { "yes", "no", NULL } },
@@ -206,6 +208,7 @@ static struct special_t checker_specials[] = {
     { "Euler", "Trapezoidal", "Gear", "AdamsMoulton", NULL } },
   { "TR",     "Solver",      { "CroutLU", "DoolittleLU", "HouseholderQR",
 			       "HouseholderLQ", NULL } },
+  { "TR",     "relaxTSR",    { "yes", "no", NULL } },
   { "MLIN",   "DispModel",   { "Kirschning", "Kobayashi", "Yamashita",
 			       "Getsinger", "Schneider", "Pramanick",
 			       "Hammerstad", NULL } },
@@ -217,6 +220,11 @@ static struct special_t checker_specials[] = {
   { "CSTEP",  "Backside",    { "Metal", "Air", NULL } },
   { "SW",     "Type",        { "lin", "log", "list", "const", NULL } },
   { "SPfile", "Data",        { "rectangular", "polar", NULL } },
+  { "SPfile", "Interpolator",{ "linear", "cubic", NULL } },
+  { "SPfile", "duringDC",    { "open", "short", "shortall", "unspecified",
+			       NULL } },
+  { "DigiSource", "init",    { "low", "high", NULL } },
+  { "Switch", "init",        { "on", "off", NULL } },
   { "MSTEP",  "MSDispModel", { "Kirschning", "Kobayashi", "Yamashita",
 			       "Getsinger", "Schneider", "Pramanick",
 			       "Hammerstad", NULL } },
@@ -565,7 +573,7 @@ static int checker_validate_ports (struct definition_t * root) {
   return errors;
 }
 
-/* The following funtion checks whether the parametric sweeps in the
+/* The following function checks whether the parametric sweeps in the
    netlist are valid or not.  It returns zero on success and non-zero
    otherwise. */
 static int checker_validate_lists (struct definition_t * root) {
@@ -879,16 +887,44 @@ static int checker_value_in_prop_range (char * instance, struct define_t * def,
 	errors++;
       }
     }
+    else {
+      // a value list
+      struct value_t * val = pair->value;
+      val->var = eqn::TAG_VECTOR;
+      // check and evaluate the unit scale in a value list
+      for (; val != NULL; val = val->next) {
+	if (!checker_evaluate_scale (val))
+	  errors++;
+      }
+    }
     // check range of all values
     if (PROP_HAS_RANGE (*prop)) {
       struct value_t * val = pair->value;
+      if (val->ident) {
+	/* no range checking on variable identifier */
+	logprint (LOG_STATUS, 
+		  "checker notice, value of `%s' (variable `%s') could be "
+		  "out of range `%c%g,%g%c' in `%s:%s'\n",
+		  pair->key, val->ident, prop->range.il, prop->range.l,
+		  prop->range.h, prop->range.ih, def->type, instance);
+	val = NULL;
+      }
       for (; val != NULL; val = val->next) {
-	if (val->value < prop->range.l || val->value > prop->range.h) {
+	int rerror = 0;
+	if (prop->range.il == '[' &&  (val->value < prop->range.l))
+	  rerror++;
+	if (prop->range.il == ']' && !(val->value > prop->range.l))
+	  rerror++;
+	if (prop->range.ih == '[' && !(val->value < prop->range.h))
+	  rerror++;
+	if (prop->range.ih == ']' &&  (val->value > prop->range.h))
+	  rerror++;
+	if (rerror) {
 	  logprint (LOG_ERROR, 
 		    "checker error, value of `%s' (%g) is out of "
-		    "range [%g,%g] in `%s:%s'\n",
-		    pair->key, val->value, prop->range.l,
-		    prop->range.h, def->type, instance);
+		    "range `%c%g,%g%c' in `%s:%s'\n",
+		    pair->key, val->value, prop->range.il, prop->range.l,
+		    prop->range.h, prop->range.ih, def->type, instance);
 	  errors++;
 	}
       }
@@ -1510,16 +1546,19 @@ static int netlist_checker_intern (struct definition_t * root) {
 		    pair->key, def->type, def->instance);
 	  errors++;
 	}
-	/* check and evaluate the unit scale in a property */
-	if (!checker_evaluate_scale (pair->value))
-	  errors++;
-	/* check whether properties are in range */
-	if (!checker_value_in_range (def->instance, available, pair)) {
-	  errors++;
+	// do not check zero-length lists
+	if (pair->value != NULL) {
+	  /* check and evaluate the unit scale in a property */
+	  if (!checker_evaluate_scale (pair->value))
+	    errors++;
+	  /* check whether properties are in range */
+	  if (!checker_value_in_range (def->instance, available, pair)) {
+	    errors++;
+	  }
+	  /* check variables in properties */
+	  if (!checker_resolve_variable (root, def, pair->value))
+	    errors++;
 	}
-	/* check variables in properties */
-	if (!checker_resolve_variable (root, def, pair->value))
-	  errors++;
       }
     }
     /* check the number of definitions */
@@ -1542,7 +1581,9 @@ static int netlist_checker_intern (struct definition_t * root) {
 #if DEBUG
 /* Debug function: Prints value representation. */
 static void netlist_list_value (struct value_t * value) {
-  if (value->ident)
+  if (value == NULL)
+    logprint (LOG_STATUS, "[]");
+  else if (value->ident)
     logprint (LOG_STATUS, "%s", value->ident);
   else if (value->next) {
     logprint (LOG_STATUS, "[");
@@ -1649,4 +1690,5 @@ void netlist_destroy (void) {
   definition_root = subcircuit_root = NULL;
   node_root = NULL;
   pair_root = NULL;
+  netlist_lex_destroy ();
 }
