@@ -1,7 +1,7 @@
 /*
  * check_touchstone.h - checker definitions for Touchstone files
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_touchstone.h,v 1.4 2005/06/02 18:17:49 raimi Exp $
+ * $Id: check_touchstone.h,v 1.6 2006/02/06 09:50:15 raimi Exp $
  *
  */
 
@@ -55,6 +55,7 @@ struct touchstone_t {
 /* Externalize variables used by the scanner and parser. */
 extern int touchstone_lineno;
 extern FILE * touchstone_in;
+void touchstone_restart (FILE *);
 
 __BEGIN_DECLS
 
@@ -65,6 +66,7 @@ extern struct touchstone_t touchstone_options;
 int touchstone_parse (void);
 int touchstone_error (char *);
 int touchstone_lex (void);
+int touchstone_lex_destroy (void);
 int touchstone_check (void);
 
 __END_DECLS
