@@ -1,7 +1,7 @@
 /*
  * circuit.cpp - circuit class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: circuit.cpp,v 1.39 2005/06/02 18:17:49 raimi Exp $
+ * $Id: circuit.cpp,v 1.46 2006/04/19 07:03:26 raimi Exp $
  *
  */
 
@@ -37,9 +37,13 @@
 #include "matrix.h"
 #include "node.h"
 #include "property.h"
+#include "valuelist.h"
+#include "tvector.h"
+#include "history.h"
 #include "circuit.h"
 #include "microstrip/substrate.h"
 #include "operatingpoint.h"
+#include "characteristic.h"
 #include "component_id.h"
 
 // normalising impedance
@@ -49,7 +53,10 @@ const nr_double_t circuit::z0 = 50.0;
 circuit::circuit () : object (), integrator () {
   size = 0;
   MatrixN = MatrixS = MatrixY = NULL;
-  MatrixB = MatrixC = MatrixD = MatrixE = MatrixI = MatrixV = MatrixJ = NULL;
+  MatrixB = MatrixC = MatrixD = NULL;
+  VectorQ = VectorE = VectorI = VectorV = VectorJ = NULL;
+  MatrixQV = NULL;
+  VectorCV = VectorGV = NULL;
   nodes = NULL;
   pacport = 0;
   pol = 1;
@@ -58,10 +65,12 @@ circuit::circuit () : object (), integrator () {
   vsource = -1;
   vsources = 0;
   nsources = 0;
-  oper = NULL;
   inserted = -1;
   subcircuit = NULL;
   subnet = NULL;
+  deltas = NULL;
+  histories = NULL;
+  nHistories = 0;
   type = CIR_UNKNOWN;
 }
 
@@ -72,7 +81,10 @@ circuit::circuit (int s) : object (), integrator () {
   size = s;
   if (size > 0) nodes = new node[s];
   MatrixN = MatrixS = MatrixY = NULL;
-  MatrixB = MatrixC = MatrixD = MatrixE = MatrixI = MatrixV = MatrixJ = NULL;
+  MatrixB = MatrixC = MatrixD = NULL;
+  VectorQ = VectorE = VectorI = VectorV = VectorJ = NULL;
+  MatrixQV = NULL;
+  VectorCV = VectorGV = NULL;
   pacport = 0;
   pol = 1;
   flag = CIRCUIT_ORIGINAL | CIRCUIT_LINEAR;
@@ -80,10 +92,12 @@ circuit::circuit (int s) : object (), integrator () {
   vsource = -1;
   vsources = 0;
   nsources = 0;
-  oper = NULL;
   inserted = -1;
   subcircuit = NULL;
   subnet = NULL;
+  deltas = NULL;
+  histories = NULL;
+  nHistories = 0;
   type = CIR_UNKNOWN;
 }
 
@@ -101,6 +115,9 @@ circuit::circuit (const circuit & c) : object (c), integrator (c) {
   nsources = c.nsources;
   inserted = c.inserted;
   subnet = c.subnet;
+  deltas = c.deltas;
+  nHistories = c.nHistories;
+  histories = NULL;
   subcircuit = c.subcircuit ? strdup (c.subcircuit) : NULL;
 
   if (size > 0) {
@@ -121,29 +138,40 @@ circuit::circuit (const circuit & c) : object (c), integrator (c) {
       int i = size + nsources;
       memcpy (MatrixN, c.MatrixN, i * i * sizeof (complex));
     }
-    // copy each G-MNA entry
+    // copy each HB-matrix entry
+    if (c.MatrixQV) {
+      allocMatrixHB ();
+      memcpy (MatrixQV, c.MatrixQV, size * size * sizeof (complex));
+      memcpy (VectorGV, c.VectorGV, size * sizeof (complex));
+      memcpy (VectorCV, c.VectorCV, size * sizeof (complex));
+      memcpy (VectorQ, c.VectorQ, size * sizeof (complex));
+    }
+    // copy each G-MNA matrix entry
     if (c.MatrixY) {
       allocMatrixMNA ();
       memcpy (MatrixY, c.MatrixY, size * size * sizeof (complex));
-      memcpy (MatrixI, c.MatrixI, size * sizeof (complex));
-      memcpy (MatrixV, c.MatrixV, size * sizeof (complex));
+      memcpy (VectorI, c.VectorI, size * sizeof (complex));
+      memcpy (VectorV, c.VectorV, size * sizeof (complex));
       if (vsources > 0) {
 	memcpy (MatrixB, c.MatrixB, vsources * size * sizeof (complex));
 	memcpy (MatrixC, c.MatrixC, vsources * size * sizeof (complex));
 	memcpy (MatrixD, c.MatrixD, vsources * vsources * sizeof (complex));
-	memcpy (MatrixE, c.MatrixE, vsources * sizeof (complex));
-	memcpy (MatrixJ, c.MatrixJ, vsources * sizeof (complex));
+	memcpy (VectorE, c.VectorE, vsources * sizeof (complex));
+	memcpy (VectorJ, c.VectorJ, vsources * sizeof (complex));
       }
     }
   }
   else {
     nodes = NULL;
     MatrixS = MatrixN = MatrixY = NULL;
-    MatrixB = MatrixC = MatrixD = MatrixE = MatrixI = MatrixV = MatrixJ = NULL;
+    MatrixB = MatrixC = MatrixD = NULL;
+    VectorQ = VectorE = VectorI = VectorV = VectorJ = NULL;
+    MatrixQV = NULL;
+    VectorCV = VectorGV = NULL;
   }
 
   // copy operating points
-  copyOperatingPoints (c.oper);
+  oper = valuelist<operatingpoint> (c.oper);
 }
 
 // Destructor deletes a circuit object.
@@ -152,10 +180,11 @@ circuit::~circuit () {
     if (MatrixS) delete[] MatrixS;
     if (MatrixN) delete[] MatrixN;
     freeMatrixMNA ();
+    freeMatrixHB ();
     delete[] nodes;
   }
   if (subcircuit) free (subcircuit);
-  deleteOperatingPoints ();
+  deleteHistory ();
 }
 
 /* With this function the number of ports of the circuit object can be
@@ -184,6 +213,38 @@ void circuit::setSize (int s) {
   }
 }
 
+/* Destroys the HB-matrix memory. */
+void circuit::freeMatrixHB (void) {
+  if (VectorQ) { delete[] VectorQ; VectorQ = NULL; }
+  if (MatrixQV) { delete[] MatrixQV; MatrixQV = NULL; }
+  if (VectorCV) { delete[] VectorCV; VectorCV = NULL; }
+  if (VectorGV) { delete[] VectorGV; VectorGV = NULL; }
+}
+
+/* Allocates the HB-matrix memory. */
+void circuit::allocMatrixHB (void) {
+  if (VectorQ) {
+    memset (VectorQ, 0, size * sizeof (complex));
+  } else {
+    VectorQ = new complex[size];
+  }
+  if (MatrixQV) {
+    memset (MatrixQV, 0, size * size * sizeof (complex));
+  } else {
+    MatrixQV = new complex[size * size];
+  }
+  if (VectorCV) {
+    memset (VectorCV, 0, size * sizeof (complex));
+  } else {
+    VectorCV = new complex[size];
+  }
+  if (VectorGV) {
+    memset (VectorGV, 0, size * sizeof (complex));
+  } else {
+    VectorGV = new complex[size];
+  }
+}
+
 /* Allocates the S-parameter matrix memory. */
 void circuit::allocMatrixS (void) {
   if (MatrixS) {
@@ -205,14 +266,14 @@ void circuit::allocMatrixMNA (void) {
   freeMatrixMNA ();
   if (size > 0) {
     MatrixY = new complex[size * size];
-    MatrixI = new complex[size];
-    MatrixV = new complex[size];
+    VectorI = new complex[size];
+    VectorV = new complex[size];
     if (vsources > 0) {
       MatrixB = new complex[vsources * size];
       MatrixC = new complex[vsources * size];
       MatrixD = new complex[vsources * vsources];
-      MatrixE = new complex[vsources];
-      MatrixJ = new complex[vsources];
+      VectorE = new complex[vsources];
+      VectorJ = new complex[vsources];
     }
   }
 }
@@ -223,10 +284,10 @@ void circuit::freeMatrixMNA (void) {
   if (MatrixB) { delete[] MatrixB; MatrixB = NULL; }
   if (MatrixC) { delete[] MatrixC; MatrixC = NULL; }
   if (MatrixD) { delete[] MatrixD; MatrixD = NULL; }
-  if (MatrixE) { delete[] MatrixE; MatrixE = NULL; }
-  if (MatrixI) { delete[] MatrixI; MatrixI = NULL; }
-  if (MatrixV) { delete[] MatrixV; MatrixV = NULL; }
-  if (MatrixJ) { delete[] MatrixJ; MatrixJ = NULL; }
+  if (VectorE) { delete[] VectorE; VectorE = NULL; }
+  if (VectorI) { delete[] VectorI; VectorI = NULL; }
+  if (VectorV) { delete[] VectorV; VectorV = NULL; }
+  if (VectorJ) { delete[] VectorJ; VectorJ = NULL; }
 }
 
 /* This function sets the name and port number of one of the circuit's
@@ -314,53 +375,63 @@ void circuit::setD (int r, int c, complex z) {
 /* Returns the circuits E-MNA matrix value of the given voltage source
    built in the circuit. */
 complex circuit::getE (int nr) {
-  return MatrixE[nr - vsource];
+  return VectorE[nr - vsource];
 }
 
 /* Sets the circuits E-MNA matrix value of the given voltage source
    built in the circuit. */
 void circuit::setE (int nr, complex z) {
-  MatrixE[nr] = z;
+  VectorE[nr] = z;
 }
 
 /* Returns the circuits I-MNA matrix value of the current source built
    in the circuit. */
 complex circuit::getI (int port) {
-  return MatrixI[port];
+  return VectorI[port];
 }
 
 /* Sets the circuits I-MNA matrix value of the current source built in
    the circuit depending on the port number. */
 void circuit::setI (int port, complex z) {
-  MatrixI[port] = z;
+  VectorI[port] = z;
 }
 
 /* Modifies the circuits I-MNA matrix value of the current source
    built in the circuit depending on the port number. */
 void circuit::addI (int port, complex z) {
-  MatrixI[port] += z;
+  VectorI[port] += z;
+}
+
+/* Returns the circuits Q-HB vector value. */
+complex circuit::getQ (int port) {
+  return VectorQ[port];
+}
+
+/* Sets the circuits Q-HB vector value. */
+void circuit::setQ (int port, complex q) {
+  VectorQ[port] = q;
 }
 
 /* Returns the circuits J-MNA matrix value of the given voltage source
    built in the circuit. */
 complex circuit::getJ (int nr) {
-  return MatrixJ[nr];
+  return VectorJ[nr];
 }
 
 /* Sets the circuits J-MNA matrix value of the given voltage source
    built in the circuit. */
 void circuit::setJ (int nr, complex z) {
-  MatrixJ[nr - vsource] = z;
+  VectorJ[nr - vsource] = z;
 }
 
 // Returns the circuits voltage value at the given port.
 complex circuit::getV (int port) {
-  return MatrixV[port];
+  return VectorV[port];
 }
 
 // Sets the circuits voltage value at the given port.
 void circuit::setV (int port, complex z) {
-  MatrixV[port] = z;
+  VectorV[port] = z;
 }
 
 /* Returns the circuits G-MNA matrix value depending on the port
@@ -393,19 +464,54 @@ void circuit::setG (int r, int c, nr_double_t y) {
   MatrixY[r * size + c] = y;
 }
 
+/* Returns the circuits C-HB matrix value depending on the port
+   numbers. */
+complex circuit::getQV (int r, int c) {
+  return MatrixQV[r * size + c];
+}
+
+/* Sets the circuits C-HB matrix value depending on the port
+   numbers. */
+void circuit::setQV (int r, int c, complex qv) {
+  MatrixQV[r * size + c] = qv;
+}
+
+/* Returns the circuits GV-HB vector value depending on the port
+   number. */
+complex circuit::getGV (int port) {
+  return VectorGV[port];
+}
+
+/* Sets the circuits GV-HB matrix value depending on the port
+   number. */
+void circuit::setGV (int port, complex gv) {
+  VectorGV[port] = gv;
+}
+
+/* Returns the circuits CV-HB vector value depending on the port
+   number. */
+complex circuit::getCV (int port) {
+  return VectorCV[port];
+}
+
+/* Sets the circuits CV-HB matrix value depending on the port
+   number. */
+void circuit::setCV (int port, complex cv) {
+  VectorCV[port] = cv;
+}
+
 /* This function adds a operating point consisting of a key and a
    value to the circuit. */
 void circuit::addOperatingPoint (char * n, nr_double_t val) {
   operatingpoint * p = new operatingpoint (n, val);
-  p->setNext (oper);
-  oper = p;
+  oper.add (n, p);
 }
 
 /* Returns the requested operating point value which has been
    previously added as its double representation.  If there is no such
    operating point the function returns zero. */
 nr_double_t circuit::getOperatingPoint (char * n) {
-  operatingpoint * p = oper->findOperatingPoint (n);
+  operatingpoint * p = oper.get (n);
   if (p != NULL) return p->getValue ();
   return 0.0;
 }
@@ -413,7 +519,7 @@ nr_double_t circuit::getOperatingPoint (char * n) {
 /* This function sets the operating point specified by the given name
    to the value passed to the function. */
 void circuit::setOperatingPoint (char * n, nr_double_t val) {
-  operatingpoint * p = oper->findOperatingPoint (n);
+  operatingpoint * p = oper.get (n);
   if (p != NULL)
     p->setValue (val);
   else
@@ -424,30 +530,40 @@ void circuit::setOperatingPoint (char * n, nr_double_t val) {
    point value.  If so it returns non-zero, otherwise it returns
    zero. */
 int circuit::hasOperatingPoint (char * n) {
-  return (oper && oper->findOperatingPoint (n)) ? 1 : 0;
+  return (oper.get (n)) ? 1 : 0;
 }
 
-/* This function copies all properties in the given operating point
-   list into a circuit object. */
-void circuit::copyOperatingPoints (operatingpoint * org) {
-  operatingpoint * p;
-  oper = NULL;
-  while (org != NULL) {
-    p = new operatingpoint (*org);
-    p->setNext (oper);
-    oper = p;
-    org = org->getNext ();
-  }
+/* This function adds a characteristic point consisting of a key and a
+   value to the circuit. */
+void circuit::addCharacteristic (char * n, nr_double_t val) {
+  characteristic * p = new characteristic (n, val);
+  charac.add (n, p);
 }
 
-// Deletes all operating points of a circuit object.
-void circuit::deleteOperatingPoints (void) {
-  operatingpoint * n;
-  for (operatingpoint * p = oper; p != NULL; p = n) {
-    n = p->getNext ();
-    delete p;
-  }
-  oper = NULL;
+/* Returns the requested characteristic value which has been
+   previously added as its double representation.  If there is no such
+   characteristic value the function returns zero. */
+nr_double_t circuit::getCharacteristic (char * n) {
+  characteristic * p = charac.get (n);
+  if (p != NULL) return p->getValue ();
+  return 0.0;
+}
+
+/* This function sets the characteristic value specified by the given
+   name to the value passed to the function. */
+void circuit::setCharacteristic (char * n, nr_double_t val) {
+  characteristic * p = charac.get (n);
+  if (p != NULL)
+    p->setValue (val);
+  else
+    addCharacteristic (n, val);
+}
+
+/* The function checks whether the circuit has got a certain
+   characteristic value.  If so it returns non-zero, otherwise it
+   returns zero. */
+int circuit::hasCharacteristic (char * n) {
+  return (charac.get (n)) ? 1 : 0;
 }
 
 // Returns the S-parameter at the given matrix position.
@@ -575,22 +691,22 @@ void circuit::clearD (void) {
 
 // The function cleans up the E-MNA matrix entries.
 void circuit::clearE (void) {
-  memset (MatrixE, 0, sizeof (complex) * vsources);
+  memset (VectorE, 0, sizeof (complex) * vsources);
 }
 
 // The function cleans up the J-MNA matrix entries.
 void circuit::clearJ (void) {
-  memset (MatrixJ, 0, sizeof (complex) * vsources);
+  memset (VectorJ, 0, sizeof (complex) * vsources);
 }
 
 // The function cleans up the I-MNA matrix entries.
 void circuit::clearI (void) {
-  memset (MatrixI, 0, sizeof (complex) * size);
+  memset (VectorI, 0, sizeof (complex) * size);
 }
 
 // The function cleans up the V-MNA matrix entries.
 void circuit::clearV (void) {
-  memset (MatrixV, 0, sizeof (complex) * size);
+  memset (VectorV, 0, sizeof (complex) * size);
 }
 
 // The function cleans up the G-MNA matrix entries.
@@ -625,3 +741,47 @@ void circuit::transientCapacitance (int qstate, int pos, int neg,
   addI (pos , -i);
   addI (neg , +i);
 }
+
+// The function initializes the histories of a circuit having the given age.
+void circuit::initHistory (nr_double_t age) {
+  nHistories = getSize () + getVoltageSources ();
+  histories = new history[nHistories];
+  for (int i = 0; i < nHistories; i++) histories[i].setAge (age);
+}
+
+// The function deletes the histories for the transient analysis.
+void circuit::deleteHistory (void) {
+  if (histories != NULL) {
+    delete[] histories;
+    histories = NULL;
+  }
+  setHistory (false);
+}
+
+// Appends a history value.
+void circuit::appendHistory (int n, nr_double_t val) {
+  histories[n].append (val);
+}
+
+// Returns the required age of the history.
+nr_double_t circuit::getHistoryAge (void) {
+  if (histories) return histories[0].getAge ();
+  return 0.0;
+}
+
+/* This function should be used to apply the time vector history to
+   the value histories of a circuit. */
+void circuit::applyHistory (history * h) {
+  tvector<nr_double_t> * t = h->getTvector ();
+  for (int i = 0; i < nHistories; i++) histories[i].setTvector (t);
+}
+
+// Returns voltage at the given time for the given node.
+nr_double_t circuit::getV (int port, nr_double_t t) {
+  return histories[port].nearest (t);
+}
+
+// Returns current at the given time for the given voltage source.
+nr_double_t circuit::getJ (int nr, nr_double_t t) {
+  return histories[nr + getSize ()].nearest (t);
+}
