@@ -1,7 +1,7 @@
 /*
  * circuit.h - circuit class definitions
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: circuit.h,v 1.39 2005/06/02 18:17:49 raimi Exp $
+ * $Id: circuit.h,v 1.50 2006/05/03 09:43:56 raimi Exp $
  *
  */
 
@@ -32,6 +32,9 @@ enum circuit_flag {
   CIRCUIT_VSOURCE     = 8,
   CIRCUIT_ISOURCE     = 16,
   CIRCUIT_INTVSOURCE  = 32,
+  CIRCUIT_VARSIZE     = 64,
+  CIRCUIT_PROBE       = 128,
+  CIRCUIT_HISTORY     = 256,
 };
 
 #define NODE_1 0
@@ -51,11 +54,13 @@ class node;
 class property;
 class substrate;
 class operatingpoint;
+class characteristic;
 class matrix;
-class transient;
 class net;
+class history;
 
 #include "integrator.h"
+#include "valuelist.h"
 
 class circuit : public object, public integrator
 {
@@ -71,6 +76,7 @@ class circuit : public object, public integrator
   virtual void calcSP (nr_double_t) { }
   virtual void initDC (void) { allocMatrixMNA (); }
   virtual void calcDC (void) { }
+  virtual void restartDC (void) { }
   virtual void initNoiseSP (void) { allocMatrixN (); }
   virtual void calcNoiseSP (nr_double_t) { }
   virtual void initNoiseAC (void) { allocMatrixN (vsources); }
@@ -81,8 +87,12 @@ class circuit : public object, public integrator
   virtual void calcTR (nr_double_t) { }
   virtual void initHB (void) { allocMatrixMNA (); }
   virtual void calcHB (nr_double_t) { }
+  virtual void initHB (int) { allocMatrixMNA (); }
+  virtual void calcHB (int) { }
   virtual void calcOperatingPoints (void) { }
   virtual void saveOperatingPoints (void) { }
+  virtual void calcCharacteristics (nr_double_t) { }
+  virtual void saveCharacteristics (nr_double_t) { }
 
   // real basics
   void   setNode (int, char *, int intern = 0);
@@ -93,6 +103,10 @@ class circuit : public object, public integrator
   void   setSize (int);
   bool   isEnabled (void) { return RETFLAG (CIRCUIT_ENABLED); }
   void   setEnabled (bool e) { MODFLAG (e, CIRCUIT_ENABLED); }
+  bool   isVariableSized (void) { return RETFLAG (CIRCUIT_VARSIZE); }
+  void   setVariableSized (bool v) { MODFLAG (v, CIRCUIT_VARSIZE); }
+  bool   isProbe (void) { return RETFLAG (CIRCUIT_PROBE); }
+  void   setProbe (bool p) { MODFLAG (p, CIRCUIT_PROBE); }
   void   setNet (net * n) { subnet = n; }
   net *  getNet (void) { return subnet; }
 
@@ -108,8 +122,6 @@ class circuit : public object, public integrator
   int  getVoltageSources (void);
   void setVoltageSources (int);
   void voltageSource (int, int, int, nr_double_t value = 0.0);
-  void transientCapacitance (int, int, int, nr_double_t, nr_double_t,
-			     nr_double_t);
   bool isVSource (void) { return RETFLAG (CIRCUIT_VSOURCE); }
   void setVSource (bool v) { MODFLAG (v, CIRCUIT_VSOURCE); }
   bool isISource (void) { return RETFLAG (CIRCUIT_ISOURCE); }
@@ -117,6 +129,23 @@ class circuit : public object, public integrator
   int  getNoiseSources (void);
   void setNoiseSources (int);
 
+  // transient analyses helpers
+  void transientCapacitance (int, int, int, nr_double_t, nr_double_t,
+			     nr_double_t);
+  void setDelta (nr_double_t * d) { deltas = d; }
+  nr_double_t * getDelta (void) { return deltas; }
+
+  // history specific functionality
+  bool hasHistory (void) { return RETFLAG (CIRCUIT_HISTORY); }
+  void setHistory (bool h) { MODFLAG (h, CIRCUIT_HISTORY); }
+  void initHistory (nr_double_t);
+  void deleteHistory (void);
+  void appendHistory (int, nr_double_t);
+  void applyHistory (history *);
+  nr_double_t getV (int, nr_double_t);
+  nr_double_t getJ (int, nr_double_t);
+  nr_double_t getHistoryAge (void);
+
   // s-parameter helpers
   int  getPort (void) { return pacport; }
   void setPort (int p) { pacport = p; }
@@ -136,10 +165,14 @@ class circuit : public object, public integrator
   complex getB (int, int);
   complex getC (int, int);
   complex getD (int, int);
+  complex getQV (int, int);
+  complex getGV (int);
+  complex getCV (int);
   complex getE (int);
   complex getI (int);
   complex getJ (int);
   complex getV (int);
+  complex getQ (int);
   nr_double_t getG (int, int);
   void setS (int, int, complex);
   void setN (int, int, complex);
@@ -147,10 +180,14 @@ class circuit : public object, public integrator
   void setB (int, int, complex);
   void setC (int, int, complex);
   void setD (int, int, complex);
+  void setQV (int, int, complex);
+  void setGV (int, complex);
+  void setCV (int, complex);
   void setE (int, complex);
   void setI (int, complex);
   void setJ (int, complex);
   void setV (int, complex);
+  void setQ (int, complex);
   void setG (int, int, nr_double_t);
   void clearB (void);
   void clearC (void);
@@ -168,9 +205,14 @@ class circuit : public object, public integrator
   nr_double_t getOperatingPoint (char *);
   void        setOperatingPoint (char *, nr_double_t);
   int         hasOperatingPoint (char *);
-  void        copyOperatingPoints (operatingpoint *);
-  void        deleteOperatingPoints (void);
-  operatingpoint * getOperatingPoints (void) { return oper; }
+  valuelist<operatingpoint> & getOperatingPoints (void) { return oper; }
+
+  // characteristics functionality
+  void        addCharacteristic (char *, nr_double_t);
+  nr_double_t getCharacteristic (char *);
+  void        setCharacteristic (char *, nr_double_t);
+  int         hasCharacteristic (char *);
+  valuelist<characteristic> & getCharacteristics (void) { return charac; }
 
   // differentiate between linear and non-linear circuits
   void setNonLinear (bool l) { MODFLAG (!l, CIRCUIT_LINEAR); }
@@ -185,6 +227,8 @@ class circuit : public object, public integrator
   void   allocMatrixN (int sources = 0);
   void   allocMatrixMNA (void);
   void   freeMatrixMNA (void);
+  void   allocMatrixHB (void);
+  void   freeMatrixHB (void);
   void   setMatrixS (matrix);
   matrix getMatrixS (void);
   void   setMatrixN (matrix);
@@ -212,15 +256,23 @@ class circuit : public object, public integrator
   complex * MatrixB;
   complex * MatrixC;
   complex * MatrixD;
-  complex * MatrixE;
-  complex * MatrixI;
-  complex * MatrixV;
-  complex * MatrixJ;
+  complex * VectorE;
+  complex * VectorI;
+  complex * VectorV;
+  complex * VectorJ;
+  complex * VectorQ;
+  complex * MatrixQV;
+  complex * VectorGV;
+  complex * VectorCV;
   char * subcircuit;
   node * nodes;
   substrate * subst;
-  operatingpoint * oper;
+  valuelist<operatingpoint> oper;
+  valuelist<characteristic> charac;
   net * subnet;
+  nr_double_t * deltas;
+  int nHistories;
+  history * histories;
 };
 
 #endif /* __CIRCUIT_H__ */
