@@ -1,7 +1,8 @@
 /*
  * complex.cpp - complex number class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: complex.cpp,v 1.22 2005/07/04 08:33:58 raimi Exp $
+ * $Id: complex.cpp,v 1.31 2006/05/16 11:40:25 raimi Exp $
  *
  */
 
@@ -30,6 +31,9 @@
 
 #include "complex.h"
 #include "consts.h"
+#include "fspecial.h"
+
+using namespace fspecial;
 
 complex::complex (nr_double_t real, nr_double_t imag) {
   r = real;
@@ -46,19 +50,27 @@ complex::complex (const complex& z) {
   i = z.i;
 }
 
+nr_double_t complex::abs (void) {
+  return xhypot (r, i);
+}
+
 nr_double_t abs (const complex z) {
   return xhypot (z.r, z.i);
 }
 
-nr_double_t abs (nr_double_t r) {
+nr_double_t abs (const nr_double_t r) {
   return fabs (r);
 }
 
+nr_double_t complex::norm (void) {
+  return r * r + i * i;
+}
+
 nr_double_t norm (const complex z) {
   return z.r * z.r + z.i * z.i;
 }
 
-nr_double_t norm (nr_double_t r) {
+nr_double_t norm (const nr_double_t r) {
   return r * r;
 }
 
@@ -66,27 +78,39 @@ nr_double_t arg (const complex z) {
   return atan2 (z.i, z.r);
 }
 
+nr_double_t complex::real (void) {
+  return r;
+}
+
 nr_double_t real (const complex z) {
   return z.r;
 }
 
-nr_double_t real (nr_double_t r) {
+nr_double_t real (const nr_double_t r) {
   return r;
 }
 
+nr_double_t complex::imag (void) {
+  return i;
+}
+
 nr_double_t imag (const complex z) {
   return z.i;
 }
 
-nr_double_t imag (nr_double_t) {
+nr_double_t imag (const nr_double_t) {
   return 0.0;
 }
 
+complex complex::conj (void) {
+  return complex (r, -i);
+}
+
 complex conj (const complex z) {
   return complex (z.r, -z.i);
 }
 
-nr_double_t conj (nr_double_t r) {
+nr_double_t conj (const nr_double_t r) {
   return r;
 }
 
@@ -123,11 +147,11 @@ complex log2 (const complex z) {
   return complex (log (abs (z)) * M_LOG2E, phi * M_LOG2E);
 }
 
-complex pow (const complex z, nr_double_t d) {
+complex pow (const complex z, const nr_double_t d) {
   return polar (pow (abs (z), d), arg (z) * d);
 }
 
-complex pow (nr_double_t d, const complex z) {
+complex pow (const nr_double_t d, const complex z) {
   return exp (z * log (d));
 }
 
@@ -138,8 +162,7 @@ complex pow (const complex z1, const complex z2) {
 complex sin (const complex z) {
   nr_double_t r = real (z);
   nr_double_t i = imag (z);
-  return (polar (exp (-i), r - M_PI_2) -
-          polar (exp (i), -r - M_PI_2)) / 2.0;
+  return (polar (exp (-i), r - M_PI_2) - polar (exp (i), -r - M_PI_2)) / 2.0;
 }
 
 complex arcsin (const complex z) {
@@ -155,7 +178,13 @@ complex cos (const complex z) {
 }
 
 complex arccos (const complex z) {
-  return complex (0.0, 1.0) * ln (z + sqrt (z * z - 1.0));
+#if 0
+  return rect (0.0, -2.0) * ln (M_SQRT1_2 * (sqrt (z + 1.0) + sqrt (z - 1.0)));
+#else
+  complex y = sqrt (z * z - 1.0);
+  if (z.r * z.i < 0.0) y = -y;
+  return rect (0, -1.0) * ln (z + y);
+#endif
 }
 
 complex tan (const complex z) {
@@ -168,6 +197,11 @@ complex arctan (const complex z) {
   return rect (0.0, -0.5) * ln (rect (0.0, 2.0) / (z + rect (0.0, 1.0)) - 1.0);
 }
 
+complex arctan2 (const complex y, const complex x) {
+  complex a = arctan (y / x);
+  return real (x) > 0.0 ? a : -a;
+}
+
 complex cot (const complex z) {
   nr_double_t r = 2.0 * real (z);
   nr_double_t i = 2.0 * imag (z);
@@ -219,15 +253,25 @@ complex arcoth (const complex z) {
 }
 
 // converts impedance to reflexion coefficient
-complex ztor (const complex z, nr_double_t zref) {
+complex ztor (const complex z, complex zref) {
   return (z - zref) / (z + zref);
 }
 
+// converts admittance to reflexion coefficient
+complex ytor (const complex y, complex zref) {
+  return (1 - y * zref) / (1 + y * zref);
+}
+
 // converts reflexion coefficient to impedance
-complex rtoz (const complex r, nr_double_t zref) {
+complex rtoz (const complex r, complex zref) {
   return zref * (1 + r) / (1 - r);
 }
 
+// converts reflexion coefficient to admittance
+complex rtoy (const complex r, complex zref) {
+  return (1 - r) / (1 + r) / zref;
+}
+
 complex floor (const complex z) {
   return rect (floor (real (z)), floor (imag (z)));
 }
@@ -286,6 +330,91 @@ complex rect (const nr_double_t x, const nr_double_t y) {
   return complex (x, y);
 }
 
+complex polar (const complex a, const complex p) {
+  return a * exp (rect (p.i, -p.r));
+}
+
+complex ceil (const complex z) {
+  return rect (ceil (z.r), ceil (z.i));
+}
+
+nr_double_t fix (const nr_double_t d) {
+  return (d > 0) ? floor (d) : ceil (d);
+}
+
+complex fix (const complex z) {
+  nr_double_t x = z.r;
+  nr_double_t y = z.i;
+  x = (x > 0) ? floor (x) : ceil (x);
+  y = (y > 0) ? floor (y) : ceil (y);
+  return rect (x, y);
+}
+
+complex round (const complex z) {
+  return rect (round (z.r), round (z.i));
+}
+
+complex sqr (const complex z) {
+  return rect (z.r * z.r - z.i * z.i, 2 * z.r * z.i);
+}
+
+nr_double_t step (const nr_double_t d) {
+  nr_double_t x = d;
+  if (x < 0.0)
+    x = 0.0;
+  else if (x > 0.0)
+    x = 1.0;
+  else
+    x = 0.5;
+  return x;
+}
+
+complex step (const complex z) {
+  nr_double_t x = z.r;
+  nr_double_t y = z.i;
+  if (x < 0.0)
+    x = 0.0;
+  else if (x > 0.0)
+    x = 1.0;
+  else
+    x = 0.5;
+  if (y < 0.0)
+    y = 0.0;
+  else if (y > 0.0)
+    y = 1.0;
+  else
+    y = 0.5;
+  return rect (x, y);
+}
+
+complex jn (const int n, const complex z) {
+  return rect (jn (n, z.r), 0);
+}
+
+complex yn (const int n, const complex z) {
+  return rect (yn (n, z.r), 0);
+}
+
+complex i0 (const complex z) {
+  return rect (i0 (z.r), 0);
+}
+
+complex erf (const complex z) {
+  return rect (erf (z.r), 0);
+}
+
+complex erfc (const complex z) {
+  return rect (erfc (z.r), 0);
+}
+
+complex erfinv (const complex z) {
+  return rect (erfinv (z.r), 0);
+}
+
+complex erfcinv (const complex z) {
+  return rect (erfcinv (z.r), 0);
+}
+
 complex complex::operator+() {
   return complex (r, i);
 }
