@@ -1,7 +1,7 @@
 /*
  * biastee.h - bias T class definitions
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,10 +15,10 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
+ * Boston, MA 02110-1301, USA.  
  *
- * $Id: biastee.h,v 1.8 2004/11/24 19:15:47 raimi Exp $
+ * $Id: biastee.h,v 1.10 2005/06/02 18:17:51 raimi Exp $
  *
  */
 
@@ -33,6 +33,7 @@ class biastee : public circuit
   void initDC (void);
   void initAC (void);
   void initTR (void);
+  void calcTR (nr_double_t);
 };
 
 #endif /* __BIASTEE_H__ */
