@@ -1,7 +1,7 @@
 /*
  * capacitor.h - capacitor class definitions
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: capacitor.h,v 1.8 2005/06/02 18:17:51 raimi Exp $
+ * $Id: capacitor.h,v 1.9 2006/03/27 09:55:50 raimi Exp $
  *
  */
 
@@ -35,6 +35,8 @@ class capacitor : public circuit
   void initAC (void);
   void calcTR (nr_double_t);
   void initTR (void);
+  void initHB (void);
+  void calcHB (nr_double_t);
 };
 
 #endif /* __CAPACITOR_H__ */
