@@ -1,7 +1,7 @@
 /*
  * cccs.cpp - cccs class implementation
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: cccs.cpp,v 1.12 2005/06/02 18:17:51 raimi Exp $
+ * $Id: cccs.cpp,v 1.15 2006/02/25 14:42:50 raimi Exp $
  *
  */
 
@@ -63,8 +63,9 @@ void cccs::calcSP (nr_double_t frequency) {
 }
 
 void cccs::initDC (void) {
-  nr_double_t g = getPropertyDouble ("G");
+  setISource (false);
   allocMatrixMNA ();
+  nr_double_t g = getPropertyDouble ("G");
   setC (VSRC_1, NODE_1, +1.0); setC (VSRC_1, NODE_2, +0.0);
   setC (VSRC_1, NODE_3, +0.0); setC (VSRC_1, NODE_4, -1.0);
   setB (NODE_1, VSRC_1, +1/g); setB (NODE_2, VSRC_1, +1.0);
@@ -83,3 +84,27 @@ void cccs::calcAC (nr_double_t frequency) {
   complex r = polar (1.0 / g, - 2.0 * M_PI * frequency * t);
   setB (NODE_1, VSRC_1, +r); setB (NODE_4, VSRC_1, -r);
 }
+
+void cccs::initTR (void) {
+  nr_double_t t = getPropertyDouble ("T");
+  initDC ();
+  deleteHistory ();
+  if (t > 0.0) {
+    setISource (true);
+    setHistory (true);
+    initHistory (t);
+    setB (NODE_1, VSRC_1, +1.0); setB (NODE_2, VSRC_1, +0.0);
+    setB (NODE_3, VSRC_1, -0.0); setB (NODE_4, VSRC_1, -1.0);
+  }
+}
+
+void cccs::calcTR (nr_double_t t) {
+  nr_double_t T = getPropertyDouble ("T");
+  if (T > 0.0) {
+    T = t - T;
+    nr_double_t g = getPropertyDouble ("G");
+    nr_double_t i = getJ (VSRC_1, T);
+    setI (NODE_2, -g * i);
+    setI (NODE_3, +g * i);
+  }
+}
