@@ -1,7 +1,7 @@
 /*
  * ccvs.cpp - ccvs class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: ccvs.cpp,v 1.11 2005/06/02 18:17:51 raimi Exp $
+ * $Id: ccvs.cpp,v 1.14 2006/02/25 14:42:50 raimi Exp $
  *
  */
 
@@ -88,3 +88,28 @@ void ccvs::calcAC (nr_double_t frequency) {
   complex g = polar (getPropertyDouble ("G"), - 2.0 * M_PI * frequency * t);
   setD (VSRC_1, VSRC_1, -g);
 }
+
+void ccvs::initTR (void) {
+  nr_double_t t = getPropertyDouble ("T");
+  initDC ();
+  deleteHistory ();
+  if (t > 0.0) {
+    setHistory (true);
+    initHistory (t);
+    setC (VSRC_2, NODE_1, +0.0); setC (VSRC_2, NODE_2, +1.0);
+    setC (VSRC_2, NODE_3, -1.0); setC (VSRC_2, NODE_4, +0.0);
+    setC (VSRC_1, NODE_1, +1.0); setC (VSRC_1, NODE_2, +0.0);
+    setC (VSRC_1, NODE_3, +0.0); setC (VSRC_1, NODE_4, -1.0);
+    setD (VSRC_1, VSRC_1, 0.0);
+  }
+}
+
+void ccvs::calcTR (nr_double_t t) {
+  nr_double_t T = getPropertyDouble ("T");
+  if (T > 0.0) {
+    T = t - T;
+    nr_double_t g = getPropertyDouble ("G");
+    nr_double_t i = getJ (VSRC_1, T);
+    setE (VSRC_2, g * i);
+  }
+}
