@@ -1,7 +1,7 @@
 /*
  * component.h - global component header file
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: component.h,v 1.28 2005/06/02 18:17:51 raimi Exp $
+ * $Id: component.h,v 1.37 2006/04/05 08:27:06 raimi Exp $
  *
  */
 
@@ -32,6 +32,7 @@
 #include "component_id.h"
 #include "ground.h"
 #include "open.h"
+#include "short.h"
 #include "tee.h"
 #include "cross.h"
 #include "itrafo.h"
@@ -39,6 +40,8 @@
 #include "resistor.h"
 #include "capacitor.h"
 #include "inductor.h"
+#include "mutual.h"
+#include "mutual2.h"
 #include "vccs.h"
 #include "cccs.h"
 #include "ccvs.h"
@@ -56,19 +59,30 @@
 #include "idc.h"
 #include "vac.h"
 #include "iac.h"
+#include "vam.h"
+#include "vpm.h"
 #include "phaseshifter.h"
 #include "gyrator.h"
+#include "tswitch.h"
+#include "relais.h"
 #include "tline.h"
+#include "coaxline.h"
 #include "iprobe.h"
+#include "vprobe.h"
 #include "spfile.h"
-#include "vnoise.h"
-#include "inoise.h"
 #include "vpulse.h"
 #include "ipulse.h"
 #include "vrect.h"
 #include "irect.h"
 #include "amplifier.h"
 #include "opamp.h"
+#include "coupler.h"
+
+#include "vnoise.h"
+#include "inoise.h"
+#include "iinoise.h"
+#include "ivnoise.h"
+#include "vvnoise.h"
 
 #include "devices/diode.h"
 #include "devices/jfet.h"
@@ -94,4 +108,14 @@
 #include "microstrip/cpwgap.h"
 #include "microstrip/cpwstep.h"
 
+#include "digital/digital.h"
+#include "digital/inverter.h"
+#include "digital/nor.h"
+#include "digital/or.h"
+#include "digital/nand.h"
+#include "digital/and.h"
+#include "digital/xnor.h"
+#include "digital/xor.h"
+#include "digital/digisource.h"
+
 #endif /* __COMPONENT_H__ */
