@@ -1,7 +1,7 @@
 /*
  * component_id.h - global component identifier header file
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: component_id.h,v 1.26 2005/06/02 18:17:51 raimi Exp $
+ * $Id: component_id.h,v 1.34 2006/04/05 08:27:06 raimi Exp $
  *
  */
 
@@ -29,15 +29,20 @@
 enum circuit_type {
   CIR_UNKNOWN = -1,
 
-  // linear components
+  // linear helper components
   CIR_GROUND,
   CIR_OPEN,
+  CIR_SHORT,
   CIR_TEE,
   CIR_CROSS,
   CIR_ITRAFO,
+
+  // linear components
   CIR_RESISTOR,
   CIR_CAPACITOR,
   CIR_INDUCTOR,
+  CIR_MUTUAL,
+  CIR_MUTUAL2,
   CIR_VCCS,
   CIR_CCCS,
   CIR_CCVS,
@@ -55,19 +60,30 @@ enum circuit_type {
   CIR_IDC,
   CIR_VAC,
   CIR_IAC,
+  CIR_VAM,
+  CIR_VPM,
   CIR_PHASESHIFTER,
   CIR_GYRATOR,
+  CIR_TSWITCH,
+  CIR_RELAIS,
   CIR_TLINE,
+  CIR_COAXLINE,
   CIR_IPROBE,
+  CIR_VPROBE,
   CIR_SPFILE,
-  CIR_VNOISE,
-  CIR_INOISE,
   CIR_VPULSE,
   CIR_IPULSE,
   CIR_VRECT,
   CIR_IRECT,
   CIR_AMPLIFIER,
-  CIR_OPAMP,
+  CIR_COUPLER,
+
+  // noise sources
+  CIR_VNOISE,
+  CIR_INOISE,
+  CIR_IINOISE,
+  CIR_IVNOISE,
+  CIR_VVNOISE,
 
   // microstrip components
   CIR_MSLINE,
@@ -89,10 +105,21 @@ enum circuit_type {
   CIR_CPWSTEP,
 
   // non-linear components
+  CIR_OPAMP,
   CIR_DIODE,
   CIR_JFET,
   CIR_BJT,
   CIR_MOSFET,
+
+  // digital components
+  CIR_INVERTER,
+  CIR_NOR,
+  CIR_OR,
+  CIR_NAND,
+  CIR_AND,
+  CIR_XNOR,
+  CIR_XOR,
+  CIR_DIGISOURCE,
 };
 
 #endif /* __COMPONENT_ID_H__ */
