@@ -1,7 +1,7 @@
 /*
  * bjt.cpp - bipolar junction transistor class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: bjt.cpp,v 1.31 2005/06/02 18:17:55 raimi Exp $
+ * $Id: bjt.cpp,v 1.43 2006/05/12 14:32:10 raimi Exp $
  *
  */
 
@@ -31,6 +31,7 @@
 #include <math.h>
 #include <string.h>
 
+#include "logging.h"
 #include "complex.h"
 #include "matrix.h"
 #include "object.h"
@@ -49,6 +50,8 @@
 #define NODE_E 2 /* emitter node    */
 #define NODE_S 3 /* substrate node  */
 
+using namespace device;
+
 bjt::bjt () : circuit (4) {
   cbcx = rb = re = rc = NULL;
   type = CIR_BJT;
@@ -133,8 +136,8 @@ void bjt::calcNoiseSP (nr_double_t frequency) {
 matrix bjt::calcMatrixCy (nr_double_t frequency) {
 
   // fetch computed operating points
-  nr_double_t Ibe = getOperatingPoint ("Ibe");
-  nr_double_t Ice = getOperatingPoint ("Ice");
+  nr_double_t Ibe = fabs (getOperatingPoint ("Ibe"));
+  nr_double_t Ice = fabs (getOperatingPoint ("Ice"));
 
   // get model properties
   nr_double_t Kf  = getPropertyDouble ("Kf");
@@ -163,11 +166,110 @@ matrix bjt::calcMatrixCy (nr_double_t frequency) {
   return cy;
 }
 
+void bjt::initModel (void) {
+  // fetch necessary device properties
+  nr_double_t T  = getPropertyDouble ("Temp");
+  nr_double_t Tn = getPropertyDouble ("Tnom");
+  nr_double_t A  = getPropertyDouble ("Area");
+
+  // compute Is temperature and area dependency
+  nr_double_t Is  = getPropertyDouble ("Is");
+  nr_double_t Xti = getPropertyDouble ("Xti");
+  nr_double_t Eg  = getPropertyDouble ("Eg");
+  nr_double_t T1, T2, IsT;
+  T2 = kelvin (T);
+  T1 = kelvin (Tn);
+  IsT = pnCurrent_T (T1, T2, Is, Eg, 1, Xti);
+  setScaledProperty ("Is", IsT * A);
+
+  // compute Vje, Vjc and Vjs temperature dependencies
+  nr_double_t Vje = getPropertyDouble ("Vje");
+  nr_double_t Vjc = getPropertyDouble ("Vjc");
+  nr_double_t Vjs = getPropertyDouble ("Vjs");
+  nr_double_t VjeT, VjcT, VjsT;
+  VjeT = pnPotential_T (T1,T2, Vje);
+  VjcT = pnPotential_T (T1,T2, Vjc);
+  VjsT = pnPotential_T (T1,T2, Vjs);
+  setScaledProperty ("Vje", VjeT);
+  setScaledProperty ("Vjc", VjcT);
+  setScaledProperty ("Vjs", VjsT);
+
+  // compute Bf and Br temperature dependencies
+  nr_double_t Bf  = getPropertyDouble ("Bf");
+  nr_double_t Br  = getPropertyDouble ("Br");
+  nr_double_t Xtb = getPropertyDouble ("Xtb");
+  nr_double_t F = exp (Xtb * log (T2 / T1));
+  setScaledProperty ("Bf", Bf * F);
+  setScaledProperty ("Br", Br * F);
+
+  // compute Ise and Isc temperature and area dependencies
+  nr_double_t Ise = getPropertyDouble ("Ise");
+  nr_double_t Isc = getPropertyDouble ("Isc");
+  nr_double_t Ne  = getPropertyDouble ("Ne");
+  nr_double_t Nc  = getPropertyDouble ("Nc");
+  nr_double_t G = log (IsT / Is);
+  nr_double_t F1 = exp (G / Ne);
+  nr_double_t F2 = exp (G / Nc);
+  Ise = Ise / F * F1;
+  Isc = Isc / F * F2;
+  setScaledProperty ("Ise", Ise * A);
+  setScaledProperty ("Isc", Isc * A);
+
+  // check unphysical parameters
+  nr_double_t Nf = getPropertyDouble ("Nf");
+  nr_double_t Nr = getPropertyDouble ("Nr");
+  if (Nf < 1.0) {
+    logprint (LOG_ERROR, "WARNING: Unphysical model parameter Nf = %g in "
+	      "BJT `%s'\n", Nf, getName ());
+  }
+  if (Nr < 1.0) {
+    logprint (LOG_ERROR, "WARNING: Unphysical model parameter Nr = %g in "
+	      "BJT `%s'\n", Nr, getName ());
+  }
+
+  // compute Cje, Cjc and Cjs temperature and area dependencies
+  nr_double_t Cje = getPropertyDouble ("Cje");
+  nr_double_t Cjc = getPropertyDouble ("Cjc");
+  nr_double_t Cjs = getPropertyDouble ("Cjs");
+  nr_double_t Mje = getPropertyDouble ("Mje");
+  nr_double_t Mjc = getPropertyDouble ("Mjc");
+  nr_double_t Mjs = getPropertyDouble ("Mjs");
+  Cje = pnCapacitance_T (T1, T2, Mje, VjeT / Vje, Cje);
+  Cjc = pnCapacitance_T (T1, T2, Mjc, VjcT / Vjc, Cjc);
+  Cjs = pnCapacitance_T (T1, T2, Mjs, VjsT / Vjs, Cjs);
+  setScaledProperty ("Cje", Cje * A);
+  setScaledProperty ("Cjc", Cjc * A);
+  setScaledProperty ("Cjs", Cjs * A);
+
+  // compute Rb, Rc, Re and Rbm area dependencies
+  nr_double_t Rb  = getPropertyDouble ("Rb");
+  nr_double_t Re  = getPropertyDouble ("Re");
+  nr_double_t Rc  = getPropertyDouble ("Rc");
+  nr_double_t Rbm = getPropertyDouble ("Rbm");
+  setScaledProperty ("Rb", Rb / A);
+  setScaledProperty ("Re", Re / A);
+  setScaledProperty ("Rc", Rc / A);
+  setScaledProperty ("Rbm", Rbm / A);
+
+  // compute Ikf, Ikr, Irb and Itf area dependencies
+  nr_double_t Ikf = getPropertyDouble ("Ikf");
+  nr_double_t Ikr = getPropertyDouble ("Ikr");
+  nr_double_t Irb = getPropertyDouble ("Irb");
+  nr_double_t Itf = getPropertyDouble ("Itf");
+  setScaledProperty ("Ikf", Ikf * A);
+  setScaledProperty ("Ikr", Ikr * A);
+  setScaledProperty ("Irb", Irb * A);
+  setScaledProperty ("Itf", Itf * A);
+}
+
 void bjt::initDC (void) {
 
   // allocate MNA matrices
   allocMatrixMNA ();
 
+  // initialize scalability
+  initModel ();
+
   // apply polarity of BJT
   char * type = getPropertyString ("Type");
   pol = !strcmp (type, "pnp") ? -1 : 1;
@@ -176,87 +278,95 @@ void bjt::initDC (void) {
   nr_double_t T = getPropertyDouble ("Temp");
 
   // initialize starting values
-  UbePrev = real (getV (NODE_B) - getV (NODE_E)) * pol;
-  UbcPrev = real (getV (NODE_B) - getV (NODE_C)) * pol;
+  restartDC ();
 
   // disable additional base-collector capacitance
   if (deviceEnabled (cbcx)) {
-    disableCapacitance (this, cbcx, getNet ());
+    disableCapacitor (this, cbcx);
   }
 
   // possibly insert series resistance at emitter
-  nr_double_t Re = getPropertyDouble ("Re");
+  nr_double_t Re = getScaledProperty ("Re");
   if (Re != 0.0) {
     // create additional circuit if necessary and reassign nodes
-    re = splitResistance (this, re, getNet (), "Re", "emitter", NODE_E);
+    re = splitResistor (this, re, "Re", "emitter", NODE_E);
     re->setProperty ("R", Re);
     re->setProperty ("Temp", T);
+    re->setProperty ("Controlled", getName ());
     re->initDC ();
   }
   // no series resistance at emitter
   else {
-    disableResistance (this, re, getNet (), NODE_E);
+    disableResistor (this, re, NODE_E);
   }
 
   // possibly insert series resistance at collector
-  nr_double_t Rc = getPropertyDouble ("Rc");
+  nr_double_t Rc = getScaledProperty ("Rc");
   if (Rc != 0.0) {
     // create additional circuit if necessary and reassign nodes
-    rc = splitResistance (this, rc, getNet (), "Rc", "collector", NODE_C);
+    rc = splitResistor (this, rc, "Rc", "collector", NODE_C);
     rc->setProperty ("R", Rc);
     rc->setProperty ("Temp", T);
+    rc->setProperty ("Controlled", getName ());
     rc->initDC ();
   }
   // no series resistance at collector
   else {
-    disableResistance (this, rc, getNet (), NODE_C);
+    disableResistor (this, rc, NODE_C);
   }
 
   // possibly insert base series resistance
-  nr_double_t Rb  = getPropertyDouble ("Rb");
-  nr_double_t Rbm = getPropertyDouble ("Rbm");
+  nr_double_t Rb  = getScaledProperty ("Rb");
+  nr_double_t Rbm = getScaledProperty ("Rbm");
   if (Rbm <= 0.0) Rbm = Rb; // Rbm defaults to Rb if zero
   if (Rb < Rbm)   Rbm = Rb; // Rbm must be less or equal Rb
-  setProperty ("Rbm", Rbm);
+  setScaledProperty ("Rbm", Rbm);
   if (Rbm != 0.0) {
     // create additional circuit and reassign nodes
-    rb = splitResistance (this, rb, getNet (), "Rbb", "base", NODE_B);
+    rb = splitResistor (this, rb, "Rbb", "base", NODE_B);
     rb->setProperty ("R", Rb);
     rb->setProperty ("Temp", T);
+    rb->setProperty ("Controlled", getName ());
     rb->initDC ();
   }
   // no series resistance at base
   else {
-    disableResistance (this, rb, getNet (), NODE_B);
+    disableResistor (this, rb, NODE_B);
     Rbb = 0.0;                 // set this operating point
     setProperty ("Xcjc", 1.0); // other than 1 is senseless here
   }
 }
 
+void bjt::restartDC (void) {
+  // apply starting values to previous iteration values
+  UbePrev = real (getV (NODE_B) - getV (NODE_E)) * pol;
+  UbcPrev = real (getV (NODE_B) - getV (NODE_C)) * pol;
+}
+
 void bjt::calcDC (void) {
 
   // fetch device model parameters
-  nr_double_t Is   = getPropertyDouble ("Is");
+  nr_double_t Is   = getScaledProperty ("Is");
   nr_double_t Nf   = getPropertyDouble ("Nf");
   nr_double_t Nr   = getPropertyDouble ("Nr");
   nr_double_t Vaf  = getPropertyDouble ("Vaf");
   nr_double_t Var  = getPropertyDouble ("Var");
-  nr_double_t Ikf  = getPropertyDouble ("Ikf");
-  nr_double_t Ikr  = getPropertyDouble ("Ikr");
-  nr_double_t Bf   = getPropertyDouble ("Bf");
-  nr_double_t Br   = getPropertyDouble ("Br");
-  nr_double_t Ise  = getPropertyDouble ("Ise");
-  nr_double_t Isc  = getPropertyDouble ("Isc");
+  nr_double_t Ikf  = getScaledProperty ("Ikf");
+  nr_double_t Ikr  = getScaledProperty ("Ikr");
+  nr_double_t Bf   = getScaledProperty ("Bf");
+  nr_double_t Br   = getScaledProperty ("Br");
+  nr_double_t Ise  = getScaledProperty ("Ise");
+  nr_double_t Isc  = getScaledProperty ("Isc");
   nr_double_t Ne   = getPropertyDouble ("Ne");
   nr_double_t Nc   = getPropertyDouble ("Nc");
-  nr_double_t Rb   = getPropertyDouble ("Rb");
-  nr_double_t Rbm  = getPropertyDouble ("Rbm");
-  nr_double_t Irb  = getPropertyDouble ("Irb");
+  nr_double_t Rb   = getScaledProperty ("Rb");
+  nr_double_t Rbm  = getScaledProperty ("Rbm");
+  nr_double_t Irb  = getScaledProperty ("Irb");
   nr_double_t T    = getPropertyDouble ("Temp");
 
-  nr_double_t Ut, Ube, Ubc, Q1, Q2;
+  nr_double_t Ut, Q1, Q2;
   nr_double_t Iben, Ibcn, Ibei, Ibci, Ibc, gbe, gbc, gtiny;
-  nr_double_t Uce, IeqB, IeqC, IeqE, IeqS, UbeCrit, UbcCrit;
+  nr_double_t IeqB, IeqC, IeqE, IeqS, UbeCrit, UbcCrit;
   nr_double_t gm, go;
 
   // interpret zero as infinity for these model parameters
@@ -349,7 +459,7 @@ void bjt::calcDC (void) {
     if (Irb != 0.0) {
       nr_double_t a, b, z;
       a = (Ibci + Ibcn + Ibei + Iben) / Irb;
-      a = MAX (a, 1e-12); // enforce positive values
+      a = MAX (a, NR_TINY); // enforce positive values
       z = (sqrt (1 + 144 / sqr (M_PI) * a) - 1) / 24 * sqr (M_PI) / sqrt (a);
       b = tan (z);
       Rbb = Rbm + 3 * (Rb - Rbm) * (b - z) / z / sqr (b);
@@ -357,7 +467,7 @@ void bjt::calcDC (void) {
     else {
       Rbb = Rbm + (Rb - Rbm) / Qb;
     }
-    rb->setProperty ("R", Rbb);
+    rb->setScaledProperty ("R", Rbb);
     rb->calcDC ();
   }
 
@@ -414,53 +524,60 @@ void bjt::calcDC (void) {
 }
 
 void bjt::saveOperatingPoints (void) {
-  nr_double_t Ube, Ubc, Ucs;
-  Ube = real (getV (NODE_B) - getV (NODE_E)) * pol;
-  Ubc = real (getV (NODE_B) - getV (NODE_C)) * pol;
+  nr_double_t Vbe, Vbc;
+  Vbe = real (getV (NODE_B) - getV (NODE_E)) * pol;
+  Vbc = real (getV (NODE_B) - getV (NODE_C)) * pol;
   Ucs = real (getV (NODE_S) - getV (NODE_C)) * pol;
-  setOperatingPoint ("Vbe", Ube);
-  setOperatingPoint ("Vbc", Ubc);
-  setOperatingPoint ("Vce", Ube - Ubc);
+  setOperatingPoint ("Vbe", Vbe);
+  setOperatingPoint ("Vbc", Vbc);
+  setOperatingPoint ("Vce", Vbe - Vbc);
   setOperatingPoint ("Vcs", Ucs);
+  if (deviceEnabled (cbcx)) {
+    Ubx = real (cbcx->getV (NODE_1) - cbcx->getV (NODE_2)) * pol;
+    setOperatingPoint ("Vbx", Ubx);
+  }
+}
+
+void bjt::loadOperatingPoints (void) {
+  Ube = getOperatingPoint ("Vbe");
+  Ubc = getOperatingPoint ("Vbc");
+  Uce = getOperatingPoint ("Vce");
+  Ucs = getOperatingPoint ("Vcs");
 }
 
 void bjt::calcOperatingPoints (void) {
 
   // fetch device model parameters
-  nr_double_t Cje0 = getPropertyDouble ("Cje");
-  nr_double_t Vje  = getPropertyDouble ("Vje");
+  nr_double_t Cje0 = getScaledProperty ("Cje");
+  nr_double_t Vje  = getScaledProperty ("Vje");
   nr_double_t Mje  = getPropertyDouble ("Mje");
-  nr_double_t Cjc0 = getPropertyDouble ("Cjc");
-  nr_double_t Vjc  = getPropertyDouble ("Vjc");
+  nr_double_t Cjc0 = getScaledProperty ("Cjc");
+  nr_double_t Vjc  = getScaledProperty ("Vjc");
   nr_double_t Mjc  = getPropertyDouble ("Mjc");
   nr_double_t Xcjc = getPropertyDouble ("Xcjc");
-  nr_double_t Cjs0 = getPropertyDouble ("Cjs");
-  nr_double_t Vjs  = getPropertyDouble ("Vjs");
+  nr_double_t Cjs0 = getScaledProperty ("Cjs");
+  nr_double_t Vjs  = getScaledProperty ("Vjs");
   nr_double_t Mjs  = getPropertyDouble ("Mjs");
   nr_double_t Fc   = getPropertyDouble ("Fc");
   nr_double_t Vtf  = getPropertyDouble ("Vtf");
   nr_double_t Tf   = getPropertyDouble ("Tf");
   nr_double_t Xtf  = getPropertyDouble ("Xtf");
-  nr_double_t Itf  = getPropertyDouble ("Itf");
+  nr_double_t Itf  = getScaledProperty ("Itf");
   nr_double_t Tr   = getPropertyDouble ("Tr");
 
-  nr_double_t Cbe, Ube, Ubc, Cbci, Cbcx, Ucs, Cbc, Ccs;
+  nr_double_t Cbe, Cbci, Cbcx, Ccs;
 
   // interpret zero as infinity for that model parameter
   Vtf = Vtf > 0 ? 1.0 / Vtf : 0;
 
-  Ube = getOperatingPoint ("Vbe");
-  Ubc = getOperatingPoint ("Vbc");
-  Ucs = getOperatingPoint ("Vcs");
-
   // depletion capacitance of base-emitter diode
   Cbe = pnCapacitance (Ube, Cje0, Vje, Mje, Fc);
   Qbe = pnCharge (Ube, Cje0, Vje, Mje, Fc);
 
   // diffusion capacitance of base-emitter diode
-  if (If != 0) {
+  if (If != 0.0) {
     nr_double_t e, Tff, dTffdUbe;
-    e = 2 * exp (Ubc * Vtf);
+    e = 2 * exp (MIN (Ubc * Vtf, 709));
     Tff = Tf * (1 + Xtf * sqr (If / (If + Itf)) * e);
     dTffdUbe = Tf * Xtf * 2 * gif * If * Itf / cubic (If + Itf) * e;
     Cbe += (If * dTffdUbe + Tff * (gif - If / Qb * dQbdUbe)) / Qb;
@@ -468,13 +585,12 @@ void bjt::calcOperatingPoints (void) {
   }
 
   // depletion and diffusion capacitance of base-collector diode
-  nr_double_t Qbc;
-  Cbc = pnCapacitance (Ubc, Cjc0, Vjc, Mjc, Fc);
-  Cbci = Cbc * Xcjc + Tr * gir;
-  Qbc = pnCharge (Ubc, Cjc0, Vjc, Mjc, Fc);
-  Qbci = Xcjc * Qbc + Tr * Ir;
-  Cbcx = Cbc * (1 - Xcjc);
-  Qbcx = Qbc * (1 - Xcjc);
+  Cbci = pnCapacitance (Ubc, Cjc0 * Xcjc, Vjc, Mjc, Fc) + Tr * gir;
+  Qbci = pnCharge (Ubc, Cjc0 * Xcjc, Vjc, Mjc, Fc) + Tr * Ir;
+
+  // depletion and diffusion capacitance of external base-collector capacitor
+  Cbcx = pnCapacitance (Ubx, Cjc0 * (1 - Xcjc), Vjc, Mjc, Fc);
+  Qbcx = pnCharge (Ubx, Cjc0 * (1 - Xcjc), Vjc, Mjc, Fc);
 
   // depletion capacitance of collector-substrate diode
   Ccs = pnCapacitance (Ucs, Cjs0, Vjs, Mjs);
@@ -497,33 +613,38 @@ void bjt::calcOperatingPoints (void) {
 void bjt::initSP (void) {
   allocMatrixS ();
   processCbcx ();
-  if (deviceEnabled (cbcx)) cbcx->initSP ();
+  if (deviceEnabled (cbcx)) {
+    cbcx->initSP ();
+    cbcx->initNoiseSP ();
+  }
 }
 
 void bjt::processCbcx (void) {
   nr_double_t Xcjc = getPropertyDouble ("Xcjc");
-  nr_double_t Rbm  = getPropertyDouble ("Rbm");
-  nr_double_t Cjc0 = getPropertyDouble ("Cjc");
+  nr_double_t Rbm  = getScaledProperty ("Rbm");
+  nr_double_t Cjc0 = getScaledProperty ("Cjc");
 
   /* if necessary then insert external capacitance between internal
      collector node and external base node */
   if (Rbm != 0.0 && Cjc0 != 0.0 && Xcjc != 1.0) {
     if (!deviceEnabled (cbcx)) {
-      cbcx = splitCapacitance (this, cbcx, getNet (), "Cbcx", rb->getNode (0),
-			       getNode (NODE_C));
+      cbcx = splitCapacitor (this, cbcx, "Cbcx", rb->getNode (NODE_1),
+			     getNode (NODE_C));
     }
     cbcx->setProperty ("C", getOperatingPoint ("Cbcx"));
   }
   else {
-    disableCapacitance (this, cbcx, getNet ());
+    disableCapacitor (this, cbcx);
   }
 }
 
 void bjt::initAC (void) {
   allocMatrixMNA ();
   processCbcx ();
-  if (deviceEnabled (cbcx)) cbcx->initAC ();
-  clearI ();
+  if (deviceEnabled (cbcx)) {
+    cbcx->initAC ();
+    cbcx->initNoiseAC ();
+  }
 }
 
 void bjt::calcAC (nr_double_t frequency) {
@@ -559,24 +680,22 @@ void bjt::initTR (void) {
 void bjt::calcTR (nr_double_t t) {
   calcDC ();
   saveOperatingPoints ();
+  loadOperatingPoints ();
   calcOperatingPoints ();
 
-  nr_double_t Ube = getOperatingPoint ("Vbe");
-  nr_double_t Ubc = getOperatingPoint ("Vbc");
-  nr_double_t Ucs = getOperatingPoint ("Vcs");
-  nr_double_t Cbe = getOperatingPoint ("Cbe");
-  nr_double_t Ccs = getOperatingPoint ("Ccs");
+  nr_double_t Cbe  = getOperatingPoint ("Cbe");
+  nr_double_t Ccs  = getOperatingPoint ("Ccs");
   nr_double_t Cbci = getOperatingPoint ("Cbci");
   nr_double_t Cbcx = getOperatingPoint ("Cbcx");
 
   // handle Rbb and Cbcx appropriately
   if (Rbb != 0.0) {
-    rb->setProperty ("R", Rbb);
+    rb->setScaledProperty ("R", Rbb);
     rb->calcTR (t);
     if (deviceEnabled (cbcx)) {
       cbcx->clearI ();
       cbcx->clearY ();
-      cbcx->transientCapacitance (qbxState, 1, 2, Cbcx, Ubc, Qbcx);
+      cbcx->transientCapacitance (qbxState, NODE_1, NODE_2, Cbcx, Ubx, Qbcx);
     }
   }
 
