@@ -1,7 +1,7 @@
 /*
  * bjt.h - bipolar junction transistor class definitions
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: bjt.h,v 1.17 2005/06/02 18:17:55 raimi Exp $
+ * $Id: bjt.h,v 1.20 2006/05/03 09:43:56 raimi Exp $
  *
  */
 
@@ -34,7 +34,9 @@ class bjt : public circuit
   void initSP (void);
   void calcDC (void);
   void initDC (void);
+  void restartDC (void);
   void saveOperatingPoints (void);
+  void loadOperatingPoints (void);
   void calcOperatingPoints (void);
   void initAC (void);
   void calcAC (nr_double_t);
@@ -43,13 +45,13 @@ class bjt : public circuit
   void calcTR (nr_double_t);
 
  private:
+  void initModel (void);
   void processCbcx (void);
   matrix calcMatrixY (nr_double_t);
   matrix calcMatrixCy (nr_double_t);
 
  private:
-  nr_double_t UbePrev;
-  nr_double_t UbcPrev;
+  nr_double_t Ucs, Ubx, Ube, Ubc, Uce, UbePrev, UbcPrev;
   circuit * re;
   circuit * rc;
   circuit * rb;
