@@ -1,7 +1,7 @@
 /*
  * device.cpp - device class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: device.cpp,v 1.18 2005/06/02 18:17:55 raimi Exp $
+ * $Id: device.cpp,v 1.22 2006/02/17 07:24:06 raimi Exp $
  *
  */
 
@@ -40,18 +40,19 @@
 #include "resistor.h"
 #include "capacitor.h"
 
+using namespace device;
+
 /* This function can be used to create an extra resistor circuit.  If
    the 'res' argument is NULL then the new circuit is created, the
    nodes get re-arranged and it is inserted into the given
    netlist. The given arguments can be explained as follows.
    base:     calling circuit (this)
    res:      additional resistor circuit (can be NULL)
-   subnet:   the netlist object
    c:        name of the additional circuit
    n:        name of the inserted (internal) node
    internal: number of new internal node (the original external node) */
-circuit * splitResistance (circuit * base, circuit * res, net * subnet,
-			   char * c, char * n, int internal) {
+circuit * device::splitResistor (circuit * base, circuit * res,
+				 char * c, char * n, int internal) {
   if (res == NULL) {
     res = new resistor ();
     char * name = circuit::createInternal (c, base->getName ());
@@ -59,7 +60,7 @@ circuit * splitResistance (circuit * base, circuit * res, net * subnet,
     res->setName (name);
     res->setNode (0, base->getNode(internal)->getName ());
     res->setNode (1, node, 1);
-    subnet->insertCircuit (res);
+    base->getNet()->insertCircuit (res);
     free (name);
     free (node);
   }
@@ -68,22 +69,21 @@ circuit * splitResistance (circuit * base, circuit * res, net * subnet,
 }
 
 /* This function is the counterpart of the above routine.  It removes
-   the resistance circuit from the netlist and re-assigns the original
+   the resistor circuit from the netlist and re-assigns the original
    node. */
-void disableResistance (circuit * base, circuit * res, net * subnet,
-			int internal) {
+void device::disableResistor (circuit * base, circuit * res, int internal) {
   if (res != NULL) {
-    subnet->removeCircuit (res, 0);
+    base->getNet()->removeCircuit (res, 0);
     base->setNode (internal, res->getNode(1)->getName (), 0);
   }
 }
 
-/* This function creates a new capacitance circuit if the given one is
+/* This function creates a new capacitor circuit if the given one is
    not NULL.  The new circuit is connected between the given nodes and
    a name is applied based upon the parents (base) name and the given
    name 'c'.  The circuit is then put into the netlist. */
-circuit * splitCapacitance (circuit * base, circuit * cap, net * subnet,
-			    char * c, node * n1, node * n2) {
+circuit * device::splitCapacitor (circuit * base, circuit * cap,
+				  char * c, node * n1, node * n2) {
   if (cap == NULL) {
     cap = new capacitor ();
     char * name = circuit::createInternal (c, base->getName ());
@@ -92,21 +92,21 @@ circuit * splitCapacitance (circuit * base, circuit * cap, net * subnet,
     cap->setNode (1, n2->getName ());
     free (name);
   }
-  subnet->insertCircuit (cap);
+  base->getNet()->insertCircuit (cap);
   return cap;
 }
 
-// The function removes the given capacitance circuit from the netlist.
-void disableCapacitance (circuit *, circuit * cap, net * subnet) {
+// The function removes the given capacitor circuit from the netlist.
+void device::disableCapacitor (circuit * base, circuit * cap) {
   if (cap != NULL) {
-    subnet->removeCircuit (cap, 0);
+    base->getNet()->removeCircuit (cap, 0);
   }
 }
 
 /* This function checks whether the given circuit object exists and is
    chained within the current netlist.  It returns non-zero if so and
    zero otherwise. */
-int deviceEnabled (circuit * c) {
+int device::deviceEnabled (circuit * c) {
   if (c != NULL && c->isEnabled ())
     return 1;
   return 0;
@@ -115,8 +115,8 @@ int deviceEnabled (circuit * c) {
 /* The function limits the forward pn-voltage for each DC iteration in
    order to avoid numerical overflows and thereby improve the
    convergence. */
-nr_double_t pnVoltage (nr_double_t Ud, nr_double_t Uold,
-		       nr_double_t Ut, nr_double_t Ucrit) {
+nr_double_t device::pnVoltage (nr_double_t Ud, nr_double_t Uold,
+			       nr_double_t Ut, nr_double_t Ucrit) {
   nr_double_t arg;
   if (Ud > Ucrit && fabs (Ud - Uold) > 2 * Ut) {
     if (Uold > 0) {
@@ -138,8 +138,8 @@ nr_double_t pnVoltage (nr_double_t Ud, nr_double_t Uold,
 }
 
 // Computes current and its derivative for a MOS pn-junction.
-void pnJunctionMOS (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute,
-		    nr_double_t& I, nr_double_t& g) {
+void device::pnJunctionMOS (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute,
+			    nr_double_t& I, nr_double_t& g) {
   if (Upn <= 0) {
     g = Iss / Ute;
     I = g * Upn;
@@ -152,8 +152,8 @@ void pnJunctionMOS (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute,
 }
 
 // Computes current and its derivative for a bipolar pn-junction.
-void pnJunctionBIP (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute,
-		    nr_double_t& I, nr_double_t& g) {
+void device::pnJunctionBIP (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute,
+			    nr_double_t& I, nr_double_t& g) {
   if (Upn < -3 * Ute) {
     nr_double_t a = 3 * Ute / (Upn * M_E);
     a = cubic (a);
@@ -168,18 +168,21 @@ void pnJunctionBIP (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute,
 }
 
 // The function computes the exponential pn-junction current.
-nr_double_t pnCurrent (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute) {
+nr_double_t
+device::pnCurrent (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute) {
   return Iss * (exp (MIN (Upn / Ute, 709)) - 1);
 }
 
 // The function computes the exponential pn-junction current's derivative.
-nr_double_t pnConductance (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute) {
+nr_double_t
+device::pnConductance (nr_double_t Upn, nr_double_t Iss, nr_double_t Ute) {
   return Iss * exp (MIN (Upn / Ute, 709)) / Ute;
 }
 
 // Computes pn-junction depletion capacitance.
-nr_double_t pnCapacitance (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
-			   nr_double_t Mj, nr_double_t Fc) {
+nr_double_t
+device::pnCapacitance (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
+		       nr_double_t Mj, nr_double_t Fc) {
   nr_double_t c;
   if (Uj <= Fc * Vj)
     c = Cj * exp (-Mj * log (1 - Uj / Vj));
@@ -190,8 +193,8 @@ nr_double_t pnCapacitance (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
 }
 
 // Computes pn-junction depletion charge.
-nr_double_t pnCharge (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
-		      nr_double_t Mj, nr_double_t Fc) {
+nr_double_t device::pnCharge (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
+			      nr_double_t Mj, nr_double_t Fc) {
   nr_double_t q, a, b;
   if (Uj <= Fc * Vj) {
     a = 1 - Uj / Vj;
@@ -222,8 +225,9 @@ nr_double_t pnCharge (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
 
 /* This function computes the pn-junction depletion capacitance with
    no linearization factor given. */
-nr_double_t pnCapacitance (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
-			   nr_double_t Mj) {
+nr_double_t
+device::pnCapacitance (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
+		       nr_double_t Mj) {
   nr_double_t c;
   if (Uj <= 0)
     c = Cj * exp (-Mj * log (1 - Uj / Vj));
@@ -234,8 +238,8 @@ nr_double_t pnCapacitance (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
 
 /* This function computes the pn-junction depletion charge with no
    linearization factor given. */
-nr_double_t pnCharge (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
-		      nr_double_t Mj) {
+nr_double_t device::pnCharge (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
+			      nr_double_t Mj) {
   nr_double_t q;
   if (Uj <= 0)
     q = Cj * Vj / (1 - Mj) * (1 - exp ((1 - Mj) * log (1 - Uj / Vj)));
@@ -245,14 +249,15 @@ nr_double_t pnCharge (nr_double_t Uj, nr_double_t Cj, nr_double_t Vj,
 }
 
 // Compute critical voltage of pn-junction.
-nr_double_t pnCriticalVoltage (nr_double_t Iss, nr_double_t Ute) {
+nr_double_t device::pnCriticalVoltage (nr_double_t Iss, nr_double_t Ute) {
   return Ute * log (Ute / M_SQRT2 / Iss);
 }
 
 /* The function limits the forward fet-voltage for each DC iteration
    in order to avoid numerical overflows and thereby improve the
    convergence. */
-nr_double_t fetVoltage (nr_double_t Ufet, nr_double_t Uold, nr_double_t Uth) {
+nr_double_t
+device::fetVoltage (nr_double_t Ufet, nr_double_t Uold, nr_double_t Uth) {
   nr_double_t Utsthi = fabs (2 * (Uold - Uth)) + 2.0;
   nr_double_t Utstlo = Utsthi / 2;
   nr_double_t Utox   = Uth + 3.5;
@@ -301,7 +306,7 @@ nr_double_t fetVoltage (nr_double_t Ufet, nr_double_t Uold, nr_double_t Uth) {
 /* The function limits the drain-source voltage for each DC iteration
    in order to avoid numerical overflows and thereby improve the
    convergence. */
-nr_double_t fetVoltageDS (nr_double_t Ufet, nr_double_t Uold) {
+nr_double_t device::fetVoltageDS (nr_double_t Ufet, nr_double_t Uold) {
   if (Uold >= 3.5) {
     if (Ufet > Uold) {
       Ufet = MIN (Ufet, 3 * Uold + 2);
@@ -321,10 +326,11 @@ nr_double_t fetVoltageDS (nr_double_t Ufet, nr_double_t Uold) {
 /* This function calculates the overlap capacitance for MOS based upon
    the given voltages, surface potential and the zero-bias oxide
    capacitance. */
-void fetCapacitanceMeyer (nr_double_t Ugs, nr_double_t Ugd, nr_double_t Uth,
-			  nr_double_t Udsat, nr_double_t Phi, nr_double_t Cox,
-			  nr_double_t& Cgs, nr_double_t& Cgd,
-			  nr_double_t& Cgb) {
+void
+device::fetCapacitanceMeyer (nr_double_t Ugs, nr_double_t Ugd, nr_double_t Uth,
+			     nr_double_t Udsat, nr_double_t Phi,
+			     nr_double_t Cox, nr_double_t& Cgs,
+			     nr_double_t& Cgd, nr_double_t& Cgb) {
 
   nr_double_t Utst = Ugs - Uth;
   if (Utst <= -Phi) { // cutoff regions
@@ -353,3 +359,56 @@ void fetCapacitanceMeyer (nr_double_t Ugs, nr_double_t Ugd, nr_double_t Uth,
     }
   }
 }
+
+// Computes temperature dependency of energy bandgap.
+nr_double_t device::Egap (nr_double_t T, nr_double_t Eg0) {
+  nr_double_t a = 7.02e-4;
+  nr_double_t b = 1108;
+  return Eg0 - (a * sqr (T)) / (T + b);
+}
+
+// Computes temperature dependency of intrinsic density.
+nr_double_t device::intrinsicDensity (nr_double_t T, nr_double_t Eg0) {
+  nr_double_t TR = 300.00;
+  nr_double_t E1 = Egap (TR, Eg0);
+  nr_double_t E2 = Egap (T, Eg0);
+  nr_double_t NI = NiSi / 1e6;
+  return  NI * exp (1.5 * log (T / TR) + (E1 / TR - E2 / T) / kBoverQ / 2);
+}
+
+// Calculates temperature dependence for saturation current.
+nr_double_t
+device::pnCurrent_T (nr_double_t T1, nr_double_t T2, nr_double_t Is,
+		     nr_double_t Eg, nr_double_t N,  nr_double_t Xti) {
+  nr_double_t Vt, TR;
+  TR = T2 / T1;
+  Vt = T2 * kBoverQ;
+  return Is * exp (Xti / N * log (TR) - Eg / N / Vt * (1 - TR));
+}
+
+// Calculates temperature dependence for junction potential.
+nr_double_t
+device::pnPotential_T (nr_double_t T1, nr_double_t T2, nr_double_t Vj,
+		       nr_double_t Eg0) {
+  nr_double_t Vt, TR, E1, E2;
+  TR = T2 / T1;
+  E1 = Egap (T1, Eg0);
+  E2 = Egap (T2, Eg0);
+  Vt = T2 * kBoverQ;
+  return TR * Vj - 3 * Vt * log (TR) - (TR * E1 - E2);
+}
+
+// Calculates temperature dependence for junction capacitance.
+nr_double_t
+device::pnCapacitance_T (nr_double_t T1, nr_double_t T2, nr_double_t M,
+			 nr_double_t VR, nr_double_t Cj) {
+  return Cj * pnCapacitance_F (T1, T2, M, VR);
+}
+
+// Calculates temperature dependence for junction capacitance.
+nr_double_t
+device::pnCapacitance_F (nr_double_t T1, nr_double_t T2, nr_double_t M,
+			 nr_double_t VR) {
+  nr_double_t DT = T2 - T1;
+  return 1 + M * (4e-4 * DT - VR + 1);
+}
