@@ -1,7 +1,7 @@
 /*
  * diode.h - diode class definitions
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,35 +18,44 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: diode.h,v 1.13 2005/06/02 18:17:55 raimi Exp $
+ * $Id: diode.h,v 1.17 2006/05/03 09:43:56 raimi Exp $
  *
  */
 
 #ifndef __DIODE_H__
 #define __DIODE_H__
 
-class diode : public circuit
+#include "devstates.h"
+
+class diode : public circuit, public devstates
 {
  public:
   diode ();
   void calcSP (nr_double_t);
   void calcNoiseSP (nr_double_t);
-  void calcDC (void);
   void initDC (void);
+  void calcDC (void);
+  void restartDC (void);
   void saveOperatingPoints (void);
+  void loadOperatingPoints (void);
   void calcOperatingPoints (void);
   void initAC (void);
   void calcAC (nr_double_t);
   void calcNoiseAC (nr_double_t);
   void initTR (void);
   void calcTR (nr_double_t);
+  void initHB (int);
+  void calcHB (int);
 
  private:
-  nr_double_t Uprev, gd, Id, Qd, Bv;
+  nr_double_t Ud, gd, Id, Qd, Bv;
   circuit * rs;
+  bool hb;
 
  private:
   matrix calcMatrixCy (nr_double_t);
+  void prepareDC (void);
+  void initModel (void);
 };
 
 #endif /* __DIODE_H__ */
