@@ -1,7 +1,7 @@
 /*
  * jfet.cpp - jfet class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: jfet.cpp,v 1.26 2005/06/02 18:17:55 raimi Exp $
+ * $Id: jfet.cpp,v 1.32 2006/05/03 09:43:56 raimi Exp $
  *
  */
 
@@ -46,6 +46,8 @@
 #define NODE_D 1 /* drain node  */
 #define NODE_S 2 /* source node */
 
+using namespace device;
+
 jfet::jfet () : circuit (3) {
   rs = rd = NULL;
   type = CIR_JFET;
@@ -93,8 +95,8 @@ matrix jfet::calcMatrixCy (nr_double_t frequency) {
   nr_double_t Kf  = getPropertyDouble ("Kf");
   nr_double_t Af  = getPropertyDouble ("Af");
   nr_double_t Ffe = getPropertyDouble ("Ffe");
-  nr_double_t gm  = getOperatingPoint ("gm");
-  nr_double_t Ids = getOperatingPoint ("Id");
+  nr_double_t gm  = fabs (getOperatingPoint ("gm"));
+  nr_double_t Ids = fabs (getOperatingPoint ("Id"));
   nr_double_t T   = getPropertyDouble ("Temp");
 
   /* compute channel noise and flicker noise generated by the DC
@@ -112,14 +114,80 @@ matrix jfet::calcMatrixCy (nr_double_t frequency) {
   return cy;
 }
 
+void jfet::initModel (void) {
+  // fetch necessary device properties
+  nr_double_t T  = getPropertyDouble ("Temp");
+  nr_double_t Tn = getPropertyDouble ("Tnom");
+  nr_double_t A  = getPropertyDouble ("Area");
+
+  // compute Is temperature and area dependency
+  nr_double_t Is  = getPropertyDouble ("Is");
+  nr_double_t N   = getPropertyDouble ("N");
+  nr_double_t Xti = getPropertyDouble ("Xti");
+  nr_double_t T1, T2, Eg;
+  T2 = kelvin (T);
+  T1 = kelvin (Tn);
+  Eg = Egap (300);
+  Is = pnCurrent_T (T1, T2, Is, Eg, N, Xti);
+  setScaledProperty ("Is", Is * A);
+
+  // compute Isr temperature and area dependency
+  nr_double_t Isr = getPropertyDouble ("Isr");
+  nr_double_t Nr  = getPropertyDouble ("Nr");
+  Isr = pnCurrent_T (T1, T2, Isr, Eg, Nr, Xti);
+  setScaledProperty ("Isr", Isr * A);
+
+  // compute Pb temperature dependency
+  nr_double_t Pb = getPropertyDouble ("Pb");
+  nr_double_t PbT;
+  PbT = pnPotential_T (T1,T2, Pb);
+  setScaledProperty ("Pb", PbT);
+
+  // compute Cgs and Cgd temperature and area dependency
+  nr_double_t Cgs = getPropertyDouble ("Cgs");
+  nr_double_t Cgd = getPropertyDouble ("Cgd");
+  nr_double_t M   = getPropertyDouble ("M");
+  nr_double_t F;
+  F = A * pnCapacitance_F (T1, T2, M, PbT / Pb);
+  setScaledProperty ("Cgs", Cgs * F);
+  setScaledProperty ("Cgd", Cgd * F);
+
+  // compute Vth temperature dependency
+  nr_double_t Vt0   = getPropertyDouble ("Vt0");
+  nr_double_t Vt0tc = getPropertyDouble ("Vt0tc");
+  nr_double_t DT    = T2 - T1;
+  Vt0 = Vt0 + Vt0tc * DT;
+  setScaledProperty ("Vt0", Vt0);
+
+  // compute Beta temperature and area dependency
+  nr_double_t Beta    = getPropertyDouble ("Beta");
+  nr_double_t Betatce = getPropertyDouble ("Betatce");
+  Beta = Beta * exp (Betatce * DT * log (1.01));
+  setScaledProperty ("Beta", Beta * A);
+
+  // compute Rs and Rd area dependency
+  nr_double_t Rs = getPropertyDouble ("Rs");
+  nr_double_t Rd = getPropertyDouble ("Rd");
+  setScaledProperty ("Rs", Rs / A);
+  setScaledProperty ("Rd", Rd / A);
+}
+
+void jfet::restartDC (void) {
+  // apply starting values to previous iteration values
+  UgdPrev = real (getV (NODE_G) - getV (NODE_D));
+  UgsPrev = real (getV (NODE_G) - getV (NODE_S));
+}
+
 void jfet::initDC (void) {
 
   // allocate MNA matrices
   allocMatrixMNA ();
 
+  // initialize scalability
+  initModel ();
+
   // initialize starting values
-  UgdPrev = real (getV (NODE_G) - getV (NODE_D));
-  UgsPrev = real (getV (NODE_G) - getV (NODE_S));
+  restartDC ();
 
   // apply polarity of JFET
   char * type = getPropertyString ("Type");
@@ -129,51 +197,53 @@ void jfet::initDC (void) {
   nr_double_t T = getPropertyDouble ("Temp");
 
   // possibly insert series resistance at source
-  nr_double_t Rs = getPropertyDouble ("Rs");
+  nr_double_t Rs = getScaledProperty ("Rs");
   if (Rs != 0.0) {
     // create additional circuit if necessary and reassign nodes
-    rs = splitResistance (this, rs, this->getNet (), "Rs", "source", NODE_S);
+    rs = splitResistor (this, rs, "Rs", "source", NODE_S);
     rs->setProperty ("Temp", T);
     rs->setProperty ("R", Rs);
+    rs->setProperty ("Controlled", getName ());
     rs->initDC ();
   }
   // no series resistance at source
   else {
-    disableResistance (this, rs, getNet (), NODE_S);
+    disableResistor (this, rs, NODE_S);
   }
 
   // possibly insert series resistance at drain
-  nr_double_t Rd = getPropertyDouble ("Rd");
+  nr_double_t Rd = getScaledProperty ("Rd");
   if (Rd != 0.0) {
     // create additional circuit if necessary and reassign nodes
-    rd = splitResistance (this, rd, getNet (), "Rd", "drain", NODE_D);
+    rd = splitResistor (this, rd, "Rd", "drain", NODE_D);
     rd->setProperty ("Temp", T);
     rd->setProperty ("R", Rd);
+    rd->setProperty ("Controlled", getName ());
     rd->initDC ();
   }
   // no series resistance at drain
   else {
-    disableResistance (this, rd, getNet (), NODE_D);
+    disableResistor (this, rd, NODE_D);
   }
 }
 
 void jfet::calcDC (void) {
 
   // fetch device model parameters
-  nr_double_t Is   = getPropertyDouble ("Is");
+  nr_double_t Is   = getScaledProperty ("Is");
   nr_double_t n    = getPropertyDouble ("N");
-  nr_double_t Isr  = getPropertyDouble ("Isr");
+  nr_double_t Isr  = getScaledProperty ("Isr");
   nr_double_t nr   = getPropertyDouble ("Nr");
-  nr_double_t Vt0  = getPropertyDouble ("Vt0");
+  nr_double_t Vt0  = getScaledProperty ("Vt0");
   nr_double_t l    = getPropertyDouble ("Lambda");
-  nr_double_t beta = getPropertyDouble ("Beta");
+  nr_double_t beta = getScaledProperty ("Beta");
   nr_double_t T    = getPropertyDouble ("Temp");
 
-  nr_double_t Ugs, Ugd, Ut, IeqG, IeqD, IeqS, UgsCrit, UgdCrit;
-  nr_double_t Uds, Igs, Igd, gtiny;
+  nr_double_t Ut, IeqG, IeqD, IeqS, UgsCrit, UgdCrit;
+  nr_double_t Igs, Igd, gtiny;
 
   T = kelvin (T);
-  Ut = T * kB / Q;
+  Ut = T * kBoverQ;
   Ugd = real (getV (NODE_G) - getV (NODE_D)) * pol;
   Ugs = real (getV (NODE_G) - getV (NODE_S)) * pol;
 
@@ -270,31 +340,31 @@ void jfet::calcDC (void) {
   setY (NODE_S, NODE_S, ggs + gds + gm);
 }
 
+void jfet::loadOperatingPoints (void) {
+  Ugs = getOperatingPoint ("Vgs");
+  Ugd = getOperatingPoint ("Vgd");
+  Uds = getOperatingPoint ("Vds");
+}
+
 void jfet::saveOperatingPoints (void) {
-  nr_double_t Ugs, Ugd;
-  Ugd = real (getV (NODE_G) - getV (NODE_D)) * pol;
-  Ugs = real (getV (NODE_G) - getV (NODE_S)) * pol;
-  setOperatingPoint ("Vgs", Ugs);
-  setOperatingPoint ("Vgd", Ugd);
-  setOperatingPoint ("Vds", Ugs - Ugd);
+  nr_double_t Vgs, Vgd;
+  Vgd = real (getV (NODE_G) - getV (NODE_D)) * pol;
+  Vgs = real (getV (NODE_G) - getV (NODE_S)) * pol;
+  setOperatingPoint ("Vgs", Vgs);
+  setOperatingPoint ("Vgd", Vgd);
+  setOperatingPoint ("Vds", Vgs - Vgd);
 }
 
 void jfet::calcOperatingPoints (void) {
 
   // fetch device model parameters
   nr_double_t z    = getPropertyDouble ("M");
-  nr_double_t Cgd0 = getPropertyDouble ("Cgd");
-  nr_double_t Cgs0 = getPropertyDouble ("Cgs");
-  nr_double_t Pb   = getPropertyDouble ("Pb");
+  nr_double_t Cgd0 = getScaledProperty ("Cgd");
+  nr_double_t Cgs0 = getScaledProperty ("Cgs");
+  nr_double_t Pb   = getScaledProperty ("Pb");
   nr_double_t Fc   = getPropertyDouble ("Fc");
-  nr_double_t T    = getPropertyDouble ("Temp");
   
-  nr_double_t Ugs, Ugd, Ut, Cgs, Cgd;
-
-  T = kelvin (T);
-  Ut = kB * T / Q;
-  Ugd = getOperatingPoint ("Vgd");
-  Ugs = getOperatingPoint ("Vgs");
+  nr_double_t Cgs, Cgd;
 
   // capacitance of gate-drain diode
   Cgd = pnCapacitance (Ugd, Cgd0, Pb, z, Fc);
@@ -340,10 +410,9 @@ void jfet::initTR (void) {
 void jfet::calcTR (nr_double_t) {
   calcDC ();
   saveOperatingPoints ();
+  loadOperatingPoints ();
   calcOperatingPoints ();
 
-  nr_double_t Ugs = getOperatingPoint ("Vgs");
-  nr_double_t Ugd = getOperatingPoint ("Vgd");
   nr_double_t Cgs = getOperatingPoint ("Cgs");
   nr_double_t Cgd = getOperatingPoint ("Cgd");
 
