@@ -1,7 +1,7 @@
 /*
  * mosfet.cpp - mosfet class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: mosfet.cpp,v 1.29 2005/06/02 18:17:55 raimi Exp $
+ * $Id: mosfet.cpp,v 1.35 2006/05/03 09:43:56 raimi Exp $
  *
  */
 
@@ -48,8 +48,7 @@
 #define NODE_S 2 /* source node */
 #define NODE_B 3 /* bulk node   */
 
-// silicon bandgap as function of T
-#define Egap(T) (1.16 - (7.02e-4 * sqr (T)) / ((T) + 1108))
+using namespace device;
 
 mosfet::mosfet () : circuit (4) {
   transientMode = 0;
@@ -114,8 +113,8 @@ matrix mosfet::calcMatrixCy (nr_double_t frequency) {
   nr_double_t Kf  = getPropertyDouble ("Kf");
   nr_double_t Af  = getPropertyDouble ("Af");
   nr_double_t Ffe = getPropertyDouble ("Ffe");
-  nr_double_t gm  = getOperatingPoint ("gm");
-  nr_double_t Ids = getOperatingPoint ("Id");
+  nr_double_t gm  = fabs (getOperatingPoint ("gm"));
+  nr_double_t Ids = fabs (getOperatingPoint ("Id"));
   nr_double_t T   = getPropertyDouble ("Temp");
 
   /* compute channel noise and flicker noise generated by the DC
@@ -133,17 +132,22 @@ matrix mosfet::calcMatrixCy (nr_double_t frequency) {
   return cy;
 }
 
+void mosfet::restartDC (void) {
+  // apply starting values to previous iteration values
+  UgdPrev = real (getV (NODE_G) - getV (NODE_D));
+  UgsPrev = real (getV (NODE_G) - getV (NODE_S));
+  UbsPrev = real (getV (NODE_B) - getV (NODE_S));
+  UbdPrev = real (getV (NODE_B) - getV (NODE_D));
+  UdsPrev = UgsPrev - UgdPrev;
+}
+
 void mosfet::initDC (void) {
 
   // allocate MNA matrices
   allocMatrixMNA ();
 
   // initialize starting values
-  UgdPrev = real (getV (NODE_G) - getV (NODE_D));
-  UgsPrev = real (getV (NODE_G) - getV (NODE_S));
-  UbsPrev = real (getV (NODE_B) - getV (NODE_S));
-  UbdPrev = real (getV (NODE_B) - getV (NODE_D));
-  UdsPrev = UgsPrev - UgdPrev;
+  restartDC ();
 
   // initialize the MOSFET
   initModel ();
@@ -154,48 +158,53 @@ void mosfet::initDC (void) {
   // possibly insert series resistance at source
   if (Rs != 0.0) {
     // create additional circuit if necessary and reassign nodes
-    rs = splitResistance (this, rs, getNet (), "Rs", "source", NODE_S);
+    rs = splitResistor (this, rs, "Rs", "source", NODE_S);
     rs->setProperty ("Temp", T);
     rs->setProperty ("R", Rs);
+    rs->setProperty ("Controlled", getName ());
     rs->initDC ();
   }
   // no series resistance at source
   else {
-    disableResistance (this, rs, getNet (), NODE_S);
+    disableResistor (this, rs, NODE_S);
   }
 
   // possibly insert series resistance at gate
   nr_double_t Rg = getPropertyDouble ("Rg");
   if (Rg != 0.0) {
     // create additional circuit if necessary and reassign nodes
-    rg = splitResistance (this, rg, getNet (), "Rg", "gate", NODE_G);
+    rg = splitResistor (this, rg, "Rg", "gate", NODE_G);
     rg->setProperty ("Temp", T);
     rg->setProperty ("R", Rg);
+    rg->setProperty ("Controlled", getName ());
     rg->initDC ();
   }
   // no series resistance at source
   else {
-    disableResistance (this, rg, getNet (), NODE_G);
+    disableResistor (this, rg, NODE_G);
   }
 
   // possibly insert series resistance at drain
   if (Rd != 0.0) {
     // create additional circuit if necessary and reassign nodes
-    rd = splitResistance (this, rd, getNet (), "Rd", "drain", NODE_D);
+    rd = splitResistor (this, rd, "Rd", "drain", NODE_D);
     rd->setProperty ("Temp", T);
     rd->setProperty ("R", Rd);
+    rd->setProperty ("Controlled", getName ());
     rd->initDC ();
   }
   // no series resistance at drain
   else {
-    disableResistance (this, rd, getNet (), NODE_D);
+    disableResistor (this, rd, NODE_D);
   }
 }
 
 void mosfet::initModel (void) {
 
   // get device temperature
-  nr_double_t T = getPropertyDouble ("Temp");
+  nr_double_t T  = getPropertyDouble ("Temp");
+  nr_double_t T2 = kelvin (getPropertyDouble ("Temp"));
+  nr_double_t T1 = kelvin (getPropertyDouble ("Tnom"));
 
   // apply polarity of MOSFET
   char * type = getPropertyString ("Type");
@@ -224,6 +233,11 @@ void mosfet::initModel (void) {
   // calculate DC transconductance coefficient
   nr_double_t Kp = getPropertyDouble ("Kp");
   nr_double_t Uo = getPropertyDouble ("Uo");
+  nr_double_t F1 = exp (1.5 * log (T1 / T2));
+  Kp = Kp * F1;
+  Uo = Uo * F1;
+  setScaledProperty ("Kp", Kp);
+  setScaledProperty ("Uo", Uo);
   if (Kp > 0) {
     beta = Kp * W / Leff;
   } else {
@@ -240,13 +254,15 @@ void mosfet::initModel (void) {
   nr_double_t P    = getPropertyDouble ("Phi");
   nr_double_t Nsub = getPropertyDouble ("Nsub");
   nr_double_t Ut   = T0 * kBoverQ;
+  P = pnPotential_T (T1,T2, P);
+  setScaledProperty ("Phi", P);
   if ((Phi = P) <= 0) {
     if (Nsub > 0) {
-      if (Nsub * 1e6 >= Ni) {
-	Phi = 2 * Ut * log (Nsub * 1e6 / Ni);
+      if (Nsub * 1e6 >= NiSi) {
+	Phi = 2 * Ut * log (Nsub * 1e6 / NiSi);
       } else {
 	logprint (LOG_STATUS, "WARNING: substrate doping less than instrinsic "
-		  "density, adjust Nsub >= %g\n", Ni / 1e6);
+		  "density, adjust Nsub >= %g\n", NiSi / 1e6);
 	Phi = 0.6;
       }
     } else {
@@ -305,8 +321,16 @@ void mosfet::initModel (void) {
   }
 
   // calculate zero-bias junction capacitance
-  nr_double_t Cj = getPropertyDouble ("Cj");
-  nr_double_t Pb = getPropertyDouble ("Pb");
+  nr_double_t Cj  = getPropertyDouble ("Cj");
+  nr_double_t Mj  = getPropertyDouble ("Mj");
+  nr_double_t Mjs = getPropertyDouble ("Mjsw");
+  nr_double_t Pb  = getPropertyDouble ("Pb");
+  nr_double_t PbT, F2, F3;
+  PbT = pnPotential_T (T1,T2, Pb);
+  F2  = pnCapacitance_F (T1, T2, Mj, PbT / Pb);
+  F3  = pnCapacitance_F (T1, T2, Mjs, PbT / Pb);
+  Pb  = PbT;
+  setScaledProperty ("Pb", Pb);
   if (Cj <= 0) {
     if (Pb > 0 && Nsub > 0) {
       Cj = sqrt (ESi * E0 * Q * Nsub * 1e6 / 2 / Pb);
@@ -316,33 +340,43 @@ void mosfet::initModel (void) {
 		"valid square junction capacitance\n");
       Cj = 0.0;
     }
-    setProperty ("Cj", Cj);
   }
+  Cj = Cj * F2;
+  setScaledProperty ("Cj", Cj);
 
   // calculate junction capacitances
   nr_double_t Cbd0 = getPropertyDouble ("Cbd");
   nr_double_t Cbs0 = getPropertyDouble ("Cbs");
   nr_double_t Ad   = getPropertyDouble ("Ad");
   nr_double_t As   = getPropertyDouble ("As");
+  Cbd0 = Cbd0 * F2;
   if (Cbd0 <= 0) {
     Cbd0 = Cj * Ad;
-    setProperty ("Cbd", Cbd0);
   }
+  setScaledProperty ("Cbd", Cbd0);
+  Cbs0 = Cbs0 * F2;
   if (Cbs0 <= 0) {
     Cbs0 = Cj * As;
-    setProperty ("Cbs", Cbs0);
   }
+  setScaledProperty ("Cbs", Cbs0);
 
   // calculate periphery junction capacitances
   nr_double_t Cjs = getPropertyDouble ("Cjsw");
   nr_double_t Pd  = getPropertyDouble ("Pd");
   nr_double_t Ps  = getPropertyDouble ("Ps");
+  Cjs = Cjs * F3;
   setProperty ("Cbds", Cjs * Pd);
   setProperty ("Cbss", Cjs * Ps);
 
   // calculate junction capacitances and saturation currents
   nr_double_t Js  = getPropertyDouble ("Js");
   nr_double_t Is  = getPropertyDouble ("Is");
+  nr_double_t F4, E1, E2;
+  E1 = Egap (T1);
+  E2 = Egap (T2);
+  F4 = exp (- QoverkB / T2 * (T2 / T1 * E1 - E2));
+  Is = Is * F4;
+  Js = Js * F4;
   nr_double_t Isd = (Ad > 0) ? Js * Ad : Is;
   nr_double_t Iss = (As > 0) ? Js * As : Is;
   setProperty ("Isd", Isd);
@@ -363,8 +397,7 @@ void mosfet::calcDC (void) {
   nr_double_t l   = getPropertyDouble ("Lambda");
   nr_double_t T   = getPropertyDouble ("Temp");
 
-  nr_double_t Ugs, Ugd, Ut, IeqBS, IeqBD, IeqDS, UbsCrit, UbdCrit;
-  nr_double_t Uds, gtiny, Ubs, Ubd;
+  nr_double_t Ut, IeqBS, IeqBD, IeqDS, UbsCrit, UbdCrit, gtiny;
 
   T = kelvin (T);
   Ut = T * kBoverQ;
@@ -520,44 +553,46 @@ void mosfet::calcDC (void) {
 #define cgbState 15 // gate-bulk capacitance state
 
 void mosfet::saveOperatingPoints (void) {
-  nr_double_t Ugs, Ugd, Ubs, Ubd;
-  Ugd = real (getV (NODE_G) - getV (NODE_D)) * pol;
-  Ugs = real (getV (NODE_G) - getV (NODE_S)) * pol;
-  Ubs = real (getV (NODE_B) - getV (NODE_S)) * pol;
-  Ubd = real (getV (NODE_B) - getV (NODE_D)) * pol;
-  setOperatingPoint ("Vgs", Ugs);
-  setOperatingPoint ("Vgd", Ugd);
-  setOperatingPoint ("Vbs", Ubs);
-  setOperatingPoint ("Vbd", Ubd);
-  setOperatingPoint ("Vds", Ugs - Ugd);
+  nr_double_t Vgs, Vgd, Vbs, Vbd;
+  Vgd = real (getV (NODE_G) - getV (NODE_D)) * pol;
+  Vgs = real (getV (NODE_G) - getV (NODE_S)) * pol;
+  Vbs = real (getV (NODE_B) - getV (NODE_S)) * pol;
+  Vbd = real (getV (NODE_B) - getV (NODE_D)) * pol;
+  setOperatingPoint ("Vgs", Vgs);
+  setOperatingPoint ("Vgd", Vgd);
+  setOperatingPoint ("Vbs", Vbs);
+  setOperatingPoint ("Vbd", Vbd);
+  setOperatingPoint ("Vds", Vgs - Vgd);
+  setOperatingPoint ("Vgb", Vgs - Vbs);
+}
+
+void mosfet::loadOperatingPoints (void) {
+  Ugs = getOperatingPoint ("Vgs");
+  Ugd = getOperatingPoint ("Vgd");
+  Ubs = getOperatingPoint ("Vbs");
+  Ubd = getOperatingPoint ("Vbd");
+  Uds = getOperatingPoint ("Vds");
+  Ugb = getOperatingPoint ("Vgb");
 }
 
 void mosfet::calcOperatingPoints (void) {
 
   // fetch device model parameters
-  nr_double_t Cbd0 = getPropertyDouble ("Cbd");
-  nr_double_t Cbs0 = getPropertyDouble ("Cbs");
+  nr_double_t Cbd0 = getScaledProperty ("Cbd");
+  nr_double_t Cbs0 = getScaledProperty ("Cbs");
   nr_double_t Cbds = getPropertyDouble ("Cbds");
   nr_double_t Cbss = getPropertyDouble ("Cbss");
   nr_double_t Cgso = getPropertyDouble ("Cgso");
   nr_double_t Cgdo = getPropertyDouble ("Cgdo");
   nr_double_t Cgbo = getPropertyDouble ("Cgbo");
-  nr_double_t Pb   = getPropertyDouble ("Pb");
+  nr_double_t Pb   = getScaledProperty ("Pb");
   nr_double_t M    = getPropertyDouble ("Mj");
   nr_double_t Ms   = getPropertyDouble ("Mjsw");
   nr_double_t Fc   = getPropertyDouble ("Fc");
   nr_double_t Tt   = getPropertyDouble ("Tt");
   nr_double_t W    = getPropertyDouble ("W");
   
-  nr_double_t Ubs, Ubd, Cbs, Cbd, Ugs, Ugd, Uds, Ugb;
-  nr_double_t Cgd, Cgb, Cgs;
-
-  Ugd = getOperatingPoint ("Vgd");
-  Ugs = getOperatingPoint ("Vgs");
-  Ubs = getOperatingPoint ("Vbs");
-  Ubd = getOperatingPoint ("Vbd");
-  Uds = Ugs - Ugd;
-  Ugb = Ugs - Ubs;
+  nr_double_t Cbs, Cbd, Cgd, Cgb, Cgs;
 
   // capacitance of bulk-drain diode
   Cbd = gbd * Tt + pnCapacitance (Ubd, Cbd0, Pb, M, Fc) +
@@ -619,7 +654,6 @@ void mosfet::calcOperatingPoints (void) {
 
 void mosfet::initAC (void) {
   allocMatrixMNA ();
-  clearI ();
 }
 
 void mosfet::calcAC (nr_double_t frequency) {
@@ -639,6 +673,7 @@ void mosfet::calcTR (nr_double_t) {
   calcDC ();
   transientMode = getPropertyInteger ("capModel");
   saveOperatingPoints ();
+  loadOperatingPoints ();
   calcOperatingPoints ();
   transientMode = 0;
 
@@ -647,11 +682,9 @@ void mosfet::calcTR (nr_double_t) {
   nr_double_t Cbd = getOperatingPoint ("Cbd");
   nr_double_t Cbs = getOperatingPoint ("Cbs");
   nr_double_t Cgb = getOperatingPoint ("Cgb");
-  nr_double_t Ugd = getOperatingPoint ("Vgd");
-  nr_double_t Ugs = getOperatingPoint ("Vgs");
-  nr_double_t Ubd = getOperatingPoint ("Vbd");
-  nr_double_t Ubs = getOperatingPoint ("Vbs");
-  nr_double_t Ugb = Ugs - Ubs;
+
+  Uds = Ugs - Ugd;
+  Ugb = Ugs - Ubs;
 
   transientCapacitance (qbdState, NODE_B, NODE_D, Cbd, Ubd, Qbd);
   transientCapacitance (qbsState, NODE_B, NODE_S, Cbs, Ubs, Qbs);
