@@ -1,7 +1,7 @@
 /*
  * iac.cpp - AC current source class implementation
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: iac.cpp,v 1.10 2005/06/02 18:17:52 raimi Exp $
+ * $Id: iac.cpp,v 1.12 2006/05/23 09:48:32 raimi Exp $
  *
  */
 
@@ -68,6 +68,8 @@ void iac::initAC (void) {
 void iac::calcTR (nr_double_t t) {
   nr_double_t f = getPropertyDouble ("f");
   nr_double_t p = getPropertyDouble ("Phase");
-  nr_double_t i = getPropertyDouble ("I") * sin (2 * M_PI * f * t + rad (p));
+  nr_double_t d = getPropertyDouble ("Theta");
+  nr_double_t a = getPropertyDouble ("I");
+  nr_double_t i = a * exp (-d * t * f) * sin (2 * M_PI * f * t + rad (p));
   setI (NODE_1, +i); setI (NODE_2, -i);
 }
