@@ -1,7 +1,7 @@
 /*
  * msline.cpp - microstrip transmission line class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: msline.cpp,v 1.45 2005/06/02 18:17:55 raimi Exp $
+ * $Id: msline.cpp,v 1.47 2006/01/30 07:45:35 raimi Exp $
  *
  */
 
@@ -43,7 +43,7 @@
 #include "msline.h"
 
 msline::msline () : circuit (2) {
-  alpha = beta = zl = 0;
+  alpha = beta = zl = ereff = 0;
   type = CIR_MSLINE;
 }
 
@@ -91,6 +91,7 @@ void msline::calcPropagation (nr_double_t frequency) {
 
   // calculate propagation constants and reference impedance
   zl    = ZlEffFreq;
+  ereff = ErEffFreq;
   alpha = ac + ad;
   beta  = sqrt (ErEffFreq) * 2 * M_PI * frequency / C0;
 }
@@ -112,6 +113,11 @@ void msline::calcSP (nr_double_t frequency) {
   setS (NODE_1, NODE_2, s21); setS (NODE_2, NODE_1, s21);
 }
 
+void msline::saveCharacteristics (nr_double_t) {
+  setCharacteristic ("Zl", zl);
+  setCharacteristic ("Er", ereff);
+}
+
 /* This function calculates the quasi-static impedance of a microstrip
    line, the value of the effective dielectric constant and the
    effective width due to the finite conductor thickness for the given
@@ -444,7 +450,7 @@ void msline::initDC (void) {
   nr_double_t t     = subst->getPropertyDouble ("t");
   nr_double_t rho   = subst->getPropertyDouble ("rho");
 
-  if (t != 0.0 && rho != 0.0) {
+  if (t != 0.0 && rho != 0.0 && l != 0.0) {
     // tiny resistance
     nr_double_t g = t * W / rho / l;
     setVoltageSources (0);
@@ -473,7 +479,7 @@ void msline::calcAC (nr_double_t frequency) {
   // calculate propagation constants
   calcPropagation (frequency);
 
-  // calculate S-parameters
+  // calculate Y-parameters
   complex g = rect (alpha, beta);
   complex y11 = coth (g * l) / zl;
   complex y21 = -cosech (g * l) / zl;
