@@ -1,7 +1,7 @@
 /*
  * msline.h - microstrip transmission line class definitions
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: msline.h,v 1.18 2005/06/02 18:17:56 raimi Exp $
+ * $Id: msline.h,v 1.19 2006/01/30 07:45:35 raimi Exp $
  *
  */
 
@@ -36,6 +36,7 @@ class msline : public circuit
   void initAC (void);
   void calcAC (nr_double_t);
   void calcNoiseAC (nr_double_t);
+  void saveCharacteristics (nr_double_t);
 
   static void analyseQuasiStatic (nr_double_t, nr_double_t, nr_double_t,
 				  nr_double_t, char *,
@@ -62,7 +63,7 @@ class msline : public circuit
 			   nr_double_t&, nr_double_t&);
 
  private:
-  nr_double_t alpha, beta, zl;
+  nr_double_t alpha, beta, zl, ereff;
 };
 
 #endif /* __MSLINE_H__ */
