@@ -1,7 +1,7 @@
 /*
  * resistor.h - resistor class definitions
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: resistor.h,v 1.12 2005/06/02 18:17:52 raimi Exp $
+ * $Id: resistor.h,v 1.14 2006/03/27 09:55:50 raimi Exp $
  *
  */
 
@@ -29,6 +29,7 @@ class resistor : public circuit
 {
  public:
   resistor ();
+  void initSP (void);
   void calcSP (nr_double_t);
   void calcNoiseSP (nr_double_t);
   void calcDC (void);
@@ -38,6 +39,10 @@ class resistor : public circuit
   void initAC (void);
   void calcTR (nr_double_t);
   void initTR (void);
+  void initHB (void);
+
+ private:
+  void initModel (void);
 };
 
 #endif /* __RESISTOR_H__ */
