@@ -1,7 +1,7 @@
 /*
  * tline.h - ideal transmission line class definitions
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: tline.h,v 1.5 2005/06/02 18:17:52 raimi Exp $
+ * $Id: tline.h,v 1.7 2006/03/02 08:06:03 raimi Exp $
  *
  */
 
@@ -33,6 +33,10 @@ class tline : public circuit
   void initDC (void);
   void initAC (void);
   void calcAC (nr_double_t);
+  void initTR (void);
+  void calcTR (nr_double_t);
+  void calcNoiseAC (nr_double_t);
+  void calcNoiseSP (nr_double_t);
 };
 
 #endif /* __TLINE_H__ */
