@@ -1,7 +1,7 @@
 /*
  * vccs.cpp - vccs class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vccs.cpp,v 1.12 2005/06/02 18:17:52 raimi Exp $
+ * $Id: vccs.cpp,v 1.17 2006/02/25 14:42:50 raimi Exp $
  *
  */
 
@@ -41,9 +41,6 @@
 
 vccs::vccs () : circuit (4) {
   type = CIR_VCCS;
-#if AUGMENTED
-  setVoltageSources (1);
-#endif
 }
 
 void vccs::calcSP (nr_double_t frequency) {
@@ -64,19 +61,11 @@ void vccs::calcSP (nr_double_t frequency) {
 }
 
 void vccs::initDC (void) {
+  setISource (false);
   allocMatrixMNA ();
-#if AUGMENTED
-  setC (VSRC_1, NODE_1, +1.0); setC (VSRC_1, NODE_2, +0.0);
-  setC (VSRC_1, NODE_3, +0.0); setC (VSRC_1, NODE_4, -1.0);
-  setB (NODE_1, VSRC_1, +0.0); setB (NODE_2, VSRC_1, +1.0);
-  setB (NODE_3, VSRC_1, -1.0); setB (NODE_4, VSRC_1, +0.0);
-  setD (VSRC_1, VSRC_1, -1.0 / getPropertyDouble ("G"));
-  setE (VSRC_1, +0.0);
-#else
   nr_double_t g = getPropertyDouble ("G");
   setY (NODE_2, NODE_1, +g); setY (NODE_3, NODE_4, +g);
   setY (NODE_3, NODE_1, -g); setY (NODE_2, NODE_4, -g);
-#endif
 }
 
 void vccs::initAC (void) {
@@ -85,13 +74,30 @@ void vccs::initAC (void) {
 
 void vccs::calcAC (nr_double_t frequency) {
   nr_double_t t = getPropertyDouble ("T");
-#if AUGMENTED
-  nr_double_t g = getPropertyDouble ("G");
-  complex r = polar (1.0 / g, - 2.0 * M_PI * frequency * t);
-  setD (VSRC_1, 1, -r);
-#else
   complex g = polar (getPropertyDouble ("G"), - 2.0 * M_PI * frequency * t);
   setY (NODE_2, NODE_1, +g); setY (NODE_3, NODE_4, +g);
   setY (NODE_3, NODE_1, -g); setY (NODE_2, NODE_4, -g);
-#endif
+}
+
+void vccs::initTR (void) {
+  nr_double_t t = getPropertyDouble ("T");
+  initDC ();
+  deleteHistory ();
+  if (t > 0.0) {
+    setISource (true);
+    setHistory (true);
+    initHistory (t);
+    clearY ();
+  }
+}
+
+void vccs::calcTR (nr_double_t t) {
+  nr_double_t T = getPropertyDouble ("T");
+  if (T > 0.0) {
+    T = t - T;
+    nr_double_t g = getPropertyDouble ("G");
+    nr_double_t v = getV (NODE_1, T) - getV (NODE_4, T);
+    setI (NODE_2, -g * v);
+    setI (NODE_3, +g * v);
+  }
 }
