@@ -1,7 +1,7 @@
 /*
  * vcvs.cpp - vcvs class implementation
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vcvs.cpp,v 1.11 2005/06/02 18:17:52 raimi Exp $
+ * $Id: vcvs.cpp,v 1.14 2006/02/25 14:42:50 raimi Exp $
  *
  */
 
@@ -82,3 +82,24 @@ void vcvs::calcAC (nr_double_t frequency) {
   complex g = polar (getPropertyDouble ("G"), - 2.0 * M_PI * frequency * t);
   setC (VSRC_1, NODE_1, +g); setC (VSRC_1, NODE_4, -g);
 }
+
+void vcvs::initTR (void) {
+  nr_double_t t = getPropertyDouble ("T");
+  initDC ();
+  deleteHistory ();
+  if (t > 0.0) {
+    setHistory (true);
+    initHistory (t);
+    setC (VSRC_1, NODE_1, 0.0); setC (VSRC_1, NODE_4, 0.0);
+  }
+}
+
+void vcvs::calcTR (nr_double_t t) {
+  nr_double_t T = getPropertyDouble ("T");
+  if (T > 0.0) {
+    T = t - T;
+    nr_double_t g = getPropertyDouble ("G");
+    nr_double_t v = getV (NODE_4, T) - getV (NODE_1, T);
+    setE (VSRC_1, g * v);
+  }
+}
