@@ -1,7 +1,7 @@
 /*
  * vcvs.h - vcvs class definitions
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vcvs.h,v 1.7 2005/06/02 18:17:52 raimi Exp $
+ * $Id: vcvs.h,v 1.9 2006/02/23 09:02:01 raimi Exp $
  *
  */
 
@@ -33,6 +33,8 @@ class vcvs : public circuit
   void initDC (void);
   void initAC (void);
   void calcAC (nr_double_t);
+  void initTR (void);
+  void calcTR (nr_double_t);
 };
 
 #endif /* __VCVS_H__ */
