@@ -1,7 +1,7 @@
 /*
  * constants.h - global natural constant header file
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: constants.h,v 1.2 2005/06/02 18:17:49 raimi Exp $
+ * $Id: constants.h,v 1.4 2005/12/19 07:55:13 raimi Exp $
  *
  */
 
@@ -26,6 +26,7 @@
 #define __CONSTANTS_H__
 
 #include "consts.h"
+#include "precision.h"
 
 #define C0   299792458.0              /* speed of light in vacuum  */
 #define kB   1.380650524e-23          /* Boltzmann constant        */
@@ -37,11 +38,23 @@
 #define Z0   376.73031346958504364963 /* wave resistance in vacuum */
 #define T0   290                      /* standard temperature      */
 
-#define kBoverQ 0.86173433260414314916e-4
-#define QoverkB 1.16045045690360379713e+4
-#define ESiO2   3.9
-#define Ni      1.45e16
-#define ESi     11.7
+#define kBoverQ    0.86173433260414314916e-4
+#define QoverkB    1.16045045690360379713e+4
+
+#define ESiO2      3.9     /* relative permittivity */
+#define ESi        11.7
+#define EGe        15.8
+#define EGaAs      13.1
+#define NiSi       1.45e16 /* intrinsic carrier concentration in 1/m^3 */
+#define NiGe       2.40e19
+#define NiGaAa     9.00e12
+#define EgSi       1.11    /* energy gap at 300K in eV */
+#define EgSchottky 0.69
+#define EgGe       0.67
+#define EgGaAs     1.43
+#define Eg0Si      1.16    /* energy gap at 0K in eV */
+
+#define GMin       NR_TINY
 
 #define sqr(x)    ((x) * (x))
 #define cubic(x)  ((x) * (x) * (x))
