@@ -1,7 +1,7 @@
 /*
  * qucs_producer.cpp - the Qucs netlist producer
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: qucs_producer.cpp,v 1.9 2005/06/02 18:17:56 raimi Exp $
+ * $Id: qucs_producer.cpp,v 1.16 2006/01/09 09:11:07 raimi Exp $
  *
  */
 
@@ -33,12 +33,15 @@
 
 #include "netdefs.h"
 #include "check_spice.h"
+#include "check_vcd.h"
+#include "hash.h"
 
 /* Global variables. */
 FILE * qucs_out = NULL;
 int    qucs_actions = 1;
 char * qucs_gnd = "gnd";
-struct node_t * qucs_nodes = NULL;
+
+qucs::hash<struct node_t> qucs_nodes;
 
 /* Looks through the given list if there is such a node already in the
    list and returns non-zero if so, otherwise the function returns
@@ -53,18 +56,28 @@ int qucs_find_node (struct node_t * root, char * node) {
 /* Adds the given node list to the overall node list without
    duplicating the nodes. */
 void qucs_add_nodes (struct node_t * node) {
-  struct node_t * n;
   while (node) {
-    if (!qucs_find_node (qucs_nodes, node->node)) {
-      n = create_node ();
-      n->node = strdup (node->node);
-      n->next = qucs_nodes;
-      qucs_nodes = n;
-    }
+    if (!qucs_nodes.get (node->node))
+      qucs_nodes.put (node->node, node);
     node = node->next;
   }
 }
 
+/* Deletes the given node list. */
+void qucs_free_nodes (struct node_t * node) {
+  struct node_t * n;
+  for ( ; node; node = n) {
+    n = node->next;
+    if (node->node) free (node->node);
+    free (node);
+  }
+}
+
+/* The function deletes the collected qucs nodes. */
+static void qucs_delete_nodes (void) {
+  qucs_nodes.clear ();
+}
+
 /* Collects all nodes within the given definition root. */
 static void qucs_collect_nodes (struct definition_t * root) {
   while (root) {
@@ -173,7 +186,6 @@ static void netlist_list (void) {
   fprintf (qucs_out, "# converted Qucs netlist processed at %s\n", ctime (&t));
   if (spice_title != NULL) {
     fprintf (qucs_out, "#\n# %s#\n\n", spice_title);
-    free (spice_title);
   }
   netlist_lister (definition_root, "");
   for (def = subcircuit_root; def != NULL; def = def->next) {
@@ -184,9 +196,11 @@ static void netlist_list (void) {
   /* Print overall (toplevel only) node list. */
   qucs_collect_nodes (definition_root);
   fprintf (qucs_out, "\n### TOPLEVEL NODELIST BEGIN\n");
-  for (n = qucs_nodes; n; n = n->next) {
+  for (qucs::hashiterator<struct node_t> it (qucs_nodes); *it; ++it) {
+    n = it.currentVal ();
     fprintf (qucs_out, "# %s\n", n->node);
   }
+  qucs_delete_nodes ();
   fprintf (qucs_out, "### TOPLEVEL NODELIST END\n");
   /* Print potential external node list. */
   fprintf (qucs_out, "\n### SPICE OUTPUT NODELIST BEGIN\n");
@@ -208,6 +222,7 @@ void qucs_producer (void) {
 struct device_t {
   char * ntype;     // netlist type
   char * ltype;     // schematic type
+  char * stype;     // spice type
   int nodes;        // number of nodes
   char * props[64]; // list of properties in schematic order
   char * symbol;    // symbol text
@@ -216,9 +231,10 @@ struct device_t {
 }
 qucs_devices[] = {
   /* diode */
-  { "Diode", "Diode", 2,
+  { "Diode", "Diode", "D", 2,
     {"Is", "N", "Cj0", "M", "Vj", "Fc", "Cp", "Isr", "Nr", "Rs", "Tt", "Temp",
-     "Kf", "Af", "Ffe", "Bv", "Ibv", NULL },
+     "Kf", "Af", "Ffe", "Bv", "Ibv", "Xti", "Eg", "Tbv", "Trs", "Ttt1", "Ttt2",
+     "Tm1", "Tm2", "Tnom", "Area", NULL },
     "  <.PortSym -30 0 1>\n"
     "  <.PortSym 30 0 2>\n"
     "  <Line -10 -10 0 20 #000080 2 1>\n"
@@ -228,17 +244,18 @@ qucs_devices[] = {
     "  <Line 10 -10 0 20 #000080 2 1>\n"
     "  <Line -30 0 20 0 #000080 2 1>\n"
     "  <.ID -30 24 %s_>\n",
-    "1 130 60 -26 13 0 0",
+    "1 0 0 -26 13 0 0",
+    /*"1 130 60 -26 13 0 0",*/
     "  <Port P1 1 100 60 -23 -44 1 0 \"1\" 1>\n"
     "  <Port P2 1 160 60 4 -44 0 2 \"2\" 1>\n"
   },
   /* bipolar transistor */
-  { "BJT", "BJT", 4,
+  { "BJT", "_BJT", "Q", 4,
     { "Type", "Is", "Nf", "Nr", "Ikf", "Ikr", "Vaf", "Var", "Ise", "Ne", "Isc",
       "Nc", "Bf", "Br", "Rbm", "Irb", "Rc", "Re", "Rb", "Cje", "Vje", "Mje",
       "Cjc", "Vjc", "Mjc", "Xcjc", "Cjs", "Vjs", "Mjs", "Fc", "Tf", "Xtf",
       "Vtf", "Itf", "Tr", "Temp", "Kf", "Af", "Ffe", "Kb", "Ab", "Fb", "Ptf",
-      NULL },
+      "Xtb", "Xti", "Eg", "Tnom", "Area", NULL },
     "  <.PortSym -50 0 1>\n"
     "  <.PortSym 0 -50 2>\n"
     "  <.PortSym 0 50 3>\n"
@@ -253,16 +270,18 @@ qucs_devices[] = {
     "  <Line 0 -10 0 20 #000080 2 1>\n"
     "  <Ellipse -40 -30 60 60 #000080 0 1 #c0c0c0 1 0>\n"
     "  <.ID 13 28 %s_>\n",
-    "1 170 160 92 -49 0 0",
+    "1 0 0 8 -26 0 0",
+    /*"1 170 160 92 -49 0 0",*/
     "  <Port P2 1 170 130 -51 -23 0 3 \"2\" 1>\n"
     "  <Port P1 1 140 160 -23 12 0 0 \"1\" 1>\n"
     "  <Port P3 1 170 190 12 4 0 1 \"3\" 1>\n"
     "  <Port P4 1 200 160 4 -44 0 2 \"4\" 1>\n"
   },
   /* junction FET */
-  { "JFET", "JFET", 3,
+  { "JFET", "JFET", "J", 3,
     { "Type", "Vt0", "Beta", "Lambda", "Rd", "Rs", "Is", "N", "Isr", "Nr",
-      "Cgs", "Cgd", "Pb", "Fc", "M", "Kf", "Af", "Ffe", "Temp", NULL },
+      "Cgs", "Cgd", "Pb", "Fc", "M", "Kf", "Af", "Ffe", "Temp", "Xti",
+      "Vt0tc", "Betatce", "Tnom", "Area", NULL },
     "  <.PortSym -50 0 1>\n"
     "  <.PortSym 0 -50 2>\n"
     "  <.PortSym 0 50 3>\n"
@@ -280,12 +299,12 @@ qucs_devices[] = {
     "  <Port P3 1 190 170 -33 32 0 1 \"3\" 1>\n"
   },
   /* MOSFET */
-  { "MOSFET", "MOSFET", 4,
+  { "MOSFET", "_MOSFET", "M", 4,
     { "Type", "Vt0", "Kp", "Gamma", "Phi", "Lambda", "Rd", "Rs", "Rg", "Is",
       "N", "W", "L", "Ld", "Tox", "Cgso", "Cgdo", "Cgbo", "Cbd", "Cbs", "Pb",
       "Mj", "Fc", "Cjsw", "Mjsw", "Tt", "Nsub", "Nss", "Tpg", "Uo", "Rsh",
       "Nrd", "Nrs", "Cj", "Js", "Ad", "As", "Pd", "Ps", "Kf", "Af", "Ffe",
-      "Temp", NULL },
+      "Temp", "Tnom", NULL },
     "  <.PortSym -40 0 1>\n"
     "  <.PortSym 10 -50 2>\n"
     "  <.PortSym 10 50 3>\n"
@@ -300,13 +319,14 @@ qucs_devices[] = {
     "  <Line -10 -15 0 30 #000080 2 1>\n"
     "  <Ellipse -30 -30 60 60 #000080 0 1 #c0c0c0 1 0>\n"
     "  <.ID 30 34 %s_>\n",
-    "1 180 170 73 -51 0 0",
+    "1 0 0 8 -26 0 0",
+    /*"1 180 170 73 -51 0 0",*/
     "  <Port P1 1 150 170 -23 12 0 0 \"1\" 1>\n"
     "  <Port P2 1 180 140 -51 -23 0 3 \"2\" 1>\n"
     "  <Port P3 1 180 200 12 4 0 1 \"3\" 1>\n"
     "  <Port P4 1 200 170 4 -44 0 2 \"4\" 1>\n"
   },
-  { NULL, NULL, 0, { NULL }, NULL, NULL, NULL }
+  { NULL, NULL, NULL, 0, { NULL }, NULL, NULL, NULL }
 };
 
 /* Looks through the list of available Qucs devices.  Returns NULL if
@@ -340,35 +360,53 @@ static void qucslib_list_device (struct definition_t * def) {
   if (!(dev = qucslib_find_device (def->type))) return;
   struct pair_t * pair;
   char txt[1024];
-  // print symbol definition
-  fprintf (qucs_out, "<Symbol>\n");
-  sprintf (txt, dev->symbol, def->instance);
+  
+  sprintf (txt, "\n<Component %s>\n", def->instance[0] == dev->stype[0] ?
+	   &def->instance[1] : def->instance);
   fprintf (qucs_out, txt);
-  fprintf (qucs_out, "</Symbol>\n");
-  // print coponent definitions
-  fprintf (qucs_out, "<Components>\n");
-  fprintf (qucs_out, "  <%s %s %s", dev->ltype, def->instance, dev->coords);
+  fprintf (qucs_out, "  <Description>\n");
+  fprintf (qucs_out, "  </Description>\n");
+  fprintf (qucs_out, "  <Model>\n");
+  fprintf (qucs_out, "    <%s %s_ %s", dev->ltype, def->instance, dev->coords);
   for (int i = 0; dev->props[i]; i++) {
     if ((pair = qucslib_find_prop (def, dev->props[i])) != NULL) {
       fprintf (qucs_out, " \"");
       netlist_list_value (pair->value);
-      fprintf (qucs_out, "\" 1");
+      fprintf (qucs_out, "\" 0");
     }
   }
   fprintf (qucs_out, ">\n");
-  // print subcircuit port definitions
-  fprintf (qucs_out, dev->ports);
-  fprintf (qucs_out, "</Components>\n");
+  fprintf (qucs_out, "  </Model>\n");
+  fprintf (qucs_out, "</Component>\n");
 }
 
 /* This function is the overall Qucs library producer. */
 void qucslib_producer (void) {
   struct definition_t * def;
-  time_t t = time (NULL);
-  fprintf (qucs_out, "# converted Qucs library processed at %s\n", ctime (&t));
+  fprintf (qucs_out, "<Qucs Library " PACKAGE_VERSION " \"Generic\">\n");
   for (def = device_root; def; def = def->next) {
-    fprintf (qucs_out, "<Device>\n");
     qucslib_list_device (def);
-    fprintf (qucs_out, "</Device>\n\n");
+  }
+}
+
+/* This function is the overall Qucs dataset producer. */
+void qucsdata_producer (void) {
+  struct dataset_variable * ds;
+  struct dataset_value * dv;
+  fprintf (qucs_out, "<Qucs Dataset " PACKAGE_VERSION ">\n");
+  for (ds = dataset_root; ds; ds = ds->next) {
+    if (!ds->output || ds->type == DATA_UNKNOWN)
+      continue;
+    if (ds->type == DATA_INDEPENDENT)
+      fprintf (qucs_out, "<indep %s %d>\n", ds->ident, ds->size);
+    else if (ds->type == DATA_DEPENDENT)
+      fprintf (qucs_out, "<dep %s.X %s>\n", ds->ident, ds->dependencies);
+    for (dv = ds->values; dv; dv = dv->next) {
+      fprintf (qucs_out, "  %s\n", dv->value);
+    }
+    if (ds->type == DATA_INDEPENDENT)
+      fprintf (qucs_out, "</indep>\n");
+    else if (ds->type == DATA_DEPENDENT)
+      fprintf (qucs_out, "</dep>\n");
   }
 }
