@@ -1,7 +1,7 @@
 /*
  * dataset.cpp - dataset class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: dataset.cpp,v 1.14 2005/06/02 18:17:49 raimi Exp $
+ * $Id: dataset.cpp,v 1.17 2006/03/27 09:55:49 raimi Exp $
  *
  */
 
@@ -342,11 +342,8 @@ void dataset::printVariable (vector * v, FILE * f) {
   // print data header
   fprintf (f, "<dep %s", v->getName ());
   if (v->getDependencies () != NULL) {
-    struct strlist_t * root = v->getDependencies()->getRoot ();
-    while (root != NULL) {
-      fprintf (f, " %s", root->str);
-      root = root->next;
-    }
+    for (strlistiterator it (v->getDependencies ()); *it; ++it)
+      fprintf (f, " %s", *it);
   }
   fprintf (f, ">\n");
   
@@ -364,10 +361,10 @@ void dataset::printData (vector * v, FILE * f) {
   for (int i = 0; i < v->getSize (); i++) {
     complex c = v->get (i);
     if (imag (c) == 0.0) {
-      fprintf (f, "  %+.11e\n", (double) real (c));
+      fprintf (f, "  %+." NR_DECS "e\n", (double) real (c));
     }
     else {
-      fprintf (f, "  %+.11e%cj%.11e\n", (double) real (c), 
+      fprintf (f, "  %+." NR_DECS "e%cj%." NR_DECS "e\n", (double) real (c), 
 	       imag (c) >= 0.0 ? '+' : '-', (double) fabs (imag (c)));
     }
   }
@@ -383,6 +380,7 @@ dataset * dataset::load (const char * file) {
     return NULL;
   }
   dataset_in = f;
+  dataset_restart (dataset_in);
   if (dataset_parse () != 0) {
     fclose (f);
     return NULL;
@@ -394,6 +392,8 @@ dataset * dataset::load (const char * file) {
       return NULL;
     }
   }
+  fclose (f);
+  dataset_lex_destroy ();
   dataset_result->setFile (file);
   return dataset_result;
 }
@@ -408,6 +408,7 @@ dataset * dataset::load_touchstone (const char * file) {
     return NULL;
   }
   touchstone_in = f;
+  touchstone_restart (touchstone_in);
   if (touchstone_parse () != 0) {
     fclose (f);
     return NULL;
@@ -416,6 +417,8 @@ dataset * dataset::load_touchstone (const char * file) {
     fclose (f);
     return NULL;
   }
+  fclose (f);
+  touchstone_lex_destroy ();
   touchstone_result->setFile (file);
   return touchstone_result;
 }
