@@ -1,7 +1,7 @@
 /*
  * dcsolver.cpp - DC solver class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: dcsolver.cpp,v 1.38 2005/06/02 18:17:49 raimi Exp $
+ * $Id: dcsolver.cpp,v 1.40 2006/05/03 09:43:56 raimi Exp $
  *
  */
 
@@ -142,6 +142,7 @@ void dcsolver::solve (void) {
 		  "#%d (%s)\n", getName (), getDescription (), fallback,
 		  getHelperDescription ());
 	retry++;
+	restart ();
       }
       else {
 	retry = -1;
@@ -180,6 +181,15 @@ void dcsolver::init (void) {
   }
 }
 
+/* Goes through the list of non-linear circuit objects and runs its
+   restartDC() function. */
+void dcsolver::restart (void) {
+  circuit * root = subnet->getRoot ();
+  for (circuit * c = root; c != NULL; c = (circuit *) c->getNext ()) {
+    if (c->isNonLinear ()) c->restartDC ();
+  }
+}
+
 /* Goes through the list of non-linear circuit objects and runs its
    saveOperatingPoints() function. */
 void dcsolver::saveOperatingPoints (void) {
