@@ -1,7 +1,7 @@
 /*
  * equation.cpp - checker for the Qucs equations
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: equation.cpp,v 1.34 2005/06/02 18:17:49 raimi Exp $
+ * $Id: equation.cpp,v 1.41 2006/03/24 14:30:05 raimi Exp $
  *
  */
 
@@ -30,6 +30,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include <ctype.h>
 
 #include "logging.h"
 #include "complex.h"
@@ -42,6 +43,7 @@
 #include "equation.h"
 #include "evaluate.h"
 #include "constants.h"
+#include "range.h"
 #include "exception.h"
 #include "exceptionstack.h"
 
@@ -49,8 +51,9 @@ using namespace eqn;
 using namespace qucs;
 
 /* The global list of equations and expression lists. */
-node * eqn::equations = NULL;
-node * eqn::expressions = NULL;
+node   * eqn::equations = NULL;
+node   * eqn::expressions = NULL;
+solver * eqn::solve = NULL;
 
 #define A(a) ((assignment *) (a))
 #define N(n) ((node *) (n))
@@ -60,17 +63,41 @@ node * eqn::expressions = NULL;
 // Constructor creates an untyped instance of the constant class.
 constant::constant () : node (CONSTANT) {
   type = TAG_UNKNOWN;
+  dataref = false;
   setType (type);
 }
 
 // This constructor creates an typed instance of the constant class.
 constant::constant (int tag) : node (CONSTANT) {
   type = tag;
+  dataref = false;
   setType (type);
 }
 
 // Destructor deletes an instance of the constant class.
 constant::~constant () {
+  if (!dataref) {
+    switch (type) {
+    case TAG_COMPLEX:
+      delete c;
+      break;
+    case TAG_VECTOR:
+      delete v;
+      break;
+    case TAG_MATRIX:
+      delete m;
+      break;
+    case TAG_MATVEC:
+      delete mv;
+      break;
+    case TAG_STRING:
+      free (s);
+      break;
+    case TAG_RANGE:
+      delete r;
+      break;
+    }
+  }
 }
 
 /* Depending on the type of constant the function prints the textual
@@ -150,7 +177,7 @@ char * constant::toString (void) {
     txt = strdup (str);
     break;    
   case TAG_RANGE:
-    txt = strdup (":");
+    txt = strdup (r->toString ());
     break;    
   default:
     txt = strdup ("(no such type)");
@@ -196,11 +223,26 @@ char * reference::toString (void) {
 // Adds the name of the reference to the list of dependencies.
 void reference::addDependencies (strlist * depends) {
   depends->add (n);
-  // Additionally find and save the actual equation reference.
-  for (node * eqn = eqn::equations; eqn != NULL; eqn = eqn->getNext ()) {
-    if (!strcmp (n, A(eqn)->result)) {
-      ref = eqn;
-      break;
+  findVariable ();
+}
+
+// Find and save the actual equation reference.
+void reference::findVariable (void) {
+  if (!ref) {
+    node * eqn;
+    for (eqn = eqn::equations; eqn; eqn = eqn->getNext ()) {
+      if (!strcmp (n, A(eqn)->result)) {
+	ref = eqn;
+	break;
+      }
+    }
+    if (eqn::solve && !ref) {
+      for (eqn = eqn::solve->getEquations (); eqn; eqn = eqn->getNext ()) {
+	if (!strcmp (n, A(eqn)->result)) {
+	  ref = eqn;
+	  break;
+	}
+      }
     }
   }
 }
@@ -208,6 +250,7 @@ void reference::addDependencies (strlist * depends) {
 // Returns the type of reference.
 int reference::evalType (void) {
   setType (TAG_UNKNOWN);
+  findVariable ();
   if (ref != NULL) {
     setType (A(ref)->body->evalType ());
   }
@@ -217,6 +260,7 @@ int reference::evalType (void) {
 // Returns the actual result of the reference.
 constant * reference::evaluate (void) {
   setResult (NULL);
+  findVariable ();
   if (ref != NULL) {
     setResult (A(ref)->body->getResult ());
   }
@@ -264,6 +308,12 @@ int assignment::evalType (void) {
 constant * assignment::evaluate (void) {
   body->solvee = solvee;
   setResult (body->evaluate ());
+  // inherit drop/prep dependencies
+  if (body->dropdeps) {
+    getResult()->dropdeps = body->dropdeps;
+    strlist * preps = body->getPrepDependencies ();
+    if (preps) getResult()->addPrepDependencies (preps->get (0));
+  }
   return getResult ();
 }
 
@@ -277,11 +327,12 @@ application::application () : node (APPLICATION) {
 
 // Destructor deletes an instance of the application class.
 application::~application () {
-  node * next;
+  node * next, * res;
   for (node * arg = args; arg != NULL; arg = next) {
     next = arg->getNext ();
     delete arg;
   }
+  if ((res = getResult ()) != NULL) delete res;
   if (n) free (n);
 }
 
@@ -338,10 +389,58 @@ void application::addDependencies (strlist * depends) {
   }  
 }
 
+/* This function goes through the arguments of an application and
+   evaluates their return types. */
+void application::evalTypeArgs (void) {
+  for (node * arg = args; arg != NULL; arg = arg->getNext ()) {
+    // Skip evaluating generated reference variables.
+    if (arg->getTag () == REFERENCE)
+      if (checker::isGenerated (R (arg)->n))
+	continue;
+    // Evaluate the type of argument.
+    arg->evalType ();
+  }
+}
+
+#include "gperfapphash.cpp"
+
+/* The function creates a hash key for the given type of
+   application. */
+char * application::createKey (void) {
+  char * key = (char *) calloc (1, strlen (n) + nargs * 3 + 5);
+  strcat (key, n);
+  for (node * arg = args; arg != NULL; arg = arg->getNext ()) {
+    strcat (key, "_");
+    strcat (key, checker::tag2key (arg->getType ()));
+  }
+  return key;
+}
+
+/* This function returns the return type of the application using a
+   gperf-generated hash. */
+int application::evalTypeFast (void) {
+  char * key = createKey ();
+  struct appindex * idx = gperfapphash::get (key, strlen (key));
+  free (key);
+  if (idx != NULL) {
+    application_t * app = &applications[idx->index];
+    if (app->eval) {
+      eval = app->eval;
+      setType (app->retval);
+    }
+  }
+  return getType ();
+}
+
 /* Returns the type of application and applies the appropriate
    evaluation function if any. */
 int application::evalType (void) {
   setType (TAG_UNKNOWN);
+  // Evaluate type of arguments.
+  evalTypeArgs ();
+  // Try the fast method.
+  if (evalTypeFast () != TAG_UNKNOWN) return getType ();
+
   // Go through the list of available applications.
   for (int i = 0; applications[i].application != NULL; i++) {
     application_t * app = &applications[i];
@@ -352,7 +451,12 @@ int application::evalType (void) {
       if (nargs != app->nargs) continue;
       // The correct types of arguments?
       for (node * arg = args; arg != NULL; arg = arg->getNext (), nr++) {
-	if (!(arg->evalType () & app->args[nr])) { nr = -1; break; }
+	if (arg->getTag () == REFERENCE)
+	  // Skip checking generated reference variables.
+	  if (checker::isGenerated (R (arg)->n))
+	    continue;
+	// Evaluate and check the type of argument.
+	if (!(arg->getType () & app->args[nr])) { nr = -1; break; }
       }
       if (nr == -1) continue;
       // A valid application function?
@@ -374,20 +478,42 @@ int application::evalType (void) {
 /* This function runs the actual evaluation function and the returns
    the result. */
 constant * application::evaluate (void) {
+  int errors = 0;
   // first evaluate each argument
   for (node * arg = args; arg != NULL; arg = arg->getNext ()) {
     if (arg->evaluated == 0) {
       arg->solvee = solvee;
       arg->evaluate ();
-      arg->evaluated++;
+      if (arg->getResult () == NULL) {
+	if (arg->getTag () == REFERENCE) {
+	  logprint (LOG_ERROR, "evaluate error, no such generated variable "
+		    "`%s'\n", arg->toString ());
+	}
+	else {
+	  logprint (LOG_ERROR, "evaluate error, unable to evaluate "
+		    "`%s'\n", arg->toString ());
+	}
+	errors++;
+      }
+      else {
+	// inherit drop/prep dependencies
+	if (arg->getResult()->dropdeps) {
+	  dropdeps = arg->getResult()->dropdeps;
+	  strlist * preps = arg->getResult()->getPrepDependencies ();
+	  if (preps) addPrepDependencies (preps->get (0));
+	}
+	arg->evaluated++;
+      }
     }
   }
-  // then evaluate the application
-  setResult (eval (C (args)));
-  // check the returned type once again
-  if (getResult()->getType () != getType ()) {
-    logprint (LOG_ERROR, "evaluate error, function `%s' returned invalid "
-	      "constant type\n", toString ());
+  if (!errors) {
+    // then evaluate the application
+    setResult (eval (C (args)));
+    // check the returned type once again
+    if (getResult()->getType () != getType ()) {
+      logprint (LOG_ERROR, "evaluate error, function `%s' returned invalid "
+		"constant type\n", toString ());
+    }
   }
   return getResult ();
 }
@@ -570,12 +696,46 @@ void node::setDataDependencies (strlist * deps) {
 /* Evaluates the equation node and applies the data dependencies. */
 constant * node::calculate (void) {
   constant * res = evaluate ();
-  strlist * deps = solvee->collectDataDependencies (this);
-  getResult()->setDataDependencies (deps);
-  delete deps;
+  if (getResult ()) {
+    strlist * deps = solvee->collectDataDependencies (this);
+    getResult()->setDataDependencies (deps);
+    if (deps) delete deps;
+  }
+  else {
+    qucs::exception * e = new qucs::exception (EXCEPTION_MATH);
+    e->setText ("evaluator exception"); throw_exception (e);
+  }
   return res;
 }
 
+/* Collects the equation dependencies for a specific node. */
+strlist * node::collectDependencies (void) {
+  strlist * depends = new strlist ();
+  addDependencies (depends);
+  setDependencies (checker::foldDependencies (depends));
+  return getDependencies ();
+}
+
+/* Collects the data dependencies for a specific node. */
+strlist * node::collectDataDependencies (void) {
+  strlist * deps = getResult()->getDataDependencies ();
+  if (deps) {
+    // data dependencies already collected
+    setDataDependencies (deps);
+    return deps;
+  }
+  // collect equation dependencies
+  if (!getDependencies ())
+    collectDependencies ();
+  if (solvee) {
+    // finally collect the appropriate data dependencies
+    deps = solvee->collectDataDependencies (this);
+    setDataDependencies (deps);
+    delete deps;
+  }
+  return getDataDependencies ();
+}
+
 // Constructor creates an instance of the checker class.
 checker::checker () {
   equations = NULL;
@@ -673,6 +833,20 @@ void checker::list (void) {
   }
 }
 
+/* Checks whether the variable name is a generated name which is
+   identified by a ".[0-9]{4}" suffix. */
+int checker::isGenerated (char * var) {
+  int len = strlen (var);
+  if (len > 5) {
+    if (isdigit (var[len-1]) && isdigit (var[len-2]) &&
+	isdigit (var[len-3]) && isdigit (var[len-4]) &&
+	var[len-5] == '.') {
+      return 1;
+    }
+  }
+  return 0;
+}
+
 /* This function checks whether the variable references could be
    resolved within the equations and returns zero if so. */
 int checker::findUndefined (int noundefined) {
@@ -685,6 +859,7 @@ int checker::findUndefined (int noundefined) {
       char * var = depends->get (i);
       if (idents->contains (var) <= 0) {
 	if (noundefined) {
+	  if (isGenerated (var)) continue;
 	  logprint (LOG_ERROR, "checker error, undefined variable `%s' in "
 		    "equation `%s'\n", var, eqn->result);
 	  err++;
@@ -824,16 +999,17 @@ void checker::reorderEquations (void) {
   // Go through the list of equations.
   for (node * eqn = equations; eqn != NULL; eqn = next) {
     strlist * deps = eqn->getDependencies ();
-    int i, found;
+    int i, found, gens;
     next = eqn->getNext ();
     /* Check whether the variable dependencies can be found in
        previous equations. */
-    for (found = i = 0; i < deps->length (); i++) {
+    for (found = gens = i = 0; i < deps->length (); i++) {
       char * var = deps->get (i);
       if (findEquation (root, var) != NULL) found++;
+      if (isGenerated (var)) gens++;
     }
     // Yes.
-    if (found == deps->length ()) {
+    if (found == (deps->length () - gens)) {
       /* Remove the equation from the current list and append it to
          the new list. */
       dropEquation (eqn);
@@ -922,7 +1098,7 @@ void solver::solve (void) {
       eqn->evaluated++;
 #if DEBUG
       logprint (LOG_STATUS, "%s = %s\n", A(eqn)->result, 
-		eqn->getResult()->toString ());
+		eqn->getResult () ? eqn->getResult()->toString () : "error");
 #endif
     }
   }
@@ -930,9 +1106,10 @@ void solver::solve (void) {
 
 /* This function adds the given dataset vector to the set of equations
    stored in the equation solver. */
-node * solver::addEquationData (vector * v) {
+node * solver::addEquationData (vector * v, bool ref) {
   constant * con = new constant (TAG_VECTOR);
   con->v = v;
+  con->dataref = ref;
   assignment * assign = new assignment ();
   assign->result = strdup (v->getName ());
   assign->body = con;
@@ -968,6 +1145,7 @@ node * solver::addGeneratedEquation (vector * v, char * n) {
    given equation node to one or more valid dataset vector(s). */
 vector * solver::dataVector (node * eqn) {
   vector * v = NULL;
+  if (!eqn->getResult ()) return NULL;
   switch (eqn->getType ()) {
   case TAG_VECTOR: // simple vector
     v = new vector (* (eqn->getResult()->v));
@@ -1027,7 +1205,7 @@ void solver::checkinDataset (void) {
   findMatrixVectors (data->getVariables ());
   for (v = data->getDependencies (); v != NULL; v = (vector *) v->getNext ()) {
     if (v->getRequested () != -1) {
-      node * eqn = addEquationData (v);
+      node * eqn = addEquationData (v, true);
       strlist * deps = new strlist ();
       deps->add (v->getName ());
       eqn->setDataDependencies (deps);
@@ -1036,7 +1214,7 @@ void solver::checkinDataset (void) {
   }
   for (v = data->getVariables (); v != NULL; v = (vector *) v->getNext ()) {
     if (v->getRequested () != -1) {
-      node * eqn = addEquationData (v);
+      node * eqn = addEquationData (v, true);
       eqn->setDataDependencies (v->getDependencies ());
     }
   }
@@ -1188,11 +1366,23 @@ int solver::dataSize (strlist * deps) {
   return size;
 }
 
+/* The function returns the data vector in the dataset according to
+   the given variable name.  If there is no such variable, it returns
+   NULL. */
+vector * solver::getDataVector (char * str) {
+  vector * var;
+  if ((var = data->findVariable (str)) != NULL)
+    return var;
+  if ((var = data->findDependency (str)) != NULL)
+    return var;
+  return NULL;
+}
+
 /* The following function collects the inherited dataset dependencies
    for the given equation node and returns it as a string list.  It
    returns NULL if there are no such dependencies. */
 strlist * solver::collectDataDependencies (node * eqn) {
-  strlist * sub, * datadeps = NULL;
+  strlist * sub = NULL, * datadeps = NULL;
   if (!eqn->getResult()->dropdeps) {
     strlist * deps = eqn->getDependencies ();
     datadeps = eqn->getDataDependencies ();
@@ -1200,18 +1390,23 @@ strlist * solver::collectDataDependencies (node * eqn) {
     for (int i = 0; deps && i < deps->length (); i++) {
       char * var = deps->get (i);
       node * n = checker::findEquation (eqn::equations, var);
-      sub = strlist::join (datadeps, n->getDataDependencies ());
-      sub->del (n->getResult()->getDropDependencies ());
-      sub->add (n->getResult()->getPrepDependencies ());
+      if (n == NULL && eqn->solvee != NULL)
+	n = checker::findEquation (eqn->solvee->getEquations (), var);
+      if (n != NULL) {
+	sub = strlist::join (datadeps, n->getDataDependencies ());
+	sub->del (n->getResult()->getDropDependencies ());
+	sub->add (n->getResult()->getPrepDependencies ());
+      }
       if (datadeps) delete datadeps;
       datadeps = sub;
     }
   }
+  strlist * preps = eqn->getResult()->getPrepDependencies ();
   if (datadeps) {
-    datadeps->add (eqn->getResult()->getPrepDependencies ());
+    if (preps) datadeps->add (preps->last ());
   } else {
-    datadeps = strlist::join (datadeps,
-			      eqn->getResult()->getPrepDependencies ());
+    datadeps = new strlist ();
+    if (preps) datadeps->add (preps->last ());
   }
   datadeps = checker::foldDependencies (datadeps);
   datadeps->del (eqn->getResult()->getDropDependencies ());
@@ -1297,19 +1492,20 @@ int solver::findEquationResult (node * eqn) {
    the solver.  The optional dataset passed to the function receives
    the results of the calculations. */
 int equation_solver (dataset * data) {
-  solver * solve = new solver ();
+  if (!solve) solve = new solver ();
   solve->setEquations (eqn::equations);
   solve->setData (data);
   solve->checkinDataset ();
   eqn::equations = solve->getEquations ();
-  if (equation_checker (data ? 1 : 0) != 0)
+  if (equation_checker (data ? 1 : 0) != 0) {
+    solve->setEquations (NULL);
     return -1;
+  }
   solve->setEquations (eqn::equations);
   solve->solve ();
   solve->checkoutDataset ();
   eqn::equations = solve->getEquations ();
   solve->setEquations (NULL);
-  delete solve;
   return 0;
 }
 
@@ -1355,3 +1551,19 @@ void equation_constants (void) {
     eqn::equations = a;
   }
 }
+
+/* This is the final destructor for the equation solver. */
+void equation_destructor (void) {
+  // delete solver
+  if (solve) {
+    delete solve;
+    solve = NULL;
+  }
+  // delete equations
+  node * next, * eqn;
+  for (eqn = eqn::equations; eqn != NULL; eqn = next) {
+    next = eqn->getNext ();
+    delete eqn;
+  }
+  equations = NULL;
+}
