@@ -1,7 +1,7 @@
 /*
  * equation.h - checker definitions for Qucs equations
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: equation.h,v 1.22 2005/06/02 18:17:49 raimi Exp $
+ * $Id: equation.h,v 1.27 2006/02/21 20:56:17 raimi Exp $
  *
  */
 
@@ -33,6 +33,7 @@
 
 class strlist;
 class dataset;
+class range;
 
 namespace eqn {
 
@@ -86,6 +87,8 @@ public:
   void setInstance (char *);
   void applyInstance (void);
   constant * calculate (void);    
+  strlist * collectDependencies (void);
+  strlist * collectDataDependencies (void);
 
   /* These functions should be overloaded by derivative classes. */
   virtual void print (void) { }
@@ -141,6 +144,7 @@ public:
   constant * evaluate (void);
 
 public:
+  bool dataref;
   int type;
   union {
     nr_double_t d;
@@ -150,6 +154,7 @@ public:
     matvec * mv;
     char chr;
     char * s;
+    range * r;
   };
 };
 
@@ -161,6 +166,7 @@ public:
   ~reference ();
   void print (void);
   void addDependencies (strlist *);
+  void findVariable (void);
   int evalType (void);
   char * toString (void);
   constant * evaluate (void);
@@ -209,6 +215,11 @@ public:
   int nargs;
   node * args;
   evaluator_t eval;
+
+private:
+  void evalTypeArgs (void);
+  char * createKey (void);
+  int evalTypeFast (void);
 };
 
 /* This class implements the actual functionality regarding a set of
@@ -223,6 +234,8 @@ public:
   node * getEquations (void) { return equations; }
   void list (void);
   int findUndefined (int);
+  static char * tag2key (int);
+  static int isGenerated (char *);
   strlist * getVariables (void);
   int findDuplicate (void);
   static node * findEquation (node *, char *);
@@ -250,7 +263,7 @@ public:
   void setData (dataset * d) { data = d; }
   dataset * getDataset (void) { return data; }
   void solve (void);
-  node * addEquationData (vector *);
+  node * addEquationData (vector *, bool ref = false);
   node * addEquationData (matvec *);
   node * addGeneratedEquation (vector *, char *);
   vector * dataVector (node *);
@@ -261,6 +274,7 @@ public:
   static int getDataSize (char *);
   static strlist * collectDataDependencies (node *);
   int dataSize (strlist *);
+  vector * getDataVector (char *);
   void findMatrixVectors (vector *);
   char * isMatrixVector (char *, int&, int&);
   int findEquationResult (node *);
@@ -274,8 +288,9 @@ private:
 };
 
 /* The global list of equations and expression lists. */
-extern node * equations;
-extern node * expressions;
+extern node   * equations;
+extern node   * expressions;
+extern solver * solve;
 
 } /* namespace */
 
@@ -286,6 +301,7 @@ int equation_checker (int);
 int equation_solver (dataset *);
 strlist * equation_variables (void);
 void equation_constants (void);
+void equation_destructor (void);
 
 __END_DECLS
 
