@@ -1,7 +1,8 @@
 /*
  * evaluate.h - definitions for Qucs equation evaluations
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: evaluate.h,v 1.19 2005/06/07 07:49:06 raimi Exp $
+ * $Id: evaluate.h,v 1.29 2006/05/23 09:48:32 raimi Exp $
  *
  */
 
@@ -290,13 +291,45 @@ public:
   static constant * cosech_c (constant *);
   static constant * cosech_v (constant *);
 
-  static constant * ztor_d (constant *);
-  static constant * ztor_c (constant *);
-  static constant * ztor_v (constant *);
+  static constant * ztor_d   (constant *);
+  static constant * ztor_d_d (constant *);
+  static constant * ztor_d_c (constant *);
+  static constant * ztor_c   (constant *);
+  static constant * ztor_c_d (constant *);
+  static constant * ztor_c_c (constant *);
+  static constant * ztor_v   (constant *);
+  static constant * ztor_v_d (constant *);
+  static constant * ztor_v_c (constant *);
 
-  static constant * rtoz_d (constant *);
-  static constant * rtoz_c (constant *);
-  static constant * rtoz_v (constant *);
+  static constant * rtoz_d   (constant *);
+  static constant * rtoz_d_d (constant *);
+  static constant * rtoz_d_c (constant *);
+  static constant * rtoz_c   (constant *);
+  static constant * rtoz_c_d (constant *);
+  static constant * rtoz_c_c (constant *);
+  static constant * rtoz_v   (constant *);
+  static constant * rtoz_v_d (constant *);
+  static constant * rtoz_v_c (constant *);
+
+  static constant * ytor_d   (constant *);
+  static constant * ytor_d_d (constant *);
+  static constant * ytor_d_c (constant *);
+  static constant * ytor_c   (constant *);
+  static constant * ytor_c_d (constant *);
+  static constant * ytor_c_c (constant *);
+  static constant * ytor_v   (constant *);
+  static constant * ytor_v_d (constant *);
+  static constant * ytor_v_c (constant *);
+
+  static constant * rtoy_d   (constant *);
+  static constant * rtoy_d_d (constant *);
+  static constant * rtoy_d_c (constant *);
+  static constant * rtoy_c   (constant *);
+  static constant * rtoy_c_d (constant *);
+  static constant * rtoy_c_c (constant *);
+  static constant * rtoy_v   (constant *);
+  static constant * rtoy_v_d (constant *);
+  static constant * rtoy_v_c (constant *);
 
   static constant * rtoswr_d (constant *);
   static constant * rtoswr_c (constant *);
@@ -308,10 +341,22 @@ public:
   static constant * max_d (constant *);
   static constant * max_c (constant *);
   static constant * max_v (constant *);
+  static constant * max_r (constant *);
+
+  static constant * max_d_d (constant *);
+  static constant * max_c_d (constant *);
+  static constant * max_d_c (constant *);
+  static constant * max_c_c (constant *);
 
   static constant * min_d (constant *);
   static constant * min_c (constant *);
   static constant * min_v (constant *);
+  static constant * min_r (constant *);
+
+  static constant * min_d_d (constant *);
+  static constant * min_c_d (constant *);
+  static constant * min_d_c (constant *);
+  static constant * min_c_c (constant *);
 
   static constant * sum_d (constant *);
   static constant * sum_c (constant *);
@@ -324,6 +369,7 @@ public:
   static constant * avg_d (constant *);
   static constant * avg_c (constant *);
   static constant * avg_v (constant *);
+  static constant * avg_r (constant *);
 
   static constant * sign_d (constant *);
   static constant * sign_c (constant *);
@@ -341,18 +387,69 @@ public:
   static constant * index_m_2 (constant *);
   static constant * index_s_1 (constant *);
 
-  static constant * stoy_m  (constant *);
-  static constant * stoy_mv (constant *);
-  static constant * stoz_m  (constant *);
-  static constant * stoz_mv (constant *);
-  static constant * ytos_m  (constant *);
-  static constant * ytos_mv (constant *);
-  static constant * ytoz_m  (constant *);
-  static constant * ytoz_mv (constant *);
-  static constant * ztos_m  (constant *);
-  static constant * ztos_mv (constant *);
+  static constant * stos_m_d   (constant *);
+  static constant * stos_m_d_d (constant *);
+  static constant * stos_m_d_c (constant *);
+  static constant * stos_m_d_v (constant *);
+  static constant * stos_m_c   (constant *);
+  static constant * stos_m_c_d (constant *);
+  static constant * stos_m_c_c (constant *);
+  static constant * stos_m_c_v (constant *);
+  static constant * stos_m_v   (constant *);
+  static constant * stos_m_v_d (constant *);
+  static constant * stos_m_v_c (constant *);
+  static constant * stos_m_v_v (constant *);
+
+  static constant * stos_mv_d   (constant *);
+  static constant * stos_mv_d_d (constant *);
+  static constant * stos_mv_d_c (constant *);
+  static constant * stos_mv_d_v (constant *);
+  static constant * stos_mv_c   (constant *);
+  static constant * stos_mv_c_d (constant *);
+  static constant * stos_mv_c_c (constant *);
+  static constant * stos_mv_c_v (constant *);
+  static constant * stos_mv_v   (constant *);
+  static constant * stos_mv_v_d (constant *);
+  static constant * stos_mv_v_c (constant *);
+  static constant * stos_mv_v_v (constant *);
+
+  static constant * stoy_m    (constant *);
+  static constant * stoy_m_d  (constant *);
+  static constant * stoy_m_c  (constant *);
+  static constant * stoy_m_v  (constant *);
+  static constant * stoy_mv   (constant *);
+  static constant * stoy_mv_d (constant *);
+  static constant * stoy_mv_c (constant *);
+  static constant * stoy_mv_v (constant *);
+  static constant * stoz_m    (constant *);
+  static constant * stoz_m_d  (constant *);
+  static constant * stoz_m_c  (constant *);
+  static constant * stoz_m_v  (constant *);
+  static constant * stoz_mv   (constant *);
+  static constant * stoz_mv_d (constant *);
+  static constant * stoz_mv_c (constant *);
+  static constant * stoz_mv_v (constant *);
+  static constant * ytos_m    (constant *);
+  static constant * ytos_m_d  (constant *);
+  static constant * ytos_m_c  (constant *);
+  static constant * ytos_m_v  (constant *);
+  static constant * ytos_mv   (constant *);
+  static constant * ytos_mv_d (constant *);
+  static constant * ytos_mv_c (constant *);
+  static constant * ytos_mv_v (constant *);
+  static constant * ztos_m    (constant *);
+  static constant * ztos_m_d  (constant *);
+  static constant * ztos_m_c  (constant *);
+  static constant * ztos_m_v  (constant *);
+  static constant * ztos_mv   (constant *);
+  static constant * ztos_mv_d (constant *);
+  static constant * ztos_mv_c (constant *);
+  static constant * ztos_mv_v (constant *);
+
   static constant * ztoy_m  (constant *);
   static constant * ztoy_mv (constant *);
+  static constant * ytoz_m  (constant *);
+  static constant * ytoz_mv (constant *);
 
   static constant * twoport_m  (constant *);
   static constant * twoport_mv (constant *);
@@ -404,6 +501,132 @@ public:
 
   static constant * interpolate_v_v_d (constant *);
   static constant * interpolate_v_v (constant *);
+
+  static constant * fft_v (constant *);
+  static constant * ifft_v (constant *);
+  static constant * dft_v (constant *);
+  static constant * idft_v (constant *);
+  static constant * time2freq_v_v (constant *);
+  static constant * freq2time_v_v (constant *);
+
+  static constant * xvalue_d (constant *);
+  static constant * xvalue_c (constant *);
+  static constant * yvalue_d (constant *);
+  static constant * yvalue_c (constant *);
+
+  static constant * range_d_d (constant *);
+  static constant * range_d_c (constant *);
+  static constant * range_c_d (constant *);
+  static constant * range_c_c (constant *);
+
+  static constant * ceil_d   (constant *);
+  static constant * ceil_c   (constant *);
+  static constant * ceil_v   (constant *);
+  static constant * floor_d  (constant *);
+  static constant * floor_c  (constant *);
+  static constant * floor_v  (constant *);
+  static constant * fix_d    (constant *);
+  static constant * fix_c    (constant *);
+  static constant * fix_v    (constant *);
+  static constant * step_d   (constant *);
+  static constant * step_c   (constant *);
+  static constant * step_v   (constant *);
+  static constant * round_d  (constant *);
+  static constant * round_c  (constant *);
+  static constant * round_v  (constant *);
+
+  static constant * erf_d     (constant *);
+  static constant * erf_c     (constant *);
+  static constant * erf_v     (constant *);
+  static constant * erfc_d    (constant *);
+  static constant * erfc_c    (constant *);
+  static constant * erfc_v    (constant *);
+  static constant * erfinv_d  (constant *);
+  static constant * erfinv_c  (constant *);
+  static constant * erfinv_v  (constant *);
+  static constant * erfcinv_d (constant *);
+  static constant * erfcinv_c (constant *);
+  static constant * erfcinv_v (constant *);
+
+  static constant * rms_d      (constant *);
+  static constant * rms_c      (constant *);
+  static constant * rms_v      (constant *);
+  static constant * variance_d (constant *);
+  static constant * variance_c (constant *);
+  static constant * variance_v (constant *);
+  static constant * stddev_d   (constant *);
+  static constant * stddev_c   (constant *);
+  static constant * stddev_v   (constant *);
+
+  static constant * cumsum_d  (constant *);
+  static constant * cumsum_c  (constant *);
+  static constant * cumsum_v  (constant *);
+  static constant * cumavg_d  (constant *);
+  static constant * cumavg_c  (constant *);
+  static constant * cumavg_v  (constant *);
+  static constant * cumprod_d (constant *);
+  static constant * cumprod_c (constant *);
+  static constant * cumprod_v (constant *);
+
+  static constant * i0_d   (constant *);
+  static constant * i0_c   (constant *);
+  static constant * i0_v   (constant *);
+  static constant * jn_d_d (constant *);
+  static constant * jn_d_c (constant *);
+  static constant * jn_d_v (constant *);
+  static constant * yn_d_d (constant *);
+  static constant * yn_d_c (constant *);
+  static constant * yn_d_v (constant *);
+
+  static constant * sqr_d  (constant *);
+  static constant * sqr_c  (constant *);
+  static constant * sqr_v  (constant *);
+  static constant * sqr_m  (constant *);
+  static constant * sqr_mv (constant *);
+
+  static constant * polar_d_d (constant *);
+  static constant * polar_d_c (constant *);
+  static constant * polar_c_d (constant *);
+  static constant * polar_c_c (constant *);
+  static constant * polar_d_v (constant *);
+  static constant * polar_c_v (constant *);
+  static constant * polar_v_d (constant *);
+  static constant * polar_v_c (constant *);
+  static constant * polar_v_v (constant *);
+
+  static constant * arctan2_d_d (constant *);
+  static constant * arctan2_d_v (constant *);
+  static constant * arctan2_v_d (constant *);
+  static constant * arctan2_v_v (constant *);
+
+  static constant * w2dbm_d (constant *);
+  static constant * w2dbm_c (constant *);
+  static constant * w2dbm_v (constant *);
+  static constant * dbm2w_d (constant *);
+  static constant * dbm2w_c (constant *);
+  static constant * dbm2w_v (constant *);
+
+  static constant * integrate_d_d (constant *);
+  static constant * integrate_c_c (constant *);
+  static constant * integrate_v_d (constant *);
+  static constant * integrate_v_c (constant *);
+
+  static constant * dbm_d   (constant *);
+  static constant * dbm_d_d (constant *);
+  static constant * dbm_c   (constant *);
+  static constant * dbm_c_d (constant *);
+  static constant * dbm_v   (constant *);
+  static constant * dbm_v_d (constant *);
+  static constant * dbm_d_c (constant *);
+  static constant * dbm_c_c (constant *);
+  static constant * dbm_v_c (constant *);
+
+  static constant * runavg_d_d (constant *);
+  static constant * runavg_c_d (constant *);
+  static constant * runavg_v_d (constant *);
+
+  static constant * kbd_d_d (constant *);
+  static constant * kbd_d   (constant *);
 };
 
 // Type of application function.
