@@ -1,7 +1,7 @@
 /*
  * input.cpp - input netlist class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: input.cpp,v 1.47 2005/06/02 18:17:50 raimi Exp $
+ * $Id: input.cpp,v 1.57 2006/03/24 14:30:05 raimi Exp $
  *
  */
 
@@ -230,8 +230,8 @@ void input::factory (void) {
       c->setNonLinear (def->nonlinear != 0);
       c->setSubcircuit (def->subcircuit);
 
-      // change size (number of ports) of S-parameter files
-      if (c->getType () == CIR_SPFILE) {
+      // change size (number of ports) of variable sized components
+      if (c->isVariableSized ()) {
 	c->setSize (def->ncount);
       }
       // add appropriate nodes to circuit
@@ -241,7 +241,15 @@ void input::factory (void) {
 
       // add the properties to circuit
       for (pairs = def->pairs; pairs != NULL; pairs = pairs->next)
-	if (pairs->value->ident) {
+	if (pairs->value == NULL) {
+	  // zero-length value lists
+	  variable * v = new variable (pairs->key);
+	  constant * c = new constant (TAG_VECTOR);
+	  c->v = new vector ();
+	  v->setConstant (c);
+	  o->addProperty (pairs->key, v);
+	}
+	else if (pairs->value->ident) {
 	  if (pairs->value->var) {
 	    // at this stage it should be ensured that the variable is
 	    // already in the root environment
@@ -255,7 +263,16 @@ void input::factory (void) {
 	    o->addProperty (pairs->key, pairs->value->ident);
 	  }
 	} else {
-	  o->addProperty (pairs->key, pairs->value->value);
+	  if (pairs->value->var) {
+	    // add value lists to the properties
+	    variable * v = new variable (pairs->key);
+	    constant * c = new constant (TAG_VECTOR);
+	    c->v = createVector (pairs->value);
+	    v->setConstant (c);
+	    o->addProperty (pairs->key, v);
+	  } else {
+	    o->addProperty (pairs->key, pairs->value->value);
+	  }
 	}
       // additionally add missing optional properties
       assignDefaultProperties (c, def->define);
@@ -330,6 +347,10 @@ circuit * input::createCircuit (char * type) {
     return new vac ();
   else if (!strcmp (type, "Iac"))
     return new iac ();
+  else if (!strcmp (type, "AM_Mod"))
+    return new vam ();
+  else if (!strcmp (type, "PM_Mod"))
+    return new vpm ();
   else if (!strcmp (type, "Vpulse"))
     return new vpulse ();
   else if (!strcmp (type, "Ipulse"))
@@ -342,8 +363,16 @@ circuit * input::createCircuit (char * type) {
     return new gyrator ();
   else if (!strcmp (type, "PShift"))
     return new phaseshifter ();
+  else if (!strcmp (type, "Switch"))
+    return new tswitch ();
+  else if (!strcmp (type, "Relais"))
+    return new relais ();
   else if (!strcmp (type, "TLIN"))
     return new tline ();
+  else if (!strcmp (type, "COAX"))
+    return new coaxline ();
+  else if (!strcmp (type, "Coupler"))
+    return new coupler ();
   else if (!strcmp (type, "Diode"))
     return new diode ();
   else if (!strcmp (type, "MLIN"))
@@ -378,6 +407,8 @@ circuit * input::createCircuit (char * type) {
     return new cpwstep ();
   else if (!strcmp (type, "IProbe"))
     return new iprobe ();
+  else if (!strcmp (type, "VProbe"))
+    return new vprobe ();
   else if (!strcmp (type, "JFET"))
     return new jfet ();
   else if (!strcmp (type, "BJT"))
@@ -394,6 +425,32 @@ circuit * input::createCircuit (char * type) {
     return new amplifier ();
   else if (!strcmp (type, "OpAmp"))
     return new opamp ();
+  else if (!strcmp (type, "IInoise"))
+    return new iinoise ();
+  else if (!strcmp (type, "MUT"))
+    return new mutual ();
+  else if (!strcmp (type, "MUT2"))
+    return new mutual2 ();
+  else if (!strcmp (type, "IVnoise"))
+    return new ivnoise ();
+  else if (!strcmp (type, "VVnoise"))
+    return new vvnoise ();
+  else if (!strcmp (type, "Inv"))
+    return new inverter ();
+  else if (!strcmp (type, "NOR"))
+    return new logicnor ();
+  else if (!strcmp (type, "OR"))
+    return new logicor ();
+  else if (!strcmp (type, "NAND"))
+    return new logicnand ();
+  else if (!strcmp (type, "AND"))
+    return new logicand ();
+  else if (!strcmp (type, "XNOR"))
+    return new logicxnor ();
+  else if (!strcmp (type, "XOR"))
+    return new logicxor ();
+  else if (!strcmp (type, "DigiSource"))
+    return new digisource ();
 
   logprint (LOG_ERROR, "no such circuit type `%s'\n", type);
   return NULL;
