@@ -1,7 +1,7 @@
 /*
  * matvec.cpp - matrix vector class implementation
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: matvec.cpp,v 1.17 2005/06/02 18:17:50 raimi Exp $
+ * $Id: matvec.cpp,v 1.19 2005/10/31 16:15:31 ela Exp $
  *
  */
 
@@ -393,38 +393,82 @@ matvec transpose (matvec a) {
   return res;
 }
 
+/* Convert scattering parameters with the reference impedance 'zref'
+   to scattering parameters with the reference impedance 'z0'. */
+matvec stos (matvec s, vector zref, vector z0) {
+  assert (s.getCols () == s.getRows () &&
+	  s.getCols () == zref.getSize () && s.getCols () == z0.getSize ());
+  matvec res (s.getSize (), s.getCols (), s.getRows ());
+  for (int i = 0; i < s.getSize (); i++)
+    res.set (stos (s.get (i), zref, z0), i);
+  return res;
+}
+
+matvec stos (matvec s, complex zref, complex z0) {
+  int d = s.getRows ();
+  return stos (s, vector (d, zref), vector (d, z0));
+}
+
+matvec stos (matvec s, nr_double_t zref, nr_double_t z0) {
+  return stos (s, rect (zref, 0), rect (z0, 0));
+}
+
+matvec stos (matvec s, vector zref, complex z0) {
+  return stos (s, zref, vector (zref.getSize (), z0));
+}
+
+matvec stos (matvec s, complex zref, vector z0) {
+  return stos (s, vector (z0.getSize (), zref), z0);
+}
+
 // Convert scattering parameters to admittance matrix vector.
-matvec stoy (matvec s, complex z0) {
-  assert (s.getCols () == s.getRows ());
+matvec stoy (matvec s, vector z0) {
+  assert (s.getCols () == s.getRows () && s.getCols () == z0.getSize ());
   matvec res (s.getSize (), s.getCols (), s.getRows ());
   for (int i = 0; i < s.getSize (); i++) res.set (stoy (s.get (i), z0), i);
-  return res;  
+  return res;
+}
+
+matvec stoy (matvec s, complex z0) {
+  return stoy (s, vector (s.getCols (), z0));
 }
 
 // Convert admittance matrix to scattering parameter matrix vector.
-matvec ytos (matvec y, complex z0) {
-  assert (y.getCols () == y.getRows ());
+matvec ytos (matvec y, vector z0) {
+  assert (y.getCols () == y.getRows () && y.getCols () == z0.getSize ());
   matvec res (y.getSize (), y.getCols (), y.getRows ());
   for (int i = 0; i < y.getSize (); i++) res.set (ytos (y.get (i), z0), i);
-  return res;  
+  return res;
+}
+
+matvec ytos (matvec y, complex z0) {
+  return ytos (y, vector (y.getCols (), z0));
 }
 
 // Convert scattering parameters to impedance matrix vector.
-matvec stoz (matvec s, complex z0) {
-  assert (s.getCols () == s.getRows ());
+matvec stoz (matvec s, vector z0) {
+  assert (s.getCols () == s.getRows () && s.getCols () == z0.getSize ());
   matvec res (s.getSize (), s.getCols (), s.getRows ());
   for (int i = 0; i < s.getSize (); i++) res.set (stoz (s.get (i), z0), i);
   return res;  
 }
 
+matvec stoz (matvec s, complex z0) {
+  return stoz (s, vector (s.getCols (), z0));
+}
+
 // Convert impedance matrix vector scattering parameter matrix vector.
-matvec ztos (matvec z, complex z0) {
-  assert (z.getCols () == z.getRows ());
+matvec ztos (matvec z, vector z0) {
+  assert (z.getCols () == z.getRows () && z.getCols () == z0.getSize ());
   matvec res (z.getSize (), z.getCols (), z.getRows ());
   for (int i = 0; i < z.getSize (); i++) res.set (ztos (z.get (i), z0), i);
   return res;  
 }
 
+matvec ztos (matvec z, complex z0) {
+  return ztos (z, vector (z.getCols (), z0));
+}
+
 // Convert impedance matrix vector to admittance matrix vector.
 matvec ztoy (matvec z) {
   assert (z.getCols () == z.getRows ());
