@@ -1,7 +1,7 @@
 /*
  * nasolver.cpp - nodal analysis solver class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: nasolver.cpp,v 1.36 2005/06/02 18:17:50 raimi Exp $
+ * $Id: nasolver.cpp,v 1.43 2006/05/03 09:43:56 raimi Exp $
  *
  */
 
@@ -49,6 +49,7 @@
 #include "tmatrix.h"
 #include "eqnsys.h"
 #include "constants.h"
+#include "precision.h"
 #include "operatingpoint.h"
 #include "exception.h"
 #include "exceptionstack.h"
@@ -280,7 +281,7 @@ int nasolver<nr_type_t>::solve_nonlinear_continuation_gMin (void) {
     if (run >= MaxIterations || error) {
       gStep /= 2;
       // here the absolute minimum step checker
-      if (gStep < 1e-15) {
+      if (gStep < NR_EPSI) {
 	error = 1;
 	e = new qucs::exception (EXCEPTION_NO_CONVERGENCE);
 	e->setText ("no convergence in %s analysis after %d gMinStepping "
@@ -289,7 +290,7 @@ int nasolver<nr_type_t>::solve_nonlinear_continuation_gMin (void) {
 	break;
       }
       gMin = MAX (gPrev - gStep, 0);
-    } 
+    }
     // converged, increased the gMin-step
     else {
       gPrev = gMin;
@@ -342,7 +343,7 @@ int nasolver<nr_type_t>::solve_nonlinear_continuation_Source (void) {
     if (run >= MaxIterations || error) {
       sStep /= 2;
       // here the absolute minimum step checker
-      if (sStep < 1e-15) {
+      if (sStep < NR_EPSI) {
 	error = 1;
 	e = new qucs::exception (EXCEPTION_NO_CONVERGENCE);
 	e->setText ("no convergence in %s analysis after %d sourceStepping "
@@ -642,7 +643,9 @@ template <class nr_type_t>
 void nasolver<nr_type_t>::createNoiseMatrix (void) {
   int pr, pc, N = countNodes ();
   int M = countVoltageSources ();
-  nr_type_t n;
+  struct nodelist_t * n;
+  nr_type_t val;
+  int r, c, a, b, ri, ci, i;
   struct nodelist_t * nr, * nc;
   circuit * ct;
 
@@ -650,42 +653,83 @@ void nasolver<nr_type_t>::createNoiseMatrix (void) {
   if (C != NULL) delete C; C = new tmatrix<nr_type_t> (N + M);
 
   // go through each column of the Cy matrix
-  for (int c = 0; c < N; c++) {
+  for (c = 0; c < N; c++) {
     nc = nlist->getNode (c);
     // go through each row of the Cy matrix
-    for (int r = 0; r < N; r++) {
+    for (r = 0; r < N; r++) {
       nr = nlist->getNode (r);
-      n = 0.0;
+      val = 0.0;
       // sum up the noise-correlation of each connected circuit
-      for (int a = 0; a < nc->nNodes; a++)
-	for (int b = 0; b < nr->nNodes; b++)
+      for (a = 0; a < nc->nNodes; a++)
+	for (b = 0; b < nr->nNodes; b++)
 	  if (nc->nodes[a]->getCircuit () == nr->nodes[b]->getCircuit ()) {
 	    ct = nc->nodes[a]->getCircuit ();
 	    pc = nc->nodes[a]->getPort ();
 	    pr = nr->nodes[b]->getPort ();
-	    n += MatVal (ct->getN (pr, pc));
+	    val += MatVal (ct->getN (pr, pc));
 	  }
       // put value into Cy matrix
-      C->set (r, c, n);
+      C->set (r, c, val);
     }
   }
 
   // go through each additional voltage source and put coefficients into
   // the noise current correlation matrix
   circuit * vsr, * vsc;
-  for (int r = 0; r < M; r++) {
+  for (r = 0; r < M; r++) {
     vsr = findVoltageSource (r);
-    for (int c = 0; c < M; c++) {
+    for (c = 0; c < M; c++) {
       vsc = findVoltageSource (c);
-      n = 0.0;
+      val = 0.0;
       if (vsr == vsc) {
-	int ri = vsr->getSize () + r - vsr->getVoltageSource ();
-	int ci = vsc->getSize () + c - vsc->getVoltageSource ();
-	n = MatVal (vsr->getN (ri, ci));
+	ri = vsr->getSize () + r - vsr->getVoltageSource ();
+	ci = vsc->getSize () + c - vsc->getVoltageSource ();
+	val = MatVal (vsr->getN (ri, ci));
       }
-      C->set (r + N, c + N, n);
+      C->set (r + N, c + N, val);
     }
   }
+
+  // go through each additional voltage source
+  for (r = 0; r < M; r++) {
+    vsr = findVoltageSource (r);
+    // go through each node
+    for (c = 0; c < N; c++) {
+      val = 0.0;
+      n = nlist->getNode (c);
+      for (i = 0; i < n->nNodes; i++) {
+	// is voltage source connected to node ?
+	if (n->nodes[i]->getCircuit () == vsr) {
+	  ri = vsr->getSize () + r - vsr->getVoltageSource ();
+	  ci = n->nodes[i]->getPort ();
+	  val += MatVal (vsr->getN (ri, ci));
+	}
+      }
+      // put value into Cy matrix
+      C->set (r + N, c, val);
+    }
+  }  
+
+  // go through each voltage source
+  for (c = 0; c < M; c++) {
+    vsc = findVoltageSource (c);
+    // go through each node
+    for (r = 0; r < N; r++) {
+      val = 0.0;
+      n = nlist->getNode (r);
+      for (i = 0; i < n->nNodes; i++) {
+	// is voltage source connected to node ?
+	if (n->nodes[i]->getCircuit () == vsc) {
+	  ci = vsc->getSize () + c - vsc->getVoltageSource ();
+	  ri = n->nodes[i]->getPort ();
+	  val += MatVal (vsc->getN (ri, ci));
+	}
+      }
+      // put value into Cy matrix
+      C->set (r, c + N, val);
+    }
+  }  
+
 }
 
 /* The i matrix is an 1xN matrix with each element of the matrix
@@ -748,6 +792,22 @@ int nasolver<nr_type_t>::countNodes (void) {
   return nlist->length () - 1;
 }
 
+/* The function returns the assigned node number for the port of the
+   given circuits.  It returns -1 if there is no such node. */
+template <class nr_type_t>
+int nasolver<nr_type_t>::findAssignedNode (circuit * c, int port) {
+  int N = countNodes ();
+  struct nodelist_t * n;
+  for (int r = 0; r < N; r++) {
+    n = nlist->getNode (r);
+    for (int i = 0; i < n->nNodes; i++)
+      if (c == n->nodes[i]->getCircuit ())
+	if (port == n->nodes[i]->getPort ())
+	  return r;
+  }
+  return -1;
+}
+
 // Returns the number of voltage sources in the nodelist.
 template <class nr_type_t>
 int nasolver<nr_type_t>::countVoltageSources (void) {
@@ -841,7 +901,7 @@ void nasolver<nr_type_t>::lineSearch (void) {
 
   // compute solution deviation vector
   tvector<nr_type_t> dx = *x - *xprev;
-  nMin = DBL_MAX;
+  nMin = NR_MAX;
 
   do {
     // apply current damping factor and see what happens
@@ -1030,6 +1090,19 @@ void nasolver<nr_type_t>::saveResults (char * volts, char * amps, int saveOPs,
     }
   }
 
+  // add voltage probe data
+  if (volts) {
+    circuit * root = subnet->getRoot ();
+    for (circuit * c = root; c != NULL; c = (circuit *) c->getNext ()) {
+      if (!c->isProbe ()) continue;
+      if (c->getSubcircuit () && !(saveOPs & SAVE_ALL)) continue;
+      c->saveOperatingPoints ();
+      n = createOP (c->getName (), volts);
+      saveVariable (n, c->getOperatingPoint ("V"), f);
+      free (n);
+    }
+  }
+
   // save operating points of non-linear circuits if requested
   if (saveOPs & SAVE_OPS) {
     circuit * root = subnet->getRoot ();
@@ -1037,8 +1110,9 @@ void nasolver<nr_type_t>::saveResults (char * volts, char * amps, int saveOPs,
       if (!c->isNonLinear ()) continue;
       if (c->getSubcircuit () && !(saveOPs & SAVE_ALL)) continue;
       c->calcOperatingPoints ();
-      operatingpoint * p = c->getOperatingPoints ();
-      for (; p != NULL; p = p->getNext ()) {
+      valuelistiterator<operatingpoint> it (c->getOperatingPoints ());
+      for (; *it; ++it) {
+	operatingpoint * p = it.currentVal ();
 	n = createOP (c->getName (), p->getName ());
 	saveVariable (n, p->getValue (), f);
 	free (n);
@@ -1047,23 +1121,6 @@ void nasolver<nr_type_t>::saveResults (char * volts, char * amps, int saveOPs,
   }
 }
 
-/* Saves the given variable into dataset.  Creates the dataset vector
-   if necessary. */
-template <class nr_type_t>
-void nasolver<nr_type_t>::saveVariable (char * n, nr_type_t z, vector * f) {
-  vector * d;
-  if ((d = data->findVariable (n)) == NULL) {
-    d = new vector (n);
-    if (f != NULL) {
-      d->setDependencies (new strlist ());
-      d->getDependencies()->add (f->getName ());
-    }
-    d->setOrigin (getName ());
-    data->addVariable (d);
-  }
-  d->add (z);
-}
-
 /* Create an appropriate variable name for operating points.  The
    caller is responsible to free() the returned string. */
 template <class nr_type_t>
