@@ -1,7 +1,7 @@
 /*
  * nasolver.h - nodal analysis solver class definitions
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: nasolver.h,v 1.19 2005/06/02 18:17:50 raimi Exp $
+ * $Id: nasolver.h,v 1.21 2006/02/20 18:02:11 raimi Exp $
  *
  */
 
@@ -29,9 +29,6 @@
 #include "tmatrix.h"
 #include "eqnsys.h"
 
-#define SAVE_OPS 1 // save operating points
-#define SAVE_ALL 2 // also save subcircuit nodes and operating points
-
 // Convergence helper definitions.
 #define CONV_None            0
 #define CONV_Attenuation     1
@@ -72,6 +69,7 @@ class nasolver : public analysis
  protected:
   void savePreviousIteration (void);
   int  countNodes (void);
+  int  findAssignedNode (circuit *, int);
   int  countVoltageSources (void);
   void saveSolution (void);
   circuit * findVoltageSource (int);
@@ -98,7 +96,6 @@ class nasolver : public analysis
   void saveNodeVoltages (void);
   void saveBranchCurrents (void);
   int  checkConvergence (void);
-  void saveVariable (char *, nr_type_t, vector * f = NULL);
   nr_type_t MatValX (complex, complex *);
   nr_type_t MatValX (complex, nr_double_t *);
 
