@@ -1,7 +1,7 @@
 /*
  * object.cpp - generic object class implementation
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: object.cpp,v 1.10 2005/06/02 18:17:51 raimi Exp $
+ * $Id: object.cpp,v 1.12 2006/01/30 07:45:34 raimi Exp $
  *
  */
 
@@ -120,6 +120,15 @@ void object::setProperty (char * n, nr_double_t val) {
     addProperty (n, val);
 }
 
+/* Th function sets the specified property consisting of a key and a
+   double value in the object.  The property is marked a scalability
+   property. */
+void object::setScaledProperty (char * n, nr_double_t val) {
+  char prop[64];
+  sprintf (prop, "Scaled:%s", n);
+  setProperty (prop, val);
+}
+
 /* This function adds a property consisting of a key and a variable
    value to the object. */
 void object::addProperty (char * n, variable * val) {
@@ -153,6 +162,19 @@ nr_double_t object::getPropertyDouble (char * n) {
   return 0.0;
 }
 
+/* The functions returns the requested (scalability) property value
+   which has been previously added.  If there is no such scaled
+   property the function returns the standard property or zero. */
+nr_double_t object::getScaledProperty (char * n) {
+  char txt[64];
+  sprintf (txt, "Scaled:%s", n);
+  // try to find scaled property
+  property * p = prop->findProperty (txt);
+  if (p != NULL) return p->getDouble ();
+  // default to standard property
+  return getPropertyDouble (n);
+}
+
 /* Returns the requested property value which has been previously
    added as its integer representation.  If there is no such property
    the function returns zero. */
