@@ -1,7 +1,7 @@
 /*
  * parasweep.cpp - parameter sweep class implementation
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,10 +15,10 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
+ * Boston, MA 02110-1301, USA.  
  *
- * $Id: parasweep.cpp,v 1.9 2004/12/07 22:33:31 raimi Exp $
+ * $Id: parasweep.cpp,v 1.11 2005/06/02 18:17:51 raimi Exp $
  *
  */
 
@@ -36,6 +36,7 @@
 #include "vector.h"
 #include "dataset.h"
 #include "net.h"
+#include "ptrlist.h"
 #include "analysis.h"
 #include "variable.h"
 #include "environment.h"
@@ -106,7 +107,8 @@ void parasweep::solve (void) {
     logprint (LOG_STATUS, "NOTIFY: %s: running netlist for %s = %g\n",
 	      getName (), n, D (val));
 #endif
-    for (analysis * a = actions; a != NULL; a = (analysis *) a->getNext ()) {
+    for (int k = 0; k < actions->length (); k++) {
+      analysis * a = actions->get (k);
       a->solve ();
       // assign variable dataset dependencies to last order analyses
       analysis * last = subnet->findLastOrder (a);
