@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.1.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -36,6 +36,9 @@
 /* Identify Bison output.  */
 #define YYBISON 1
 
+/* Bison version.  */
+#define YYBISON_VERSION "2.1"
+
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
 
@@ -45,8 +48,7 @@
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
-/* If NAME_PREFIX is specified substitute the variables and functions
-   names.  */
+/* Substitute the variable and function names.  */
 #define yyparse touchstone_parse
 #define yylex   touchstone_lex
 #define yyerror touchstone_error
@@ -68,6 +70,7 @@
      Eol = 261
    };
 #endif
+/* Tokens.  */
 #define InvalidCharacter 258
 #define Float 259
 #define Option 260
@@ -82,7 +85,7 @@
 /*
  * parse_touchstone.y - parser for Touchstone Files
  *
- * Copyright (C) 2003 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2005 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,7 +102,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: parse_touchstone.y,v 1.3 2005/06/02 18:17:51 raimi Exp $
+ * $Id: parse_touchstone.y,v 1.4 2005/10/24 09:10:25 raimi Exp $
  *
  */
 
@@ -137,6 +140,11 @@
 # define YYERROR_VERBOSE 0
 #endif
 
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
 #line 56 "parse_touchstone.y"
 typedef union YYSTYPE {
@@ -145,8 +153,8 @@ typedef union YYSTYPE {
   vector * v;
   strlist * list;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
-#line 150 "parse_touchstone.cpp"
+/* Line 196 of yacc.c.  */
+#line 158 "parse_touchstone.cpp"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -157,30 +165,49 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 162 "parse_touchstone.cpp"
+/* Line 219 of yacc.c.  */
+#line 170 "parse_touchstone.cpp"
+
+#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
+# define YYSIZE_T __SIZE_TYPE__
+#endif
+#if ! defined (YYSIZE_T) && defined (size_t)
+# define YYSIZE_T size_t
+#endif
+#if ! defined (YYSIZE_T) && (defined (__STDC__) || defined (__cplusplus))
+# include <stddef.h> /* INFRINGES ON USER NAME SPACE */
+# define YYSIZE_T size_t
+#endif
+#if ! defined (YYSIZE_T)
+# define YYSIZE_T unsigned int
+#endif
+
+#ifndef YY_
+# if YYENABLE_NLS
+#  if ENABLE_NLS
+#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
+#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#  endif
+# endif
+# ifndef YY_
+#  define YY_(msgid) msgid
+# endif
+#endif
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
-# ifndef YYFREE
-#  define YYFREE free
-# endif
-# ifndef YYMALLOC
-#  define YYMALLOC malloc
-# endif
-
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
+#    if defined (__STDC__) || defined (__cplusplus)
+#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
+#     define YYINCLUDED_STDLIB_H
+#    endif
 #   endif
 #  endif
 # endif
@@ -188,13 +215,39 @@ typedef union YYSTYPE {
 # ifdef YYSTACK_ALLOC
    /* Pacify GCC's `empty if-body' warning. */
 #  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
-# else
-#  if defined (__STDC__) || defined (__cplusplus)
-#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
-#   define YYSIZE_T size_t
+#  ifndef YYSTACK_ALLOC_MAXIMUM
+    /* The OS might guarantee only one guard page at the bottom of the stack,
+       and a page size can be as small as 4096 bytes.  So we cannot safely
+       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
+       to allow for a few compiler-allocated temporary stack slots.  */
+#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2005 */
 #  endif
+# else
 #  define YYSTACK_ALLOC YYMALLOC
 #  define YYSTACK_FREE YYFREE
+#  ifndef YYSTACK_ALLOC_MAXIMUM
+#   define YYSTACK_ALLOC_MAXIMUM ((YYSIZE_T) -1)
+#  endif
+#  ifdef __cplusplus
+extern "C" {
+#  endif
+#  ifndef YYMALLOC
+#   define YYMALLOC malloc
+#   if (! defined (malloc) && ! defined (YYINCLUDED_STDLIB_H) \
+	&& (defined (__STDC__) || defined (__cplusplus)))
+void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
+#   endif
+#  endif
+#  ifndef YYFREE
+#   define YYFREE free
+#   if (! defined (free) && ! defined (YYINCLUDED_STDLIB_H) \
+	&& (defined (__STDC__) || defined (__cplusplus)))
+void free (void *); /* INFRINGES ON USER NAME SPACE */
+#   endif
+#  endif
+#  ifdef __cplusplus
+}
+#  endif
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
@@ -229,7 +282,7 @@ union yyalloc
 #   define YYCOPY(To, From, Count)		\
       do					\
 	{					\
-	  register YYSIZE_T yyi;		\
+	  YYSIZE_T yyi;				\
 	  for (yyi = 0; yyi < (Count); yyi++)	\
 	    (To)[yyi] = (From)[yyi];		\
 	}					\
@@ -264,22 +317,22 @@ union yyalloc
 /* YYFINAL -- State number of the termination state. */
 #define YYFINAL  8
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   32
+#define YYLAST   23
 
 /* YYNTOKENS -- Number of terminals. */
 #define YYNTOKENS  9
 /* YYNNTS -- Number of nonterminals. */
 #define YYNNTS  6
 /* YYNRULES -- Number of rules. */
-#define YYNRULES  18
+#define YYNRULES  19
 /* YYNRULES -- Number of states. */
-#define YYNSTATES  37
+#define YYNSTATES  30
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   261
 
-#define YYTRANSLATE(YYX) 						\
+#define YYTRANSLATE(YYX)						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
@@ -320,7 +373,7 @@ static const unsigned char yytranslate[] =
 static const unsigned char yyprhs[] =
 {
        0,     0,     3,     6,    13,    17,    20,    21,    24,    25,
-      28,    31,    36,    43,    54,    63,    73,    81,    87
+      29,    31,    34,    38,    44,    54,    62,    71,    78,    83
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS. */
@@ -328,26 +381,25 @@ static const yysigned_char yyrhs[] =
 {
       10,     0,    -1,    11,    13,    -1,     7,    12,     8,     4,
       12,     6,    -1,     7,    12,     6,    -1,     6,    11,    -1,
-      -1,     5,    12,    -1,    -1,    14,    13,    -1,     6,    13,
-      -1,     4,     4,     4,     6,    -1,     4,     4,     4,     4,
-       4,     6,    -1,     4,     4,     4,     4,     4,     4,     4,
-       4,     4,     6,    -1,     4,     4,     4,     4,     4,     4,
-       4,     6,    -1,     4,     4,     4,     4,     4,     4,     4,
-       4,     6,    -1,     4,     4,     4,     4,     4,     4,     6,
-      -1,     4,     4,     4,     4,     6,    -1,     4,     4,     6,
-      -1
+      -1,     5,    12,    -1,    -1,    14,     6,    13,    -1,    14,
+      -1,     6,    13,    -1,     4,     4,     4,    -1,     4,     4,
+       4,     4,     4,    -1,     4,     4,     4,     4,     4,     4,
+       4,     4,     4,    -1,     4,     4,     4,     4,     4,     4,
+       4,    -1,     4,     4,     4,     4,     4,     4,     4,     4,
+      -1,     4,     4,     4,     4,     4,     4,    -1,     4,     4,
+       4,     4,    -1,     4,     4,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
        0,    71,    71,    75,    79,    83,    86,    87,    94,    95,
-      99,   103,   110,   119,   132,   143,   155,   165,   173
+      99,   105,   109,   116,   125,   138,   149,   161,   171,   179
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE
-/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
+#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
@@ -370,14 +422,14 @@ static const unsigned short int yytoknum[] =
 static const unsigned char yyr1[] =
 {
        0,     9,    10,    11,    11,    11,    12,    12,    13,    13,
-      13,    14,    14,    14,    14,    14,    14,    14,    14
+      13,    13,    14,    14,    14,    14,    14,    14,    14,    14
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
 static const unsigned char yyr2[] =
 {
-       0,     2,     2,     6,     3,     2,     0,     2,     0,     2,
-       2,     4,     6,    10,     8,     9,     7,     5,     3
+       0,     2,     2,     6,     3,     2,     0,     2,     0,     3,
+       1,     2,     3,     5,     9,     7,     8,     6,     4,     2
 };
 
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
@@ -386,9 +438,8 @@ static const unsigned char yyr2[] =
 static const unsigned char yydefact[] =
 {
        0,     0,     6,     0,     8,     5,     6,     0,     1,     0,
-       8,     2,     8,     7,     4,     0,     0,    10,     9,     6,
-       0,    18,     0,     0,    11,     3,     0,    17,     0,    12,
-       0,    16,     0,    14,     0,    15,    13
+       8,     2,    10,     7,     4,     0,    19,    11,     8,     6,
+      12,     9,     0,    18,     3,    13,    17,    15,    16,    14
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
@@ -399,19 +450,18 @@ static const yysigned_char yydefgoto[] =
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -7
+#define YYPACT_NINF -10
 static const yysigned_char yypact[] =
 {
-      16,    16,    19,    25,    -3,    -7,    19,    -4,    -7,    22,
-      -3,    -7,    -3,    -7,    -7,    23,     1,    -7,    -7,    19,
-       2,    -7,    24,     5,    -7,    -7,     6,    -7,    10,    -7,
-      11,    -7,    14,    -7,    26,    -7,    -7
+       0,     0,     3,    10,    -2,   -10,     3,    -3,   -10,     7,
+      -2,   -10,     6,   -10,   -10,    11,    12,   -10,    -2,     3,
+      13,   -10,     8,    14,   -10,    15,    16,    17,    18,   -10
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yysigned_char yypgoto[] =
 {
-      -7,    -7,    27,    -6,     9,    -7
+     -10,   -10,    22,    -6,    -9,   -10
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
@@ -421,18 +471,16 @@ static const yysigned_char yypgoto[] =
 #define YYTABLE_NINF -1
 static const unsigned char yytable[] =
 {
-      13,     9,    14,    10,    15,    20,    23,    21,    24,    26,
-      28,    27,    29,    22,    30,    32,    31,    33,    34,    17,
-      35,    18,     1,     2,     6,     8,    16,    19,     5,     0,
-      25,     0,    36
+      13,    17,     9,    14,    10,    15,     1,     2,     6,    21,
+       8,    16,    18,    22,    24,    19,    20,    23,    25,    26,
+      27,    28,    29,     5
 };
 
-static const yysigned_char yycheck[] =
+static const unsigned char yycheck[] =
 {
-       6,     4,     6,     6,     8,     4,     4,     6,     6,     4,
-       4,     6,     6,    19,     4,     4,     6,     6,     4,    10,
-       6,    12,     6,     7,     5,     0,     4,     4,     1,    -1,
-       6,    -1,     6
+       6,    10,     4,     6,     6,     8,     6,     7,     5,    18,
+       0,     4,     6,    19,     6,     4,     4,     4,     4,     4,
+       4,     4,     4,     1
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
@@ -440,27 +488,10 @@ static const yysigned_char yycheck[] =
 static const unsigned char yystos[] =
 {
        0,     6,     7,    10,    11,    11,     5,    12,     0,     4,
-       6,    13,    14,    12,     6,     8,     4,    13,    13,     4,
-       4,     6,    12,     4,     6,     6,     4,     6,     4,     6,
-       4,     6,     4,     6,     4,     6,     6
+       6,    13,    14,    12,     6,     8,     4,    13,     6,     4,
+       4,    13,    12,     4,     6,     4,     4,     4,     4,     4
 };
 
-#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
-# define YYSIZE_T __SIZE_TYPE__
-#endif
-#if ! defined (YYSIZE_T) && defined (size_t)
-# define YYSIZE_T size_t
-#endif
-#if ! defined (YYSIZE_T)
-# if defined (__STDC__) || defined (__cplusplus)
-#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
-#  define YYSIZE_T size_t
-# endif
-#endif
-#if ! defined (YYSIZE_T)
-# define YYSIZE_T unsigned int
-#endif
-
 #define yyerrok		(yyerrstatus = 0)
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		(-2)
@@ -490,26 +521,59 @@ do								\
       goto yybackup;						\
     }								\
   else								\
-    { 								\
-      yyerror ("syntax error: cannot back up");\
+    {								\
+      yyerror (YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -532,19 +596,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (yydebug)					\
-    yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
-      yysymprint (stderr, 					\
-                  Token, Value);	\
+      yysymprint (stderr,					\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -591,13 +649,13 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylno = yyrline[yyrule];
-  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
+  unsigned long int yylno = yyrline[yyrule];
+  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu), ",
              yyrule - 1, yylno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
-    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
-  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
+    YYFPRINTF (stderr, "%s ", yytname[yyrhs[yyi]]);
+  YYFPRINTF (stderr, "-> %s\n", yytname[yyr1[yyrule]]);
 }
 
 # define YY_REDUCE_PRINT(Rule)		\
@@ -611,8 +669,7 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -627,13 +684,9 @@ int yydebug;
    if the built-in stack extension method is used).
 
    Do not make this value too large; the results are undefined if
-   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
+   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -655,7 +708,7 @@ yystrlen (yystr)
      const char *yystr;
 #   endif
 {
-  register const char *yys = yystr;
+  const char *yys = yystr;
 
   while (*yys++ != '\0')
     continue;
@@ -680,8 +733,8 @@ yystpcpy (yydest, yysrc)
      const char *yysrc;
 #   endif
 {
-  register char *yyd = yydest;
-  register const char *yys = yysrc;
+  char *yyd = yydest;
+  const char *yys = yysrc;
 
   while ((*yyd++ = *yys++) != '\0')
     continue;
@@ -691,7 +744,55 @@ yystpcpy (yydest, yysrc)
 #  endif
 # endif
 
-#endif /* !YYERROR_VERBOSE */
+# ifndef yytnamerr
+/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
+   quotes and backslashes, so that it's suitable for yyerror.  The
+   heuristic is that double-quoting is unnecessary unless the string
+   contains an apostrophe, a comma, or backslash (other than
+   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
+   null, do not copy; instead, return the length of what the result
+   would have been.  */
+static YYSIZE_T
+yytnamerr (char *yyres, const char *yystr)
+{
+  if (*yystr == '"')
+    {
+      size_t yyn = 0;
+      char const *yyp = yystr;
+
+      for (;;)
+	switch (*++yyp)
+	  {
+	  case '\'':
+	  case ',':
+	    goto do_not_strip_quotes;
+
+	  case '\\':
+	    if (*++yyp != '\\')
+	      goto do_not_strip_quotes;
+	    /* Fall through.  */
+	  default:
+	    if (yyres)
+	      yyres[yyn] = *yyp;
+	    yyn++;
+	    break;
+
+	  case '"':
+	    if (yyres)
+	      yyres[yyn] = '\0';
+	    return yyn;
+	  }
+    do_not_strip_quotes: ;
+    }
+
+  if (! yyres)
+    return yystrlen (yystr);
+
+  return yystpcpy (yyres, yystr) - yyres;
+}
+# endif
+
+#endif /* YYERROR_VERBOSE */
 
 
 
@@ -715,15 +816,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    {
-      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
-# ifdef YYPRINT
-      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
-    }
+    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
+
+# ifdef YYPRINT
+  if (yytype < YYNTOKENS)
+    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
   switch (yytype)
     {
       default:
@@ -739,10 +840,11 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yytype, yyvaluep)
+yydestruct (yymsg, yytype, yyvaluep)
+    const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -750,6 +852,10 @@ yydestruct (yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
+  if (!yymsg)
+    yymsg = "Deleting";
+  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
+
   switch (yytype)
     {
 
@@ -777,10 +883,10 @@ int yyparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -806,17 +912,17 @@ yyparse (void)
 #else
 int
 yyparse ()
-
+    ;
 #endif
 #endif
 {
   
-  register int yystate;
-  register int yyn;
+  int yystate;
+  int yyn;
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -830,12 +936,12 @@ yyparse ()
   /* The state stack.  */
   short int yyssa[YYINITDEPTH];
   short int *yyss = yyssa;
-  register short int *yyssp;
+  short int *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
   YYSTYPE *yyvs = yyvsa;
-  register YYSTYPE *yyvsp;
+  YYSTYPE *yyvsp;
 
 
 
@@ -867,7 +973,6 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -900,7 +1005,7 @@ yyparse ()
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
 	   be undefined if yyoverflow is a macro.  */
-	yyoverflow ("parser stack overflow",
+	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
 
@@ -911,11 +1016,11 @@ yyparse ()
       }
 #else /* no yyoverflow */
 # ifndef YYSTACK_RELOCATE
-      goto yyoverflowlab;
+      goto yyexhaustedlab;
 # else
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
-	goto yyoverflowlab;
+	goto yyexhaustedlab;
       yystacksize *= 2;
       if (YYMAXDEPTH < yystacksize)
 	yystacksize = YYMAXDEPTH;
@@ -925,7 +1030,7 @@ yyparse ()
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
-	  goto yyoverflowlab;
+	  goto yyexhaustedlab;
 	YYSTACK_RELOCATE (yyss);
 	YYSTACK_RELOCATE (yyvs);
 
@@ -957,18 +1062,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -983,7 +1088,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1003,8 +1108,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1062,7 +1167,7 @@ yyreduce:
 #line 75 "parse_touchstone.y"
     {
     touchstone_vector = NULL;
-    touchstone_options.resistance = yyvsp[-2].f;
+    touchstone_options.resistance = (yyvsp[-2].f);
   }
     break;
 
@@ -1088,8 +1193,8 @@ yyreduce:
 #line 87 "parse_touchstone.y"
     {
     if (touchstone_idents == NULL) touchstone_idents = new strlist ();
-    touchstone_idents->add (yyvsp[-1].ident);
-    free (yyvsp[-1].ident);
+    touchstone_idents->add ((yyvsp[-1].ident));
+    free ((yyvsp[-1].ident));
   }
     break;
 
@@ -1101,129 +1206,140 @@ yyreduce:
   case 9:
 #line 95 "parse_touchstone.y"
     { /* append vector lines */
-    yyvsp[-1].v->setNext (touchstone_vector);
-    touchstone_vector = yyvsp[-1].v;
+    (yyvsp[-2].v)->setNext (touchstone_vector);
+    touchstone_vector = (yyvsp[-2].v);
   }
     break;
 
   case 10:
 #line 99 "parse_touchstone.y"
-    { /* skip this line */ }
-    break;
-
-  case 11:
-#line 103 "parse_touchstone.y"
-    { 
-    /* 1-port start */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-3].f);
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+    { /* last line, no trailing end-of-line */
+    (yyvsp[0].v)->setNext (touchstone_vector);
+    touchstone_vector = (yyvsp[0].v);
+    logprint (LOG_ERROR, "line %d: no trailing end-of-line found, "
+	      "continuing...\n", touchstone_lineno);
   }
     break;
 
+  case 11:
+#line 105 "parse_touchstone.y"
+    { /* skip this line */ }
+    break;
+
   case 12:
-#line 110 "parse_touchstone.y"
-    {
-    /* noise parameters */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-5].f);
-    yyval.v->add (yyvsp[-4].f);
-    yyval.v->add (yyvsp[-3].f);
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+#line 109 "parse_touchstone.y"
+    { 
+    /* 1-port start */
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-2].f));
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
   }
     break;
 
   case 13:
-#line 119 "parse_touchstone.y"
+#line 116 "parse_touchstone.y"
     {
-    /* 2-port and 4- to n-port start */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-9].f);
-    yyval.v->add (yyvsp[-8].f);
-    yyval.v->add (yyvsp[-7].f);
-    yyval.v->add (yyvsp[-6].f);
-    yyval.v->add (yyvsp[-5].f);
-    yyval.v->add (yyvsp[-4].f);
-    yyval.v->add (yyvsp[-3].f);
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+    /* noise parameters */
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-4].f));
+    (yyval.v)->add ((yyvsp[-3].f));
+    (yyval.v)->add ((yyvsp[-2].f));
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
   }
     break;
 
   case 14:
-#line 132 "parse_touchstone.y"
+#line 125 "parse_touchstone.y"
     {
-    /* 3-port start */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-7].f);
-    yyval.v->add (yyvsp[-6].f);
-    yyval.v->add (yyvsp[-5].f);
-    yyval.v->add (yyvsp[-4].f);
-    yyval.v->add (yyvsp[-3].f);
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+    /* 2-port and 4- to n-port start */
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-8].f));
+    (yyval.v)->add ((yyvsp[-7].f));
+    (yyval.v)->add ((yyvsp[-6].f));
+    (yyval.v)->add ((yyvsp[-5].f));
+    (yyval.v)->add ((yyvsp[-4].f));
+    (yyval.v)->add ((yyvsp[-3].f));
+    (yyval.v)->add ((yyvsp[-2].f));
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
   }
     break;
 
   case 15:
-#line 143 "parse_touchstone.y"
-    { 
-    /* 4- and n-port continued */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-8].f);
-    yyval.v->add (yyvsp[-7].f);
-    yyval.v->add (yyvsp[-6].f);
-    yyval.v->add (yyvsp[-5].f);
-    yyval.v->add (yyvsp[-4].f);
-    yyval.v->add (yyvsp[-3].f);
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+#line 138 "parse_touchstone.y"
+    {
+    /* 3-port start */
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-6].f));
+    (yyval.v)->add ((yyvsp[-5].f));
+    (yyval.v)->add ((yyvsp[-4].f));
+    (yyval.v)->add ((yyvsp[-3].f));
+    (yyval.v)->add ((yyvsp[-2].f));
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
   }
     break;
 
   case 16:
-#line 155 "parse_touchstone.y"
+#line 149 "parse_touchstone.y"
     { 
-    /* 3- and n-port continued */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-6].f);
-    yyval.v->add (yyvsp[-5].f);
-    yyval.v->add (yyvsp[-4].f);
-    yyval.v->add (yyvsp[-3].f);
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+    /* 4- and n-port continued */
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-7].f));
+    (yyval.v)->add ((yyvsp[-6].f));
+    (yyval.v)->add ((yyvsp[-5].f));
+    (yyval.v)->add ((yyvsp[-4].f));
+    (yyval.v)->add ((yyvsp[-3].f));
+    (yyval.v)->add ((yyvsp[-2].f));
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
   }
     break;
 
   case 17:
-#line 165 "parse_touchstone.y"
+#line 161 "parse_touchstone.y"
     { 
-    /* n-port continued */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-4].f);
-    yyval.v->add (yyvsp[-3].f);
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+    /* 3- and n-port continued */
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-5].f));
+    (yyval.v)->add ((yyvsp[-4].f));
+    (yyval.v)->add ((yyvsp[-3].f));
+    (yyval.v)->add ((yyvsp[-2].f));
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
   }
     break;
 
   case 18:
-#line 173 "parse_touchstone.y"
+#line 171 "parse_touchstone.y"
     { 
     /* n-port continued */
-    yyval.v = new vector ();
-    yyval.v->add (yyvsp[-2].f);
-    yyval.v->add (yyvsp[-1].f);
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-3].f));
+    (yyval.v)->add ((yyvsp[-2].f));
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
+  }
+    break;
+
+  case 19:
+#line 179 "parse_touchstone.y"
+    { 
+    /* n-port continued */
+    (yyval.v) = new vector ();
+    (yyval.v)->add ((yyvsp[-1].f));
+    (yyval.v)->add ((yyvsp[0].f));
   }
     break;
 
 
+      default: break;
     }
 
-/* Line 1010 of yacc.c.  */
-#line 1227 "parse_touchstone.cpp"
+/* Line 1126 of yacc.c.  */
+#line 1343 "parse_touchstone.cpp"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1262,12 +1378,36 @@ yyerrlab:
 
       if (YYPACT_NINF < yyn && yyn < YYLAST)
 	{
-	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
-	  const char* yyprefix;
-	  char *yymsg;
+	  YYSIZE_T yysize0 = yytnamerr (0, yytname[yytype]);
+	  YYSIZE_T yysize = yysize0;
+	  YYSIZE_T yysize1;
+	  int yysize_overflow = 0;
+	  char *yymsg = 0;
+#	  define YYERROR_VERBOSE_ARGS_MAXIMUM 5
+	  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
 	  int yyx;
 
+#if 0
+	  /* This is so xgettext sees the translatable formats that are
+	     constructed on the fly.  */
+	  YY_("syntax error, unexpected %s");
+	  YY_("syntax error, unexpected %s, expecting %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s or %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
+#endif
+	  char *yyfmt;
+	  char const *yyf;
+	  static char const yyunexpected[] = "syntax error, unexpected %s";
+	  static char const yyexpecting[] = ", expecting %s";
+	  static char const yyor[] = " or %s";
+	  char yyformat[sizeof yyunexpected
+			+ sizeof yyexpecting - 1
+			+ ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
+			   * (sizeof yyor - 1))];
+	  char const *yyprefix = yyexpecting;
+
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
 	  int yyxbegin = yyn < 0 ? -yyn : 0;
@@ -1275,81 +1415,91 @@ yyerrlab:
 	  /* Stay within bounds of both yycheck and yytname.  */
 	  int yychecklim = YYLAST - yyn;
 	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
-	  int yycount = 0;
+	  int yycount = 1;
+
+	  yyarg[0] = yytname[yytype];
+	  yyfmt = yystpcpy (yyformat, yyunexpected);
 
-	  yyprefix = ", expecting ";
 	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 	      {
-		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
-		yycount += 1;
-		if (yycount == 5)
+		if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
 		  {
-		    yysize = 0;
+		    yycount = 1;
+		    yysize = yysize0;
+		    yyformat[sizeof yyunexpected - 1] = '\0';
 		    break;
 		  }
+		yyarg[yycount++] = yytname[yyx];
+		yysize1 = yysize + yytnamerr (0, yytname[yyx]);
+		yysize_overflow |= yysize1 < yysize;
+		yysize = yysize1;
+		yyfmt = yystpcpy (yyfmt, yyprefix);
+		yyprefix = yyor;
 	      }
-	  yysize += (sizeof ("syntax error, unexpected ")
-		     + yystrlen (yytname[yytype]));
-	  yymsg = (char *) YYSTACK_ALLOC (yysize);
-	  if (yymsg != 0)
-	    {
-	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
-	      yyp = yystpcpy (yyp, yytname[yytype]);
 
-	      if (yycount < 5)
+	  yyf = YY_(yyformat);
+	  yysize1 = yysize + yystrlen (yyf);
+	  yysize_overflow |= yysize1 < yysize;
+	  yysize = yysize1;
+
+	  if (!yysize_overflow && yysize <= YYSTACK_ALLOC_MAXIMUM)
+	    yymsg = (char *) YYSTACK_ALLOC (yysize);
+	  if (yymsg)
+	    {
+	      /* Avoid sprintf, as that infringes on the user's name space.
+		 Don't have undefined behavior even if the translation
+		 produced a string with the wrong number of "%s"s.  */
+	      char *yyp = yymsg;
+	      int yyi = 0;
+	      while ((*yyp = *yyf))
 		{
-		  yyprefix = ", expecting ";
-		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
-		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-		      {
-			yyp = yystpcpy (yyp, yyprefix);
-			yyp = yystpcpy (yyp, yytname[yyx]);
-			yyprefix = " or ";
-		      }
+		  if (*yyp == '%' && yyf[1] == 's' && yyi < yycount)
+		    {
+		      yyp += yytnamerr (yyp, yyarg[yyi++]);
+		      yyf += 2;
+		    }
+		  else
+		    {
+		      yyp++;
+		      yyf++;
+		    }
 		}
 	      yyerror (yymsg);
 	      YYSTACK_FREE (yymsg);
 	    }
 	  else
-	    yyerror ("syntax error; also virtual memory exhausted");
+	    {
+	      yyerror (YY_("syntax error"));
+	      goto yyexhaustedlab;
+	    }
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	yyerror ("syntax error");
+	yyerror (YY_("syntax error"));
     }
 
 
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
         {
-          /* If at end of input, pop the error token,
-	     then the rest of the stack, then return failure.  */
+	  /* Return failure if at end of input.  */
 	  if (yychar == YYEOF)
-	     for (;;)
-	       {
-		 YYPOPSTACK;
-		 if (yyssp == yyss)
-		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-		 yydestruct (yystos[*yyssp], yyvsp);
-	       }
+	    YYABORT;
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-	  yydestruct (yytoken, &yylval);
+	  yydestruct ("Error: discarding", yytoken, &yylval);
 	  yychar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1359,14 +1509,13 @@ yyerrlab:
 `---------------------------------------------------*/
 yyerrorlab:
 
-#ifdef __GNUC__
-  /* Pacify GCC when the user code never invokes YYERROR and the label
-     yyerrorlab therefore never appears in user code.  */
+  /* Pacify compilers like GCC when the user code never invokes
+     YYERROR and the label yyerrorlab therefore never appears in user
+     code.  */
   if (0)
      goto yyerrorlab;
-#endif
 
-  yyvsp -= yylen;
+yyvsp -= yylen;
   yyssp -= yylen;
   yystate = *yyssp;
   goto yyerrlab1;
@@ -1396,8 +1545,8 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-      yydestruct (yystos[yystate], yyvsp);
+
+      yydestruct ("Error: popping", yystos[yystate], yyvsp);
       YYPOPSTACK;
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -1406,11 +1555,12 @@ yyerrlab1:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++yyvsp = yylval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
+
   yystate = yyn;
   goto yynewstate;
 
@@ -1430,16 +1580,25 @@ yyabortlab:
   goto yyreturn;
 
 #ifndef yyoverflow
-/*----------------------------------------------.
-| yyoverflowlab -- parser overflow comes here.  |
-`----------------------------------------------*/
-yyoverflowlab:
-  yyerror ("parser stack overflow");
+/*-------------------------------------------------.
+| yyexhaustedlab -- memory exhaustion comes here.  |
+`-------------------------------------------------*/
+yyexhaustedlab:
+  yyerror (YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
 
 yyreturn:
+  if (yychar != YYEOF && yychar != YYEMPTY)
+     yydestruct ("Cleanup: discarding lookahead",
+		 yytoken, &yylval);
+  while (yyssp != yyss)
+    {
+      yydestruct ("Cleanup: popping",
+		  yystos[*yyssp], yyvsp);
+      YYPOPSTACK;
+    }
 #ifndef yyoverflow
   if (yyss != yyssa)
     YYSTACK_FREE (yyss);
@@ -1448,7 +1607,7 @@ yyreturn:
 }
 
 
-#line 181 "parse_touchstone.y"
+#line 187 "parse_touchstone.y"
 
 
 int touchstone_error (char * error) {
