@@ -1,7 +1,7 @@
 /*
  * qucsdefs.h - netlist definitions for the Qucs netlists
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: qucsdefs.h,v 1.23 2005/07/20 16:49:51 raimi Exp $
+ * $Id: qucsdefs.h,v 1.49 2006/05/23 09:48:32 raimi Exp $
  *
  */
 
@@ -31,7 +31,10 @@ struct define_t qucs_definition_available[] =
   /* resistor */
   { "R", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR, 
     { { "R", PROP_REAL, { 50, PROP_NO_STR }, PROP_NO_RANGE }, PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      { "Tc1", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Tc2", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       PROP_NO_PROP }
   },
   /* inductor */
@@ -45,6 +48,25 @@ struct define_t qucs_definition_available[] =
       PROP_NO_PROP },
     { PROP_NO_PROP }
   },
+  /* two mutual inductors */
+  { "MUT", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "L1", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
+      { "L2", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
+      { "k", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
+      PROP_NO_PROP },
+    { PROP_NO_PROP }
+  },
+  /* three mutual inductors */
+  { "MUT2", 6, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "L1", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
+      { "L2", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
+      { "L3", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
+      { "k12", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
+      { "k13", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
+      { "k23", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
+      PROP_NO_PROP },
+    { PROP_NO_PROP }
+  },
   /* voltage controlled current source */
   { "VCCS", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "G", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE }, PROP_NO_PROP },
@@ -68,11 +90,11 @@ struct define_t qucs_definition_available[] =
   /* power source */
   { "Pac", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "f", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Z", PROP_REAL, { 50, PROP_NO_STR }, { PROP_VAL_MIN, PROP_VAL_MAX } },
-      { "Num", PROP_INT, { 1, PROP_NO_STR }, { 1, MAX_PORTS } },
+      { "Z", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Num", PROP_INT, { 1, PROP_NO_STR }, { '[', 1, MAX_PORTS, ']' } },
       PROP_NO_PROP },
     { { "P", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       PROP_NO_PROP }
   },
   /* circulator */
@@ -85,15 +107,15 @@ struct define_t qucs_definition_available[] =
   /* isolator */
   { "Isolator", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "Z1", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
       { "Z2", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
   },
   /* attenuator */
   { "Attenuator", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
-    { { "L", PROP_REAL, { 10, PROP_NO_STR }, { 1, PROP_VAL_MAX } },
+    { { "L", PROP_REAL, { 10, PROP_NO_STR }, PROP_MIN_VAL (1) },
       PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "Zref", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
       PROP_NO_PROP }
   },
@@ -141,14 +163,34 @@ struct define_t qucs_definition_available[] =
   { "Vac", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "U", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE }, 
       { "f", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
-    { { "Phase", PROP_REAL, { 0, PROP_NO_STR }, { -360, 360 } },
+    { { "Phase", PROP_REAL, { 0, PROP_NO_STR }, { '[', -360, 360, ']' } },
+      { "Theta", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       PROP_NO_PROP }
   },
   /* AC current source */
   { "Iac", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "I", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_NO_RANGE }, 
       { "f", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
-    { { "Phase", PROP_REAL, { 0, PROP_NO_STR }, { -360, 360 } },
+    { { "Phase", PROP_REAL, { 0, PROP_NO_STR }, { '[', -360, 360, ']' } },
+      { "Theta", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP }
+  },
+  /* AM modulated AC voltage source */
+  { "AM_Mod", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "U", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "f", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE },
+      { "m", PROP_REAL, { 1, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      PROP_NO_PROP },
+    { { "Phase", PROP_REAL, { 0, PROP_NO_STR }, { '[', -360, 360, ']' } },
+      PROP_NO_PROP }
+  },
+  /* PM modulated AC voltage source */
+  { "PM_Mod", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "U", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "f", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE },
+      { "M", PROP_REAL, { 1, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      PROP_NO_PROP },
+    { { "Phase", PROP_REAL, { 0, PROP_NO_STR }, { '[', -360, 360, ']' } },
       PROP_NO_PROP }
   },
   /* pulse voltage source */
@@ -202,15 +244,63 @@ struct define_t qucs_definition_available[] =
     { { "Zref", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
       PROP_NO_PROP }
   },
+  /* time controlled switch */
+  { "Switch", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "init", PROP_STR, { PROP_NO_VAL, "off" }, PROP_NO_RANGE },
+      { "time", PROP_LIST, { 1e-9, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP },
+    { { "Ron", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Roff", PROP_REAL, { 1e12, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
+  /* relais */
+  { "Relais", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "Vt", PROP_REAL, { 0.5, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Vh", PROP_REAL, { 0.1, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP },
+    { { "Ron", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Roff", PROP_REAL, { 1e12, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
   /* ideal transmission line */
   { "TLIN", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "Z", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE }, 
       { "L", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_NO_RANGE },
       PROP_NO_PROP },
+    { { "Alpha", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
+  /* coaxial cable */
+  { "COAX", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "D", PROP_REAL, { 2.95e-3, PROP_NO_STR }, PROP_POS_RANGEX }, 
+      { "d", PROP_REAL, { 0.9e-3, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "L", PROP_REAL, { 1500e-3, PROP_NO_STR }, PROP_NO_RANGE },
+      { "er", PROP_REAL, { 2.29, PROP_NO_STR }, { '[', 1, 100, ']' } },
+      { "mur", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1, 100, ']' } },
+      { "tand", PROP_REAL, { 4e-4, PROP_NO_STR }, PROP_POS_RANGE },
+      { "rho", PROP_REAL, { 0.022e-6, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
+  /* ideal coupler */
+  { "Coupler", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "k", PROP_REAL, { M_SQRT1_2, PROP_NO_STR }, PROP_NO_RANGE },
+      { "phi", PROP_REAL, { 0, PROP_NO_STR }, { '[', -180, +180, ']' } },
+      PROP_NO_PROP },
+    { { "Z", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP }
+  },
+  /* current probe */
+  { "IProbe", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { PROP_NO_PROP },
     { PROP_NO_PROP }
   },
-  /* DC current probe */
-  { "IProbe", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+  /* voltage probe */
+  { "VProbe", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { PROP_NO_PROP },
     { PROP_NO_PROP }
   },
@@ -219,12 +309,14 @@ struct define_t qucs_definition_available[] =
     { { "File", PROP_STR, { PROP_NO_VAL, "spfile.snp" }, PROP_NO_RANGE },
       PROP_NO_PROP },
     { { "Data", PROP_STR, { PROP_NO_VAL, "polar" }, PROP_NO_RANGE },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "Interpolator", PROP_STR, { PROP_NO_VAL, "linear" }, PROP_NO_RANGE },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      { "duringDC", PROP_STR, { PROP_NO_VAL, "open" }, PROP_NO_RANGE },
       PROP_NO_PROP }
   },
   /* amplifier */
   { "Amp", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
-    { { "G", PROP_REAL, { 10, PROP_NO_STR }, { 1, PROP_VAL_MAX } },
+    { { "G", PROP_REAL, { 10, PROP_NO_STR }, PROP_MIN_VAL (1) },
       PROP_NO_PROP },
     { { "Z1", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
       { "Z2", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
@@ -232,7 +324,7 @@ struct define_t qucs_definition_available[] =
   },
   /* operational amplifier */
   { "OpAmp", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
-    { { "G", PROP_REAL, { 1e6, PROP_NO_STR }, { 1, PROP_VAL_MAX } },
+    { { "G", PROP_REAL, { 1e6, PROP_NO_STR }, PROP_MIN_VAL (1) },
       PROP_NO_PROP },
     { { "Umax", PROP_REAL, { 15, PROP_NO_STR }, PROP_POS_RANGE },
       PROP_NO_PROP }
@@ -255,82 +347,128 @@ struct define_t qucs_definition_available[] =
       { "e", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       PROP_NO_PROP }
   },
+  /* correlated noise current sources */
+  { "IInoise", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "i1", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "i2", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "C", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', -1, 1, ']' } }, 
+      PROP_NO_PROP },
+    { { "a", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "c", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
+      { "e", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP }
+  },
+  /* correlated noise voltage sources */
+  { "VVnoise", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "v1", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "v2", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "C", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', -1, 1, ']' } }, 
+      PROP_NO_PROP },
+    { { "a", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "c", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
+      { "e", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP }
+  },
+  /* correlated noise sources */
+  { "IVnoise", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "i1", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "v2", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "C", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', -1, 1, ']' } }, 
+      PROP_NO_PROP },
+    { { "a", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "c", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
+      { "e", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP }
+  },
 
   /* diode */
   { "Diode", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
     { { "Is", PROP_REAL, { 1e-15, PROP_NO_STR }, PROP_POS_RANGE },
-      { "N", PROP_REAL, { 1, PROP_NO_STR }, { 1, 100 } },
-      { "M", PROP_REAL, { 0.5, PROP_NO_STR }, { 0, 1 } },
+      { "N", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1, 100, ']' } },
+      { "M", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 0, 2, ']' } },
       { "Cj0", PROP_REAL, { 10e-15, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Vj", PROP_REAL, { 0.7, PROP_NO_STR }, { PROP_VAL_MIN, 10 } },
+      { "Vj", PROP_REAL, { 0.7, PROP_NO_STR }, { ']', 0, 10, ']' } },
       PROP_NO_PROP },
     { { "Rs", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Isr", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Nr", PROP_REAL, { 2, PROP_NO_STR }, { 1, 100 } },
+      { "Nr", PROP_REAL, { 2, PROP_NO_STR }, { '[', 1, 100, ']' } },
       { "Bv", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ibv", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_POS_RANGE },
       { "Tt", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { 0, 1 - PROP_VAL_MIN } },
+      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 0, 1, '[' } },
       { "Cp", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Kf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Af", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ffe", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      { "Xti", PROP_REAL, { 3, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Eg", PROP_REAL, { EgSi, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Tbv", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Trs", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Ttt1", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Ttt2", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Tm1", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Tm2", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      { "Area", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGEX },
       PROP_NO_PROP }
   },
   /* jfet */
   { "JFET", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
     { { "Is", PROP_REAL, { 1e-14, PROP_NO_STR }, PROP_POS_RANGE },
-      { "N", PROP_REAL, { 1, PROP_NO_STR }, { 1, 100 } },
+      { "N", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1, 100, ']' } },
       { "Vt0", PROP_REAL, { -2, PROP_NO_STR }, PROP_NEG_RANGE },
       { "Lambda", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Beta", PROP_REAL, { 1e-4, PROP_NO_STR }, PROP_POS_RANGE },
-      { "M", PROP_REAL, { 0.5, PROP_NO_STR }, { 0, 1 } },
-      { "Pb", PROP_REAL, { 1.0, PROP_NO_STR }, { PROP_VAL_MIN, 10 } },
-      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { 0, 1 - PROP_VAL_MIN } },
+      { "M", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "Pb", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 0, 1, '[' } },
       { "Cgs", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Cgd", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
     { { "Rd", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Rs", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Isr", PROP_REAL, { 1e-14, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Nr", PROP_REAL, { 2, PROP_NO_STR }, { 1, 100 } },
+      { "Nr", PROP_REAL, { 2, PROP_NO_STR }, { '[', 1, 100, ']' } },
       { "Kf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Af", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ffe", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "Type", PROP_STR, { PROP_NO_VAL, "nfet" }, PROP_NO_RANGE },
+      { "Xti", PROP_REAL, { 3, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Vt0tc", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Betatce", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      { "Area", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGEX },
       PROP_NO_PROP }
   },
   /* sgp bjt */
   { "BJT", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
     { { "Is", PROP_REAL, { 1e-16, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Nf", PROP_REAL, { 1, PROP_NO_STR }, { 1, 100 } },
-      { "Nr", PROP_REAL, { 1, PROP_NO_STR }, { 1, 100 } },
+      { "Nf", PROP_REAL, { 1, PROP_NO_STR }, { '[', 0.9, 100, ']' } },
+      { "Nr", PROP_REAL, { 1, PROP_NO_STR }, { '[', 0.9, 100, ']' } },
       { "Ikf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ikr", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Vaf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Var", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ise", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Ne", PROP_REAL, { 1.5, PROP_NO_STR }, { 1, 100 } },
+      { "Ne", PROP_REAL, { 1.5, PROP_NO_STR }, { '[', 1, 100, ']' } },
       { "Isc", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Nc", PROP_REAL, { 2, PROP_NO_STR }, { 1, 100 } },
-      { "Bf", PROP_REAL, 
-	{ 100, PROP_NO_STR }, { PROP_VAL_MIN, PROP_VAL_MAX } },
-      { "Br", PROP_REAL, 
-	{ 1, PROP_NO_STR }, { PROP_VAL_MIN, PROP_VAL_MAX } },
+      { "Nc", PROP_REAL, { 2, PROP_NO_STR }, { '[', 1, 100, ']' } },
+      { "Bf", PROP_REAL, { 100, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Br", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGEX },
       { "Rbm", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Irb", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Cje", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Vje", PROP_REAL, { 0.75, PROP_NO_STR }, { PROP_VAL_MIN, 10 } },
-      { "Mje", PROP_REAL, { 0.33, PROP_NO_STR }, { 0, 1 } },
+      { "Vje", PROP_REAL, { 0.75, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "Mje", PROP_REAL, { 0.33, PROP_NO_STR }, { '[', 0, 1, ']' } },
       { "Cjc", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Vjc", PROP_REAL, { 0.75, PROP_NO_STR }, { PROP_VAL_MIN, 10 } },
-      { "Mjc", PROP_REAL, { 0.33, PROP_NO_STR }, { 0, 1 } },
-      { "Xcjc", PROP_REAL, { 1, PROP_NO_STR }, { 0, 1 } },
+      { "Vjc", PROP_REAL, { 0.75, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "Mjc", PROP_REAL, { 0.33, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "Xcjc", PROP_REAL, { 1, PROP_NO_STR }, { '[', 0, 1, ']' } },
       { "Cjs", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Vjs", PROP_REAL, { 0.75, PROP_NO_STR }, { PROP_VAL_MIN, 10 } },
-      { "Mjs", PROP_REAL, { 0, PROP_NO_STR }, { 0, 1 } },
-      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { 0, 1 - PROP_VAL_MIN } },
+      { "Vjs", PROP_REAL, { 0.75, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "Mjs", PROP_REAL, { 0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 0, 1, '[' } },
       { "Vtf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Tf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Xtf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
@@ -346,15 +484,20 @@ struct define_t qucs_definition_available[] =
       { "Kb", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ab", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
       { "Fb", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "Type", PROP_STR, { PROP_NO_VAL, "npn" }, PROP_NO_RANGE },
-      { "Ptf", PROP_REAL, { 0, PROP_NO_STR }, { -180, +180 } },
+      { "Ptf", PROP_REAL, { 0, PROP_NO_STR }, { '[', -180, +180, ']' } },
+      { "Xtb", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Xti", PROP_REAL, { 3, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Eg", PROP_REAL, { EgSi, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      { "Area", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGEX },
       PROP_NO_PROP }
   },
   /* fet: level 1 */
   { "MOSFET", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
     { { "Is", PROP_REAL, { 1e-14, PROP_NO_STR }, PROP_POS_RANGE },
-      { "N", PROP_REAL, { 1, PROP_NO_STR }, { 1, 100 } },
+      { "N", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1, 100, ']' } },
       { "Vt0", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
       { "Lambda", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Kp", PROP_REAL, { 2e-5, PROP_NO_STR }, PROP_POS_RANGE },
@@ -364,27 +507,27 @@ struct define_t qucs_definition_available[] =
     { { "Rd", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Rs", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Rg", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "L", PROP_REAL, { 100e-6, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
+      { "L", PROP_REAL, { 100e-6, PROP_NO_STR }, PROP_RNG_X01I },
       { "Ld", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "W", PROP_REAL, { 100e-6, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "Tox", PROP_REAL, { 1e-7, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
+      { "W", PROP_REAL, { 100e-6, PROP_NO_STR }, PROP_RNG_X01I },
+      { "Tox", PROP_REAL, { 1e-7, PROP_NO_STR }, PROP_RNG_X01I },
       { "Cgso", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Cgdo", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Cgbo", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Cbd", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Cbs", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Pb", PROP_REAL, { 0.8, PROP_NO_STR }, { PROP_VAL_MIN, 10 } },
-      { "Mj", PROP_REAL, { 0.5, PROP_NO_STR }, { 0, 1 } },
-      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { 0, 1 - PROP_VAL_MIN } },
+      { "Pb", PROP_REAL, { 0.8, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "Mj", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 0, 1, '[' } },
       { "Cjsw", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Mjsw", PROP_REAL, { 0.33, PROP_NO_STR }, { 0, 1 } },
+      { "Mjsw", PROP_REAL, { 0.33, PROP_NO_STR }, { '[', 0, 1, ']' } },
       { "Tt", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Kf", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Af", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ffe", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
       { "Nsub", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Nss", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Tpg", PROP_INT, { 1, PROP_NO_STR }, { -1 , 1 } },
+      { "Tpg", PROP_INT, { 1, PROP_NO_STR }, { '[', -1 , 1, ']' } },
       { "Uo", PROP_REAL, { 600, PROP_NO_STR }, PROP_POS_RANGE },
       { "Rsh", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Nrd", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE },
@@ -395,15 +538,16 @@ struct define_t qucs_definition_available[] =
       { "As", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Pd", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Ps", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "Type", PROP_STR, { PROP_NO_VAL, "nfet" }, PROP_NO_RANGE },
-      { "capModel", PROP_INT, { 2, PROP_NO_STR }, { 1 , 2 } },
+      { "capModel", PROP_INT, { 2, PROP_NO_STR }, { '[', 1 , 2, ']' } },
       PROP_NO_PROP }
   },
 
   /* microstrip substrate */
   { "SUBST", 0, PROP_COMPONENT, PROP_SUBSTRATE, PROP_LINEAR,
-    { { "er", PROP_REAL, { 9.8, PROP_NO_STR }, { 1, 100 } },
+    { { "er", PROP_REAL, { 9.8, PROP_NO_STR }, { '[', 1, 100, ']' } },
       { "h", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_POS_RANGE },
       { "t", PROP_REAL, { 35e-6, PROP_NO_STR }, PROP_POS_RANGE },
       { "tand", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_POS_RANGE },
@@ -420,7 +564,7 @@ struct define_t qucs_definition_available[] =
       { "DispModel", PROP_STR, { PROP_NO_VAL, "Kirschning" }, PROP_NO_RANGE },
       { "Model", PROP_STR, { PROP_NO_VAL, "Hammerstad" }, PROP_NO_RANGE },
       PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       PROP_NO_PROP }
   },
   /* parallel coupled microstrip lines */
@@ -432,7 +576,7 @@ struct define_t qucs_definition_available[] =
       { "Model", PROP_STR, { PROP_NO_VAL, "Kirschning" }, PROP_NO_RANGE },
       { "DispModel", PROP_STR, { PROP_NO_VAL, "Kirschning" }, PROP_NO_RANGE },
       PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       PROP_NO_PROP }
   },
   /* microstrip corner */
@@ -493,7 +637,7 @@ struct define_t qucs_definition_available[] =
 	PROP_NO_RANGE },
       { "MSModel", PROP_STR, { PROP_NO_VAL, "Hammerstad" }, PROP_NO_RANGE },
       PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       PROP_NO_PROP }
   },
   /* microstrip cross-junction */
@@ -511,7 +655,7 @@ struct define_t qucs_definition_available[] =
     { { "D", PROP_REAL, { 100e-6, PROP_NO_STR }, PROP_POS_RANGE },
       { "Subst", PROP_STR, { PROP_NO_VAL, "Subst1" }, PROP_NO_RANGE },
       PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       PROP_NO_PROP }
   },
   /* coplanar line */
@@ -521,7 +665,7 @@ struct define_t qucs_definition_available[] =
       { "L", PROP_REAL, { 10e-3, PROP_NO_STR }, PROP_POS_RANGE },
       { "Subst", PROP_STR, { PROP_NO_VAL, "Subst1" }, PROP_NO_RANGE },
       PROP_NO_PROP },
-    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+    { { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "Backside", PROP_STR, { PROP_NO_VAL, "Metal" }, PROP_NO_RANGE },
       { "Approx", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
       PROP_NO_PROP }
@@ -565,28 +709,73 @@ struct define_t qucs_definition_available[] =
       PROP_NO_PROP }
   },
 
+  /* logical inverter */
+  { "Inv", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
+    { { "t", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+  /* logical nor */
+  { "NOR", PROP_NODES, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
+    { { "t", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+  /* logical or */
+  { "OR", PROP_NODES, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
+    { { "t", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+  /* logical nand */
+  { "NAND", PROP_NODES, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
+    { { "t", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+  /* logical and */
+  { "AND", PROP_NODES, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
+    { { "t", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+  /* logical xnor */
+  { "XNOR", PROP_NODES, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
+    { { "t", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+  /* logical xor */
+  { "XOR", PROP_NODES, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP },
+    { { "t", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+  /* digital source */
+  { "DigiSource", 1, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "init", PROP_STR, { PROP_NO_VAL, "low" }, PROP_NO_RANGE },
+      { "times", PROP_LIST, { 1e-9, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP },
+    { { "V", PROP_REAL, { 1, PROP_NO_STR }, PROP_POS_RANGE }, PROP_NO_PROP }
+  },
+
   /* s-parameter analysis */
   { "SP", 0, PROP_ACTION, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "Type", PROP_STR, { PROP_NO_VAL, "lin" }, PROP_NO_RANGE },
       PROP_NO_PROP },
     { { "Noise", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
-      { "NoiseIP", PROP_INT, { 1, PROP_NO_STR }, { 1, MAX_PORTS } }, 
-      { "NoiseOP", PROP_INT, { 2, PROP_NO_STR }, { 1, MAX_PORTS } },
+      { "NoiseIP", PROP_INT, { 1, PROP_NO_STR }, { '[', 1, MAX_PORTS, ']' } }, 
+      { "NoiseOP", PROP_INT, { 2, PROP_NO_STR }, { '[', 1, MAX_PORTS, ']' } },
       { "Start", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE },
       { "Stop", PROP_REAL, { 10e9, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Points", PROP_INT, { 10, PROP_NO_STR }, { 2, PROP_VAL_MAX } },
+      { "Points", PROP_INT, { 10, PROP_NO_STR }, PROP_MIN_VAL (2) },
       { "Values", PROP_LIST, { 10, PROP_NO_STR }, PROP_POS_RANGE },
+      { "saveCVs", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
+      { "saveAll", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
       PROP_NO_PROP }
   },
   /* dc analysis */
   { "DC", 0, PROP_ACTION, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { PROP_NO_PROP },
-    { { "MaxIter", PROP_REAL, { 150, PROP_NO_STR }, { 2, 10000 } },
-      { "abstol", PROP_REAL, { 1e-12, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "vntol", PROP_REAL, { 1e-6, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "reltol", PROP_REAL, { 1e-3, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
+    { { "MaxIter", PROP_INT, { 150, PROP_NO_STR }, { '[', 2, 10000, ']' } },
+      { "abstol", PROP_REAL, { 1e-12, PROP_NO_STR }, PROP_RNG_X01I },
+      { "vntol", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_RNG_X01I },
+      { "reltol", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_RNG_X01I },
       { "saveOPs", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "saveAll", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
       { "convHelper", PROP_STR, { PROP_NO_VAL, "none" }, PROP_NO_RANGE },
       { "Solver", PROP_STR, { PROP_NO_VAL, "CroutLU" }, PROP_NO_RANGE },
@@ -598,7 +787,7 @@ struct define_t qucs_definition_available[] =
       { "Param", PROP_STR, { PROP_NO_VAL, "R1" }, PROP_NO_RANGE },
       { "Sim", PROP_STR, { PROP_NO_VAL, "DC1" }, PROP_NO_RANGE },
       PROP_NO_PROP },
-    { { "Points", PROP_INT, { 5, PROP_NO_STR }, { 2, PROP_VAL_MAX } },
+    { { "Points", PROP_INT, { 5, PROP_NO_STR }, PROP_MIN_VAL (2) },
       { "Stop", PROP_REAL, { 50, PROP_NO_STR }, PROP_NO_RANGE },
       { "Start", PROP_REAL, { 5, PROP_NO_STR }, PROP_NO_RANGE },
       { "Values", PROP_LIST, { 5, PROP_NO_STR }, PROP_NO_RANGE },
@@ -611,7 +800,7 @@ struct define_t qucs_definition_available[] =
     { { "Noise", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
       { "Start", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE },
       { "Stop", PROP_REAL, { 10e9, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Points", PROP_INT, { 10, PROP_NO_STR }, { 2, PROP_VAL_MAX } },
+      { "Points", PROP_INT, { 10, PROP_NO_STR }, PROP_MIN_VAL (2) },
       { "Values", PROP_LIST, { 10, PROP_NO_STR }, PROP_POS_RANGE },
       PROP_NO_PROP }
   },
@@ -620,29 +809,35 @@ struct define_t qucs_definition_available[] =
     { { "Type", PROP_STR, { PROP_NO_VAL, "lin" }, PROP_NO_RANGE },
       { "Start", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Stop", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_POS_RANGE },
-      { "Points", PROP_INT, { 10, PROP_NO_STR }, { 2, PROP_VAL_MAX } },
+      { "Points", PROP_INT, { 10, PROP_NO_STR }, PROP_MIN_VAL (2) },
       PROP_NO_PROP },
     { { "IntegrationMethod", PROP_STR, { PROP_NO_VAL, "Trapezoidal" },
 	PROP_NO_RANGE },
-      { "Order", PROP_INT, { 2, PROP_NO_STR }, { 1, 6 } },
+      { "Order", PROP_INT, { 2, PROP_NO_STR }, { '[', 1, 6, ']' } },
       { "InitialStep", PROP_REAL, { 1e-9, PROP_NO_STR }, PROP_POS_RANGE },
       { "MinStep", PROP_REAL, { 1e-16, PROP_NO_STR }, PROP_POS_RANGE },
-      { "MaxIter", PROP_REAL, { 150, PROP_NO_STR }, { 2, 10000 } },
-      { "abstol", PROP_REAL, { 1e-12, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "vntol", PROP_REAL, { 1e-6, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "reltol", PROP_REAL, { 1e-3, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "LTEabstol", PROP_REAL, { 1e-6, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "LTEreltol", PROP_REAL, { 1e-3, PROP_NO_STR }, { PROP_VAL_MIN, 1 } },
-      { "LTEfactor", PROP_REAL, { 1, PROP_NO_STR }, { 1, 16 } },
-      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, { K, PROP_VAL_MAX } },
+      { "MaxIter", PROP_INT, { 150, PROP_NO_STR }, { '[', 2, 10000, ']' } },
+      { "abstol", PROP_REAL, { 1e-12, PROP_NO_STR }, PROP_RNG_X01I },
+      { "vntol", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_RNG_X01I },
+      { "reltol", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_RNG_X01I },
+      { "LTEabstol", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_RNG_X01I },
+      { "LTEreltol", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_RNG_X01I },
+      { "LTEfactor", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1, 16, ']' } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
       { "Solver", PROP_STR, { PROP_NO_VAL, "CroutLU" }, PROP_NO_RANGE },
+      { "relaxTSR", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
       PROP_NO_PROP }
   },
   /* harmonic balance analysis */
   { "HB", 0, PROP_ACTION, PROP_NO_SUBSTRATE, PROP_LINEAR,
-    { { "n", PROP_INT, { 1, PROP_NO_STR }, { 1, PROP_VAL_MAX } },
+    { { "n", PROP_INT, { 1, PROP_NO_STR }, PROP_MIN_VAL (1) },
       PROP_NO_PROP },
-    { PROP_NO_PROP }
+    { { "f", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "iabstol", PROP_REAL, { 1e-12, PROP_NO_STR }, PROP_RNG_X01I },
+      { "vabstol", PROP_REAL, { 1e-6, PROP_NO_STR }, PROP_RNG_X01I },
+      { "reltol", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_RNG_X01I },
+      { "MaxIter", PROP_INT, { 150, PROP_NO_STR }, { '[', 2, 10000, ']' } },
+      PROP_NO_PROP }
   },
   /* subcircuit definition */
   { "Def", PROP_NODES, PROP_ACTION, PROP_NO_SUBSTRATE, PROP_LINEAR,
