@@ -1,7 +1,7 @@
 /*
  * strlist.cpp - string list class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: strlist.cpp,v 1.8 2005/06/02 18:17:51 raimi Exp $
+ * $Id: strlist.cpp,v 1.11 2006/03/29 08:02:03 raimi Exp $
  *
  */
 
@@ -130,6 +130,21 @@ char * strlist::get (int pos) {
   return s ? s->str : NULL;
 }
 
+/* This function returns the string positioned at the end of the
+   string list. */
+char * strlist::last (void) {
+  struct strlist_t * s;
+  for (s = root; s != NULL && s->next != NULL; s = s->next);
+  return s ? s->str : NULL;
+}
+
+/* This function returns the string positioned at the beginning of the
+   string list. */
+char * strlist::first (void) {
+  struct strlist_t * s = root;
+  return s ? s->str : NULL;
+}
+
 /* The function removes each occurrence of the given string list entry
    from the string list object. */
 void strlist::del (strlist * cand) {
@@ -171,3 +186,66 @@ char * strlist::toString (char * concat) {
   if (txt) txt[strlen (txt) - 1] = '\0';
   return txt ? txt : (char *) "";
 }
+
+// Constructor for string list iterator.
+strlistiterator::strlistiterator (strlist & s) {
+  _strlist = &s;
+  toLast ();
+  toFirst ();
+}
+
+// Another constructor for string list iterator.
+strlistiterator::strlistiterator (strlist * s) {
+  _strlist = s;
+  toLast ();
+  toFirst ();
+}
+
+// Default constructor for string list iterator.
+strlistiterator::strlistiterator () {
+  _strlist = NULL;
+  _first = _last = _current = NULL;
+}
+
+// Destructor for string list iterator.
+strlistiterator::~strlistiterator () {
+}
+
+// Returns number of items this iterator operates on.
+int strlistiterator::count (void) {
+  return _strlist->length ();
+}
+
+// Sets the current to the first item in the iterator list.
+char * strlistiterator::toFirst (void) {
+  _current = _first = _strlist->root;
+  return _current ? _current->str : NULL;
+}
+
+// Sets the current to the last item in the iterator list.
+char * strlistiterator::toLast (void) {
+  for (_last = _strlist->root; _last && _last->next; _last = _last->next);
+  _current = _last;
+  return _current ? _current->str : NULL;
+}
+
+// Makes the succeeding item current and returns the new current item.
+char * strlistiterator::operator++ (void) {
+  _current = _current->next;
+  return _current ? _current->str : NULL;
+}
+
+// Returns the current iterator item.
+char * strlistiterator::current (void) {
+  return _current ? _current->str : NULL;
+}
+
+// Returns the first iterator item.
+char * strlistiterator::first (void) {
+  return _first ? _first->str : NULL;
+}
+
+// Returns the last iterator item.
+char * strlistiterator::last (void) {
+  return _last ? _last->str : NULL;
+}
