@@ -1,7 +1,7 @@
 /*
  * strlist.h - string list class definitions
  *
- * Copyright (C) 2003, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,20 +18,24 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: strlist.h,v 1.7 2005/06/02 18:17:51 raimi Exp $
+ * $Id: strlist.h,v 1.10 2006/03/29 08:02:03 raimi Exp $
  *
  */
 
 #ifndef __STRLIST_H__
 #define __STRLIST_H__
 
+/* String list entry. */
 struct strlist_t {
   char * str;
   struct strlist_t * next;
 };
 
+/* String list class. */
 class strlist
 {
+  friend class strlistiterator;
+
  public:
   strlist ();
   strlist (const strlist &);
@@ -40,10 +44,11 @@ class strlist
   void add (strlist *);
   void append (char *);
   void append (strlist *);
-  struct strlist_t * getRoot (void) { return root; }
   int length (void);
   int contains (char *);
   char * get (int);
+  char * first (void);
+  char * last (void);
   int index (char *);
   static strlist * join (strlist *, strlist *);
   void del (strlist *);
@@ -54,4 +59,29 @@ class strlist
   char * txt;
 };
 
+/* String list iterator. */
+class strlistiterator
+{
+ public:
+  strlistiterator ();
+  strlistiterator (strlist &);
+  strlistiterator (strlist *);
+  ~strlistiterator ();
+
+  int count (void);
+  char * toFirst (void);
+  char * toLast (void);
+  char * operator++ (void);
+  char * operator * (void) { return current (); }
+  char * current (void);
+  char * first (void);
+  char * last (void);
+
+ private:
+  strlist * _strlist;
+  struct strlist_t * _first;
+  struct strlist_t * _last;
+  struct strlist_t * _current;
+};
+
 #endif /* __STRLIST_H__ */
