@@ -1,7 +1,7 @@
 /*
  * trsolver.cpp - transient solver class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: trsolver.cpp,v 1.36 2005/06/02 18:17:51 raimi Exp $
+ * $Id: trsolver.cpp,v 1.46 2006/04/28 07:08:26 raimi Exp $
  *
  */
 
@@ -39,16 +39,20 @@
 #include "net.h"
 #include "analysis.h"
 #include "nasolver.h"
+#include "history.h"
 #include "trsolver.h"
 #include "transient.h"
 #include "exception.h"
 #include "exceptionstack.h"
 
-#define STEPDEBUG 0 // set to zero for release
+#define STEPDEBUG   0 // set to zero for release
+#define BREAKPOINTS 0 // exact breakpoint calculation
 
 #define dState 0 // delta T state
 #define sState 1 // solution state
 
+using namespace transient;
+
 // Constructor creates an unnamed instance of the trsolver class.
 trsolver::trsolver ()
   : nasolver<nr_double_t> (), states<nr_double_t> () {
@@ -56,6 +60,8 @@ trsolver::trsolver ()
   type = ANALYSIS_TRANSIENT;
   setDescription ("transient");
   for (int i = 0; i < 8; i++) solution[i] = NULL;
+  tHistory = NULL;
+  relaxTSR = false;
 }
 
 // Constructor creates a named instance of the trsolver class.
@@ -65,12 +71,15 @@ trsolver::trsolver (char * n)
   type = ANALYSIS_TRANSIENT;
   setDescription ("transient");
   for (int i = 0; i < 8; i++) solution[i] = NULL;
+  tHistory = NULL;
+  relaxTSR = false;
 }
 
 // Destructor deletes the trsolver class object.
 trsolver::~trsolver () {
   if (swp) delete swp;
   for (int i = 0; i < 8; i++) if (solution[i] != NULL) delete solution[i];
+  if (tHistory) delete tHistory;
 }
 
 /* The copy constructor creates a new instance of the trsolver class
@@ -79,6 +88,8 @@ trsolver::trsolver (trsolver & o)
   : nasolver<nr_double_t> (o), states<nr_double_t> (o) {
   swp = o.swp ? new sweep (*o.swp) : NULL;
   for (int i = 0; i < 8; i++) solution[i] = NULL;
+  tHistory = o.tHistory ? new history (*o.tHistory) : NULL;
+  relaxTSR = o.relaxTSR;
 }
 
 // This function creates the time sweep if necessary.
@@ -93,11 +104,15 @@ void trsolver::initSteps (void) {
 /* This is the transient netlist solver.  It prepares the circuit list
    for each requested time and solves it then. */
 void trsolver::solve (void) {
-  nr_double_t time;
+  nr_double_t time, saveCurrent;
   int error = 0, convError = 0;
   char * solver = getPropertyString ("Solver");
+  relaxTSR = !strcmp (getPropertyString ("relaxTSR"), "yes") ? true : false;
+
   runs++;
-  current = 0;
+  saveCurrent = current = 0;
+  stepDelta = -1;
+  converged = 0;
   fixpoint = 0;
   statRejected = statSteps = statIterations = statConvergence = 0;
 
@@ -183,7 +198,7 @@ void trsolver::solve (void) {
       if (delta == deltaMin) {
 	logprint (LOG_ERROR,
 		  "WARNING: %s: minimum delta h = %.3e at t = %.3e\n",
-		  getName (), delta, current);
+		  getName (), (double) delta, (double) current);
       }
 #endif
       updateCoefficients (delta);
@@ -214,6 +229,7 @@ void trsolver::solve (void) {
 	statRejected++;
 	statConvergence++;
 	rejected++;
+	converged = 0;
 	error = 0;
 
 	// Start using damped Newton-Raphson.
@@ -222,7 +238,7 @@ void trsolver::solve (void) {
 
 #if DEBUG
 	logprint (LOG_ERROR, "WARNING: delta rejected at t = %.3e, h = %.3e "
-		  "(no convergence)\n", current, delta);
+		  "(no convergence)\n", (double) saveCurrent, (double) delta);
 #endif
 	break;
       default:
@@ -237,7 +253,7 @@ void trsolver::solve (void) {
       // check whether Jacobian matrix is still non-singular
       if (!A->isFinite ()) {
 	logprint (LOG_ERROR, "ERROR: %s: Jacobian singular at t = %.3e, "
-		  "aborting %s analysis\n", getName (), current,
+		  "aborting %s analysis\n", getName (), (double) current,
 		  getDescription ());
 	return;
       }
@@ -248,7 +264,7 @@ void trsolver::solve (void) {
 
       // Now advance in time or not...
       if (running > 1) {
-	adjustDelta ();
+	adjustDelta (time);
 	adjustOrder ();
       }
       else {
@@ -257,28 +273,100 @@ void trsolver::solve (void) {
 	rejected = 0;
       }
 
+      saveCurrent = current;
       current += delta;
       running++;
+      converged++;
 
       // Tell integrators to be running.
       setMode (MODE_NONE);
+
+      // Initialize or update history.
+      if (running > 1) {
+	updateHistory (saveCurrent);
+      }
+      else {
+	initHistory (saveCurrent);
+      }
     }
-    while (current < time); // Hit a requested time point?
+    while (saveCurrent < time); // Hit a requested time point?
     
     // Save results.
 #if STEPDEBUG
     logprint (LOG_STATUS, "DEBUG: save point at t = %.3e, h = %.3e\n",
-	      current, delta);
+	      (double) saveCurrent, (double) delta);
 #endif
+
+#if BREAKPOINTS
+    saveAllResults (saveCurrent);
+#else
     saveAllResults (time);
+#endif
   }
   solve_post ();
   logprogressclear (40);
   logprint (LOG_STATUS, "NOTIFY: %s: average time-step %g, %d rejections\n",
-	    getName (), current / statSteps, statRejected);
+	    getName (), (double) (saveCurrent / statSteps), statRejected);
   logprint (LOG_STATUS, "NOTIFY: %s: average NR-iterations %g, "
 	    "%d non-convergences\n", getName (),
 	    (double) statIterations / statSteps, statConvergence);
+
+  // cleanup
+  deinitTR ();
+}
+
+// The function initializes the history.
+void trsolver::initHistory (nr_double_t t) {
+  // initialize time vector
+  tHistory = new history ();
+  tHistory->append (t);
+  tHistory->self ();
+  // initialize circuit histories
+  nr_double_t age = 0.0;
+  circuit * root = subnet->getRoot ();
+  for (circuit * c = root; c != NULL; c = (circuit *) c->getNext ()) {
+    if (c->hasHistory ()) {
+      c->applyHistory (tHistory);
+      saveHistory (c);
+      if (c->getHistoryAge () > age) age = c->getHistoryAge ();
+    }
+  }
+  // set maximum required age for all circuits
+  tHistory->setAge (age);
+}
+
+/* The following function updates the histories for the circuits which
+   requested them. */
+void trsolver::updateHistory (nr_double_t t) {
+  if (t > tHistory->last ()) {
+    // update time vector
+    tHistory->append (t);
+    // update circuit histories
+    circuit * root = subnet->getRoot ();
+    for (circuit * c = root; c != NULL; c = (circuit *) c->getNext ()) {
+      if (c->hasHistory ()) saveHistory (c);
+    }
+    tHistory->drop ();
+  }
+}
+
+// Stores node voltages and branch currents in the given circuits history.
+void trsolver::saveHistory (circuit * c) {
+  int N = countNodes ();
+  int r, i, s = c->getSize ();
+  for (i = 0; i < s; i++) {
+    // save node voltages
+    r = findAssignedNode (c, i);
+    if (r < 0)
+      c->appendHistory (i, 0.0);
+    else
+      c->appendHistory (i, x->get (r));
+  }
+  for (i = 0; i < c->getVoltageSources (); i++) {
+    // save branch currents
+    r = c->getVoltageSource () + i;
+    c->appendHistory (i + s, x->get (r + N));
+  }
 }
 
 /* This function predicts a start value for the solution vector for
@@ -292,7 +380,7 @@ int trsolver::predictor (void) {
   case INTEGRATOR_ADAMSBASHFORD: // ADAMS-BASHFORD
     predictBashford ();
     break;
-  case INTEGRATOR_EULER: // BACKWARD EULER
+  case INTEGRATOR_EULER: // FORWARD EULER
     predictEuler ();
     break;
   default:
@@ -330,7 +418,7 @@ void trsolver::predictBashford (void) {
 }
 
 /* The function predicts the successive solution vector using the
-   explicit backward Euler integration formula.  Actually this is
+   explicit forward Euler integration formula.  Actually this is
    Adams-Bashford order 1. */
 void trsolver::predictEuler (void) {
   int N = countNodes ();
@@ -401,21 +489,55 @@ void trsolver::setMode (int state) {
     c->setMode (state);
 }
 
+// The function passes the time delta array to the circuit list.
+void trsolver::setDelta (void) {
+  circuit * root = subnet->getRoot ();
+  for (circuit * c = root; c != NULL; c = (circuit *) c->getNext ())
+    c->setDelta (deltas);
+}
+
 /* This function tries to adapt the current time-step according to the
    global truncation error. */
-void trsolver::adjustDelta (void) {
+void trsolver::adjustDelta (nr_double_t t) {
   deltaOld = delta;
   delta = checkDelta ();
   if (delta > deltaMax) delta = deltaMax;
   if (delta < deltaMin) delta = deltaMin;
 
-  if (delta > 0.9 * deltaOld) { // accept current delta
+  // delta correction in order to hit exact breakpoint
+  int good = 0;
+  if (!relaxTSR) { // relaxed step raster?
+    if (!statConvergence || converged > 64) { /* Is this a good guess? */
+      // check next breakpoint
+      if (stepDelta > 0.0) {
+	// restore last valid delta
+	delta = stepDelta;
+	stepDelta = -1.0;
+      }
+      else {
+	if (delta > (t - current) && t > current) {
+	  // save last valid delta and set exact step
+	  stepDelta = deltaOld;
+	  delta = t - current;
+	  good = 1;
+	}
+	else {
+	  stepDelta = -1.0;
+	}
+      }
+      if (delta > deltaMax) delta = deltaMax;
+      if (delta < deltaMin) delta = deltaMin;
+    }
+  }
+
+  // usual delta correction
+  if (delta > 0.9 * deltaOld || good) { // accept current delta
     nextStates ();
     rejected = 0;
 #if STEPDEBUG
     logprint (LOG_STATUS,
 	      "DEBUG: delta accepted at t = %.3e, h = %.3e\n",
-	      current, delta);
+	      (double) current, (double) delta);
 #endif
   }
   else if (deltaOld > delta) { // reject current delta
@@ -424,9 +546,9 @@ void trsolver::adjustDelta (void) {
 #if STEPDEBUG
     logprint (LOG_STATUS,
 	      "DEBUG: delta rejected at t = %.3e, h = %.3e\n",
-	      current, delta);
+	      (double) current, (double) delta);
 #endif
-    current -= deltaOld;
+    if (current > 0) current -= deltaOld;
   }
   else {
     nextStates ();
@@ -437,11 +559,12 @@ void trsolver::adjustDelta (void) {
 /* The function can be used to increase the current order of the
    integration method or to reduce it. */
 void trsolver::adjustOrder (int reduce) {
-  if (corrOrder < corrMaxOrder || reduce) {
-    if (reduce)
+  if ((corrOrder < corrMaxOrder && !rejected) || reduce) {
+    if (reduce) {
       corrOrder = 1;
-    else
+    } else if (!rejected) {
       corrOrder++;
+    }
 
     // adjust type and order of corrector and predictor
     corrType = correctorType (CMethod, corrOrder);
@@ -502,9 +625,12 @@ void trsolver::initTR (void) {
   delta = getPropertyDouble ("InitialStep");
   deltaMin = getPropertyDouble ("MinStep");
   deltaMax = getPropertyDouble ("MaxStep");
-  if (deltaMax == 0.0) deltaMax = MIN ((stop - start) / points, stop / 200);
-  if (deltaMin == 0.0) deltaMin = 1e-11 * deltaMax;
-  if (delta == 0.0) delta = MIN (stop / 200, deltaMax) / 10;
+  if (deltaMax == 0.0)
+    deltaMax = MIN ((stop - start) / (points - 1), stop / 200);
+  if (deltaMin == 0.0)
+    deltaMin = NR_TINY * 10 * deltaMax;
+  if (delta == 0.0)
+    delta = MIN (stop / 200, deltaMax) / 10;
   if (delta < deltaMin) delta = deltaMin;
   if (delta > deltaMax) delta = deltaMax;
 
@@ -514,6 +640,7 @@ void trsolver::initTR (void) {
   fillState (dState, delta);
 
   saveState (dState, deltas);
+  setDelta ();
   calcCorrectorCoeff (corrType, corrOrder, corrCoeff, deltas);
   calcPredictorCoeff (predType, predOrder, predCoeff, deltas);
 
@@ -532,6 +659,20 @@ void trsolver::initTR (void) {
     initCircuitTR (c);
 }
 
+// This function cleans up some memory used by the transient analysis.
+void trsolver::deinitTR (void) {
+  // cleanup solutions
+  for (int i = 0; i < 8; i++) {
+    delete solution[i];
+    solution[i] = NULL;
+  }
+  // cleanup history
+  if (tHistory) {
+    delete tHistory;
+    tHistory = NULL;
+  }
+}
+
 // The function initialize a single circuit.
 void trsolver::initCircuitTR (circuit * c) {
   c->initTR ();
@@ -561,7 +702,7 @@ nr_double_t trsolver::checkDelta (void) {
   nr_double_t LTEreltol = getPropertyDouble ("LTEreltol");
   nr_double_t LTEabstol = getPropertyDouble ("LTEabstol");
   nr_double_t LTEfactor = getPropertyDouble ("LTEfactor");
-  nr_double_t dif, rel, tol, lte, q, n = DBL_MAX;
+  nr_double_t dif, rel, tol, lte, q, n = NR_MAX;
   int N = countNodes ();
   int M = countVoltageSources ();
 
@@ -575,7 +716,7 @@ nr_double_t trsolver::checkDelta (void) {
     
     // skip real voltage sources
     if (r >= N) {
-      if (findVoltageSource (r - N)->isVSource ())
+      if (findVoltageSource(r - N)->isVSource ())
 	continue;
     }
 
@@ -591,7 +732,7 @@ nr_double_t trsolver::checkDelta (void) {
   }
 #if STEPDEBUG
   logprint (LOG_STATUS, "DEBUG: delta according to local truncation "
-	    "error h = %.3e\n", n);
+	    "error h = %.3e\n", (double) n);
 #endif
   delta = MIN ((n > 1.9 * delta) ? 2 * delta : delta, n);
   return delta;
