@@ -1,7 +1,7 @@
 /*
  * trsolver.h - transient solver class definitions
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: trsolver.h,v 1.17 2005/06/02 18:17:51 raimi Exp $
+ * $Id: trsolver.h,v 1.22 2006/04/24 08:25:46 raimi Exp $
  *
  */
 
@@ -30,6 +30,7 @@
 
 class sweep;
 class circuit;
+class history;
 
 class trsolver : public nasolver<nr_double_t>, public states<nr_double_t>
 {
@@ -44,9 +45,11 @@ class trsolver : public nasolver<nr_double_t>, public states<nr_double_t>
   void nextStates (void);
   void fillStates (void);
   void setMode (int);
-  void adjustDelta (void);
+  void setDelta (void);
+  void adjustDelta (nr_double_t);
   void adjustOrder (int reduce = 0);
   void initTR (void);
+  void deinitTR (void);
   static void calcTR (trsolver *);
   void initDC (void);
   static void calcDC (trsolver *);
@@ -54,6 +57,9 @@ class trsolver : public nasolver<nr_double_t>, public states<nr_double_t>
   void saveAllResults (nr_double_t);
   nr_double_t checkDelta (void);
   void updateCoefficients (nr_double_t);
+  void initHistory (nr_double_t);
+  void updateHistory (nr_double_t);
+  void saveHistory (circuit *);
   void predictBashford (void);
   void predictEuler (void);
   void predictGear (void);
@@ -69,6 +75,7 @@ class trsolver : public nasolver<nr_double_t>, public states<nr_double_t>
   nr_double_t deltaMax;
   nr_double_t deltaMin;
   nr_double_t deltaOld;
+  nr_double_t stepDelta;
   int CMethod;      // user specified corrector method
   int PMethod;      // user specified predictor method
   int corrMaxOrder; // maximum corrector order
@@ -78,12 +85,15 @@ class trsolver : public nasolver<nr_double_t>, public states<nr_double_t>
   int corrOrder;    // current corrector order
   int predOrder;    // current predictor order
   int rejected;
+  int converged;
   tvector<nr_double_t> * solution[8];
   nr_double_t current;
   int statSteps;
   int statRejected;
   int statIterations;
   int statConvergence;
+  history * tHistory;
+  bool relaxTSR;
 };
 
 #endif /* __TRSOLVER_H__ */
