@@ -1,7 +1,7 @@
 /*
  * tvector.cpp - simple vector template class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: tvector.cpp,v 1.12 2005/06/27 14:18:08 raimi Exp $
+ * $Id: tvector.cpp,v 1.17 2006/04/26 09:06:09 raimi Exp $
  *
  */
 
@@ -47,7 +47,7 @@
 template <class nr_type_t>
 tvector<nr_type_t>::tvector () {
   external = 0;
-  size = 0;
+  capacity = size = 0;
   data = NULL;
 }
 
@@ -56,7 +56,7 @@ tvector<nr_type_t>::tvector () {
 template <class nr_type_t>
 tvector<nr_type_t>::tvector (int s)  {
   external = 0;
-  size = s;
+  capacity = size = s;
   if (s > 0) {
     data = new nr_type_t[s];
     memset (data, 0, sizeof (nr_type_t) * s);
@@ -70,6 +70,7 @@ template <class nr_type_t>
 tvector<nr_type_t>::tvector (const tvector & v) {
   external = 0;
   size = v.size;
+  capacity = v.capacity;
   data = NULL;
 
   // copy tvector elements
@@ -86,6 +87,7 @@ const tvector<nr_type_t>&
 tvector<nr_type_t>::operator=(const tvector<nr_type_t> & v) {
   if (&v != this) {
     size = v.size;
+    capacity = v.capacity;
     if (data && !external) { delete[] data; data = NULL; }
     external = 0;
     if (size > 0) {
@@ -105,19 +107,21 @@ tvector<nr_type_t>::~tvector () {
 // Returns the tvector element at the given position.
 template <class nr_type_t>
 nr_type_t tvector<nr_type_t>::get (int i) {
+  assert (i >= 0 && i < size);
   return data[i];
 }
 
 // Sets the tvector element at the given position.
 template <class nr_type_t>
 void tvector<nr_type_t>::set (int i, nr_type_t z) {
+  assert (i >= 0 && i < size);
   data[i] = z;
 }
 
 // Sets all the tvector elements to the given value.
 template <class nr_type_t>
 void tvector<nr_type_t>::set (nr_type_t z) {
-  for (int i = 0; i < getSize (); i++) data[i] = z;
+  for (int i = 0; i < size; i++) data[i] = z;
 }
 
 // Sets the specified tvector elements to the given value.
@@ -126,6 +130,49 @@ void tvector<nr_type_t>::set (nr_type_t z, int start, int stop) {
   for (int i = start; i < stop; i++) data[i] = z;
 }
 
+// Appends the given value to the tvector.
+template <class nr_type_t>
+void tvector<nr_type_t>::add (nr_type_t z) {
+  if (size >= capacity) {
+    if (data) {
+      // double the vectors capacity
+      capacity *= 2;
+      data = (nr_type_t *) realloc (data, capacity * sizeof (nr_type_t));
+    }
+    else {
+      // initial capacity
+      capacity = 4;
+      data = (nr_type_t *) malloc (capacity * sizeof (nr_type_t));
+    }
+  }
+  data[size++] = z;
+}
+
+// Rejects the given number of values in the tvector.
+template <class nr_type_t>
+void tvector<nr_type_t>::drop (int n) {
+  if (n < size) {
+    for (int i = 0; i < size - n; i++) data[i] = data[i + n];
+    size -= n;
+  }
+  else size = 0;
+}
+
+// Sets size to zero.  Does not reduce the capacity.
+template <class nr_type_t>
+void tvector<nr_type_t>::clear (void) {
+  size = 0;
+}
+
+/* The function returns the number of entries with the given value
+   deviating no more than the given epsilon. */
+template <class nr_type_t>
+int tvector<nr_type_t>::contains (nr_type_t val, nr_double_t eps) {
+  int count = 0;
+  for (int i = 0; i < size; i++) if (abs (data[i] - val) <= eps) count++;
+  return count;
+}
+
 // Copies the specified elements from the given tvector.
 template <class nr_type_t>
 void tvector<nr_type_t>::set (tvector<nr_type_t> a, int start, int stop) {
@@ -138,7 +185,7 @@ void tvector<nr_type_t>::setData (nr_type_t * d, int len) {
   if (data && !external) delete[] data;
   external = 1;
   data = d;
-  size = len;
+  capacity = size = len;
 }
 
 // The function swaps the given rows with each other.
@@ -160,6 +207,16 @@ tvector<nr_type_t> operator + (tvector<nr_type_t> a, tvector<nr_type_t> b) {
   return res;
 }
 
+// Intrinsic vector addition.
+template <class nr_type_t>
+tvector<nr_type_t> tvector<nr_type_t>::operator += (tvector<nr_type_t> a) {
+  assert (a.getSize () == size);
+  nr_type_t * src = a.getData ();
+  nr_type_t * dst = data;
+  for (int i = 0; i < size; i++) *dst++ += *src++;
+  return *this;
+}
+
 // Subtraction.
 template <class nr_type_t>
 tvector<nr_type_t> operator - (tvector<nr_type_t> a, tvector<nr_type_t> b) {
@@ -170,6 +227,32 @@ tvector<nr_type_t> operator - (tvector<nr_type_t> a, tvector<nr_type_t> b) {
   return res;
 }
 
+// Intrinsic vector substration.
+template <class nr_type_t>
+tvector<nr_type_t> tvector<nr_type_t>::operator -= (tvector<nr_type_t> a) {
+  assert (a.getSize () == size);
+  nr_type_t * src = a.getData ();
+  nr_type_t * dst = data;
+  for (int i = 0; i < size; i++) *dst++ -= *src++;
+  return *this;
+}
+
+// Intrinsic scalar multiplication.
+template <class nr_type_t>
+tvector<nr_type_t> tvector<nr_type_t>::operator *= (nr_double_t s) {
+  nr_type_t * dst = data;
+  for (int i = 0; i < size; i++) *dst++ *= s;
+  return *this;
+}
+
+// Intrinsic scalar division.
+template <class nr_type_t>
+tvector<nr_type_t> tvector<nr_type_t>::operator /= (nr_double_t s) {
+  nr_type_t * dst = data;
+  for (int i = 0; i < size; i++) *dst++ /= s;
+  return *this;
+}
+
 // Scalar multiplication.
 template <class nr_type_t>
 tvector<nr_type_t> operator * (nr_double_t s, tvector<nr_type_t> a) {
@@ -206,7 +289,7 @@ nr_type_t scalar (tvector<nr_type_t> a, tvector<nr_type_t> b) {
 // Constant assignment operation.
 template <class nr_type_t>
 tvector<nr_type_t> tvector<nr_type_t>::operator = (const nr_type_t val) {
-  for (int i = 0; i < getSize (); i++) data[i] = val;
+  for (int i = 0; i < size; i++) data[i] = val;
   return *this;
 }
 
@@ -338,7 +421,8 @@ void tvector<nr_type_t>::reorder (int * idx) {
 template <class nr_type_t>
 void tvector<nr_type_t>::print (void) {
   for (int r = 0; r < size; r++) {
-    fprintf (stderr, "%+.2e\n", (double) real (get (r)));
+    fprintf (stderr, "%+.2e%+.2ei\n", (double) real (get (r)),
+	     (double) imag (get (r)));
   }
 }
 #endif /* DEBUG */
