@@ -1,7 +1,7 @@
 /*
  * ucs.cpp - main program implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: ucs.cpp,v 1.20 2005/06/02 18:17:51 raimi Exp $
+ * $Id: ucs.cpp,v 1.24 2006/01/04 10:40:32 raimi Exp $
  *
  */
 
@@ -31,6 +31,7 @@
 #include <string.h>
 
 #include "logging.h"
+#include "precision.h"
 #include "component.h"
 #include "net.h"
 #include "input.h"
@@ -55,13 +56,14 @@ int main (int argc, char ** argv) {
   environment * root;
 
   loginit ();
+  precinit ();
 
   // check program arguments
   for (int i = 1; i < argc; i++) {
     if (!strcmp (argv[i], "-v") || !strcmp (argv[i], "--version")) {
       fprintf (stdout,
 	"Qucsator " PACKAGE_VERSION "\n"
-	"Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>\n"
+	"Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>\n"
 	"\nThis is free software; see the source for copying "
 	"conditions.  There is NO\n"
 	"warranty; not even for MERCHANTABILITY or FITNESS FOR A "
@@ -76,6 +78,7 @@ int main (int argc, char ** argv) {
 	"  -i FILENAME    use file as input netlist (default stdin)\n"
 	"  -o FILENAME    use file as output dataset (default stdout)\n"
 	"  -b, --bar      enable textual progress bar\n"
+	"  -g, --gui      special progress bar used by gui\n"
 	"  -c, --check    check the input netlist and exit\n"
 	"\nReport bugs to <" PACKAGE_BUGREPORT ">.\n", argv[0]);
       return 0;
@@ -90,6 +93,9 @@ int main (int argc, char ** argv) {
     else if (!strcmp (argv[i], "-b") || !strcmp (argv[i], "--bar")) {
       progressbar_enable = 1;
     }
+    else if (!strcmp (argv[i], "-g") || !strcmp (argv[i], "--gui")) {
+      progressbar_gui = 1;
+    }
     else if (!strcmp (argv[i], "-c") || !strcmp (argv[i], "--check")) {
       netlist_check = 1;
     }
@@ -129,6 +135,7 @@ int main (int argc, char ** argv) {
 
   // evaluate output dataset
   equation_solver (out);
+  equation_destructor ();
   out->setFile (outfile);
   out->print ();
 
