@@ -1,7 +1,8 @@
 /*
  * vector.cpp - vector class implementation
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vector.cpp,v 1.21 2005/06/07 07:49:06 raimi Exp $
+ * $Id: vector.cpp,v 1.28 2006/03/15 16:46:28 raimi Exp $
  *
  */
 
@@ -60,6 +61,18 @@ vector::vector (int s) : object () {
   requested = 0;
 }
 
+/* Constructor creates an unnamed instance of the vector class with a
+   given initial size and content. */
+vector::vector (int s, complex val) : object () {
+  assert (s >= 0);
+  capacity = size = s;
+  data = s > 0 ? (complex *) calloc (capacity, sizeof (complex)) : NULL;
+  for (int i = 0; i < s; i++) data[i] = val;
+  dependencies = NULL;
+  origin = NULL;
+  requested = 0;
+}
+
 // Constructor creates an named instance of the vector class.
 vector::vector (char * n) : object (n) {
   capacity = size = 0;
@@ -115,6 +128,17 @@ vector::~vector () {
   if (origin) free (origin);
 }
 
+// Returns data dependencies.
+strlist * vector::getDependencies (void) {
+  return dependencies;
+}
+
+// Sets the data dependencies.
+void vector::setDependencies (strlist * s) {
+  if (dependencies) delete dependencies;
+  dependencies = s;
+}
+
 /* The function appends a new complex data item to the end of the
    vector and ensures that the vector can hold the increasing number
    of data items. */
@@ -132,15 +156,17 @@ void vector::add (complex c) {
 
 /* This function appends the given vector to the vector. */
 void vector::add (vector * v) {
-  if (data == NULL) {
-    size = 0; capacity = v->getSize ();
-    data = (complex *) malloc (sizeof (complex) * capacity);
+  if (v != NULL) {
+    if (data == NULL) {
+      size = 0; capacity = v->getSize ();
+      data = (complex *) malloc (sizeof (complex) * capacity);
+    }
+    else if (size + v->getSize () > capacity) {
+      capacity += v->getSize ();
+      data = (complex *) realloc (data, sizeof (complex) * capacity);
+    }
+    for (int i = 0; i < v->getSize (); i++) data[size++] = v->get (i);
   }
-  else if (size + v->getSize () > capacity) {
-    capacity += v->getSize ();
-    data = (complex *) realloc (data, sizeof (complex) * capacity);
-  }
-  for (int i = 0; i < v->getSize (); i++) data[size++] = v->get (i);
 }
 
 // Returns the complex data item at the given position.
@@ -175,7 +201,7 @@ int vector::checkSizes (vector v1, vector v2) {
 // complex numbers in the 2. and 3. quadrant are counted as "-abs(c)".
 nr_double_t vector::maximum (void) {
   complex c;
-  nr_double_t d, max_D = -DBL_MAX;
+  nr_double_t d, max_D = -NR_MAX;
   for (int i = 0; i < getSize (); i++) {
     c = data[i];
     d = fabs (arg (c)) < M_PI_2 ? abs (c) : -abs (c);
@@ -189,7 +215,7 @@ nr_double_t vector::maximum (void) {
 // complex numbers in the 2. and 3. quadrant are counted as "-abs(c)".
 nr_double_t vector::minimum (void) {
   complex c;
-  nr_double_t d, min_D = DBL_MAX;
+  nr_double_t d, min_D = +NR_MAX;
   for (int i = 0; i < getSize (); i++) {
     c = data[i];
     d = fabs (arg (c)) < M_PI_2 ? abs (c) : -abs (c);
@@ -448,18 +474,30 @@ vector arcoth (vector v) {
 }
 
 // converts impedance to reflexion coefficient
-vector ztor (vector v, nr_double_t zref) {
+vector ztor (vector v, complex zref) {
   vector result (v);
-  for (int i = 0; i < v.getSize (); i++)
-    result.set (ztor (v.get (i), zref), i);
+  for (int i = 0; i < v.getSize (); i++) result (i) = ztor (v (i), zref);
+  return result;
+}
+
+// converts admittance to reflexion coefficient
+vector ytor (vector v, complex zref) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result (i) = ytor (v (i), zref);
   return result;
 }
 
 // converts reflexion coefficient to impedance
-vector rtoz (vector v, nr_double_t zref) {
+vector rtoz (vector v, complex zref) {
   vector result (v);
-  for (int i = 0; i < v.getSize (); i++)
-    result.set (rtoz (v.get (i), zref), i);
+  for (int i = 0; i < v.getSize (); i++) result (i) = rtoz (v (i), zref);
+  return result;
+}
+
+// converts reflexion coefficient to admittance
+vector rtoy (vector v, complex zref) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result (i) = rtoy (v (i), zref);
   return result;
 }
 
@@ -502,7 +540,7 @@ vector diff (vector var, vector dep, int n) {
 }
 
 vector vector::operator=(const complex c) {
-  for (int i = 0; i < getSize (); i++) data[i] = complex (c);
+  for (int i = 0; i < getSize (); i++) data[i] = c;
   return *this;
 }
 
@@ -736,8 +774,7 @@ vector operator%(vector v1, vector v2) {
 /* This function reverses the order of the data list. */
 void vector::reverse (void) {
   complex * buffer = (complex *) malloc (sizeof (complex) * size);
-  for (int i = 0; i < size; i++)
-    buffer[i] = data[size - 1 - i];
+  for (int i = 0; i < size; i++) buffer[i] = data[size - 1 - i];
   free (data);
   data = buffer;
   capacity = size;
@@ -786,8 +823,7 @@ vector linspace (nr_double_t start, nr_double_t stop, int points) {
   nr_double_t val, step = (stop - start) / (points - 1);
   for (int i = 0; i < points; i++) {
     val = start + (i * step);
-    if (i != 0 && fabs (val) < fabs (step) / 2 &&
-	fabs (val - (start + (i - 1) * step)) < fabs (step))
+    if (i != 0 && fabs (val) < fabs (step) / 4 && fabs (val) < NR_EPSI)
       val = 0.0;
     result.set (val, i);
   }
@@ -823,3 +859,233 @@ vector logspace (nr_double_t start, nr_double_t stop, int points) {
   }
   return result;
 }
+
+vector cumsum (vector v) {
+  vector result (v);
+  complex val (0.0);
+  for (int i = 0; i < v.getSize (); i++) {
+    val += v.get (i);
+    result.set (val, i);
+  }
+  return result;
+}
+
+vector cumavg (vector v) {
+  vector result (v);
+  complex val (0.0);
+  for (int i = 0; i < v.getSize (); i++) {
+    val = (val * i + v.get (i)) / (i + 1);
+    result.set (val, i);
+  }
+  return result;
+}
+
+vector cumprod (vector v) {
+  vector result (v);
+  complex val (1.0);
+  for (int i = 0; i < v.getSize (); i++) {
+    val *= v.get (i);
+    result.set (val, i);
+  }
+  return result;
+}
+
+vector ceil (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (ceil (v.get (i)), i);
+  return result;
+}
+
+vector fix (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (fix (v.get (i)), i);
+  return result;
+}
+
+vector floor (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (floor (v.get (i)), i);
+  return result;
+}
+
+vector round (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (round (v.get (i)), i);
+  return result;
+}
+
+vector sqr (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (sqr (v.get (i)), i);
+  return result;
+}
+
+vector step (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (step (v.get (i)), i);
+  return result;
+}
+
+static nr_double_t integrate_n (vector v) { /* using trapezoidal rule */
+  nr_double_t result = 0.0;
+  for (int i = 1; i < v.getSize () - 1; i++) result += norm (v.get (i));
+  result += 0.5 * norm (v.get (0));
+  result += 0.5 * norm (v.get (v.getSize () - 1));
+  return result;
+}
+
+nr_double_t vector::rms (void) {
+  nr_double_t result = sqrt (integrate_n (*this) / getSize ());
+  return result; 
+}
+
+nr_double_t vector::variance (void) { 
+  nr_double_t rms2 = integrate_n (*this) / getSize ();
+  nr_double_t avg2 = norm (avg (*this));
+  return rms2 - avg2;
+}
+
+nr_double_t vector::stddev (void) {
+  return sqrt (variance ());
+}
+
+vector erf (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (erf (v.get (i)), i);
+  return result;
+}
+
+vector erfc (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (erfc (v.get (i)), i);
+  return result;
+}
+
+vector erfinv (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (erfinv (v.get (i)), i);
+  return result;
+}
+
+vector erfcinv (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (erfcinv (v.get (i)), i);
+  return result;
+}
+
+vector i0 (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (i0 (v.get (i)), i);
+  return result;
+}
+
+vector jn (const int n, vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (jn (n, v.get (i)), i);
+  return result;
+}
+
+vector yn (const int n, vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (yn (n, v.get (i)), i);
+  return result;
+}
+
+vector polar (const complex a, vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (polar (a, v.get (i)), i);
+  return result;
+}
+
+vector polar (vector v, const complex p) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++) result.set (polar (v.get (i), p), i);
+  return result;
+}
+
+vector polar (vector a, vector p) {
+  assert (a.checkSizes (a, p));
+  int n = a.getSize () < p.getSize () ? a.getSize () : p.getSize ();
+  vector result (n);
+  for (int i = 0; i < n; i++) result.set (polar (a.get (i), p.get (i)), i);
+  return result;
+}
+
+vector arctan2 (const nr_double_t y, vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++)
+    result.set (arctan2 (y, v.get (i)), i);
+  return result;
+}
+
+vector arctan2 (vector v, const nr_double_t x) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++)
+    result.set (arctan2 (v.get (i), x) , i);
+  return result;
+}
+
+vector arctan2 (vector y, vector x) {
+  assert (y.checkSizes (y, x));
+  int n = y.getSize () < x.getSize () ? y.getSize () : x.getSize ();
+  vector result (n);
+  for (int i = 0; i < n; i++)
+    result.set (arctan2 (y.get (i), x.get (i)), i);
+  return result;
+}
+
+vector w2dbm (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++)
+    result.set (10.0 * log10 (v.get (i) / 0.001), i);
+  return result;
+}
+
+vector dbm2w (vector v) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++)
+    result.set (0.001 * pow (10.0 , v.get (i) / 10.0), i);
+  return result;
+}
+
+nr_double_t integrate (vector v, const nr_double_t h) {
+  nr_double_t s = real (v.get (0) ) / 2;
+  for (int i = 1; i < v.getSize () - 1; i++)
+    s += real (v.get (i));
+  return (s + real (v.get (v.getSize () - 1) ) / 2) * h;
+}
+
+complex integrate (vector v, const complex h) {
+  complex s;
+  s = v.get (0) / 2;
+  for (int i = 1; i < v.getSize () - 1; i++)
+    s += v.get (i);
+  return (s + v.get (v.getSize () - 1) / 2) * h;
+}
+
+vector dbm (vector v, const complex z) {
+  vector result (v);
+  for (int i = 0; i < v.getSize (); i++)
+    result.set (10.0 * log10 (norm (v.get (i)) / conj (z) / 0.001), i);
+  return result;
+}
+
+vector runavg (const complex x, const int n) {
+  vector result (n);
+  for (int i = 0; i < n; i++) result.set (x, i);
+  return result;
+}
+
+vector runavg (vector v, const int n) {
+  complex s (0.0), y;
+  int len = v.getSize () - n + 1, i;
+  vector result (len);
+  for (i = 0; i < n; i++) s += v.get (i);
+  y = s / n; // first running average value
+  result.set (y, 0);
+  for (i = 0; i < len - 1; i++) {
+    y += (v.get (i + n) - v.get (i)) / n;
+    result.set (y, i + 1);
+  }
+  return result;
+}
