@@ -1,7 +1,8 @@
 /*
  * vector.h - vector class definitions
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vector.h,v 1.17 2005/06/07 07:49:06 raimi Exp $
+ * $Id: vector.h,v 1.24 2006/03/15 16:46:28 raimi Exp $
  *
  */
 
@@ -26,6 +27,7 @@
 #define __VECTOR_H__
 
 #include "consts.h"
+#include "precision.h"
 
 #ifdef log2
 #undef log2
@@ -33,6 +35,12 @@
 
 class complex;
 class strlist;
+class vector;
+
+vector linspace (nr_double_t, nr_double_t, int);
+vector logspace (nr_double_t, nr_double_t, int);
+vector runavg (vector, const int);
+vector runavg (const complex, const int);
 
 class vector : public object
 {
@@ -40,6 +48,7 @@ class vector : public object
   vector ();
   vector (char *);
   vector (int);
+  vector (int, complex);
   vector (char *, int);
   vector (const vector &);
   const vector& operator = (const vector &);
@@ -54,21 +63,28 @@ class vector : public object
   int getRequested (void) { return requested; }
   void setRequested (int n) { requested = n; }
   void reverse (void);
-  strlist * getDependencies (void) { return dependencies; }
-  void setDependencies (strlist * s) { dependencies = s; }
+  strlist * getDependencies (void);
+  void setDependencies (strlist *);
   void setOrigin (char *);
   char * getOrigin (void);
-  nr_double_t maximum (void);
-  nr_double_t minimum (void);
-  int contains (complex, nr_double_t eps = 1e-12);
+  int contains (complex, nr_double_t eps = NR_EPSI);
   void sort (bool ascending = true);
 
-  friend complex sum  (vector);
-  friend complex prod (vector);
-  friend complex avg  (vector);
+  nr_double_t maximum  (void);
+  nr_double_t minimum  (void);
+  nr_double_t rms      (void);
+  nr_double_t variance (void);
+  nr_double_t stddev   (void);
 
-  friend vector linspace (nr_double_t, nr_double_t, int);
-  friend vector logspace (nr_double_t, nr_double_t, int);
+  friend complex sum     (vector);
+  friend complex prod    (vector);
+  friend complex avg     (vector);
+  friend vector  cumsum  (vector);
+  friend vector  cumprod (vector);
+  friend vector  cumavg  (vector);
+  friend vector  dbm     (vector, const complex z = 50.0);
+  friend complex integrate (vector v, const complex);
+  friend nr_double_t integrate (vector v, const nr_double_t);
 
   // vector manipulations
   friend vector real   (vector);  // the real part
@@ -84,34 +100,58 @@ class vector : public object
   friend vector pow    (const complex, vector);
   friend vector pow    (const nr_double_t, vector);
   friend vector pow    (vector, vector);
-  friend vector ztor   (vector, nr_double_t zref = 50.0);
-  friend vector rtoz   (vector, nr_double_t zref = 50.0);
+  friend vector ztor   (vector, complex zref = 50.0);
+  friend vector rtoz   (vector, complex zref = 50.0);
+  friend vector ytor   (vector, complex zref = 50.0);
+  friend vector rtoy   (vector, complex zref = 50.0);
   friend vector diff   (vector, vector, int n = 1);
   friend vector unwrap (vector, nr_double_t tol = M_PI);
 
+  friend vector polar   (vector, const complex);
+  friend vector polar   (const complex, vector);
+  friend vector polar   (vector, vector);
+  friend vector arctan2 (vector, const nr_double_t);
+  friend vector arctan2 (const nr_double_t, vector);
+  friend vector arctan2 (vector, vector);
+  friend vector dbm2w   (vector);
+  friend vector w2dbm   (vector);
+
   // overloaded math functions
-  friend vector abs    (vector);
-  friend vector log10  (vector);
-  friend vector exp    (vector);
-  friend vector sqrt   (vector);
-  friend vector sin    (vector);
-  friend vector arcsin (vector);
-  friend vector cos    (vector);
-  friend vector arccos (vector);
-  friend vector tan    (vector);
-  friend vector arctan (vector);
-  friend vector cot    (vector);
-  friend vector arccot (vector);
-  friend vector sinh   (vector);
-  friend vector arsinh (vector);
-  friend vector cosh   (vector);
-  friend vector arcosh (vector);
-  friend vector tanh   (vector);
-  friend vector artanh (vector);
-  friend vector coth   (vector);
-  friend vector arcoth (vector);
-  friend vector sign   (vector);
-  friend vector sinc   (vector);
+  friend vector abs     (vector);
+  friend vector log10   (vector);
+  friend vector exp     (vector);
+  friend vector sqrt    (vector);
+  friend vector sin     (vector);
+  friend vector arcsin  (vector);
+  friend vector cos     (vector);
+  friend vector arccos  (vector);
+  friend vector tan     (vector);
+  friend vector arctan  (vector);
+  friend vector cot     (vector);
+  friend vector arccot  (vector);
+  friend vector sinh    (vector);
+  friend vector arsinh  (vector);
+  friend vector cosh    (vector);
+  friend vector arcosh  (vector);
+  friend vector tanh    (vector);
+  friend vector artanh  (vector);
+  friend vector coth    (vector);
+  friend vector arcoth  (vector);
+  friend vector sign    (vector);
+  friend vector sinc    (vector);
+  friend vector ceil    (vector);
+  friend vector floor   (vector);
+  friend vector fix     (vector);
+  friend vector round   (vector);
+  friend vector sqr     (vector);
+  friend vector step    (vector);
+  friend vector jn      (const int, vector);
+  friend vector yn      (const int, vector);
+  friend vector i0      (vector);
+  friend vector erf     (vector);
+  friend vector erfc    (vector);
+  friend vector erfinv  (vector);
+  friend vector erfcinv (vector);
 
   // operator functions
   friend vector operator + (vector, vector);
