@@ -21,6 +21,8 @@
 
 #include "qucsedit.h"
 
+#include <qtextedit.h>
+#include <qlabel.h>
 #include <qlayout.h>
 #include <qhbox.h>
 #include <qpushbutton.h>
@@ -36,7 +38,7 @@ QucsEdit::QucsEdit(const QString& FileName_, bool readOnly)
 {
   // set application icon
   setIcon (QPixmap(QucsSettings.BitmapDir + "big.qucs.xpm"));
-  setCaption("QucsEdit " PACKAGE_VERSION " - " + tr("File: "));
+  setCaption("Qucs Editor " PACKAGE_VERSION " - " + tr("File: "));
 
   QVBoxLayout *v = new QVBoxLayout(this);
 
@@ -54,6 +56,8 @@ QucsEdit::QucsEdit(const QString& FileName_, bool readOnly)
   connect(ButtSave, SIGNAL(clicked()), SLOT(slotSave()));
   ButtSave->setDisabled(readOnly);
 
+  h->setStretchFactor(new QWidget(h),5); // stretchable placeholder
+  PosText = new QLabel(tr("Line: %1  -  Column: %2").arg(1).arg(1), h);
   h->setStretchFactor(new QWidget(h),5); // stretchable placeholder
 
   QPushButton *ButtAbout = new QPushButton(tr("About"),h);
@@ -69,6 +73,8 @@ QucsEdit::QucsEdit(const QString& FileName_, bool readOnly)
   text->setWordWrap(QTextEdit::NoWrap);
   text->setMinimumSize(300,200);
   v->addWidget(text);
+  connect(text, SIGNAL(cursorPositionChanged(int, int)),
+          SLOT(slotPrintCursorPosition(int, int)));
 
   // .................................................
   loadFile(FileName_);
@@ -78,11 +84,17 @@ QucsEdit::~QucsEdit()
 {
 }
 
+// ************************************************************
+void QucsEdit::slotPrintCursorPosition(int Para, int Pos)
+{
+  PosText->setText(tr("Line: %1  -  Column: %2").arg(Para+1).arg(Pos+1));
+}
+
 // ************************************************************
 void QucsEdit::slotAbout()
 {
   QMessageBox::about(this, tr("About..."),
-    tr("Qucs Editor Version ")+PACKAGE_VERSION+
+    "QucsEdit Version " PACKAGE_VERSION+
     tr("\nVery simple text editor for Qucs\n")+
     tr("Copyright (C) 2004, 2005 by Michael Margraf\n")+
     "\nThis is free software; see the source for copying conditions."
@@ -165,7 +177,7 @@ bool QucsEdit::loadFile(const QString& Name)
   FileName = Name;
 //  QFileInfo info(Name);
 //  FileName = info.fileName();
-  setCaption("QucsEdit " PACKAGE_VERSION " - " + tr("File: ")+FileName);
+  setCaption("Qucs Editor " PACKAGE_VERSION " - " + tr("File: ")+FileName);
   return true;
 }
 
