@@ -138,7 +138,7 @@ QucsLib::~QucsLib()
 void QucsLib::slotAbout()
 {
   QMessageBox::about(this, tr("About..."),
-    "QucsLib " PACKAGE_VERSION "\n"+
+    "QucsLib Version " PACKAGE_VERSION "\n"+
     tr("Library Manager for Qucs\n")+
     tr("Copyright (C) 2005 by Michael Margraf\n")+
     "\nThis is free software; see the source for copying conditions."
@@ -226,6 +226,7 @@ void QucsLib::slotSelectLibrary(int Index)
 
   CompList->clear();
   LibraryComps.clear();
+  DefaultSymbol = "";
 
   QFile file(QucsSettings.LibDir + Library->text(Index) + ".lib");
   if(!file.open(IO_ReadOnly)) {
@@ -251,6 +252,19 @@ void QucsLib::slotSelectLibrary(int Index)
   }
   QString LibName = LibraryString.mid(Start, End-Start).section('"', 1, 1);
 
+  Start = LibraryString.find("\n<", End);
+  if(Start < 0) return;
+  if(LibraryString.mid(Start+2, 14) == "DefaultSymbol>") {
+    End = LibraryString.find("\n</DefaultSymbol>");
+    if(End < 0) {
+      QMessageBox::critical(this, tr("Error"), tr("Library is corrupt."));
+      return;
+    }
+
+    DefaultSymbol = LibraryString.mid(Start+16, End-Start-16);
+    Start = End + 3;
+  }
+
   while((Start=LibraryString.find("\n<Component ", Start)) > 0) {
     Start++;
     NameStart = Start + 11;
@@ -272,7 +286,7 @@ void QucsLib::slotSelectLibrary(int Index)
 void QucsLib::slotSearchComponent()
 {
   SearchDialog *d = new SearchDialog(this);
-  if(d->exec() != QDialog::Accepted)
+  if(d->exec() == QDialog::Accepted)
     QMessageBox::information(this, tr("Result"),
                              tr("No appropriate component found."));
 }
@@ -328,4 +342,8 @@ void QucsLib::slotShowComponent(QListBoxItem *Item)
     Symbol->setSymbol((*CompString).mid(Start, End-Start),
                       (*CompString).section('\n', 0, 0), Item->text());
   }
+  else if(!DefaultSymbol.isEmpty()) {  // has library a default symbol ?
+    Symbol->setSymbol(DefaultSymbol,
+                      (*CompString).section('\n', 0, 0), Item->text());
+  }
 }
