@@ -2,7 +2,7 @@
                           qucstrans.cpp  -  description
                              -------------------
     begin                : Sun Feb 27 2005
-    copyright            : (C) 2005 by Stefan Jahn
+    copyright            : (C) 2005, 2006 by Stefan Jahn
     email                : stefan@lkcc.org
  ***************************************************************************/
 
@@ -199,7 +199,7 @@ struct TransUnit TransUnits[] = {
 QucsTranscalc::QucsTranscalc() {
   // set application icon
   setIcon (QPixmap(QucsSettings.BitmapDir + "big.qucs.xpm"));
-  setCaption("QucsTranscalc " PACKAGE_VERSION);
+  setCaption("Qucs Transcalc " PACKAGE_VERSION);
 
   QMenuBar * menuBar = new QMenuBar (this);
 
@@ -816,7 +816,7 @@ bool QucsTranscalc::isSelected (QString prop) {
 void QucsTranscalc::slotAbout()
 {
   QMessageBox::about(this, tr("About..."),
-    "QucsTranscalc " PACKAGE_VERSION "\n"+
+    "QucsTranscalc Version " PACKAGE_VERSION "\n"+
     tr("Transmission Line Calculator for Qucs\n")+
     tr("Copyright (C) 2001 by Gopal Narayanan\n")+
     tr("Copyright (C) 2002 by Claudio Girardi\n")+
@@ -1213,6 +1213,40 @@ void QucsTranscalc::slotCopyToClipBoard()
     created++;
   }
 
+  // create coaxial line schematic
+  if (mode == ModeCoaxial) {
+    transline * l = TransLineTypes[2].line;
+    s += "<Components>\n";
+    s += "  <Pac P1 1 90 150 -74 -26 1 1 \"1\" 1 \"50 Ohm\" 1 \"0 dBm\" 0 \"1 GHz\" 0 \"26.85\" 0>\n";
+    s +="  <Pac P2 1 270 150 18 -26 0 1 \"2\" 1 \"50 Ohm\" 1 \"0 dBm\" 0 \"1 GHz\" 0 \"26.85\" 0>\n";
+    s += "  <GND * 1 90 180 0 0 0 0>\n";
+    s += "  <GND * 1 270 180 0 0 0 0>\n";
+    s += "  <.SP SPTC1 1 90 240 0 51 0 0 ";
+    double freq = l->getProperty("Freq", UNIT_FREQ, FREQ_GHZ);
+    if (freq > 0)
+      s += QString("\"log\" 1 \"%1 GHz\" 1 \"%2 GHz\" 1 ").
+	arg(freq / 10).arg(freq * 10);
+    else
+      s += "\"lin\" 1 \"0 GHz\" 1 \"10 GHz\" 1 ";
+    s += "\"51\" 1 \"no\" 0 \"1\" 0 \"2\" 0>\n";
+    s += QString("  <COAX CXTC1 1 180 100 -26 15 0 0 \"%1\" 1 \"%2\" 0 \"%3\" 0 \"%4 mm\" 1 \"%5 mm\" 1  \"%6 mm\" 1  \"%7\" 0 \"26.85\" 0>\n").
+      arg(l->getProperty("Er")).
+      arg(1 / l->getProperty("Sigma")).
+      arg(l->getProperty("Mur")).
+      arg(l->getProperty("dout", UNIT_LENGTH, LENGTH_MM)).
+      arg(l->getProperty("din", UNIT_LENGTH, LENGTH_MM)).
+      arg(l->getProperty("L", UNIT_LENGTH, LENGTH_MM)).
+      arg(l->getProperty("Tand"));
+    s += "</Components>\n";
+    s += "<Wires>\n";
+    s += "  <90 100 150 100 \"\" 0 0 0 \"\">\n";
+    s += "  <90 100 90 120 \"\" 0 0 0 \"\">\n";
+    s += "  <210 100 270 100 \"\" 0 0 0 \"\">\n";
+    s += "  <270 100 270 120 \"\" 0 0 0 \"\">\n";
+    s += "</Wires>\n";
+    created++;
+  }
+
   // put resulting transmission line schematic into clipboard
   QClipboard *cb = QApplication::clipboard();
   cb->setText(s);
