@@ -1,6 +1,6 @@
 /***************************************************************************
-                            bjt.h  -  description
-                             -------------------
+                                  bjt.h
+                                 -------
     begin                : Fri Jun 4 2004
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,14 +21,16 @@
 #include "component.h"
 
 
-class BJT : public Component  {
+class BJT : public MultiViewComponent  {
 public:
   BJT();
-  ~BJT();
+ ~BJT() {};
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
   static Element* info_pnp(QString&, char* &, bool getNewOne=false);
-  void recreate();
+
+protected:
+  void createSymbol();
 };
 
 #endif
