@@ -1,6 +1,6 @@
 /***************************************************************************
-                            bjtsub.h  -  description
-                             -------------------
+                                bjtsub.h
+                               ----------
     begin                : Sat Jul 17 2004
     copyright            : (C) 2004 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,14 +21,16 @@
 #include "component.h"
 
 
-class BJTsub : public Component  {
+class BJTsub : public MultiViewComponent  {
 public:
   BJTsub();
-  ~BJTsub();
+ ~BJTsub() {};
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
   static Element* info_pnp(QString&, char* &, bool getNewOne=false);
-  void recreate();
+
+protected:
+  void createSymbol();
 };
 
 #endif
