@@ -15,19 +15,23 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <stdlib.h>
+
 #include "components.h"
+#include "node.h"
 #include "main.h"
 #include "qucs.h"
-#include "qucsview.h"
-#include "node.h"
+#include "schematic.h"
 #include "viewpainter.h"
 
-#include <qpoint.h>
-#include <qpainter.h>
-#include <qstring.h>
-#include <qpen.h>
-#include <qmessagebox.h>
 #include <qdir.h>
+#include <qpen.h>
+#include <qpoint.h>
+#include <qstring.h>
+#include <qpainter.h>
+#include <qtabwidget.h>
+#include <qmessagebox.h>
+
 
 
 // ***********************************************************************
@@ -37,12 +41,13 @@
 // ***********************************************************************
 Component::Component()
 {
-  Type = isComponent;
+  Type = isAnalogComponent;
 
   mirroredX = false;
   rotated = 0;
   isSelected = false;
-  isActive   = true;
+  isActive = COMP_IS_ACTIVE;
+  showName = true;
 
   cx = 0;
   cy = 0;
@@ -56,10 +61,7 @@ Component::Component()
   Props.setAutoDelete(true);
 }
 
-Component::~Component()
-{
-}
-
+// -------------------------------------------------------
 Component* Component::newOne()
 {
   return new Component();
@@ -76,19 +78,25 @@ void Component::Bounding(int& _x1, int& _y1, int& _x2, int& _y2)
 
 // -------------------------------------------------------
 // Size of component text.
-void Component::TextSize(int& _dx, int& _dy)
+int Component::textSize(int& _dx, int& _dy)
 {
   QFontMetrics  metrics(QucsSettings.font);   // get size of text
-  int tmp;
-  _dx = metrics.width(Name);
-  _dy = metrics.height();    // for "Name"
+  int tmp, count=0;
+  _dx = _dy = 0;
+  if(showName) {
+    _dx = metrics.width(Name);
+    _dy = metrics.height();
+    count++;
+  }
   for(Property *pp = Props.first(); pp != 0; pp = Props.next())
     if(pp->display) {
       // get width of text
       tmp = metrics.width(pp->Name+"="+pp->Value);
       if(tmp > _dx)  _dx = tmp;
       _dy += metrics.height();
+      count++;
     }
+  return count;
 }
 
 // -------------------------------------------------------
@@ -104,21 +112,11 @@ void Component::entireBounds(int& _x1, int& _y1, int& _x2, int& _y2, float Corr)
   if(tx < x1) _x1 = tx+cx;
   if(ty < y1) _y1 = ty+cy;
 
-  QFontMetrics  metrics(QucsSettings.font);
-  QSize r = metrics.size(0, Name);
-  if((tx+r.width()) > x2) _x2 = tx+r.width()+cx;
-  if((ty+r.height()) > y2) _y2 = ty+r.height()+cy;
+  int dx, dy, ny;
+  ny = textSize(dx, dy);
+  dy = int(float(ny) / Corr);  // correction for unproportional font scaling
 
-  int dy=1; // due to 'Name' text
-  for(Property *pp = Props.first(); pp != 0; pp = Props.next())
-    if(pp->display) {
-      // get width of text
-      r = metrics.size(0, pp->Name+"="+pp->Value);
-      if((tx+r.width()) > x2) _x2 = tx+r.width()+cx;
-      dy++;
-    }
-    
-  dy = int(float(dy) / Corr);  // correction for unproportional font scaling
+  if((tx+dx) > x2) _x2 = tx+dx+cx;
   if((ty+dy) > y2) _y2 = ty+dy+cy;
 }
 
@@ -146,18 +144,21 @@ int Component::getTextSelected(int x_, int y_, float Corr)
 
   x_ -= tx;
   y_ -= ty;
+  int w, dy = int(float(y_) * Corr);  // correction for font scaling
   QFontMetrics  metrics(QucsSettings.font);
-  int w  = metrics.width(Name);
-  int dy = int(float(y_) * Corr);  // correction for font scaling
-  if(dy < 1) {
-    if(x_ < w) return 0;
-    return -1;
+  if(showName) {
+    w  = metrics.width(Name);
+    if(dy < 1) {
+      if(x_ < w) return 0;
+      return -1;
+    }
+    dy--;
   }
 
   Property *pp;
   for(pp = Props.first(); pp != 0; pp = Props.next())
     if(pp->display)
-      if((--dy) < 1) break;
+      if((dy--) < 1) break;
   if(!pp) return -1;
 
   // get width of text
@@ -189,7 +190,7 @@ void Component::paint(ViewPainter *p)
     newFont.setPointSizeFloat(float(p->Scale) * QucsSettings.largeFontSize);
     newFont.setWeight(QFont::DemiBold);
     p->Painter->setFont(newFont);
-    p->map(cx, cy, &x, &y);
+    p->map(cx, cy, x, y);
 
     p->Painter->setPen(QPen(QPen::darkBlue,2));
     a = b = 0;
@@ -205,8 +206,8 @@ void Component::paint(ViewPainter *p)
     y2 = y1+23 + int(float(b) / p->Scale);
     if(ty < y2+1) if(ty > y1-r.height())  ty = y2 + 1;
 
-    p->map(cx-1, cy,   &x, &y);
-    p->map(cx-6, cy-5, &a, &b);
+    p->map(cx-1, cy, x, y);
+    p->map(cx-6, cy-5, a, b);
     p->Painter->drawRect(a, b, xb, yb);
     p->Painter->drawLine(x,      y+yb, a,      b+yb);
     p->Painter->drawLine(x+xb-1, y+yb, x,      y+yb);
@@ -256,7 +257,6 @@ void Component::paint(ViewPainter *p)
       p->Painter->setFont(newFont);
       p->Painter->setPen(pt->Color);
       p->Painter->drawText(0, 0, 0, 0, Qt::DontClip, pt->s);
-//      p->Painter->drawText(0, 0, pt->s);
     }
     p->Painter->setWorldMatrix(wm);
     p->Painter->setWorldXForm(false);
@@ -265,18 +265,23 @@ void Component::paint(ViewPainter *p)
 
 
   p->Painter->setPen(QPen(QPen::black,1));
-  int Height = p->LineSpacing;
-  p->map(cx+tx, cy+ty, &x, &y);
-  p->Painter->drawText(x, y, 0, 0, Qt::DontClip, Name);
+  p->map(cx+tx, cy+ty, x, y);
+  if(showName) {
+    p->Painter->drawText(x, y, 0, 0, Qt::DontClip, Name);
+    y += p->LineSpacing;
+  }
   // write all properties
   for(Property *p4 = Props.first(); p4 != 0; p4 = Props.next())
     if(p4->display) {
-      y += Height;
       p->Painter->drawText(x, y, 0, 0, Qt::DontClip, p4->Name+"="+p4->Value);
+      y += p->LineSpacing;
     }
 
-  if(!isActive) {
+  if(isActive == COMP_IS_OPEN)
     p->Painter->setPen(QPen(QPen::red,0));
+  else if(isActive & COMP_IS_SHORTEN)
+    p->Painter->setPen(QPen(QPen::darkGreen,0));
+  if(isActive != COMP_IS_ACTIVE) {
     p->drawRect(cx+x1, cy+y1, x2-x1+1, y2-y1+1);
     p->drawLine(cx+x1, cy+y1, cx+x2, cy+y2);
     p->drawLine(cx+x1, cy+y2, cx+x2, cy+y1);
@@ -297,7 +302,8 @@ void Component::paintScheme(QPainter *p)
     int a, b, xb, yb;
     QFont newFont = p->font();
 
-    float Scale = QucsMain->view->Docs.current()->Scale;
+    float Scale =
+          ((Schematic*)QucsMain->DocumentTab->currentPage())->Scale;
     newFont.setPointSizeFloat(float(Scale) * QucsSettings.largeFontSize);
     newFont.setWeight(QFont::DemiBold);
     QFontMetrics  metrics(newFont);
@@ -361,13 +367,6 @@ void Component::print(ViewPainter *p)
   }
 }
 
-// -------------------------------------------------------
-// Set position of property text to not interfere with component
-// symbol.
-void Component::recreate()
-{
-}
-
 // -------------------------------------------------------
 // Rotates the component 90 counter-clockwise around its center
 void Component::rotate()
@@ -445,8 +444,11 @@ void Component::rotate()
   tx  = ty;
   ty  = tmp;
   QFontMetrics  metrics(QucsSettings.font);   // get size of text
-  dx = metrics.width(Name);
-  dy = metrics.lineSpacing();
+  dx = dy = 0;
+  if(showName) {
+    dx = metrics.width(Name);
+    dy = metrics.lineSpacing();
+  }
   for(Property *pp = Props.first(); pp != 0; pp = Props.next())
     if(pp->display) {
       // get width of text
@@ -503,14 +505,16 @@ void Component::mirrorX()
     f.setPointSizeFloat(pt->Size);
     QFontMetrics  smallMetrics(f);
     QSize s = smallMetrics.size(0, pt->s);   // use size for more lines
-    pt->y = -pt->y - s.height();
+    pt->y = -pt->y - int(pt->mCos)*s.height() + int(pt->mSin)*s.width();
   }
 
   int tmp = y1;
   y1  = -y2; y2 = -tmp;   // mirror boundings
 
   QFontMetrics  metrics(QucsSettings.font);   // get size of text
-  int dy = metrics.lineSpacing();    // for "Name"
+  int dy = 0;
+  if(showName)
+    dy = metrics.lineSpacing();   // for "Name"
   for(Property *pp = Props.first(); pp != 0; pp = Props.next())
     if(pp->display)  dy += metrics.lineSpacing();
   if((tx > x1) && (tx < x2)) ty = -ty-dy;     // mirror text position
@@ -560,14 +564,16 @@ void Component::mirrorY()
     f.setPointSizeFloat(pt->Size);
     QFontMetrics  smallMetrics(f);
     QSize s = smallMetrics.size(0, pt->s);   // use size for more lines
-    pt->x = -pt->x - s.width();
+    pt->x = -pt->x - int(pt->mSin)*s.height() - int(pt->mCos)*s.width();
   }
 
   tmp = x1;
   x1  = -x2; x2 = -tmp;   // mirror boundings
 
   QFontMetrics  metrics(QucsSettings.font);   // get size of text
-  int dx = metrics.width(Name);
+  int dx = 0;
+  if(showName)
+    dx = metrics.width(Name);
   for(Property *pp = Props.first(); pp != 0; pp = Props.next())
     if(pp->display) {
       // get width of text
@@ -586,8 +592,6 @@ void Component::mirrorY()
 // -------------------------------------------------------
 QString Component::NetList()
 {
-  if(!isActive) return QString("");       // should it be simulated ?
-
   QString s = Model+":"+Name;
 
   // output all node names
@@ -611,19 +615,47 @@ QString Component::NetList()
   return s;
 }
 
+// -------------------------------------------------------
+QString Component::getShortenNetlist()
+{
+  int z=0;
+  QString s;
+  QString Node1 = Ports.first()->Connection->Name;
+  for(Port *pp = Ports.next(); pp != 0; pp = Ports.next())
+    s += "R:" + Name + "." + QString::number(z++) + " " +
+         Node1 + " " + pp->Connection->Name + " R=\"0\"\n";
+  return s;
+}
+
+// -------------------------------------------------------
+QString Component::VHDL_Code(int)
+{
+  return QString("");   // no digital model
+}
+
+// -------------------------------------------------------
+QString Component::getShortenVHDL()
+{
+  QString s;
+  QString Node1 = Ports.first()->Connection->Name;
+  for(Port *pp = Ports.next(); pp != 0; pp = Ports.next())
+    s += "  " + pp->Connection->Name + " <= " + Node1 + ";\n";
+  return s;
+}
+
 // -------------------------------------------------------
 QString Component::save()
 {
-  QString s = "<";
-  if(Model.at(0) == '#')
-    s  += Model.mid(1) + QString::number(Ports.count()-1);
-  else s += Model;
+  QString s = "<" + Model;
 
-  if(Name.isEmpty()) s += " *";
-  else s += " "+Name;
+  if(Name.isEmpty()) s += " * ";
+  else s += " "+Name+" ";
 
-  if(isActive) s += " 1";
-  else s += " 0";
+  int i=0;
+  if(!showName)
+    i = 4;
+  i |= isActive;
+  s += QString::number(i);
   s += " "+QString::number(cx)+" "+QString::number(cy);
   s += " "+QString::number(tx)+" "+QString::number(ty);
   if(mirroredX) s += " 1";
@@ -658,9 +690,14 @@ bool Component::load(const QString& _s)
   if(Name == "*") Name = "";
 
   n  = s.section(' ',2,2);      // isActive
-  if(n.toInt(&ok) == 1) isActive = true;
-  else isActive = false;
+  tmp = n.toInt(&ok);
   if(!ok) return false;
+  isActive = tmp & 3;
+
+  if(tmp & 4)
+    showName = false;
+  else
+    showName = true;
 
   n  = s.section(' ',3,3);    // cx
   cx = n.toInt(&ok);
@@ -678,18 +715,20 @@ bool Component::load(const QString& _s)
   tty = n.toInt(&ok);
   if(!ok) return false;
 
-if(Model.at(0) != '.') {  // is simulation component (dc, ac, ...) ?
+  if(Model.at(0) != '.') {  // is simulation component (dc, ac, ...) ?
 
-  n  = s.section(' ',7,7);    // mirroredX
-  if(n.toInt(&ok) == 1) mirrorX();  // mirror component
-  if(!ok) return false;
+    n  = s.section(' ',7,7);    // mirroredX
+    if(n.toInt(&ok) == 1) mirrorX();
+    if(!ok) return false;
 
-  n  = s.section(' ',8,8);    // rotated
-  tmp = n.toInt(&ok);
-  if(!ok) return false;
-  for(int z=0; z<tmp; z++) rotate();   // rotate component
+    n  = s.section(' ',8,8);    // rotated
+    tmp = n.toInt(&ok);
+    if(!ok) return false;
+    if(rotated > tmp)  // neccessary because of historical flaw in ...
+      tmp += 4;        // ... components like "volt_dc"
+    for(int z=rotated; z<tmp; z++) rotate();
 
-}
+  }
 
   tx = ttx; ty = tty; // restore text position (was changed by rotate/mirror)
 
@@ -715,6 +754,11 @@ if(Model.at(0) != '.') {  // is simulation component (dc, ac, ...) ?
 	Props.prev();
       }
     }
+    if(z == 6)  if(counts == 6)     // backward compatible
+      if(Model == "R") {
+        Props.getLast()->Value = n;
+        return true;
+      }
     p1->Value = n;
 
     n  = s.section('"',z,z);    // display
@@ -865,7 +909,7 @@ int Component::analyseLine(const QString& Row)
     return 1;
   }
   else if(s == "Text") {  // must be last in order to reuse "s" *********
-    if(!getIntegers(Row, &i1, &i2, &i3))  return -1;
+    if(!getIntegers(Row, &i1, &i2, &i3, 0, &i4))  return -1;
     Color.setNamedColor(Row.section(' ',4,4));
     if(!Color.isValid()) return -1;
 
@@ -874,19 +918,29 @@ int Component::analyseLine(const QString& Row)
     if(s.isEmpty()) return -1;
     convert2Unicode(s);
 
-    Texts.append(new Text(i1, i2, s, Color, float(i3)));
+    Texts.append(new Text(i1, i2, s, Color, float(i3),
+                          float(cos(float(i4)*M_PI/180.0)),
+                          float(sin(float(i4)*M_PI/180.0))));
 
     QFont Font(QucsSettings.font);
     Font.setPointSizeFloat(float(i3));
     QFontMetrics  metrics(Font);
     QSize r = metrics.size(0, s);    // get size of text
-    i3 = i1 + r.width();
-    i4 = i2 + r.height();
+    i3 = i1 + int(float(r.width())  * Texts.current()->mCos)
+            + int(float(r.height()) * Texts.current()->mSin);
+    i4 = i2 + int(float(r.width())  * -Texts.current()->mSin)
+            + int(float(r.height()) * Texts.current()->mCos);
 
     if(i1 < x1)  x1 = i1;  // keep track of component boundings
-    if(i3 > x2)  x2 = i3;
     if(i2 < y1)  y1 = i2;
+    if(i1 > x2)  x2 = i1;
+    if(i2 > y2)  y2 = i2;
+    
+    if(i3 < x1)  x1 = i3;
+    if(i4 < y1)  y1 = i4;
+    if(i3 > x2)  x2 = i3;
     if(i4 > y2)  y2 = i4;
+    return 1;
   }
 
   return 0;
@@ -914,10 +968,11 @@ bool Component::getIntegers(const QString& s, int *i1, int *i2, int *i3,
   *i3 = n.toInt(&ok);
   if(!ok) return false;
 
-  if(!i4) return true;
-  n  = s.section(' ',4,4);
-  *i4 = n.toInt(&ok);
-  if(!ok) return false;
+  if(i4) {
+    n  = s.section(' ',4,4);
+    *i4 = n.toInt(&ok);
+    if(!ok) return false;
+  }
 
   if(!i5) return true;
   n  = s.section(' ',5,5);
@@ -982,17 +1037,198 @@ bool Component::getBrush(const QString& s, QBrush& Brush, int i)
   return true;
 }
 
-// ---------------------------------------------------------------------
-void Component::performModification()
+
+// ***********************************************************************
+// ********                                                       ********
+// ********          Functions of class MultiViewComponent        ********
+// ********                                                       ********
+// ***********************************************************************
+void MultiViewComponent::recreate(Schematic *Doc)
 {
+  if(Doc) {
+    Doc->Components->setAutoDelete(false);
+    Doc->deleteComp(this);
+  }
+
+  Ellips.clear();
+  Texts.clear();
+  Ports.clear();
+  Lines.clear();
+  Rects.clear();
+  Arcs.clear();
+  createSymbol();
+  
   bool mmir = mirroredX;
   int  rrot = rotated;
   if(mmir)  mirrorX();   // mirror
   for(int z=0; z<rrot; z++)  rotate(); // rotate
 
-
   rotated = rrot;   // restore properties (were changed by rotate/mirror)
   mirroredX = mmir;
+
+  if(Doc) {
+    Doc->insertRawComponent(this);
+    Doc->Components->setAutoDelete(true);
+  }
+}
+
+
+// ***********************************************************************
+// ********                                                       ********
+// ********            Functions of class GateComponent           ********
+// ********                                                       ********
+// ***********************************************************************
+GateComponent::GateComponent()
+{
+  Type = isComponent;   // both analog and digital
+  Name  = "Y";
+
+  // the list order must be preserved !!!
+  Props.append(new Property("in", "2", false,
+		QObject::tr("number of input ports")));
+  Props.append(new Property("V", "1 V", false,
+		QObject::tr("voltage of high level")));
+  Props.append(new Property("t", "0", false,
+		QObject::tr("delay time")));
+
+  // this must be the last property in the list !!!
+  Props.append(new Property("Symbol", "old", false,
+		QObject::tr("schematic symbol")+" [old, DIN40900]"));
+}
+
+// -------------------------------------------------------
+QString GateComponent::NetList()
+{
+  QString s = Model+":"+Name;
+
+  // output all node names
+  for(Port *pp = Ports.first(); pp != 0; pp = Ports.next())
+    s += " "+pp->Connection->Name;   // node names
+
+  // output all properties
+  Property *p = Props.at(1);
+  s += " " + p->Name + "=\"" + p->Value + "\"";
+  p = Props.next();
+  s += " " + p->Name + "=\"" + p->Value + "\"";
+  return s;
+}
+
+// -------------------------------------------------------
+QString GateComponent::VHDL_Code(int NumPorts)
+{
+  Port *pp = Ports.first();
+  QString s = "  " + pp->Connection->Name + " <= ";  // output port
+
+  QString Op = ' ' + Model.lower() + ' ';
+  if(Model.at(0) == 'N') {
+    s += "not (";    // nor, nand is NOT assoziative !!! but xnor is !!!
+    Op = Op.remove(1, 1);
+  }
+
+  pp = Ports.next();
+  s += pp->Connection->Name;   // first input port
+
+  // output all input ports with node names
+  for(pp = Ports.next(); pp != 0; pp = Ports.next())
+    s += Op + pp->Connection->Name;
+  if(Model.at(0) == 'N')
+    s += ')';
+
+  if(NumPorts <= 0)  // no truth table simulation ?
+    if(strtod(Props.at(2)->Value.latin1(), 0) != 0.0) {  // delay time
+      QString t = Props.current()->Value;
+      if(!VHDL_Time(t, Name))
+        return t;    // time has not VHDL format
+
+      s += " after " + t;
+    }
+
+  s += ';';
+  return s;
+}
+
+// -------------------------------------------------------
+void GateComponent::createSymbol()
+{
+  int Num = Props.getFirst()->Value.toInt();
+  if(Num < 2) Num = 2;
+  else if(Num > 8) Num = 8;
+  Props.getFirst()->Value = QString::number(Num);
+
+  int xl, xr, y = 10*Num, z;
+  x1 = -30; y1 = -y-3;
+  x2 =  30; y2 =  y+3;
+
+  tx = x1+4;
+  ty = y2+4;
+
+  z = 0;
+  if(Model.at(0) == 'N')  z = 1;
+
+  if(Props.getLast()->Value.at(0) == 'D') {  // DIN symbol
+    xl = -15;
+    xr =  15;
+    Lines.append(new Line( 15,-y, 15, y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line(-15,-y, 15,-y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line(-15, y, 15, y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line(-15,-y,-15, y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line( 15, 0, 30, 0,QPen(QPen::darkBlue,2)));
+
+    if(Model.at(z) == 'O') {
+      Lines.append(new Line(-11, 6-y,-6, 9-y,QPen(QPen::darkBlue,0)));
+      Lines.append(new Line(-11,12-y,-6, 9-y,QPen(QPen::darkBlue,0)));
+      Lines.append(new Line(-11,14-y,-6,14-y,QPen(QPen::darkBlue,0)));
+      Lines.append(new Line(-11,16-y,-6,16-y,QPen(QPen::darkBlue,0)));
+      Texts.append(new Text( -4, 3-y, "1", QPen::darkBlue, 15.0));
+    }
+    else if(Model.at(z) == 'A')
+      Texts.append(new Text( -10, 3-y, "&", QPen::darkBlue, 15.0));
+    else if(Model.at(0) == 'X') {
+      if(Model.at(1) == 'N')
+        Texts.append(new Text( -11, 3-y, "=", QPen::darkBlue, 15.0));
+      else
+        Texts.append(new Text( -12, 3-y, "=1", QPen::darkBlue, 15.0));
+    }
+  }
+  else {   // old symbol
+
+    if(Model.at(z) == 'O')  xl = 10;
+    else  xl = -10;
+    xr = 10;
+    Lines.append(new Line(-10,-y,-10, y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line( 10, 0, 30, 0,QPen(QPen::darkBlue,2)));
+    Arcs.append(new Arc(-30,-y, 40, 30, 0, 16*90,QPen(QPen::darkBlue,2)));
+    Arcs.append(new Arc(-30,y-30, 40, 30, 0,-16*90,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line( 10,15-y, 10, y-15,QPen(QPen::darkBlue,2)));
+
+    if(Model.at(0) == 'X') {
+      Lines.append(new Line(-5, 0, 5, 0,QPen(QPen::darkBlue,1)));
+      if(Model.at(1) == 'N') {
+        Lines.append(new Line(-5,-3, 5,-3,QPen(QPen::darkBlue,1)));
+        Lines.append(new Line(-5, 3, 5, 3,QPen(QPen::darkBlue,1)));
+      }
+      else {
+        Arcs.append(new Arc(-6,-6, 12, 12, 0, 16*360,QPen(QPen::darkBlue,1)));
+        Lines.append(new Line( 0,-5, 0, 5,QPen(QPen::darkBlue,1)));
+      }
+    }
+  }
+
+  if(Model.at(0) == 'N')
+    Ellips.append(new Area(xr,-4, 8, 8,
+                  QPen(QPen::darkBlue,0), QBrush(QPen::darkBlue)));
+
+  Ports.append(new Port( 30,  0));
+  y += 10;
+  for(z=0; z<Num; z++) {
+    y -= 20;
+    Ports.append(new Port(-30, y));
+    if(xl == 10) if((z == 0) || (z == Num-1)) {
+      Lines.append(new Line(-30, y, 9, y,QPen(QPen::darkBlue,2)));
+      continue;
+    }
+    Lines.append(new Line(-30, y, xl, y,QPen(QPen::darkBlue,2)));
+  }
 }
 
 
@@ -1023,17 +1259,21 @@ Component* getComponentFromName(QString& Line)
   // letter of their name
   switch(first) {
   case 'R' : if(cstr.isEmpty()) c = new Resistor();
-	else if(cstr == "us") c = new Resistor(false);
+	else if(cstr == "us") c = new Resistor(false);  // backward capatible
+	else if(cstr == "SFF") c = new RS_FlipFlop();
+	else if(cstr == "elais") c = new Relais();
 	break;
   case 'C' : if(cstr.isEmpty()) c = new Capacitor();
 	else if(cstr == "CCS") c = new CCCS();
 	else if(cstr == "CVS") c = new CCVS();
 	else if(cstr == "irculator") c = new Circulator();
+	else if(cstr == "oupler") c = new Coupler();
 	else if(cstr == "LIN") c = new Coplanar();
 	else if(cstr == "OPEN") c = new CPWopen();
 	else if(cstr == "SHORT") c = new CPWshort();
 	else if(cstr == "GAP") c = new CPWgap();
 	else if(cstr == "STEP") c = new CPWstep();
+	else if(cstr == "OAX") c = new CoaxialLine();
 	break;
   case 'L' : if(cstr.isEmpty()) c = new Inductor();
 	else if(cstr == "ib") c = new LibComp();
@@ -1048,16 +1288,23 @@ Component* getComponentFromName(QString& Line)
         else if(cstr == "solator") c = new Isolator();
         else if(cstr == "pulse") c = new iPulse();
         else if(cstr == "rect") c = new iRect();
+        else if(cstr == "Inoise") c = new Noise_ii();
+        else if(cstr == "Vnoise") c = new Noise_iv();
+        else if(cstr == "nv") c = new Logical_Inv();
         break;
   case 'J' : if(cstr == "FET") c = new JFET();
+	else if(cstr == "KFF") c = new JK_FlipFlop();
         break;
   case 'V' : if(cstr == "dc") c = new Volt_dc();
         else if(cstr == "ac") c = new Volt_ac();
         else if(cstr == "CCS") c = new VCCS();
         else if(cstr == "CVS") c = new VCVS();
+        else if(cstr == "Probe") c = new vProbe();
         else if(cstr == "noise") c = new Volt_noise();
         else if(cstr == "pulse") c = new vPulse();
         else if(cstr == "rect") c = new vRect();
+        else if(cstr == "Vnoise") c = new Noise_vv();
+        else if(cstr == "HDL") c = new VHDL_File();
         break;
   case 'T' : if(cstr == "r") c = new Transformer();
         else if(cstr == "LIN") c = new TLine();
@@ -1067,24 +1314,34 @@ Component* getComponentFromName(QString& Line)
   case 'P' : if(cstr == "ac") c = new Source_ac();
         else if(cstr == "ort") c = new SubCirPort();
         else if(cstr == "Shift") c = new Phaseshifter();
+        else if(cstr == "M_Mod") c = new PM_Modulator();
         break;
-  case 'S' : if(cstr.left(5) == "Pfile") {
-	       c = new SParamFile(cstr.mid(5).toInt()); }
+  case 'S' : if(cstr == "Pfile") c = new SParamFile();
+        else if(cstr.left(5) == "Pfile") {  // backward compatible
+          c = new SParamFile();
+          c->Props.getLast()->Value = cstr.mid(5); }
         else if(cstr == "ub")   c = new Subcircuit();
         else if(cstr == "UBST") c = new Substrate();
         else if(cstr == "PICE") c = new SpiceFile();
+        else if(cstr == "witch") c = new Switch();
         break;
   case 'D' : if(cstr == "CBlock") c = new dcBlock();
 	else if(cstr == "CFeed") c = new dcFeed();
 	else if(cstr == "iode") c = new Diode();
+	else if(cstr == "igiSource") c = new Digi_Source();
+	else if(cstr == "FF") c = new D_FlipFlop();
 	break;
   case 'B' : if(cstr == "iasT") c = new BiasT();
-	else if(cstr == "JT") c = new BJTsub();
-	break;
-  case 'A' : if(cstr == "ttenuator") c = new Attenuator();
-	else if(cstr == "mp") c = new Amplifier();
+        else if(cstr == "JT") c = new BJTsub();
         break;
-  case 'M' : if(cstr == "LIN") c = new MSline();
+  case 'A' : if(cstr == "ttenuator") c = new Attenuator();
+        else if(cstr == "mp") c = new Amplifier();
+        else if(cstr == "ND") c = new Logical_AND();
+        else if(cstr == "M_Mod") c = new AM_Modulator();
+        break;
+  case 'M' : if(cstr == "UT") c = new Mutual();
+	else if(cstr == "UT2") c = new Mutual2();
+	else if(cstr == "LIN") c = new MSline();
 	else if(cstr == "OSFET") c = new MOSFET_sub();
 	else if(cstr == "STEP") c = new MSstep();
 	else if(cstr == "CORN") c = new MScorner();
@@ -1099,6 +1356,10 @@ Component* getComponentFromName(QString& Line)
   case 'E' : if(cstr == "qn") c = new Equation();
         break;
   case 'O' : if(cstr == "pAmp") c = new OpAmp();
+        else if(cstr == "R") c = new Logical_OR();
+        break;
+  case 'N' : if(cstr == "OR") c = new Logical_NOR();
+        else if(cstr == "AND") c = new Logical_NAND();
         break;
   case '.' : if(cstr == "DC") c = new DC_Sim();
         else if(cstr == "AC") c = new AC_Sim();
@@ -1106,10 +1367,14 @@ Component* getComponentFromName(QString& Line)
         else if(cstr == "SP") c = new SP_Sim();
         else if(cstr == "HB") c = new HB_Sim();
         else if(cstr == "SW") c = new Param_Sweep();
+        else if(cstr == "Digi") c = new Digi_Sim();
         break;
   case '_' : if(cstr == "BJT") c = new BJT();
 	else if(cstr == "MOSFET") c = new MOSFET();
         break;
+  case 'X' : if(cstr == "OR") c = new Logical_XOR();
+        else if(cstr == "NOR") c = new Logical_XNOR();
+        break;
   }
   if(!c) {
     QMessageBox::critical(0, QObject::tr("Error"),
@@ -1126,7 +1391,7 @@ Component* getComponentFromName(QString& Line)
 
   cstr = c->Name;   // is perhaps changed in "recreate" (e.g. subcircuit)
   int x = c->tx, y = c->ty;
-  c->recreate();
+  c->recreate(0);
   c->Name = cstr;
   c->tx = x;  c->ty = y;
   return c;
