@@ -25,6 +25,7 @@
 #include <qpoint.h>
 #include <qwidget.h>
 
+class Schematic;
 class ViewPainter;
 class QString;
 
@@ -32,17 +33,20 @@ class QString;
 class Component : public Element {
 public:
   Component();
-  virtual ~Component();
+  virtual ~Component() {};
 
   virtual Component* newOne();
-  virtual void recreate();
+  virtual void recreate(Schematic*) {};
   virtual QString NetList();
+  virtual QString VHDL_Code(int);
+  QString getShortenNetlist();
+  QString getShortenVHDL();
   void    paint(ViewPainter*);
   void    paintScheme(QPainter*);
   void    print(ViewPainter*);
   void    setCenter(int, int, bool relative=false);
   void    getCenter(int&, int&);
-  void    TextSize(int&, int&);
+  int     textSize(int&, int&);
   void    Bounding(int&, int&, int&, int&);
   void    entireBounds(int&, int&, int&, int&, float);
   bool    getSelected(int, int);
@@ -65,10 +69,14 @@ public:
   QPtrList<Text>     Texts;
   QPtrList<Property> Props;
 
-  bool     isActive; // should it be used in simulation or not ?
-  int      tx, ty;   // upper left corner of text (position)
-  QString  Description;
+  #define COMP_IS_OPEN    0
+  #define COMP_IS_ACTIVE  1
+  #define COMP_IS_SHORTEN 2
+  int  isActive; // should it be used in simulation or not ?
+  int  tx, ty;   // upper left corner of text (position)
+  bool showName;
   QString  Model, Name;
+  QString  Description;
 
 protected:
   int  analyseLine(const QString&);
@@ -76,11 +84,31 @@ protected:
 		   int *i4=0, int *i5=0, int *i6=0);
   bool getPen(const QString&, QPen&, int);
   bool getBrush(const QString&, QBrush&, int);
-  void performModification();
-
 };
 
 
+class MultiViewComponent : public Component {
+public:
+  MultiViewComponent() {};
+  virtual ~MultiViewComponent() {};
+
+  void recreate(Schematic*);
+
+protected:
+  virtual void createSymbol() {};
+};
+
+
+class GateComponent : public MultiViewComponent {
+public:
+  GateComponent();
+  QString NetList();
+  QString VHDL_Code(int);
+
+protected:
+  void createSymbol();
+};
+
 // prototype of independent function
 Component* getComponentFromName(QString&);
 
