@@ -16,22 +16,24 @@
  ***************************************************************************/
 
 #include "componentdialog.h"
+#include "main.h"
 #include "qucs.h"
-#include "qucsview.h"
-#include "qucsdoc.h"
+#include "schematic.h"
 
-#include <qlayout.h>
 #include <qhbox.h>
 #include <qvbox.h>
-#include <qmessagebox.h>
+#include <qlayout.h>
+#include <qhgroupbox.h>
 #include <qvalidator.h>
+#include <qtabwidget.h>
+#include <qmessagebox.h>
 #include <qfiledialog.h>
 
 #include <math.h>
 
 
-ComponentDialog::ComponentDialog(Component *c, QucsDoc *d, QWidget *parent)
-			: QDialog(parent, 0, TRUE, Qt::WDestructiveClose)
+ComponentDialog::ComponentDialog(Component *c, Schematic *d)
+			: QDialog(d, 0, TRUE, Qt::WDestructiveClose)
 {
   resize(400, 250);
   setCaption(tr("Edit Component Properties"));
@@ -40,23 +42,24 @@ ComponentDialog::ComponentDialog(Component *c, QucsDoc *d, QWidget *parent)
   QString s;
 
   all = new QVBoxLayout(this); // to provide neccessary size
-  QGridLayout *gp2;
+  QGridLayout *gp1;
   QWidget *myParent = this;
   ValInteger = new QIntValidator(1, 1000000, this);
 
-  Expr.setPattern("[^\"=]+");  // valid expression for property 'edit' etc
+  Expr.setPattern("[^\"=]+");  // valid expression for property 'edit'
   Validator = new QRegExpValidator(Expr, this);
-  Expr.setPattern("[\\w_]+");  // valid expression for property 'NameEdit' etc
+  Expr.setPattern("[\\w_]+");  // valid expression for property 'NameEdit'
   ValRestrict = new QRegExpValidator(Expr, this);
 
-  checkSim  = 0;  editSim   = 0;  comboType = 0;  checkParam = 0;
-  editStart = 0;  editStop  = 0;  editNumber = 0;
+  checkSim  = 0;  editSim  = 0;  comboType  = 0;  checkParam = 0;
+  editStart = 0;  editStop = 0;  editNumber = 0;
 
   Property *pp = 0;   // last property not to put in ListView
   // ...........................................................
   // if simulation component
   if((Comp->Model[0] == '.') &&
-     (Comp->Model != ".DC") && (Comp->Model != ".HB")) {
+     (Comp->Model != ".DC") && (Comp->Model != ".HB") &&
+     (Comp->Model != ".Digi")) {
     QTabWidget *t = new QTabWidget(this);
     all->addWidget(t);
 
@@ -155,7 +158,8 @@ ComponentDialog::ComponentDialog(Component *c, QucsDoc *d, QWidget *parent)
 
 
     if(Comp->Model == ".SW") {   // parameter sweep
-      for(Component *pc=Doc->Comps->first(); pc!=0; pc=Doc->Comps->next())
+      Component *pc;
+      for(pc=Doc->Components->first(); pc!=0; pc=Doc->Components->next())
         if(pc != Comp)
           if(pc->Model[0] == '.')
             editSim->insertItem(pc->Name);
@@ -223,63 +227,65 @@ ComponentDialog::ComponentDialog(Component *c, QucsDoc *d, QWidget *parent)
 
     QWidget *Tab2 = new QWidget(t);
     t->addTab(Tab2, tr("Properties"));
-    gp2 = new QGridLayout(Tab2, 9,2,5,5);
+    gp1 = new QGridLayout(Tab2, 9,2,5,5);
     myParent = Tab2;
   }
   else {   // no simulation component
-    gp2 = new QGridLayout(0, 9,2,5,5);
-    all->addLayout(gp2);
+    gp1 = new QGridLayout(0, 9,2,5,5);
+    all->addLayout(gp1);
   }
 
 
   // ...........................................................
-  gp2->addMultiCellWidget(new QLabel(Comp->Description, myParent), 0,0,0,1);
+  gp1->addMultiCellWidget(new QLabel(Comp->Description, myParent), 0,0,0,1);
 
   QHBox *h5 = new QHBox(myParent);
   h5->setSpacing(5);
-  gp2->addWidget(h5, 1,0);
+  gp1->addWidget(h5, 1,0);
   new QLabel(tr("Name:"), h5);
   CompNameEdit = new QLineEdit(h5);
   CompNameEdit->setValidator(ValRestrict);
   connect(CompNameEdit, SIGNAL(returnPressed()), SLOT(slotButtOK()));
 
-  prop = new QListView(myParent);
+  showName = new QCheckBox(tr("display in schematic"), myParent);
+  gp1->addWidget(showName, 1,1);
+
+  QHGroupBox *PropertyBox = new QHGroupBox(tr("Properties"), myParent);
+  gp1->addMultiCellWidget(PropertyBox, 2,2,0,1);
+
+  prop = new QListView(PropertyBox);
   prop->setMinimumSize(200, 150);
   prop->addColumn(tr("Name"));
   prop->addColumn(tr("Value"));
   prop->addColumn(tr("display"));
   prop->addColumn(tr("Description"));
   prop->setSorting(-1);   // no sorting
-  gp2->addMultiCellWidget(prop, 2,8,0,0);
 
-  Name = new QLabel(myParent);
-  gp2->addWidget(Name, 2,1);
+  QVBox *v1 = new QVBox(PropertyBox);
+  v1->setSpacing(3);
 
-  Description = new QLabel(myParent);
-  gp2->addWidget(Description, 3,1);
+  Name = new QLabel(v1);
+
+  Description = new QLabel(v1);
 
   // hide, because it only replaces 'Description' in some cases
-  NameEdit = new QLineEdit(myParent);
+  NameEdit = new QLineEdit(v1);
   NameEdit->setShown(false);
   NameEdit->setValidator(ValRestrict);
-  gp2->addWidget(NameEdit, 3,1);
   connect(NameEdit, SIGNAL(returnPressed()), SLOT(slotApplyPropName()));
 
-  edit = new QLineEdit(myParent);
+  edit = new QLineEdit(v1);
   edit->setMinimumWidth(150);
-  gp2->addWidget(edit, 4,1);
   edit->setValidator(Validator);
   connect(edit, SIGNAL(returnPressed()), SLOT(slotApplyProperty()));
 
   // hide, because it only replaces 'edit' in some cases
-  ComboEdit = new QComboBox(false, myParent);
+  ComboEdit = new QComboBox(false, v1);
   ComboEdit->setShown(false);
-  gp2->addWidget(ComboEdit, 4,1);
   connect(ComboEdit, SIGNAL(activated(const QString&)),
 	  SLOT(slotApplyChange(const QString&)));
 
-  QHBox *h3 = new QHBox(myParent);
-  gp2->addWidget(h3, 5,1);
+  QHBox *h3 = new QHBox(v1);
   h3->setStretchFactor(new QWidget(h3),5); // stretchable placeholder
   EditButt = new QPushButton(tr("Edit"),h3);
   EditButt->setEnabled(false);
@@ -290,17 +296,13 @@ ComponentDialog::ComponentDialog(Component *c, QucsDoc *d, QWidget *parent)
   BrowseButt->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
   connect(BrowseButt, SIGNAL(clicked()), SLOT(slotBrowseFile()));
 
-  disp = new QCheckBox(tr("display in schematic"), myParent);
-  gp2->addWidget(disp, 6,1);
+  disp = new QCheckBox(tr("display in schematic"), v1);
   connect(disp, SIGNAL(stateChanged(int)), SLOT(slotApplyState(int)));
 
-  QVBoxLayout *v = new QVBoxLayout(); // stretchable placeholder
-  v->addStretch(2);
-  gp2->addLayout(v,7,1);
+  v1->setStretchFactor(new QWidget(v1),5); // stretchable placeholder
 
-  QHBox *h4 = new QHBox(myParent);
+  QHBox *h4 = new QHBox(v1);
   h4->setSpacing(5);
-  gp2->addMultiCellWidget(h4, 8,8,1,1);
   ButtAdd = new QPushButton(tr("Add"),h4);
   ButtAdd->setEnabled(false);
   ButtRem = new QPushButton(tr("Remove"),h4);
@@ -321,9 +323,10 @@ ComponentDialog::ComponentDialog(Component *c, QucsDoc *d, QWidget *parent)
 
   // ------------------------------------------------------------
   CompNameEdit->setText(Comp->Name);
+  showName->setChecked(Comp->showName);
   changed = false;
 
-  Comp->TextSize(tx_Dist, ty_Dist);
+  Comp->textSize(tx_Dist, ty_Dist);
   int tmp = Comp->tx+tx_Dist - Comp->x1;
   if((tmp > 0) || (tmp < -6))  tx_Dist = 0;  // remember the text position
   tmp = Comp->ty+ty_Dist - Comp->y1;
@@ -334,9 +337,7 @@ ComponentDialog::ComponentDialog(Component *c, QucsDoc *d, QWidget *parent)
     if(p == pp)  break;   // do not insert if already on first tab
     if(p->display) s = tr("yes");
     else s = tr("no");
-    QString str = p->Description;
-    correctDesc (str);
-    new QListViewItem(prop, p->Name, p->Value, s, str);
+    new QListViewItem(prop, p->Name, p->Value, s, p->Description);
   }
 
   if(prop->childCount() > 0) {
@@ -356,27 +357,6 @@ ComponentDialog::~ComponentDialog()
   delete ValInteger;
 }
 
-// -------------------------------------------------------------------------
-// Used to correct the given property description to handle special combobox
-// items.  If 'clst' is not NULL, then an appropriate ComboBox string list
-// is returned.
-void ComponentDialog::correctDesc(QString &desc, QStringList *clst)
-{
-  int b, e;
-  QString str;
-  QStringList List;
-  b = desc.find('[');
-  e = desc.findRev(']');
-  if (e-b > 2) {
-    str = desc.mid(b+1, e-b-1);
-    List = List.split(',',str);
-    desc = desc.left(b)+"["+List.join(",")+"]"+desc.mid(e+1);
-    for (QStringList::Iterator it = List.begin(); it != List.end(); ++it )
-      (*it).replace( QRegExp("[^a-zA-Z0-9_]"), "" );
-  }
-  if(clst != 0) *clst = List;
-}
-
 // -------------------------------------------------------------------------
 // Is called if a property is selected. It transfers the values to the right
 // side for editing.
@@ -427,17 +407,22 @@ void ComponentDialog::slotSelectProperty(QListViewItem *item)
 
     // handle special combobox items
     QStringList List;
-    correctDesc( PropDesc, &List );
-
-    QString s = PropDesc;
-    QFontMetrics  metrics(QucsSettings.font);   // get size of text
-    while(metrics.width(s) > 270) {  // if description too long, cut it
-      if (s.findRev(' ') != -1)
-	s = s.left(s.findRev(' ', -1)) + "....";
-      else
-	s = s.left(s.length()-5) + "....";
+    int b = PropDesc.find('[');
+    int e = PropDesc.findRev(']');
+    if (e-b > 2) {
+      QString str = PropDesc.mid(b+1, e-b-1);
+      str.replace( QRegExp("[^a-zA-Z0-9_,]"), "" );
+      List = List.split(',',str);
     }
-    Description->setText(s);
+
+    QFontMetrics  metrics(QucsSettings.font);   // get size of text
+    while(metrics.width(PropDesc) > 270) {  // if description too long, cut it
+      if (PropDesc.findRev(' ') != -1)
+	PropDesc = PropDesc.left(PropDesc.findRev(' ', -1)) + "....";
+      else
+	PropDesc = PropDesc.left(PropDesc.length()-5) + "....";
+    }
+    Description->setText(PropDesc);
 
     if(List.count() >= 1) {    // ComboBox with value list or line edit ?
       ComboEdit->clear();
@@ -565,12 +550,17 @@ void ComponentDialog::reject()
 // Is called, if the "Apply"-button is pressed.
 void ComponentDialog::slotApplyInput()
 {
+  if(Comp->showName != showName->isChecked()) {
+    Comp->showName = showName->isChecked();
+    changed = true;
+  }
+
   QString tmp;
   Component *pc;
   if(CompNameEdit->text().isEmpty())  CompNameEdit->setText(Comp->Name);
   else
   if(CompNameEdit->text() != Comp->Name) {
-    for(pc = Doc->Comps->first(); pc!=0; pc = Doc->Comps->next())
+    for(pc = Doc->Components->first(); pc!=0; pc = Doc->Components->next())
       if(pc->Name == CompNameEdit->text())
         break;  // found component with the same name ?
     if(pc)  CompNameEdit->setText(Comp->Name);
@@ -736,7 +726,7 @@ void ComponentDialog::slotApplyInput()
 
   if(changed) {
     int dx, dy;
-    Comp->TextSize(dx, dy);
+    Comp->textSize(dx, dy);
     if(tx_Dist != 0) {
       Comp->tx += tx_Dist-dx;
       tx_Dist = dx;
@@ -746,14 +736,8 @@ void ComponentDialog::slotApplyInput()
       ty_Dist = dy;
     }
 
-    tmp = Comp->Name;    // is sometimes changed by "recreate"
-    Doc->Comps->setAutoDelete(false);
-    Doc->deleteComp(Comp);
-    Comp->recreate();   // to apply changes to the schematic symbol
-    Doc->insertRawComponent(Comp);
-    Doc->Comps->setAutoDelete(true);
-    Comp->Name = tmp;
-    ((QucsView*)parent())->viewport()->repaint();
+    Doc->recreateComponent(Comp);
+    Doc->viewport()->repaint();
   }
 }
 
@@ -761,8 +745,10 @@ void ComponentDialog::slotApplyInput()
 void ComponentDialog::slotBrowseFile()
 {
   QString s = QFileDialog::getOpenFileName(QucsWorkDir.path(),
-					tr("All Files")+" (*.*)",
-					this, "", tr("Select a file"));
+          tr("All Files")+" (*.*);;"+tr("Touchstone files")+" (*.s?p);;"+
+          tr("SPICE files")+" (*.cir *.spi);;"+
+          tr("VHDL files")+" (*.vhdl *.vhd)",
+          this, "", tr("Select a file"));
   if(!s.isEmpty()) {
     // snip path if file in current directory
     QFileInfo file(s);
@@ -776,7 +762,7 @@ void ComponentDialog::slotBrowseFile()
 // -------------------------------------------------------------------------
 void ComponentDialog::slotEditFile()
 {
-  Doc->App->Acts.editFile(QucsWorkDir.filePath(edit->text()));
+  Doc->App->editFile(QucsWorkDir.filePath(edit->text()));
 }
 
 // -------------------------------------------------------------------------
@@ -784,7 +770,16 @@ void ComponentDialog::slotEditFile()
 // properties.
 void ComponentDialog::slotButtAdd()
 {
-  QListViewItem *item = prop->selectedItem();
+  QListViewItem *item;
+  // Search if property with this name already exist.
+  for(item = prop->firstChild(); item != 0; item = item->itemBelow())
+    if(item->text(0) == NameEdit->text()) {
+      prop->setSelected(item, true);
+      slotSelectProperty(item);
+      return;
+    }
+
+  item = prop->selectedItem();
   if(item == 0) item = prop->lastItem();
 
   QString s = tr("no");
