@@ -31,7 +31,7 @@
 #include <qptrlist.h>
 #include <qdir.h>
 
-class QucsDoc;
+class Schematic;
 class QGridLayout;
 class QValidator;
 class QVBoxLayout;
@@ -44,8 +44,8 @@ extern QDir QucsWorkDir;
 class ComponentDialog : public QDialog {
    Q_OBJECT
 public:
-  ComponentDialog(Component*, QucsDoc*, QWidget *parent=0);
-  ~ComponentDialog();
+  ComponentDialog(Component*, Schematic*);
+ ~ComponentDialog();
 
 private slots:
   void slotButtOK();
@@ -78,8 +78,6 @@ protected slots:
     void reject();
 
 private:
-  void correctDesc(QString &desc, QStringList *clst = 0);
-
   QVBoxLayout *all;   // the mother of all widgets
   QValidator  *Validator, *ValRestrict;
   QRegExp     Expr;
@@ -91,7 +89,7 @@ private:
   QPushButton *BrowseButt, *EditButt, *ButtAdd, *ButtRem;
   QCheckBox   *disp;
   Component   *Comp;
-  QucsDoc     *Doc;
+  Schematic   *Doc;
   bool        changed;
   int         tx_Dist, ty_Dist;   // remember the text position
 
@@ -101,7 +99,7 @@ private:
   QLineEdit *editParam, *editValues, *editStart, *editStop,
             *editStep, *editNumber;
   QCheckBox *checkSim, *checkParam, *checkValues, *checkStart, *checkStop,
-            *checkNumber, *checkType;
+            *checkNumber, *checkType, *showName;
   QComboBox *editSim, *comboType;
 };
 
