@@ -52,6 +52,7 @@
 #include "vcvs.h"
 #include "ccvs.h"
 #include "tline.h"
+#include "coaxialline.h"
 #include "substrate.h"
 #include "msline.h"
 #include "mscoupled.h"
@@ -81,14 +82,37 @@
 #include "hb_sim.h"
 #include "param_sweep.h"
 #include "iprobe.h"
+#include "vprobe.h"
 #include "volt_noise.h"
 #include "ampere_noise.h"
+#include "noise_ii.h"
+#include "noise_iv.h"
+#include "noise_vv.h"
 #include "vpulse.h"
 #include "ipulse.h"
 #include "vrect.h"
 #include "irect.h"
 #include "spicefile.h"
 #include "libcomp.h"
-
+#include "mutual.h"
+#include "mutual2.h"
+#include "coupler.h"
+#include "switch.h"
+#include "relais.h"
+#include "am_modulator.h"
+#include "pm_modulator.h"
+#include "logical_or.h"
+#include "logical_nor.h"
+#include "logical_and.h"
+#include "logical_nand.h"
+#include "logical_xor.h"
+#include "logical_xnor.h"
+#include "logical_inv.h"
+#include "digi_sim.h"
+#include "digi_source.h"
+#include "rs_flipflop.h"
+#include "d_flipflop.h"
+#include "jk_flipflop.h"
+#include "vhdlfile.h"
 
 #endif
