@@ -1,6 +1,6 @@
 /***************************************************************************
-                          ground.cpp  -  description
-                             -------------------
+                                ground.cpp
+                               ------------
     begin                : Sat Aug 23 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -16,10 +16,12 @@
  ***************************************************************************/
 
 #include "ground.h"
+#include "node.h"
 
 
 Ground::Ground()
 {
+  Type = isComponent;   // both analog and digital
   Description = QObject::tr("ground (reference potential)");
 
   Lines.append(new Line(  0,  0,  0, 10,QPen(QPen::darkBlue,2)));
@@ -47,6 +49,7 @@ Component* Ground::newOne()
   return new Ground();
 }
 
+// -------------------------------------------------------
 Element* Ground::info(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("Ground");
@@ -56,6 +59,7 @@ Element* Ground::info(QString& Name, char* &BitmapFile, bool getNewOne)
   return 0;
 }
 
+// -------------------------------------------------------
 QString Ground::NetList()
 {
   return QString("");
