@@ -1,6 +1,6 @@
 /***************************************************************************
-                         ipulse.cpp  -  description
-                             -------------------
+                                ipulse.cpp
+                               ------------
     begin                : Sat Sep 18 2004
     copyright            : (C) 2004 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -59,6 +59,8 @@ iPulse::iPulse()
 		QObject::tr("rise time of the leading edge")));
   Props.append(new Property("Tf", "1 ns", false,
 		QObject::tr("fall time of the trailing edge")));
+
+  rotate();  // fix historical flaw
 }
 
 iPulse::~iPulse()
