@@ -1,6 +1,6 @@
 /***************************************************************************
-                          resistor.cpp  -  description
-                             -------------------
+                               resistor.cpp
+                              --------------
     begin                : Sat Aug 23 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -16,43 +16,47 @@
  ***************************************************************************/
 
 #include "resistor.h"
+#include "node.h"
+#include "schematic.h"
+
 
 Resistor::Resistor(bool european)
 {
   Description = QObject::tr("resistor");
 
-  createSymbol(european);
-
-  Ports.append(new Port(-30,  0));
-  Ports.append(new Port( 30,  0));
-
-  x1 = -30; y1 = -11;
-  x2 =  30; y2 =  11;
-
-  tx = x1+4;
-  ty = y2+4;
-  Model = "R";
-  Name  = "R";
-
   Props.append(new Property("R", "50 Ohm", true,
-		QObject::tr("ohmic resistance in Ohms")));
+	QObject::tr("ohmic resistance in Ohms")));
   Props.append(new Property("Temp", "26.85", false,
-		QObject::tr("simulation temperature in degree Celsius")));
+	QObject::tr("simulation temperature in degree Celsius")));
+  Props.append(new Property("Tc1", "0.0", false,
+	QObject::tr("first order temperature coefficient")));
+  Props.append(new Property("Tc2", "0.0", false,
+	QObject::tr("second order temperature coefficient")));
+  Props.append(new Property("Tnom", "26.85", false,
+	QObject::tr("temperature at which parameters were extracted")));
 
   // this must be the last property in the list !!!
   Props.append(new Property("Symbol", "european", false,
 		QObject::tr("schematic symbol")+" [european, US]"));
   if(!european)  Props.getLast()->Value = "US";
+
+  createSymbol();
+  tx = x1+4;
+  ty = y2+4;
+  Model = "R";
+  Name  = "R";
 }
 
-Resistor::~Resistor()
+// -------------------------------------------------------
+Component* Resistor::newOne()
 {
+  return new Resistor(Props.getLast()->Value != "US");
 }
 
-
-void Resistor::createSymbol(bool european)
+// -------------------------------------------------------
+void Resistor::createSymbol()
 {
-  if(european) {
+  if(Props.getLast()->Value != "US") {
     Lines.append(new Line(-18, -9, 18, -9,QPen(QPen::darkBlue,2)));
     Lines.append(new Line( 18, -9, 18,  9,QPen(QPen::darkBlue,2)));
     Lines.append(new Line( 18,  9,-18,  9,QPen(QPen::darkBlue,2)));
@@ -71,16 +75,15 @@ void Resistor::createSymbol(bool european)
     Lines.append(new Line( 15,  7, 18,  0,QPen(QPen::darkBlue,2)));
     Lines.append(new Line( 18,  0, 30,  0,QPen(QPen::darkBlue,2)));
   }
+
+  Ports.append(new Port(-30,  0));
+  Ports.append(new Port( 30,  0));
+
+  x1 = -30; y1 = -11;
+  x2 =  30; y2 =  11;
 }
 
-Component* Resistor::newOne()
-{
-  Resistor* p = new Resistor();
-  p->Props.getLast()->Value = Props.getLast()->Value;
-  p->recreate();
-  return p;
-}
-
+// -------------------------------------------------------
 Element* Resistor::info(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("Resistor");
@@ -90,45 +93,12 @@ Element* Resistor::info(QString& Name, char* &BitmapFile, bool getNewOne)
   return 0;
 }
 
+// -------------------------------------------------------
 Element* Resistor::info_us(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("Resistor US");
   BitmapFile = "resistor_us";
 
-  if(getNewOne) {
-    Resistor* p = new Resistor();
-    p->Props.getLast()->Value = "US";
-    p->recreate();
-    return p;
-  }
+  if(getNewOne)  return new Resistor(false);
   return 0;
 }
-
-void Resistor::recreate()
-{
-  Lines.clear();
-  createSymbol(Props.getLast()->Value != "US");
-
-  Line *p1;
-  bool mmir = mirroredX;
-  int  tmp, rrot = rotated;
-  if(mmir)  // mirror all lines
-    for(p1 = Lines.first(); p1 != 0; p1 = Lines.next()) {
-      p1->y1 = -p1->y1;
-      p1->y2 = -p1->y2;
-    }
-
-  for(int z=0; z<rrot; z++)    // rotate all lines
-    for(p1 = Lines.first(); p1 != 0; p1 = Lines.next()) {
-      tmp = -p1->x1;
-      p1->x1 = p1->y1;
-      p1->y1 = tmp;
-      tmp = -p1->x2;
-      p1->x2 = p1->y2;
-      p1->y2 = tmp;
-    }
-
-
-  rotated = rrot;  // restore properties (were changed by rotate/mirror)
-  mirroredX = mmir;
-}
