@@ -17,17 +17,132 @@
 
 #include "sparamfile.h"
 #include "main.h"
+#include "schematic.h"
 
 #include <qfileinfo.h>
 
 extern QDir QucsWorkDir;
 
 
-SParamFile::SParamFile(int No)
+SParamFile::SParamFile()
 {
   Description = QObject::tr("S parameter file");
 
-  int h = 30*((No-1)/2) + 15;
+  Model = "SPfile";
+  Name  = "X";
+
+  // must be the first property !!!
+  Props.append(new Property("File", "test.s1p", true,
+		QObject::tr("name of the s parameter file")));
+  Props.append(new Property("Data", "rectangular", false,
+		QObject::tr("data type")+" [rectangular, polar]"));
+  Props.append(new Property("Interpolator", "linear", false,
+		QObject::tr("interpolation type")+" [linear, cubic]"));
+  Props.append(new Property("duringDC", "open", false,
+		QObject::tr("representation during DC analysis")+
+			    " [open, short, shortall, unspecified]"));
+
+  // must be the last property !!!
+  Props.append(new Property("Ports", "1", false,
+		QObject::tr("number of ports")));
+
+  createSymbol();
+}
+
+// -------------------------------------------------------
+Component* SParamFile::newOne()
+{
+  SParamFile* p = new SParamFile();
+  p->Props.getLast()->Value = Props.getLast()->Value;
+  p->recreate(0);
+  return p;
+}
+
+// -------------------------------------------------------
+Element* SParamFile::info(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("n-port S parameter file");
+  BitmapFile = "spfile3";
+
+  if(getNewOne) {
+    SParamFile* p = new SParamFile();
+    p->Props.getFirst()->Value = "test.s3p";
+    p->Props.getLast()->Value = "3";
+    p->recreate(0);
+    return p;
+  }
+  return 0;
+}
+
+// -------------------------------------------------------
+Element* SParamFile::info1(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("1-port S parameter file");
+  BitmapFile = "spfile1";
+
+  if(getNewOne)  return new SParamFile();
+  return 0;
+}
+
+// -------------------------------------------------------
+Element* SParamFile::info2(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("2-port S parameter file");
+  BitmapFile = "spfile2";
+
+  if(getNewOne) {
+    SParamFile* p = new SParamFile();
+    p->Props.getFirst()->Value = "test.s2p";
+    p->Props.getLast()->Value = "2";
+    p->recreate(0);
+    return p;
+  }
+  return 0;
+}
+
+// -------------------------------------------------------
+QString SParamFile::NetList()
+{
+  QString s = Model+":"+Name;
+
+  // output all node names
+  for(Port *p1 = Ports.first(); p1 != 0; p1 = Ports.next())
+    s += " "+p1->Connection->Name;   // node names
+
+  // output all properties
+  Property *p2 = Props.first();
+  QFileInfo info(p2->Value);
+  if(info.isRelative())  info.setFile(QucsWorkDir, p2->Value);
+  s += " "+p2->Name+"=\"{"+info.absFilePath()+"}\"";
+
+  // data type
+  p2 = Props.next();
+  s += " "+p2->Name+"=\""+p2->Value+"\"";
+
+  // interpolator type
+  p2 = Props.next();
+  s += " "+p2->Name+"=\""+p2->Value+"\"";
+
+  // DC property
+  p2 = Props.next();
+  s += " "+p2->Name+"=\""+p2->Value+"\"";
+
+  return s;
+}
+
+// -------------------------------------------------------
+void SParamFile::createSymbol()
+{
+  int PortDistance = 60;
+  int Num = Props.getLast()->Value.toInt();
+  if(Num < 1) Num = 1;
+  else if(Num > 8) {
+    PortDistance = 20;
+    if(Num > 40) Num = 40;
+  }
+  Props.getLast()->Value = QString::number(Num);
+
+  int h = (PortDistance/2)*((Num-1)/2) + 15;
   Lines.append(new Line(-15, -h, 15, -h,QPen(QPen::darkBlue,2)));
   Lines.append(new Line( 15, -h, 15,  h,QPen(QPen::darkBlue,2)));
   Lines.append(new Line(-15,  h, 15,  h,QPen(QPen::darkBlue,2)));
@@ -36,18 +151,18 @@ SParamFile::SParamFile(int No)
 
 
   int i=0, y = 15-h;
-  while(i<No) {
+  while(i<Num) {
     i++;
-    Lines.append(new Line(-30,  y,-15,  y,QPen(QPen::darkBlue,2)));
-    Ports.append(new Port(-30,  y));
+    Lines.append(new Line(-30, y,-15, y,QPen(QPen::darkBlue,2)));
+    Ports.append(new Port(-30, y));
     Texts.append(new Text(-25,y-14,QString::number(i)));
 
-    if(i == No) break;
+    if(i == Num) break;
     i++;
-    Lines.append(new Line( 15,  y, 30,  y,QPen(QPen::darkBlue,2)));
-    Ports.append(new Port( 30,  y));
+    Lines.append(new Line( 15, y, 30, y,QPen(QPen::darkBlue,2)));
+    Ports.append(new Port( 30, y));
     Texts.append(new Text( 19,y-14,QString::number(i)));
-    y += 60;
+    y += PortDistance;
   }
 
   Lines.append(new Line( 0, h, 0,h+15,QPen(QPen::darkBlue,2)));
@@ -60,52 +175,4 @@ SParamFile::SParamFile(int No)
   QFontMetrics  metrics(QucsSettings.font);   // get size of text
   tx = x1+4;
   ty = y1 - 2*metrics.lineSpacing() - 4;
-  Model = "#SPfile";
-  Name  = "X";
-
-  Props.append(new Property("File", "test.s2p", true,
-		QObject::tr("name of the s parameter file")));
-  Props.append(new Property("Data", "rectangular", false,
-		QObject::tr("interpolation type")+" [rectangular, polar]"));
-}
-
-SParamFile::~SParamFile()
-{
-}
-
-Component* SParamFile::newOne()
-{
-  return new SParamFile(Ports.count()-1);
-}
-
-Element* SParamFile::info(QString& Name, char* &BitmapFile, bool getNewOne)
-{
-  Name = QObject::tr("1-port S parameter file");
-  BitmapFile = "spfile1";
-
-  if(getNewOne)  return new SParamFile(1);
-  return 0;
-}
-
-// -------------------------------------------------------
-QString SParamFile::NetList()
-{
-  if(!isActive) return QString("");  // should it be simulated ?
-
-  QString s = Model.mid(1)+":"+Name;
-
-  // output all node names
-  for(Port *p1 = Ports.first(); p1 != 0; p1 = Ports.next())
-    s += " "+p1->Connection->Name;   // node names
-
-  // output all properties
-  Property *p2 = Props.first();
-  QFileInfo info(p2->Value);
-  if(info.isRelative())  info.setFile(QucsWorkDir, p2->Value);
-  s += " "+p2->Name+"=\"{"+info.absFilePath()+"}\"";
-
-  p2 = Props.next();
-  s += " "+p2->Name+"=\""+p2->Value+"\"";
-
-  return s;
 }
