@@ -1,6 +1,6 @@
 /***************************************************************************
-                          sparamfile.h  -  description
-                             -------------------
+                                sparamfile.h
+                               --------------
     begin                : Sat Aug 23 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,13 +21,18 @@
 #include "component.h"
 
 
-class SParamFile : public Component  {
+class SParamFile : public MultiViewComponent  {
 public:
-  SParamFile(int No);
-  ~SParamFile();
+  SParamFile();
+ ~SParamFile() {};
   Component* newOne();
   QString NetList();
   static Element* info(QString&, char* &, bool getNewOne=false);
+  static Element* info1(QString&, char* &, bool getNewOne=false);
+  static Element* info2(QString&, char* &, bool getNewOne=false);
+
+protected:
+  void createSymbol();
 };
 
 #endif
