@@ -20,6 +20,7 @@
 #endif
 
 #include "spicefile.h"
+#include "schematic.h"
 #include "main.h"
 
 #include <qregexp.h>
@@ -37,36 +38,38 @@ SpiceFile::SpiceFile()
   Props.append(new Property("File", "", true, QString("x")));
   Props.append(new Property("Ports", "", false, QString("x")));
   Props.append(new Property("Sim", "yes", false, QString("x")));
-  recreate();
+  withSim = false;
 
   Model = "SPICE";
   Name  = "X";
-  withSim = false;
-}
 
-SpiceFile::~SpiceFile()
-{
+  // Do NOT call createSymbol() here. But create port to let it rotate.
+  Ports.append(new Port(0, 0));
 }
 
+// -------------------------------------------------------
 Component* SpiceFile::newOne()
 {
   return new SpiceFile();
 }
 
+// -------------------------------------------------------
 Element* SpiceFile::info(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("SPICE netlist");
   BitmapFile = "spicefile";
 
-  if(getNewOne)  return new SpiceFile();
+  if(getNewOne) {
+    SpiceFile *p = new SpiceFile();
+    p->recreate(0);   // createSymbol() is NOT called in constructor !!!
+    return p;
+  }
   return 0;
 }
 
-void SpiceFile::recreate()
+// -------------------------------------------------------
+void SpiceFile::createSymbol()
 {
-  Lines.clear();
-  Texts.clear();
-  Ports.clear();
   QFontMetrics  metrics(QucsSettings.font);   // get size of text
   int fHeight = metrics.lineSpacing();
 
@@ -74,32 +77,37 @@ void SpiceFile::recreate()
   QString tmp, PortNames = Props.at(1)->Value;
   if(!PortNames.isEmpty())  No = PortNames.contains(',') + 1;
 
+  #define HALFWIDTH  17
   int h = 30*((No-1)/2) + 15;
-  Lines.append(new Line(-16, -h, 16, -h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 16, -h, 16,  h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-16,  h, 16,  h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-16, -h,-16,  h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-HALFWIDTH, -h, HALFWIDTH, -h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line( HALFWIDTH, -h, HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-HALFWIDTH,  h, HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-HALFWIDTH, -h,-HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
 
-  int i = fHeight/2;
+  int w, i = fHeight/2;
   if(withSim) {
     i = fHeight - 2;
-    Texts.append(new Text(-10, 0, QObject::tr("sim"), Qt::red));
+    tmp = QObject::tr("sim");
+    w = metrics.width(tmp);
+    Texts.append(new Text(w/-2, 0, tmp, Qt::red));
   }
-  Texts.append(new Text(-15, -i, QObject::tr("spice")));
+  tmp = QObject::tr("spice");
+  w = metrics.width(tmp);
+  Texts.append(new Text(w/-2, -i, tmp));
 
 
   i = 0;
-  int w, y = 15-h;
+  int y = 15-h;
   while(i<No) {
-    Lines.append(new Line(-30,  y,-16,  y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line(-30,  y,-HALFWIDTH,  y,QPen(QPen::darkBlue,2)));
     Ports.append(new Port(-30,  y));
     tmp = PortNames.section(',', i, i).mid(4);
     w = metrics.width(tmp);
-    Texts.append(new Text(-19-w, y-fHeight-2, tmp));
+    Texts.append(new Text(-20-w, y-fHeight-2, tmp));
     i++;
 
     if(i == No) break;
-    Lines.append(new Line( 16,  y, 30,  y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line(HALFWIDTH,  y, 30,  y,QPen(QPen::darkBlue,2)));
     Ports.append(new Port( 30,  y));
     tmp = PortNames.section(',', i, i).mid(4);
     Texts.append(new Text( 20, y-fHeight-2, tmp));
@@ -110,7 +118,7 @@ void SpiceFile::recreate()
   if(No > 0) {
     Lines.append(new Line( 0, h, 0,h+15,QPen(QPen::darkBlue,2)));
     Texts.append(new Text( 4, h,"Ref"));
-    Ports.append(new Port( 0,h+15));    // 'Ref' port
+    Ports.append(new Port( 0, h+15));    // 'Ref' port
   }
 
   x1 = -30; y1 = -h-2;
@@ -119,34 +127,18 @@ void SpiceFile::recreate()
   tx = x1+4;
   ty = y1 - fHeight - 4;
   if(Props.first()->display) ty -= fHeight;
-
-  // rotate and mirror
-  bool mmir = mirroredX;
-  int  rrot = rotated;
-  if(mmir)  mirrorX();   // mirror
-  for(i=0; i<rrot; i++)  rotate(); // rotate
-
-
-  rotated = rrot;   // restore properties (were changed by rotate/mirror)
-  mirroredX = mmir;
 }
 
 // ---------------------------------------------------
 QString SpiceFile::NetList()
 {
-  if(!isActive) return QString("");   // should it be simulated ?
-
-  QString Type = Props.first()->Value;
-  if(Props.next()->Value.isEmpty())
+  if(Props.at(1)->Value.isEmpty())
     return QString("");  // no ports, no subcircuit instance
 
   QString s = "Sub:"+Name;   // SPICE netlist is subcircuit
   for(Port *pp = Ports.first(); pp != 0; pp = Ports.next())
     s += " "+pp->Connection->Name;   // output all node names
 
-  if(Type.at(0) <= '9') if(Type.at(0) >= '0') Type = '_' + Type;
-  Type.replace(QRegExp("\\W"), "_"); // none [a-zA-Z0-9] into "_"
-  s += " Type=\""+Type+"\"";   // type for SPICE subcircuit
-
+  s += " Type=\""+properName(Props.first()->Value)+"\"";
   return s;
 }
