@@ -21,6 +21,7 @@
 
 #include "subcircuit.h"
 #include "qucs.h"
+#include "schematic.h"
 #include "main.h"
 
 #include <qdir.h>
@@ -35,19 +36,17 @@ extern QDir QucsWorkDir;
 
 Subcircuit::Subcircuit()
 {
+  Type = isComponent;   // both analog and digital
   Description = QObject::tr("subcircuit");
 
-  Ports.append(new Port(0,  0));  // dummy port because of being device
+  Props.append(new Property("File", "", true,
+		QObject::tr("name of qucs schematic file")));
 
   Model = "Sub";
   Name  = "SUB";
 
-  Props.append(new Property("File", "", true,
-		QObject::tr("name of qucs schematic file")));
-}
-
-Subcircuit::~Subcircuit()
-{
+  // Do NOT call createSymbol() here. But create port to let it rotate.
+  Ports.append(new Port(0, 0));
 }
 
 // ---------------------------------------------------------------------
@@ -55,50 +54,53 @@ Component* Subcircuit::newOne()
 {
   Subcircuit *p = new Subcircuit();
   p->Props.getFirst()->Value = Props.getFirst()->Value;
-//  p->remakeSymbol(Ports.count());
-  p->recreate();
+  p->recreate(0);
   return p;
 }
 
+// -------------------------------------------------------
+Element* Subcircuit::info(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("Subcircuit");
+  BitmapFile = "subcircuit";
+
+  if(getNewOne) {
+    Subcircuit *p = new Subcircuit();
+    p->recreate(0);   // createSymbol() is NOT called in constructor !!!
+    return p;
+  }
+  return 0;
+}
+
 // ---------------------------------------------------------------------
 // Makes the schematic symbol subcircuit with the correct number
 // of ports.
-void Subcircuit::recreate()
+void Subcircuit::createSymbol()
 {
   int No;
-  QString FileName;
-
-  QFileInfo Info(Props.getFirst()->Value);
+  QString FileName(Props.getFirst()->Value);
+  QFileInfo Info(FileName);
   if(Info.isRelative())
-    FileName = QucsWorkDir.filePath(Props.getFirst()->Value);
-  else
-    FileName = Props.getFirst()->Value;
+    FileName = QucsWorkDir.filePath(FileName);
 
   tx = INT_MIN;
   ty = INT_MIN;
-  if(loadSymbol(FileName) > 0) {
+  if(loadSymbol(FileName) > 0) {  // try to load subcircuit symbol
     if(tx == INT_MIN)  tx = x1+4;
     if(ty == INT_MIN)  ty = y2+4;
-    performModification();
-    return;
   }
+  else {
+    No = QucsApp::testFile(FileName);
+    if(No < 0)  No = 0;
 
-  No = QucsApp::testFile(FileName);
-  if(No < 0)  No = 0;
-
-  remakeSymbol(No);
+    Ports.clear();
+    remakeSymbol(No);  // no symbol was found -> create standard symbol
+  }
 }
 
 // ---------------------------------------------------------------------
 void Subcircuit::remakeSymbol(int No)
 {
-  Arcs.clear();
-  Lines.clear();
-  Rects.clear();
-  Ellips.clear();
-  Texts.clear();
-  Ports.clear();
-
   int h = 30*((No-1)/2) + 15;
   Lines.append(new Line(-15, -h, 15, -h,QPen(QPen::darkBlue,2)));
   Lines.append(new Line( 15, -h, 15,  h,QPen(QPen::darkBlue,2)));
@@ -123,11 +125,8 @@ void Subcircuit::remakeSymbol(int No)
 
   x1 = -30; y1 = -h-2;
   x2 =  30; y2 =  h+2;
-
   tx = x1+4;
   ty = y2+4;
-
-  performModification();
 }
 
 // ---------------------------------------------------------------------
@@ -135,17 +134,9 @@ void Subcircuit::remakeSymbol(int No)
 // returns the number of painting elements.
 int Subcircuit::loadSymbol(const QString& DocName)
 {
-  Arcs.clear();
-  Lines.clear();
-  Rects.clear();
-  Ellips.clear();
-  Texts.clear();
-  Ports.clear();
-
   QFile file(DocName);
-  if(!file.open(IO_ReadOnly)) {
+  if(!file.open(IO_ReadOnly))
     return -1;
-  }
 
   QString Line;
   // *****************************************************************
@@ -195,35 +186,43 @@ int Subcircuit::loadSymbol(const QString& DocName)
     }
 
     Line = Line.stripWhiteSpace();
-    if(Line.at(0) != '<') return -1;
-    if(Line.at(Line.length()-1) != '>') return -1;
+    if(Line.at(0) != '<') return -5;
+    if(Line.at(Line.length()-1) != '>') return -6;
     Line = Line.mid(1, Line.length()-2); // cut off start and end character
     Result = analyseLine(Line);
-    if(Result < 0) return -6;   // line format error
+    if(Result < 0) return -7;   // line format error
     z += Result;
   }
 
-  return -5;   // field not closed
+  return -8;   // field not closed
 }
 
 // -------------------------------------------------------
 QString Subcircuit::NetList()
 {
-  if(!isActive) return QString("");       // should it be simulated ?
-
   QString s = Model+":"+Name;
 
   // output all node names
   for(Port *p1 = Ports.first(); p1 != 0; p1 = Ports.next())
     s += " "+p1->Connection->Name;   // node names
 
-  // output property
-  QString  Type = Props.getFirst()->Value;
-  QFileInfo Info(Type);
-  if(Info.extension() == "sch")  Type = Type.left(Type.length()-4);
-  if(Type.at(0) <= '9') if(Type.at(0) >= '0') Type = '_' + Type;
-  Type.replace(QRegExp("\\W"), "_"); // none [a-zA-Z0-9] into "_"
-  s += " Type=\""+Type+"\"";   // type for subcircuit
+  // type for subcircuit
+  s += " Type=\""+properName(Props.getFirst()->Value)+"\"";
+  return s;
+}
 
+// -------------------------------------------------------
+QString Subcircuit::VHDL_Code(int)
+{
+  QString s = "  " + Name + ": entity Sub_" +
+              properName(Props.getFirst()->Value) + " port map (";
+
+  // output all node names
+  Port *pp = Ports.first();
+  if(pp)  s += pp->Connection->Name;
+  for(pp = Ports.next(); pp != 0; pp = Ports.next())
+    s += ", "+pp->Connection->Name;   // node names
+
+  s += ");";
   return s;
 }
