@@ -21,15 +21,17 @@
 #include "component.h"
 
 
-class Subcircuit : public Component  {
+class Subcircuit : public MultiViewComponent  {
 public:
   Subcircuit();
-  ~Subcircuit();
+ ~Subcircuit() {};
   Component* newOne();
+  static Element* info(QString&, char* &, bool getNewOne=false);
   QString NetList();
-  void recreate();
+  QString VHDL_Code(int);
 
-private:
+protected:
+  void createSymbol();
   void remakeSymbol(int No);
   int  loadSymbol(const QString&);
 };
