@@ -1,6 +1,6 @@
 /***************************************************************************
-                          subcirport.h  -  description
-                             -------------------
+                               subcirport.h
+                              --------------
     begin                : Sat Aug 23 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,13 +21,17 @@
 #include "component.h"
 
 
-class SubCirPort : public Component  {
+class SubCirPort : public MultiViewComponent  {
 public:
   SubCirPort();
-  ~SubCirPort();
+ ~SubCirPort() {};
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
   QString NetList();
+  QString VHDL_Code(int);
+
+protected:
+  void createSymbol();
 };
 
 #endif
