@@ -1,6 +1,6 @@
 /***************************************************************************
-                          tr_sim.cpp  -  description
-                             -------------------
+                                tr_sim.cpp
+                               ------------
     begin                : Sat Aug 23 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -45,7 +45,7 @@ TR_Sim::TR_Sim()
 	QObject::tr("start time in seconds")));
   Props.append(new Property("Stop", "1 ms", true,
 	QObject::tr("stop time in seconds")));
-  Props.append(new Property("Points", "10", false,
+  Props.append(new Property("Points", "11", false,
 	QObject::tr("number of simulation time steps")));
   Props.append(new Property("IntegrationMethod", "Trapezoidal", false,
 	QObject::tr("integration method")+
@@ -75,6 +75,8 @@ TR_Sim::TR_Sim()
   Props.append(new Property("Solver", "CroutLU", false,
 	QObject::tr("method for solving the circuit matrix")+
 	" [CroutLU, DoolittleLU, HouseholderQR, HouseholderLQ]"));
+  Props.append(new Property("relaxTSR", "no", false,
+	QObject::tr("relax time step raster")+" [no, yes]"));
 }
 
 TR_Sim::~TR_Sim()
@@ -95,7 +97,7 @@ Element* TR_Sim::info(QString& Name, char* &BitmapFile, bool getNewOne)
   return 0;
 }
 
-void TR_Sim::recreate()
+void TR_Sim::recreate(Schematic*)
 {
   if((Props.getFirst()->Value == "list") ||
      (Props.getFirst()->Value == "const")) {
