@@ -1,6 +1,6 @@
 /***************************************************************************
                                 diagram.cpp
-                             -----------------
+                               -------------
     begin                : Thu Oct 2 2003
     copyright            : (C) 2003, 2004, 2005 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -43,6 +43,22 @@
 # define finite(x) _finite(x)
 #endif
 
+#if defined (__MINGW32__)
+// strtod() appears to be so sloooooooo under Win32...
+static double strtod_faster (char * pPos, char ** pEnd) {
+  *pEnd = pPos;
+  while((**pEnd) && (**pEnd > ' ') && (**pEnd != 'j') && (**pEnd != 'i'))
+    (*pEnd)++;
+  if ((**pEnd == 'j') || (**pEnd == 'i'))
+    (*pEnd)--;
+  QCString str = QCString (pPos, *pEnd - pPos + 1);
+  bool ok;
+  double x = str.toDouble(&ok);
+  if (!ok) *pEnd = pPos;
+  return x;
+}
+#define strtod(a,b) strtod_faster(a,b)
+#endif /* __MINGW32__ */
 
 using namespace std;
 
@@ -71,6 +87,7 @@ Diagram::Diagram(int _cx, int _cy)
   rotX = 315;  // for 3D diagram
   rotY = 0;
   rotZ = 225;
+  hideLines = true;  // hide invisible lines
 
   Type = isDiagram;
   isSelected = false;
@@ -258,12 +275,14 @@ void Diagram::createAxisLabels()
     if(w > wmax)  wmax = w;
     Texts.append(new Text(x, y+w, Str, Qt::black, 12.0, 0.0, -1.0));
   }
+  x -= x2;
   if(Bounding_x2 < x) Bounding_x2 = x;
 
   wmax -= y2 >> 1;
   if(wmax > 0) {
     Bounding_y2 = wmax;
-    if(wmax > Bounding_y1) Bounding_y1 = wmax;
+    wmax *= -1;
+    if(wmax < Bounding_y1) Bounding_y1 = wmax;
   }
 }
 
@@ -308,7 +327,7 @@ void Diagram::rectClip(int* &p)
 
   if(code1 != 0) if(*(p-5) >= 0) { // is there already a line end flag ?
     p++;
-    *(p-5) = -2;
+    *(p-5) = STROKEEND;
   }
   if(code1 & code2) {   // line not visible at all ?
     *(p-4) = x_2;
@@ -317,7 +336,7 @@ void Diagram::rectClip(int* &p)
     return;
   }
   if(code2 != 0) {
-    *p     = -2;
+    *p = STROKEEND;
     *(p+1) = x_2;
     *(p+2) = y_2;
     z += 3;
@@ -384,7 +403,7 @@ void Diagram::clip(int* &p)
 
   if(dt1 < 0) if(*(p-5) >= 0) { // is there already a line end flag ?
     p++;
-    *(p-5) = -2;
+    *(p-5) = STROKEEND;
   }
 
   int x = x_1-x_2;
@@ -422,7 +441,7 @@ void Diagram::clip(int* &p)
   if((dt2 > 0) && (dt2 < D)) { // intersection outside start/end point ?
     *(p-2) = x_1 - x*dt2 / D;
     *(p-1) = y_1 - y*dt2 / D;
-    *p = -2;
+    *p = STROKEEND;
     p += 3;
     code |= 2;
   }
@@ -438,44 +457,28 @@ void Diagram::clip(int* &p)
 }
 
 
-// ------------------------------------------------------------
-// Enlarge memory block if neccessary.
-#define  FIT_MEMORY_SIZE  \
-  if(p >= p_end) {     \
-    Size += 256;        \
-    tmp = p - g->Points; \
-    p = p_end = g->Points = (int*)realloc(g->Points, Size*sizeof(int)); \
-    p += tmp; \
-    p_end += Size - 9; \
-  } \
-
 // ------------------------------------------------------------
 // g->Points must already be empty!!!
 void Diagram::calcData(Graph *g)
 {
-  if(Name[0] == 'T')  return;   // no graph within tabulars
-
   double *px;
   double *pz = g->cPointsY;
   if(!pz)  return;
   if(g->cPointsX.count() < 1) return;
 
   int dx, dy, xtmp, ytmp, tmp, i, z, Counter=2;
-  int Size = ((2*(g->cPointsX.getFirst()->count) + 1) * g->countY) + 8;
-  int *p = (int*)malloc( Size*sizeof(int) );  // create memory for points
-  int *p_end;
-  g->Points = p_end = p;
-  p_end += Size - 5;   // limit of buffer
-
+  int Size = ((2*(g->cPointsX.getFirst()->count) + 1) * g->countY) + 10;
+  
   if(xAxis.autoScale)  if(yAxis.autoScale)  if(zAxis.autoScale)
     Counter = -50000;
 
-  double Dummy = 0.0;  // number for 1-dimensional data in 3D cartesian
+  double Dummy = 0.0;  // not used
   double *py = &Dummy;
-  if(Name == "Rect3D") {
-    if(g->countY > 1)  py = g->cPointsX.at(1)->Points;
-    Counter = 2;
-  }
+
+  int *p = (int*)malloc( Size*sizeof(int) );  // create memory for points
+  int *p_end;
+  g->Points = p_end = p;
+  p_end += Size - 9;   // limit of buffer
 
   Axis *pa;
   if(g->yAxisNo == 0)  pa = &yAxis;
@@ -495,107 +498,35 @@ void Diagram::calcData(Graph *g)
 	  if(Counter >= 2)   // clipping only if an axis is manual
 	    clip(p);
 	}
-	if(*(p-3) == -2)  p -= 3;  // no single point after "no stroke"
-	*(p++) = -10;
-	if(py != &Dummy) {   // more-dimensional Rect3D
-	  py++;
-	  if(py >= (g->cPointsX.at(1)->Points + g->cPointsX.at(1)->count))
-	    py = g->cPointsX.at(1)->Points;
+	switch(*(p-3)) {
+	  case STROKEEND:
+	       p -= 3;  // no single point after "no stroke"
+	       break;
+	  case BRANCHEND:
+	       if((*(p-2) < 0) || (*(p-1) < 0))
+	         p -= 2;  // erase last hidden point
+	       break;
 	}
+	*(p++) = BRANCHEND;
       }
-/*qDebug("\n****** p=%p", p);
-for(int zz=10; zz>0; zz-=2)
-  qDebug("c: %d/%d", *(p-zz), *(p-zz+1));*/
 
-#ifdef HIDDENLINE
-      if(Name == "Rect3D") {
-        if(g->countY > 1) {
-	  // px, py, pz are nor used !!!
-	  for(int j=g->countY/g->cPointsX.at(1)->count; j>0; j--) {
-	    DataX *pD = g->cPointsX.first();
-	    dx = pD->count;
-	    pD = g->cPointsX.next();
-	    dy = pD->count;
-	    for(i=g->cPointsX.getFirst()->count; i>0; i--) {  // every branch
-	      calcCoordinate(px, pz, py, p, p+1, 0);
-	      p += 2;
-	      for(z=dy-1; z>0; z--) {  // every point
-	        FIT_MEMORY_SIZE;  // need to enlarge memory block ?
-	        calcCoordinate(px, pz, py, p, p+1, 0);
-	        p += 2;
-	        clip(p);
-	      }
-	      if(*(p-3) == -2)  p -= 3;  // no single point after "no stroke"
-	      *(p++) = -10;
-	    }
-/*qDebug("\n------ p=%p", p);
-for(int zz=120; zz>0; zz-=2)
-  qDebug("c: %d/%d", *(p-zz), *(p-zz+1));*/
-	  }
-	}
-	delete ((Rect3DDiagram*)this)->Mem;
-	((Rect3DDiagram*)this)->Mem  = 0;
-	((Rect3DDiagram*)this)->pMem = 0;
-      }
-#else
-      if(Name == "Rect3D") if(g->countY > 1) {
-	// create cross lines
-	pz = g->cPointsY;
-	for(int j=g->countY/g->cPointsX.at(1)->count; j>0; j--) {
-	  DataX *pD = g->cPointsX.first();
-	  px = pD->Points;
-	  dx = pD->count;
-	  pD = g->cPointsX.next();
-	  dy = pD->count;
-	  for(i=g->cPointsX.getFirst()->count; i>0; i--) {  // every branch
-	    py = pD->Points;
-	    calcCoordinate(px, pz, py, p, p+1, 0);
-	    p += 2;
-	    px--;  // back to the current x coordinate
-	    py++;  // next y coordinate
-	    pz += 2*(dx-1);  // next z coordinate
-	    for(z=dy-1; z>0; z--) {  // every point
-	      FIT_MEMORY_SIZE;  // need to enlarge memory block ?
-	      calcCoordinate(px, pz, py, p, p+1, 0);
-	      p += 2;
-	      if(Counter >= 2)   // clipping only if an axis is manual
-	        rectClip(p);
-	      px--;  // back to the current x coordinate
-	      py++;  // next y coordinate
-	      pz += 2*(dx-1);  // next z coordinate
-	    }
-	    if(*(p-3) == -2)  p -= 3;  // no single point after "no stroke"
-	    *(p++) = -10;
 
-	    px++;   // next x coordinate
-	    pz -= 2*dx*dy - 2;  // next z coordinate
-	  }
-	  pz += 2*dx*(dy-1);
-	}
-/*qDebug("\n------ p=%p", p);
-for(int zz=120; zz>0; zz-=2)
-  qDebug("c: %d/%d", *(p-zz), *(p-zz+1));*/
-      }
-#endif
-
-      
-      *p = -100;
+      *p = GRAPHEND;
 /*z = p-g->Points+1;
 p = g->Points;
 qDebug("\n****** p=%p", p);
 for(int zz=0; zz<z; zz+=2)
   qDebug("c: %d/%d", *(p+zz), *(p+zz+1));*/
-
       return;
 
     case 1: Stroke = 10.0; Space =  6.0;  break;   // dash line
     case 2: Stroke =  2.0; Space =  4.0;  break;   // dot line
     case 3: Stroke = 24.0; Space =  8.0;  break;   // long dash line
 
-    default:
-      if(g->Style == 4)  xtmp = -7;      // **** a star at each point ******
-      else if(g->Style == 5)  xtmp = -6; // **** a circle at each point ****
-      else if(g->Style == 6)  xtmp = -5; // **** an arrow at each point ****
+    default:  // symbol at each point ************************************
+      if(g->Style == 4)  xtmp = GRAPHSTAR;
+      else if(g->Style == 5)  xtmp = GRAPHCIRCLE;
+      else if(g->Style == 6)  xtmp = GRAPHARROW;
 
       for(i=g->countY; i>0; i--) {  // every branch of curves
 	px = g->cPointsX.getFirst()->Points;
@@ -607,14 +538,9 @@ for(int zz=0; zz<z; zz+=2)
 	    p += 3;
 	  }
 	}
-	*(p++) = -10;
-	if(py != &Dummy) {   // more-dimensional Rect3D
-	  py++;
-	  if(py >= (g->cPointsX.at(1)->Points + g->cPointsX.at(1)->count))
-	    py = g->cPointsX.at(1)->Points;
-	}
+	*(p++) = BRANCHEND;
       }
-      *p = -100;
+      *p = GRAPHEND;
 /*qDebug("\n******");
 for(int zz=0; zz<60; zz+=2)
   qDebug("c: %d/%d", *(g->Points+zz), *(g->Points+zz+1));*/
@@ -665,7 +591,7 @@ for(int zz=0; zz<60; zz+=2)
         else {
 	  dist -= Space;
 	  if(*(p-3) < 0)  p -= 2;
-	  else *(p++) = -2;  // value for interrupt stroke
+	  else *(p++) = STROKEEND;
 	  if(Counter < 0)  Counter = -50000;   // if auto-scale
 	  else  Counter = 0;
         }
@@ -673,92 +599,25 @@ for(int zz=0; zz<60; zz+=2)
       }
 
     } // of x loop
-    if(*(p-3) == -2)
-      p -= 3;  // no single point after "no stroke"
-    *(p++) = -10;
-    if(py != &Dummy) {   // more-dimensional Rect3D
-      py++;
-      if(py >= (g->cPointsX.at(1)->Points + g->cPointsX.at(1)->count))
-        py = g->cPointsX.at(1)->Points;
+    switch(*(p-3)) {
+      case STROKEEND:
+           p -= 3;  // no single point after "no stroke"
+           break;
+      case BRANCHEND:
+           if((*(p-2) < 0) || (*(p-1) < 0))
+             p -= 2;  // erase last hidden point
+           break;
     }
+    *(p++) = BRANCHEND;
   } // of y loop
 
 
-
- if(Name == "Rect3D") if(g->countY > 1) {
-  pz = g->cPointsY;
-  for(int j=g->countY/g->cPointsX.at(1)->count; j>0; j--) {
-    DataX *pD = g->cPointsX.first();
-    px = pD->Points;
-    int xlen = pD->count;
-    pD = g->cPointsX.next();
-    for(i=g->cPointsX.getFirst()->count; i>0; i--) {  // every branch
-      Flag = 1;
-      dist = -Stroke;
-      py = pD->Points;
-      calcCoordinate(px, pz, py, &xtmp, &ytmp, 0);
-      *(p++) = xtmp;
-      *(p++) = ytmp;
-      Counter = 1;
-      px--;  // back to the current x coordinate
-      py++;  // next y coordinate
-      pz += 2*(xlen-1);  // next z coordinate
-      for(z=pD->count-1; z>0; z--) {  // every point
-        dx = xtmp;
-        dy = ytmp;
-        calcCoordinate(px, pz, py, &xtmp, &ytmp, 0);
-        px--;  // back to the current x coordinate
-        py++;  // next y coordinate
-        pz += 2*(xlen-1);  // next z coordinate
-
-        dx = xtmp - dx;
-        dy = ytmp - dy;
-        dist += sqrt(double(dx*dx + dy*dy)); // distance between points
-        if(Flag == 1) if(dist <= 0.0) {
-	  FIT_MEMORY_SIZE;  // need to enlarge memory block ?
-
-	  *(p++) = xtmp;    // if stroke then save points
-	  *(p++) = ytmp;
-	  if((++Counter) >= 2)  clip(p);
-	  continue;
-        }
-        alpha = atan2(double(dy), double(dx));   // slope for interpolation
-        while(dist > 0) {   // stroke or space finished ?
-	  FIT_MEMORY_SIZE;  // need to enlarge memory block ?
-
-	  *(p++) = xtmp - int(dist*cos(alpha) + 0.5); // linearly interpolate
-	  *(p++) = ytmp - int(dist*sin(alpha) + 0.5);
-	  if((++Counter) >= 2)  clip(p);
-
-          if(Flag == 0) {
-            dist -= Stroke;
-            if(dist <= 0) {
-	      *(p++) = xtmp;  // don't forget point after ...
-	      *(p++) = ytmp;  // ... interpolated point
-	      if((++Counter) >= 2)  clip(p);
-            }
-          }
-          else {
-	    dist -= Space;
-	    if(*(p-3) < 0)  p -= 2;
-	    else *(p++) = -2;  // value for interrupt stroke
-	    if(Counter < 0)  Counter = -50000;   // if auto-scale
-	    else  Counter = 0;
-          }
-          Flag ^= 1; // toggle between stroke and space
-        }
-      }
-      if(*(p-3) == -2)  p -= 3;  // no single point after "no stroke"
-      *(p++) = -10;
-
-      px++;   // next x coordinate
-      pz -= 2*xlen*pD->count - 2;  // next z coordinate
-    }
-    pz += 2*xlen*(pD->count-1);
-  }
- }
-
-  *p = -100;
+  *p = GRAPHEND;
+/*z = p-g->Points+1;
+p = g->Points;
+qDebug("\n****** p=%p", p);
+for(int zz=0; zz<z; zz+=2)
+  qDebug("c: %d/%d", *(p+zz), *(p+zz+1));*/
 }
 
 // -------------------------------------------------------
@@ -767,7 +626,7 @@ void Diagram::Bounding(int& _x1, int& _y1, int& _x2, int& _y2)
   _x1 = cx - Bounding_x1;
   _y1 = cy - y2 - Bounding_y2;
   _x2 = cx + x2 + Bounding_x2;
-  _y2 = cy + Bounding_y1;
+  _y2 = cy - Bounding_y1;
 }
 
 // -------------------------------------------------------
@@ -819,9 +678,6 @@ void Diagram::loadGraphData(const QString& defaultDataSet)
     if(yAxis.min > zAxis.min)  yAxis.min = zAxis.min;
     if(yAxis.max < zAxis.max)  yAxis.max = zAxis.max;
   }*/
-/*qDebug("x:  %g, %g", xAxis.min, xAxis.max);
-qDebug("y:  %g, %g", yAxis.min, yAxis.max);
-qDebug("z:  %g, %g", zAxis.min, zAxis.max);*/
   updateGraphData();
 }
 
@@ -912,17 +768,21 @@ void Diagram::updateGraphData()
 {
   int valid = calcDiagram();   // do not calculate graph data if invalid
 
-  for(Graph *pg = Graphs.first(); pg != 0; pg = Graphs.next()) {
+  Graph *pg;
+  for(pg = Graphs.first(); pg != 0; pg = Graphs.next()) {
     if(pg->Points != 0) { free(pg->Points);  pg->Points = 0; }
     if((valid & (pg->yAxisNo+1)) != 0)
       calcData(pg);   // calculate screen coordinates
     else if(pg->cPointsY) { delete[] pg->cPointsY;  pg->cPointsY = 0; }
-
-    for(Marker *pm = pg->Markers.first(); pm != 0; pm = pg->Markers.next())
-      pm->createText();
   }
 
   createAxisLabels();  // virtual function
+
+  // Setting markers must be done last, because in 3D diagram "Mem"
+  // is released in "createAxisLabels()".
+  for(pg = Graphs.first(); pg != 0; pg = Graphs.next())
+    for(Marker *pm = pg->Markers.first(); pm != 0; pm = pg->Markers.next())
+      pm->createText();
 }
 
 // --------------------------------------------------------------------------
@@ -932,7 +792,6 @@ bool Diagram::loadVarData(const QString& fileName, Graph *g)
   g->cPointsX.clear();
   if(g->cPointsY) { delete[] g->cPointsY;  g->cPointsY = 0; }
   if(g->Var.isEmpty()) return false;
-  if(fileName.isEmpty()) return false;
 
   QFile file;
   QString Variable;
@@ -942,11 +801,11 @@ bool Diagram::loadVarData(const QString& fileName, Graph *g)
     Variable = g->Var;
   }
   else {
-    file.setName(g->Var.left(pos)+".dat");
+    QFileInfo Info(fileName);
+    file.setName(Info.dirPath()+QDir::separator() + g->Var.left(pos)+".dat");
     Variable = g->Var.mid(pos+1);
   }
 
-  file.setName(QucsWorkDir.filePath(file.name()));
   if(!file.open(IO_ReadOnly))  return false;
 
   // *****************************************************************
@@ -956,6 +815,7 @@ bool Diagram::loadVarData(const QString& fileName, Graph *g)
   FileContent = file.readAll();
   file.close();
   char *FileString = FileContent.data();
+  if(!FileString)  return false;
   char *pPos = FileString+FileContent.size()-1;
   if(*pPos > ' ')  if(*pPos != '>')  return false;
   *pPos = 0;
@@ -1179,6 +1039,43 @@ int Diagram::loadIndepVarData(const QString& Variable,
   return n;   // return number of independent data
 }
 
+// ------------------------------------------------------------
+// Checks if the two graphs have the same independent variables.
+bool Diagram::sameDependencies(Graph *g1, Graph *g2)
+{
+  if(g1 == g2)  return true;
+
+  DataX *g1Data = g1->cPointsX.first();
+  DataX *g2Data = g2->cPointsX.first();
+  while(g1Data && g2Data) {
+    if(g1Data->Var != g2Data->Var)  return false;
+    g1Data = g1->cPointsX.next();
+    g2Data = g2->cPointsX.next();
+  }
+
+  if(g1Data)  return false;  // Is there more data ?
+  if(g2Data)  return false;  // Is there more data ?
+  return true;
+}
+
+// ------------------------------------------------------------
+int Diagram::checkColumnWidth(const QString& Str,
+		const QFontMetrics& metrics, int colWidth, int x, int y)
+{
+  int w = metrics.width(Str);  // width of text
+  if(w > colWidth) {
+    colWidth = w;
+    if((x+colWidth) >= x2) {    // enough space for text ?
+      // mark lack of space with a small arrow
+      Lines.append(new Line(x2-6, y-4, x2+7, y-4, QPen(QPen::red,2)));
+      Lines.append(new Line(x2,   y-7, x2+6, y-4, QPen(QPen::red,2)));
+      Lines.append(new Line(x2,   y-1, x2+6, y-4, QPen(QPen::red,2)));
+      return -1;
+    }
+  }
+  return colWidth;
+}
+
 // ------------------------------------------------------------
 void Diagram::setCenter(int x, int y, bool relative)
 {
@@ -1208,12 +1105,14 @@ QString Diagram::save()
 {
   QString s = "<"+Name+" "+QString::number(cx)+" "+QString::number(cy)+" ";
   s += QString::number(x2)+" "+QString::number(y2)+" ";
-  if(xAxis.GridOn) s+= "1 ";
-  else s += "0 ";
-  s += GridPen.color().name() + " " + QString::number(GridPen.style());
+  char c = '0';
+  if(xAxis.GridOn) c |= 1;
+  if(hideLines) c |= 2;
+  s += c;
+  s += " " + GridPen.color().name() + " " + QString::number(GridPen.style());
 
   if(xAxis.log) s+= " 1";  else s += " 0";
-  char c = '0';
+  c = '0';
   if(yAxis.log)  c |= 1;
   if(zAxis.log)  c |= 2;
   s += c;
@@ -1274,8 +1173,11 @@ bool Diagram::load(const QString& Line, QTextStream *stream)
   y2 = n.toInt(&ok);
   if(!ok) return false;
 
+  char c;
   n = s.section(' ',5,5);    // GridOn
-  xAxis.GridOn = yAxis.GridOn = n.at(0) != '0';
+  c = n.at(0).latin1() - '0';
+  xAxis.GridOn = yAxis.GridOn = (c & 1) != 0;
+  hideLines = (c & 2) != 0;
 
   n = s.section(' ',6,6);    // color for GridPen
   QColor co;
@@ -1287,7 +1189,6 @@ bool Diagram::load(const QString& Line, QTextStream *stream)
   GridPen.setStyle((Qt::PenStyle)n.toInt(&ok));
   if(!ok) return false;
 
-  char c;
   n = s.section(' ',8,8);    // xlog, ylog
   xAxis.log = n.at(0) != '0';
   c = n.at(1).latin1();
@@ -1576,13 +1477,21 @@ void Diagram::calcPolarAxisScale(Axis *Axis, double& numGrids,
     GridStep = Base * pow(10.0,Expo); // grid distance in real values
     numGrids -= floor(numGrids - Axis->max/GridStep); // correct num errors
     Axis->up = GridStep*numGrids;
+
+    zD = double(x2) / numGrids;   // grid distance in pixel
   }
   else {   // no auto-scale
     Axis->up = Axis->limit_max = fabs(Axis->limit_max);
     GridStep = Axis->step;
-    numGrids = Axis->limit_max / Axis->step;
+    zD = double(x2) / Axis->limit_max * Axis->step; // grid distance in pixel
+
+    if(fabs(zD) < 2.0) {  // if grid too small, then no grid
+      zD = double(x2);
+      GridStep = Axis->step = Axis->up;
+      numGrids = 1.0;
+    }
+    else numGrids = Axis->limit_max / Axis->step;
   }
-  zD = double(x2) / numGrids;   // grid distance in pixel
 }
 
 // ------------------------------------------------------------
@@ -1760,6 +1669,12 @@ else {   // user defined limits
 }
 
   zDstep = GridStep/(Axis->up-Axis->low)*Dist; // grid in pixel
+
+  if(fabs(zDstep) < 2.0) {  // if grid too small, then no grid
+    zDstep = Dist;
+    GridStep = Axis->step = Axis->up-Axis->low;
+  }
+
   return back;
 }
 
