@@ -16,8 +16,8 @@
  ***************************************************************************/
 
 #include "diagramdialog.h"
-#include "qucsview.h"
 #include "qucs.h"
+#include "schematic.h"
 #include "rect3ddiagram.h"
 
 #include <math.h>
@@ -38,6 +38,9 @@
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qslider.h>
+#include <qcombobox.h>
+#include <qlistview.h>
+#include <qlistbox.h>
 
 
 #define CROSS3D_SIZE   30
@@ -98,7 +101,7 @@ static const QRgb DefaultColors[]
 
 DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
                              QWidget *parent, Graph *currentGraph)
-                    : QDialog(parent, "", TRUE, Qt::WDestructiveClose)
+                    : QDialog(parent, 0, TRUE, Qt::WDestructiveClose)
 {
   Diag = d;
   Graphs.setAutoDelete(true);
@@ -150,7 +153,10 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
   Label4 = 0;     // different types with same content
   yrLabel = 0;
   yAxisBox = 0;
-  rotationY = rotationZ = 0;
+  Property2 = 0;
+  ColorButt = 0;
+  hideInvisible = 0;
+  rotationX = rotationY = rotationZ = 0;
 
   QVButtonGroup *InputGroup = new QVButtonGroup(tr("Graph Input"), Tab1);
   GraphInput = new QLineEdit(InputGroup);
@@ -166,6 +172,7 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
     PropertyBox->insertItem(tr("real/imaginary"));
     PropertyBox->insertItem(tr("magnitude/angle (degree)"));
     PropertyBox->insertItem(tr("magnitude/angle (radian)"));
+    PropertyBox->setCurrentItem(1);
     connect(PropertyBox, SIGNAL(activated(int)), SLOT(slotSetNumMode(int)));
     Box2->setStretchFactor(new QWidget(Box2), 5); // stretchable placeholder
 
@@ -176,7 +183,7 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
     Property2->setMaximumWidth(25);
     Property2->setText("3");
   }
-  else {
+  else if(Diag->Name != "Truth") {
     Label1 = new QLabel(tr("Color:"),Box2);
     ColorButt = new QPushButton("   ",Box2);
     ColorButt->setMinimumWidth(50);
@@ -190,10 +197,12 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
     PropertyBox->insertItem(tr("solid line"));
     PropertyBox->insertItem(tr("dash line"));
     PropertyBox->insertItem(tr("dot line"));
-    PropertyBox->insertItem(tr("long dash line"));
-    PropertyBox->insertItem(tr("stars"));
-    PropertyBox->insertItem(tr("circles"));
-    PropertyBox->insertItem(tr("arrows"));
+    if(Diag->Name != "Time") {
+      PropertyBox->insertItem(tr("long dash line"));
+      PropertyBox->insertItem(tr("stars"));
+      PropertyBox->insertItem(tr("circles"));
+      PropertyBox->insertItem(tr("arrows"));
+    }
     connect(PropertyBox, SIGNAL(activated(int)),
 			 SLOT(slotSetGraphStyle(int)));
     Box2->setStretchFactor(new QWidget(Box2), 5); // stretchable placeholder
@@ -220,13 +229,15 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
       Box3->setStretchFactor(new QWidget(Box3), 5); // stretchable placeholder
     }
   }
-  connect(Property2, SIGNAL(textChanged(const QString&)),
+  if(Property2) {
+    connect(Property2, SIGNAL(textChanged(const QString&)),
 			SLOT(slotSetProp2(const QString&)));
 
-  Label1->setEnabled(false);
-  PropertyBox->setEnabled(false);
-  Label2->setEnabled(false);
-  Property2->setEnabled(false);
+    Label1->setEnabled(false);
+    PropertyBox->setEnabled(false);
+    Label2->setEnabled(false);
+    Property2->setEnabled(false);
+  }
 
   QHBox *Box1 = new QHBox(Tab1);
   Box1->setSpacing(5);
@@ -237,7 +248,7 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
   connect(ChooseData, SIGNAL(activated(int)), SLOT(slotReadVars(int)));
   ChooseVars = new QListView(DataGroup);
   ChooseVars->addColumn(tr("Name"));
-  ChooseVars->addColumn(tr("Status"));
+  ChooseVars->addColumn(tr("Type"));
   ChooseVars->addColumn(tr("Size"));
   connect(ChooseVars, SIGNAL(doubleClicked(QListViewItem*)),
 		      SLOT(slotTakeVar(QListViewItem*)));
@@ -256,7 +267,7 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
 
   // ...........................................................
   int Row = 0;
-  if(Diag->Name != "Tab") {
+  if(Diag->Name.at(0) != 'T') {  // not tabular or timing diagram
     QWidget *Tab2 = new QWidget(t);
     QGridLayout *gp = new QGridLayout(Tab2,13,3,5,5);
 
@@ -323,7 +334,6 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
     }
 
     // ...........................................................
-    // transfer the diagram properties to the dialog
     xLabel->setText(Diag->xAxis.Label);
     ylLabel->setText(Diag->yAxis.Label);
     if(yrLabel)  yrLabel->setText(Diag->zAxis.Label);
@@ -349,6 +359,10 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
 
 
       if(Diag->Name == "Rect3D") {
+	hideInvisible = new QCheckBox(tr("hide invisible lines"), Tab2);
+	gp->addMultiCellWidget(hideInvisible, Row,Row,0,2);
+	Row++;
+
 	QLabel *LabelRotX = new QLabel(tr("Rotation around x-Axis:"), Tab2);
 	LabelRotX->setPaletteForegroundColor(Qt::red);
 	gp->addWidget(LabelRotX, Row,0);
@@ -404,6 +418,7 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
 	gp->addWidget(DiagCross, Row,1);
 
 	// transfer the diagram properties to the dialog
+	hideInvisible->setChecked(Diag->hideLines);
 	rotationX->setText(QString::number(((Rect3DDiagram*)Diag)->rotX));
 	rotationY->setText(QString::number(((Rect3DDiagram*)Diag)->rotY));
 	rotationZ->setText(QString::number(((Rect3DDiagram*)Diag)->rotZ));
@@ -545,29 +560,24 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
   connect(ApplyButt, SIGNAL(clicked()), SLOT(slotApply()));
   QPushButton *CancelButt = new QPushButton(tr("Cancel"), Butts);
   connect(CancelButt, SIGNAL(clicked()), SLOT(slotCancel()));
-//  QPushButton *HelpButt = new QPushButton(tr("Function Help"), Butts);
-//  connect(HelpButt, SIGNAL(clicked()), SLOT(slotFuncHelp()));
 
   OkButt->setDefault(true);
 
 
   // ...........................................................
   // put all data files into ComboBox
-  QDir ProjDir(QucsWorkDir);
+  QFileInfo Info(defaultDataSet);
+  QDir ProjDir(Info.dirPath());
   QStringList Elements = ProjDir.entryList("*.dat", QDir::Files, QDir::Name);
   QStringList::iterator it;
   for(it = Elements.begin(); it != Elements.end(); ++it) {
     ChooseData->insertItem((*it).left((*it).length()-4));
-    if((*it) == defaultDataSet)
+    if((*it) == Info.fileName())
       // default dataset should be the current
       ChooseData->setCurrentItem(ChooseData->count()-1);
   }
   slotReadVars(0);  // put variables into the ListView
 
-  if(Diag->Name != "Tab")
-    ColorButt->setPaletteBackgroundColor
-	(QColor(DefaultColors[GraphList->count()]));
-
   // ...........................................................
   // put all graphs into the ListBox
   Row = 0;
@@ -579,6 +589,11 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
     }
     Row++;
   }
+
+  if(ColorButt)
+    if(!currentGraph)
+      ColorButt->setPaletteBackgroundColor
+	(QColor(DefaultColors[GraphList->count()]));
 }
 
 DiagramDialog::~DiagramDialog()
@@ -592,14 +607,15 @@ DiagramDialog::~DiagramDialog()
 // --------------------------------------------------------------------------
 void DiagramDialog::slotReadVars(int)
 {
+  QFileInfo Info(defaultDataSet);
   QString DocName = ChooseData->currentText()+".dat";
 
-  QFile file(QucsWorkDir.filePath(DocName));
+  QFile file(Info.dirPath() + QDir::separator() + DocName);
   if(!file.open(IO_ReadOnly)) {
     return;
   }
 
-  QString Line, tmp;
+  QString Line, tmp, Var;
   QTextStream ReadWhole(&file);
   QString FileString = ReadWhole.read();   // read whole data file
   file.close();
@@ -612,15 +628,17 @@ void DiagramDialog::slotReadVars(int)
     j = FileString.find('>', i);
     Line = FileString.mid(i, j-i);
     i = FileString.find('<', j)+1;
+
+    Var = Line.section(' ', 1, 1).remove('>');
+    if(Var.at(0) == '_')  continue;
+
     if(Line.left(3) == "dep") {
       tmp = Line.section(' ', 2);
-      new QListViewItem(ChooseVars, Line.section(' ', 1, 1).remove('>'),
-			"dep", tmp.remove('>'));
+      new QListViewItem(ChooseVars, Var, "dep", tmp.remove('>'));
     }
     else if(Line.left(5) == "indep") {
       tmp = Line.section(' ', 2, 2);
-      new QListViewItem(ChooseVars, Line.section(' ', 1, 1).remove('>'),
-			"indep", tmp.remove('>'));
+      new QListViewItem(ChooseVars, Var, "indep", tmp.remove('>'));
     }
   } while(i > 0);
 }
@@ -637,7 +655,8 @@ void DiagramDialog::slotTakeVar(QListViewItem *Item)
   int     i  = GraphInput->cursorPosition();
   QString s  = GraphInput->text();
   QString s1 = Item->text(0);
-  if(ChooseData->currentText() != defaultDataSet.section('.',0,0))
+  QFileInfo Info(defaultDataSet);
+  if(ChooseData->currentText() != Info.baseName())
     s1 = ChooseData->currentText() + ":" + s1;
   GraphInput->setText(s.left(i) + s1 + s.right(s.length()-i));
 
@@ -648,20 +667,22 @@ void DiagramDialog::slotTakeVar(QListViewItem *Item)
     Graph *g = new Graph(GraphInput->text());   // create a new graph
 
     if(Diag->Name != "Tab") {
-      g->Color = ColorButt->paletteBackgroundColor();
-      g->Thick = Property2->text().toInt();
-      ColorButt->setPaletteBackgroundColor(
+      if(Diag->Name != "Truth") {
+        g->Color = ColorButt->paletteBackgroundColor();
+        g->Thick = Property2->text().toInt();
+        ColorButt->setPaletteBackgroundColor(
 		QColor(DefaultColors[GraphList->count()]));
-      g->Style   = PropertyBox->currentItem();
-      if(yAxisBox) {
-        g->yAxisNo = yAxisBox->currentItem();
-        yAxisBox->setEnabled(true);
-        Label4->setEnabled(true);
-      }
-      else if(Diag->Name == "Rect3D") g->yAxisNo = 1;
+        g->Style   = PropertyBox->currentItem();
+        if(yAxisBox) {
+          g->yAxisNo = yAxisBox->currentItem();
+          yAxisBox->setEnabled(true);
+          Label4->setEnabled(true);
+        }
+        else if(Diag->Name == "Rect3D") g->yAxisNo = 1;
 
-      Label3->setEnabled(true);
-      ColorButt->setEnabled(true);
+        Label3->setEnabled(true);
+        ColorButt->setEnabled(true);
+      }
     }
     else {
       g->Precision = Property2->text().toInt();
@@ -675,10 +696,12 @@ void DiagramDialog::slotTakeVar(QListViewItem *Item)
 
   GraphInput->blockSignals(false);
 
-  Label1->setEnabled(true);
-  PropertyBox->setEnabled(true);
-  Label2->setEnabled(true);
-  Property2->setEnabled(true);
+  if(Property2) {
+    Label1->setEnabled(true);
+    PropertyBox->setEnabled(true);
+    Label2->setEnabled(true);
+    Property2->setEnabled(true);
+  }
 }
 
 // --------------------------------------------------------------------------
@@ -702,17 +725,19 @@ void DiagramDialog::SelectGraph(Graph *g)
   GraphInput->blockSignals(false);
 
   if(Diag->Name != "Tab") {
-    Property2->setText(QString::number(g->Thick));
-    ColorButt->setPaletteBackgroundColor(g->Color);
-    PropertyBox->setCurrentItem(g->Style);
-    if(yAxisBox) {
-      yAxisBox->setCurrentItem(g->yAxisNo);
-      yAxisBox->setEnabled(true);
-      Label4->setEnabled(true);
-    }
+    if(Diag->Name != "Truth") {
+      Property2->setText(QString::number(g->Thick));
+      ColorButt->setPaletteBackgroundColor(g->Color);
+      PropertyBox->setCurrentItem(g->Style);
+      if(yAxisBox) {
+        yAxisBox->setCurrentItem(g->yAxisNo);
+        yAxisBox->setEnabled(true);
+        Label4->setEnabled(true);
+      }
 
-    Label3->setEnabled(true);
-    ColorButt->setEnabled(true);
+      Label3->setEnabled(true);
+      ColorButt->setEnabled(true);
+    }
   }
   else {
     Property2->setText(QString::number(g->Precision));
@@ -720,10 +745,12 @@ void DiagramDialog::SelectGraph(Graph *g)
   }
   toTake = false;
 
-  Label1->setEnabled(true);
-  PropertyBox->setEnabled(true);
-  Label2->setEnabled(true);
-  Property2->setEnabled(true);
+  if(Property2) {
+    Label1->setEnabled(true);
+    PropertyBox->setEnabled(true);
+    Label2->setEnabled(true);
+    Property2->setEnabled(true);
+  }
 }
 
 // --------------------------------------------------------------------------
@@ -738,27 +765,32 @@ void DiagramDialog::slotDeleteGraph()
 
   GraphInput->setText("");  // erase input line and back to default values
   if(Diag->Name != "Tab") {
-    ColorButt->setPaletteBackgroundColor(
+    if(Diag->Name != "Truth") {
+      ColorButt->setPaletteBackgroundColor(
 		QColor(DefaultColors[GraphList->count()]));
-    Property2->setText("0");
-    if(yAxisBox) {
-      yAxisBox->setCurrentItem(0);
-      yAxisBox->setEnabled(false);
-      Label4->setEnabled(false);
-    }
+      Property2->setText("0");
+      if(yAxisBox) {
+        yAxisBox->setCurrentItem(0);
+        yAxisBox->setEnabled(false);
+        Label4->setEnabled(false);
+      }
 
-    Label3->setEnabled(false);
-    ColorButt->setEnabled(false);
+      Label3->setEnabled(false);
+      ColorButt->setEnabled(false);
+    }
   }
   else  Property2->setText("3");
-  PropertyBox->setCurrentItem(0);
   changed = true;
   toTake  = false;
 
-  Label1->setEnabled(false);
-  PropertyBox->setEnabled(false);
-  Label2->setEnabled(false);
-  Property2->setEnabled(false);
+  if(Property2) {
+    PropertyBox->setCurrentItem(0);
+
+    Label1->setEnabled(false);
+    PropertyBox->setEnabled(false);
+    Label2->setEnabled(false);
+    Property2->setEnabled(false);
+  }
 }
 
 // --------------------------------------------------------------------------
@@ -770,11 +802,13 @@ void DiagramDialog::slotNewGraph()
 
   Graph *g = new Graph(GraphInput->text());   // create a new graph
   if(Diag->Name != "Tab") {
-    g->Color = ColorButt->paletteBackgroundColor();
-    g->Thick = Property2->text().toInt();
-    g->Style = PropertyBox->currentItem();
-    if(yAxisBox)  g->yAxisNo = yAxisBox->currentItem();
-    else if(Diag->Name == "Rect3D")  g->yAxisNo = 1;
+    if(Diag->Name != "Truth") {
+      g->Color = ColorButt->paletteBackgroundColor();
+      g->Thick = Property2->text().toInt();
+      g->Style = PropertyBox->currentItem();
+      if(yAxisBox)  g->yAxisNo = yAxisBox->currentItem();
+      else if(Diag->Name == "Rect3D")  g->yAxisNo = 1;
+    }
   }
   else {
     g->Precision = Property2->text().toInt();
@@ -797,7 +831,7 @@ void DiagramDialog::slotOK()
 // Is called if "Apply" button is pressed.
 void DiagramDialog::slotApply()
 {
-  if(Diag->Name != "Tab") {
+  if(Diag->Name.at(0) != 'T') {  // not tabular or timing
     if(Diag->xAxis.Label.isEmpty())
       Diag->xAxis.Label = ""; // can be not 0 and empty!
     if(xLabel->text().isEmpty()) xLabel->setText("");
@@ -911,26 +945,31 @@ void DiagramDialog::slotApply()
       changed = true;
     }
 
-    if(Diag->Name == "Rect3D") {
-      if(rotationX) {
-        if(((Rect3DDiagram*)Diag)->rotX != rotationX->text().toInt()) {
-          ((Rect3DDiagram*)Diag)->rotX = rotationX->text().toInt();
-          changed = true;
-        }
+    // for "rect3D"
+    if(hideInvisible)
+      if(((Rect3DDiagram*)Diag)->hideLines != hideInvisible->isChecked()) {
+        ((Rect3DDiagram*)Diag)->hideLines = hideInvisible->isChecked();
+        changed = true;
       }
-      if(rotationY) {
-        if(((Rect3DDiagram*)Diag)->rotY != rotationY->text().toInt()) {
-          ((Rect3DDiagram*)Diag)->rotY = rotationY->text().toInt();
-          changed = true;
-        }
+
+    if(rotationX)
+      if(((Rect3DDiagram*)Diag)->rotX != rotationX->text().toInt()) {
+        ((Rect3DDiagram*)Diag)->rotX = rotationX->text().toInt();
+        changed = true;
       }
-      if(rotationZ) {
-        if(((Rect3DDiagram*)Diag)->rotZ != rotationZ->text().toInt()) {
-          ((Rect3DDiagram*)Diag)->rotZ = rotationZ->text().toInt();
-          changed = true;
-        }
+
+    if(rotationY)
+      if(((Rect3DDiagram*)Diag)->rotY != rotationY->text().toInt()) {
+        ((Rect3DDiagram*)Diag)->rotY = rotationY->text().toInt();
+        changed = true;
       }
-    }
+
+    if(rotationZ)
+      if(((Rect3DDiagram*)Diag)->rotZ != rotationZ->text().toInt()) {
+        ((Rect3DDiagram*)Diag)->rotZ = rotationZ->text().toInt();
+        changed = true;
+      }
+
   }   // of "if(Diag->Name != "Tab")"
 
   Diag->Graphs.clear();   // delete the graphs
@@ -941,7 +980,7 @@ void DiagramDialog::slotApply()
   Graphs.setAutoDelete(true);
 
   Diag->loadGraphData(defaultDataSet);
-  ((QucsView*)parent())->viewport()->repaint();
+  ((Schematic*)parent())->viewport()->repaint();
   copyDiagramGraphs();
   if(changed) transfer = true;   // changes have been applied ?
 }
