@@ -19,6 +19,11 @@
 #define DIAGRAMDIALOG_H
 
 #include "diagram.h"
+#include "node.h"
+
+#ifndef M_PI
+#define M_PI 3.1415926535897932384626433832795029
+#endif
 
 #include <qdialog.h>
 #include <qregexp.h>
@@ -100,7 +105,7 @@ private:
   QVBoxLayout *all;   // the mother of all widgets
   QLineEdit   *GraphInput, *Property2, *xLabel, *ylLabel, *yrLabel;
   QCheckBox   *GridOn, *GridLogX, *GridLogY, *GridLogZ;
-  QCheckBox   *manualX, *manualY, *manualZ;
+  QCheckBox   *manualX, *manualY, *manualZ, *hideInvisible;
   QLineEdit   *startX, *stepX, *stopX;
   QLineEdit   *startY, *stepY, *stopY;
   QLineEdit   *startZ, *stepZ, *stopZ;
