@@ -75,9 +75,9 @@ void Graph::paintLines(ViewPainter *p, int x0, int y0)
   int *pp = Points;
 
   if(*pp < 0)  pp++;
-//  for(int n1=countY; n1>0; n1--) {    // every branch of curves
   while(*pp > -99) {
-    if(*pp >= 0)  p->drawPoint(x0+(*pp), y0-(*(pp+1)));
+    if(*pp >= 0) if(*(pp+2) != GRAPHCIRCLE)
+      p->drawPoint(x0+(*pp), y0-(*(pp+1)));
     while(*pp > -9) {   // until end of branch
       pp += 2;
       while(*pp > -2) {    // until end of stroke
@@ -88,14 +88,14 @@ void Graph::paintLines(ViewPainter *p, int x0, int y0)
       else {
 	x = x0 + *(pp-2);
 	y = y0 - *(pp-1);
-	if(*pp == -7) {    // paint star
+	if(*pp == GRAPHSTAR) {    // paint star
 	  p->drawLine(x-5, y, x+5, y);     // horizontal line
 	  p->drawLine(x-4, y+4, x+4, y-4); // upper left to lower right
 	  p->drawLine(x+4, y+4, x-4, y-4); // upper right to lower left
 	}
-	else if(*pp == -6)    // paint circle
+	else if(*pp == GRAPHCIRCLE)    // paint circle
 	  p->drawEllipse(x-4, y-4, 8, 8);
-	else if(*pp == -5) {  // paint arrow
+	else if(*pp == GRAPHARROW) {  // paint arrow
 	  p->drawLine(x, y, x, y0);
 	  p->drawLine(x-4, y+7, x, y);
 	  p->drawLine(x+4, y+7, x, y);
@@ -103,6 +103,7 @@ void Graph::paintLines(ViewPainter *p, int x0, int y0)
       }
       pp++;
     }
+//    if(*pp < -99) break; // end of all lines ?
     pp++;
   }
 }
@@ -170,7 +171,7 @@ int Graph::getSelected(int x, int y)
   int *pp = Points;
   if(pp == 0) return -1;
 
-  int A, z=0, zi;
+  int A, z=0;
   int dx, dx2, x1;
   int dy, dy2, y1;
 
@@ -184,12 +185,10 @@ int Graph::getSelected(int x, int y)
       if(*pp < -10)  return -1;   // not even one point ?
     }
   }
-//  for(int z=0; z<countY; z++) {  // check every branch of curves
+
   while(*pp > -99) {
-    zi = 0;
-    do {
+    while(*pp > -5) {
       x1 = *(pp++);  y1 = *(pp++);
-      zi++;
       dx  = x - x1;
       dy  = y - y1;
 
@@ -203,11 +202,10 @@ int Graph::getSelected(int x, int y)
 	  if(dx >  5) continue;
 	  if(dy < -5) continue;
 	  if(dy >  5) continue;
-	  return z*countX;// + zi;   // points on graph
+	  return z*countX;   // points on graph
 	}
 	dx2 = *pp;
 	if(dx2 < -9) break;
-	zi -= 2;  // because of space (edge-values)
       }
       if(dx < -5) { if(x < dx2-5) continue; } // point between x coordinates ?
       else { if(x > 5) if(x > dx2+5) continue; }
@@ -223,8 +221,8 @@ int Graph::getSelected(int x, int y)
       A *= A;                  // avoid the need for square root
       A -= 25*(dx2*dx2 + dy2*dy2);  // substract selectable area
 
-      if(A <= 0)  return z*countX;// + zi;  // lies x/y onto the graph line ?
-    } while(true);
+      if(A <= 0)  return z*countX;  // lies x/y onto the graph line ?
+    }
     pp++;
     z++;
   }
