@@ -32,7 +32,8 @@ PSDiagram::PSDiagram(int _cx, int _cy, bool _polarUp)
   if(_polarUp)  Name = "PS";  // polar diagram upper half ?
   else  Name = "SP";
 
-  calcDiagram();
+  Arcs.append(new struct Arc(0, y2, x2, y2, 0, 16*360, QPen(QPen::black,0)));
+//  calcDiagram();
 }
 
 PSDiagram::~PSDiagram()
@@ -40,13 +41,13 @@ PSDiagram::~PSDiagram()
 }
 
 // ------------------------------------------------------------
-void PSDiagram::calcCoordinate(double* &, double* &yD,
+void PSDiagram::calcCoordinate(double* &, double* &yD, double* &,
 			       int *px, int *py, Axis *pa)
 {
   double yr = *(yD++);
   double yi = *(yD++);
-  *px = (x2>>1)+int(yr/pa->up*double(x2>>1) + 0.5);
-  *py = (y2>>1)+int(yi/pa->up*double(y2>>1) + 0.5);
+  *px = (x2>>1)+int(yr/pa->up*double(x2)/2.0 + 0.5);
+  *py = (y2>>1)+int(yi/pa->up*double(y2)/2.0 + 0.5);
 }
 
 // --------------------------------------------------------------
@@ -94,8 +95,8 @@ int PSDiagram::calcDiagram()
   }
 
   // x line
-  Lines.append(new Line(0, y2>>1, x2, y2>>1, QPen(QPen::black,0)));
-  return 1;
+  Lines.append(new Line(0, y2>>1, x2, y2>>1, GridPen));
+  return 3;
 }
 
 // ------------------------------------------------------------
@@ -103,3 +104,23 @@ Diagram* PSDiagram::newOne()
 {
   return new PSDiagram();
 }
+
+// ------------------------------------------------------------
+Element* PSDiagram::info(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("Polar-Smith Combi");
+  BitmapFile = "polarsmith";
+
+  if(getNewOne)  return new PSDiagram();
+  return 0;
+}
+
+// ------------------------------------------------------------
+Element* PSDiagram::info_sp(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("Smith-Polar Combi");
+  BitmapFile = "smithpolar";
+
+  if(getNewOne)  return new PSDiagram(0, 0, false);
+  return 0;
+}
