@@ -24,19 +24,18 @@
 class TabDiagram : public Diagram  {
 public: 
   TabDiagram(int _cx=0, int _cy=0);
-  ~TabDiagram();
+ ~TabDiagram();
 
-  Diagram* newOne();
+  virtual Diagram* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
   void paint(ViewPainter*);
-  int  calcDiagram();
+  virtual int  calcDiagram();
   bool scroll(int);
 
   void createAxisLabels() {};   // no labels in this diagram
 
-private:
-  int  checkColumnWidth(const QString&, const QFontMetrics&, int, int, int);
-  bool sameDependencies(Graph*, Graph*);
+protected:
+  void calcData(Graph*) {};  // no graph data
 };
 
 #endif
