@@ -1,6 +1,6 @@
 /***************************************************************************
-                          simmessage.cpp  -  description
-                             -------------------
+                              simmessage.cpp
+                             ----------------
     begin                : Sat Sep 6 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -15,10 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "simmessage.h"
-#include "main.h"
-#include "qucs.h"
-#include "qucsdoc.h"
+#include <stdlib.h>
 
 #include <qlabel.h>
 #include <qlayout.h>
@@ -32,12 +29,30 @@
 #include <qdatetime.h>
 #include <qregexp.h>
 
+#include "simmessage.h"
+#include "main.h"
+#include "qucs.h"
+#include "textdoc.h"
+#include "schematic.h"
 
-SimMessage::SimMessage(QucsDoc *Doc_, QWidget *parent)
+
+SimMessage::SimMessage(QWidget *w, QWidget *parent)
 		: QDialog(parent, 0, FALSE, Qt::WDestructiveClose)
 {
-  Doc = Doc_;
   setCaption(tr("Qucs Simulation Messages"));
+  QucsDoc *Doc;
+  DocWidget = w;
+  if(DocWidget->inherits("QTextEdit"))
+    Doc = (QucsDoc*) ((TextDoc*)DocWidget);
+  else
+    Doc = (QucsDoc*) ((Schematic*)DocWidget);
+
+  DocName = Doc->DocName;
+  DataDisplay = Doc->DataDisplay;
+  QFileInfo Info(DocName);
+  DataSet = Info.dirPath() + QDir::separator() + Doc->DataSet;
+  showBias = Doc->showBias;     // save some settings as the document...
+  SimOpenDpl = Doc->SimOpenDpl; // ...could be closed during the simulation.
 
   all = new QVBoxLayout(this);
   all->setSpacing(5);
@@ -58,6 +73,7 @@ SimMessage::SimMessage(QucsDoc *Doc_, QWidget *parent)
   all->addWidget(HGroup);
   new QLabel(tr("Progress:"), HGroup);
   SimProgress = new QProgressBar(HGroup);
+//  SimProgress->setPercentageVisible(false);
 
   QVGroupBox *Group2 = new QVGroupBox(tr("Errors and Warnings:"),this);
   all->addWidget(Group2);
@@ -103,20 +119,25 @@ bool SimMessage::startProcess()
     return false;
   }
 
-  ProgText->insert(tr("creating netlist ...."));
-  NetlistFile.setName(QucsHomeDir.filePath("netlist.txt"));
-  if(!NetlistFile.open(IO_WriteOnly)) {
-    ErrText->insert(tr("ERROR: Cannot write netlist file!"));
-    FinishSimulation(-1);
-    return false;
-  }
-
   Collect.clear();  // clear list for NodeSets, SPICE components etc.
-  Stream.setDevice(&NetlistFile);
-  if(!Doc->File.prepareNetlist(Stream, Collect, ErrText)) {
-    NetlistFile.close();
-    FinishSimulation(-1);
-    return false;
+  if(!DocWidget->inherits("QTextEdit")) {
+    ProgText->insert(tr("creating netlist... "));
+    NetlistFile.setName(QucsHomeDir.filePath("netlist.txt"));
+    if(!NetlistFile.open(IO_WriteOnly)) {
+      ErrText->insert(tr("ERROR: Cannot write netlist file!"));
+      FinishSimulation(-1);
+      return false;
+    }
+
+    Stream.setDevice(&NetlistFile);
+
+    SimPorts =
+       ((Schematic*)DocWidget)->prepareNetlist(Stream, Collect, ErrText);
+    if(SimPorts < -5) {
+      NetlistFile.close();
+      FinishSimulation(-1);
+      return false;
+    }
   }
   Collect.append("*");   // mark the end
 
@@ -127,8 +148,11 @@ bool SimMessage::startProcess()
                        SLOT(slotReadSpiceNetlist()));
   connect(&SimProcess, SIGNAL(processExited()),
                        SLOT(slotFinishSpiceNetlist()));
+
   nextSPICE();
   return true;
+  // Since now, the Doc pointer may be obsolete, as the user could have
+  // closed the schematic !!!
 }
   
 // ---------------------------------------------------
@@ -140,7 +164,7 @@ void SimMessage::nextSPICE()
     Line = *(Collect.begin());
     Collect.remove(Collect.begin());
     if(Line == "*") {  // worked on all components ?
-      startSimulator();
+      startSimulator(); // <<<<<================== go on ===
       return;
     }
     if(Line.left(5) == "SPICE") {
@@ -161,15 +185,16 @@ void SimMessage::nextSPICE()
   com << (QucsSettings.BinDir + "qucsconv");
   if(makeSubcircuit)
     com << "-g" << "_ref";
-  com << "-if" << "spice" << "-of" << "qucs" << "-i" << FileName;
+  com << "-if" << "spice" << "-of" << "qucs" << "-i";
+  if(FileName.find(QDir::separator()) < 0)  // add path ?
+    com << QucsWorkDir.path() + QDir::separator() + FileName;
+  else
+    com << FileName;
   SimProcess.setArguments(com);
 
 
   if(makeSubcircuit) {
-    if(FileName.at(0) <= '9') if(FileName.at(0) >= '0')
-      FileName = '_' + FileName;
-    FileName.replace(QRegExp("\\W"), "_"); // none [a-zA-Z0-9] into "_"
-    Stream << "\n.Def:" << FileName << " ";
+    Stream << "\n.Def:" << properName(FileName) << " ";
   
     Line.replace(',', ' ');
     Stream << Line;
@@ -224,23 +249,61 @@ void SimMessage::slotFinishSpiceNetlist()
 // ------------------------------------------------------------------------
 void SimMessage::startSimulator()
 {
-  // output NodeSets, SPICE simulations etc.
-  Stream << Collect.join("\n") << '\n';
-  Doc->File.createNetlist(Stream);
-  NetlistFile.close();
-  ProgText->insert(tr("done.\n"));
+  // Using the Doc pointer here is risky as the user may have closed
+  // the schematic, but converting the SPICE netlists is (hopefully)
+  // faster than the user (I have no other idea).
 
-  QStringList com;
-  com << QucsSettings.BinDir + "qucsator" << "-b" << "-i"
-      << QucsHomeDir.filePath("netlist.txt")
-      << "-o" << QucsWorkDir.filePath(Doc->DataSet);
-  SimProcess.setArguments(com);
+  QString SimTime;
+  QStringList CommandLine;
+  QString SimPath = QDir::convertSeparators (QucsHomeDir.absPath());
+#ifdef __MINGW32__
+  QString QucsDigi = "qucsdigi.bat";
+#else
+  QString QucsDigi = "qucsdigi";
+#endif
 
+  if(DocWidget->inherits("QTextEdit")) {
+    if(copyFile(DocName, QucsHomeDir.filePath("netlist.txt")) < 0) {
+      ErrText->insert(tr("ERROR: Cannot copy \"%1\" !").arg(DocName));
+      FinishSimulation(-1);
+      return;
+    }
+
+    CommandLine << QucsSettings.BinDir + QucsDigi << "netlist.txt" << DataSet
+       << ((TextDoc*)DocWidget)->SimTime << QucsHomeDir.absPath()
+       << QucsSettings.BinDir;
+  }
+  else {
+    // output NodeSets, SPICE simulations etc.
+    Stream << Collect.join("\n") << '\n';
+    SimTime = ((Schematic*)DocWidget)->createNetlist(Stream, SimPorts);
+    NetlistFile.close();
+    if(SimTime.at(0) == '') {
+      ErrText->insert(SimTime.mid(1));
+      FinishSimulation(-1);
+      return;
+    }
+    ProgText->insert(tr("done.\n"));  // of "creating netlist... 
+
+    if(SimPorts < 0)
+      CommandLine << QucsSettings.BinDir + "qucsator" << "-b" << "-g"
+         << "-i" << QucsHomeDir.filePath("netlist.txt") << "-o" << DataSet;
+    else
+      CommandLine << QucsSettings.BinDir + QucsDigi << "netlist.txt"
+         << DataSet << SimTime << SimPath << QucsSettings.BinDir << "-c";
+  }
+
+  SimProcess.setArguments(CommandLine);
 
   disconnect(&SimProcess, 0, 0, 0);
   connect(&SimProcess, SIGNAL(readyReadStderr()), SLOT(slotDisplayErr()));
   connect(&SimProcess, SIGNAL(readyReadStdout()), SLOT(slotDisplayMsg()));
   connect(&SimProcess, SIGNAL(processExited()), SLOT(slotSimEnded()));
+
+#ifdef SPEEDUP_PROGRESSBAR
+  waitForUpdate = false;
+#endif
+  wasLF = false;
   ProgressText = "";
   if(!SimProcess.start()) {
     ErrText->insert(tr("ERROR: Cannot start simulator!"));
@@ -253,49 +316,66 @@ void SimMessage::startSimulator()
 // Is called when the process sends an output to stdout.
 void SimMessage::slotDisplayMsg()
 {
-  int i, Para;
-  QString s = QString(SimProcess.readStdout());
-//qDebug(s);
-  while((i = s.find('\r')) >= 0) {
-    if (s.find('\n') == i + 1) break; // necessary on Win32 platforms
-    if(wasLF)
-      ProgressText += s.left(i-1);
-    else {
-      int k = s.findRev('\n',i-s.length());
-      if (k > 0) {
-	ProgText->insert(s.left(k));
-	s = s.mid(k+1);
-	i = s.find('\r');
-      }
-      Para = ProgText->paragraphs()-1;
-      ProgressText = ProgText->text(Para) + s.left(i-1);
-      ProgText->removeParagraph(Para);  // remove last text line
-    }
-    s = s.mid(i+1);
-    Para = ProgressText.length()-11;
-    Para = 10*int(ProgressText.at(Para).latin1()-'0') +
-	      int(ProgressText.at(Para+1).latin1()-'0');
-    if(Para < 0)  Para += 160;
-    SimProgress->setProgress(Para, 100);
-    ProgressText = "";
-    wasLF = true;
-  }
-  if(s.length() < 1)  return;
-
+  int i;
+  ProgressText += QString(SimProcess.readStdout());
   if(wasLF) {
-    if(s.find('\n') >= 0) {
-      ProgText->insert("\n"+s);
-      wasLF = false;
+    i = ProgressText.findRev('\r');
+#ifdef __MINGW32__
+    while (i > 1 && ProgressText.at(i+1) == '\n') {
+      i = ProgressText.findRev('\r', i-1);
+    }
+#endif /* __MINGW32__ */
+    if(i > 1) {
+#ifdef SPEEDUP_PROGRESSBAR
+      iProgress = 10*int(ProgressText.at(i-2).latin1()-'0') +
+                     int(ProgressText.at(i-1).latin1()-'0');
+      if(!waitForUpdate) {
+        QTimer::singleShot(20, this, SLOT(slotUpdateProgressBar()));
+        waitForUpdate = true;
+      }
+#else
+      SimProgress->setProgress(
+         10*int(ProgressText.at(i-2).latin1()-'0') +
+            int(ProgressText.at(i-1).latin1()-'0'), 100);
+#endif
+      ProgressText.remove(0, i+1);
+    }
+
+    if(ProgressText.at(0).latin1() <= '\t')
+      return;
+  }
+  else {
+    i = ProgressText.find('\t');
+    if(i >= 0) {
+      wasLF = true;
+      ProgText->insert(ProgressText.left(i));
+      ProgressText.remove(0, i+1);
+      return;
     }
   }
-  else  ProgText->insert(s);
+
+  ProgText->insert(ProgressText);
+  ProgressText = "";
+  wasLF = false;
 }
 
+#ifdef SPEEDUP_PROGRESSBAR
+// ------------------------------------------------------------------------
+void SimMessage::slotUpdateProgressBar()
+{
+  SimProgress->setProgress(iProgress, 100);
+  waitForUpdate = false;
+}
+#endif
+
 // ------------------------------------------------------------------------
 // Is called when the process sends an output to stderr.
 void SimMessage::slotDisplayErr()
 {
-  ErrText->append(QString(SimProcess.readStderr()));
+  int par = ErrText->paragraphs();
+  int idx = ErrText->paragraphLength(par-1);
+  ErrText->setCursorPosition(par-1,idx);
+  ErrText->insert(QString(SimProcess.readStderr()));
 }
 
 // ------------------------------------------------------------------------
@@ -357,6 +437,42 @@ void SimMessage::slotClose()
 // ------------------------------------------------------------------------
 void SimMessage::slotDisplayButton()
 {
-  emit displayDataPage(Doc->DataDisplay);
+  emit displayDataPage(DocName, DataDisplay);
   accept();
 }
+
+// ------------------------------------------------------------------------
+int SimMessage::copyFile(const QString& SrcName, const QString& DestName)
+{
+  char *Buffer = (char*)malloc(0x10000);
+  if(!Buffer) return -10;  // should never happen
+
+  QFile origFile, destFile;
+  origFile.setName(SrcName);
+  destFile.setName(DestName);
+
+  if(!origFile.open(IO_ReadOnly)) {
+    free(Buffer);
+    return -1;
+  }
+
+  if(!destFile.open(IO_WriteOnly)) {
+    origFile.close();
+    free(Buffer);
+    return -2;
+  }
+
+  int Num;
+  do {     // copy data
+    Num = origFile.readBlock(Buffer, 0x10000);
+    if(Num < 0)  break;
+    Num = destFile.writeBlock(Buffer, Num);
+    if(Num < 0)  break;
+  } while(Num == 0x10000);
+
+  origFile.close();
+  destFile.close();
+  free(Buffer);
+  if(Num < 0)  return -3;
+  return 0;
+}
