@@ -1,6 +1,6 @@
 /***************************************************************************
-                          simmessage.h  -  description
-                             -------------------
+                               simmessage.h
+                              --------------
     begin                : Sat Sep 6 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -27,23 +27,21 @@ class QTextEdit;
 class QVBoxLayout;
 class QPushButton;
 class QProgressBar;
-class QucsDoc;
 
-/**
-  *@author Michael Margraf
-  */
+// #define SPEEDUP_PROGRESSBAR
+
 
 class SimMessage : public QDialog  {
    Q_OBJECT
 public:
-  SimMessage(QucsDoc*, QWidget *parent=0);
-  ~SimMessage();
+  SimMessage(QWidget*, QWidget *parent=0);
+ ~SimMessage();
 
   bool startProcess();
 
 signals:
   void SimulationEnded(int, SimMessage*);
-  void displayDataPage(QString);
+  void displayDataPage(QString&, QString&);
 
 public slots:
   void slotClose();
@@ -57,13 +55,25 @@ private slots:
   void slotReadSpiceNetlist();
   void slotFinishSpiceNetlist();
 
+/* #ifdef SPEEDUP_PROGRESSBAR
+  void slotUpdateProgressBar();
+private:
+  int  iProgress;
+  bool waitForUpdate;
+#endif
+*/
+
 private:
   void FinishSimulation(int);
   void nextSPICE();
   void startSimulator();
+  int  copyFile(const QString&, const QString&);
 
 public:
-  QucsDoc *Doc;
+  QWidget *DocWidget;
+  int showBias;
+  bool SimOpenDpl;
+  QString DocName, DataSet, DataDisplay;
 
   QProcess      SimProcess;
   QTextEdit    *ProgText, *ErrText;
@@ -72,6 +82,7 @@ public:
   QProgressBar *SimProgress;
   QString       ProgressText;
 
+  int           SimPorts;
   bool          makeSubcircuit, insertSim;
   QStringList   Collect;
   QFile         NetlistFile;
