@@ -32,7 +32,6 @@
 #include <qregexp.h>
 
 #include "qucs.h"
-#include "qucsview.h"
 #include "main.h"
 #include "node.h"
 
@@ -42,12 +41,6 @@ QFont savingFont;    // to remember which font to save in "qucsrc"
 
 QucsApp *QucsMain;   // the Qucs application itself
 
-// just dummies for empty lists
-QPtrList<Wire>      SymbolWires;
-QPtrList<Node>      SymbolNodes;
-QPtrList<Diagram>   SymbolDiags;
-QPtrList<Component> SymbolComps;
-
 // #########################################################################
 // Loads the settings file and stores the settings.
 bool loadSettings()
@@ -62,7 +55,7 @@ bool loadSettings()
   while(!stream.atEnd()) {
     Line = stream.readLine();
     Setting = Line.section('=',0,0);
-    Line    = Line.section('=',1,1);
+    Line    = Line.section('=',1).stripWhiteSpace();
     if(Setting == "Position") {
 	QucsSettings.x = Line.section(",",0,0).toInt(&ok);
 	QucsSettings.y = Line.section(",",1,1).toInt(&ok); }
@@ -84,6 +77,10 @@ bool loadSettings()
 	QucsSettings.maxUndo = Line.toInt(&ok); }
     else if(Setting == "Editor") {
 	QucsSettings.Editor = Line; }
+    else if(Setting == "FileType") {
+	QucsSettings.FileTypes.append(Line); }
+    else if(Setting == "Language") {
+	QucsSettings.Language = Line; }
   }
 
   file.close();
@@ -108,12 +105,16 @@ bool saveApplSettings(QucsApp *qucs)
     << "Position=" << qucs->x() << "," << qucs->y() << "\n"
     << "Size=" << qucs->width() << "," << qucs->height() << "\n"
     << "Font=" << savingFont.toString() << "\n"
-    << "BGColor=" << qucs->view->viewport()->paletteBackgroundColor().name()
-    << "\n"
+    << "Language=" << QucsSettings.Language << "\n"
+    << "BGColor=" << QucsSettings.BGColor.name() << "\n"
     << "maxUndo=" << QucsSettings.maxUndo << "\n"
     << "Editor=" << QucsSettings.Editor << "\n";
-  file.close();
 
+  QStringList::Iterator it = QucsSettings.FileTypes.begin();
+  while(it != QucsSettings.FileTypes.end())
+    stream << "FileType=" << (*(it++)) << "\n";
+
+  file.close();
   return true;
 }
 
@@ -271,6 +272,38 @@ void str2num(const QString& s_, double& Number, QString& Unit, double& Factor)
   return;
 }
 
+// #########################################################################
+QString num2str(double Num)
+{
+  char c = 0;
+  double cal = fabs(Num);
+  if(cal > 1e-20) {
+    cal = log10(cal) / 3.0;
+    if(cal < -0.2)  cal -= 0.98;
+    int Expo = int(cal);
+
+    if(Expo >= -5) if(Expo <= 4)
+      switch(Expo) {
+        case -5: c = 'f'; break;
+        case -4: c = 'p'; break;
+        case -3: c = 'n'; break;
+        case -2: c = 'u'; break;
+        case -1: c = 'm'; break;
+        case  1: c = 'k'; break;
+        case  2: c = 'M'; break;
+        case  3: c = 'G'; break;
+        case  4: c = 'T'; break;
+      }
+
+    if(c)  Num /= pow(10.0, double(3*Expo));
+  }
+
+  QString Str = QString::number(Num);
+  if(c)  Str += c;
+  
+  return Str;
+}
+
 // #########################################################################
 void convert2Unicode(QString& Text)
 {
@@ -288,6 +321,50 @@ void convert2Unicode(QString& Text)
   Text.replace("\\\\", "\\");
 }
 
+// #########################################################################
+// Takes a file name (with path) and replaces all special characters.
+QString properName (const QString& Name)
+{
+  QString s = Name;
+  QFileInfo Info(s);
+  if(Info.extension() == "sch")
+    s = s.left(s.length()-4);
+  if(s.at(0) <= '9') if(s.at(0) >= '0')
+    s = 'n' + s;
+  s.replace(QRegExp("\\W"), "_"); // none [a-zA-Z0-9] into "_"
+  s.replace("__", "_");  // '__' not allowed in VHDL
+  if(s.at(0) == '_')
+    s = 'n' + s;
+  return s;
+}
+
+// #########################################################################
+// Checks and corrects a time (number & unit) according VHDL standard.
+bool VHDL_Time(QString& t, const QString& Name)
+{
+  char *p;
+  double Time = strtod(t.latin1(), &p);
+  while(*p == ' ') p++;
+  for(;;) {
+    if(Time >= 0.0) {
+      if(strcmp(p, "fs") == 0)  break;
+      if(strcmp(p, "ps") == 0)  break;
+      if(strcmp(p, "ns") == 0)  break;
+      if(strcmp(p, "us") == 0)  break;
+      if(strcmp(p, "ms") == 0)  break;
+      if(strcmp(p, "sec") == 0) break;
+      if(strcmp(p, "min") == 0) break;
+      if(strcmp(p, "hr") == 0)  break;
+    }
+    t = "" + QObject::tr("Error: Wrong time format in \"%1\". Use positive number with units").arg(Name)
+            + " fs, ps, ns, us, ms, sec, min, hr.\n";
+    return false;
+  }
+
+  t = QString::number(Time) + " " + QString(p);  // the space is mandatory !
+  return true;
+}
+
 
 // #########################################################################
 // ##########                                                     ##########
@@ -297,43 +374,6 @@ void convert2Unicode(QString& Text)
 
 int main(int argc, char *argv[])
 {
-#if 0
-  double zD;
-  zD = 0.0;
-  qDebug(StringNiceNum(zD));
-  zD = 112e8;
-  qDebug(StringNiceNum(zD));
-  qDebug(" ");
-
-  zD = 1.0e5;
-  qDebug(StringNiceNum(zD));
-
-  zD = 1.1e5;
-  qDebug(StringNiceNum(zD));
-
-  zD = 1.12e5;
-  qDebug(StringNiceNum(zD));
-
-  zD = 1.123e5;
-  qDebug(StringNiceNum(zD));
-
-  zD = 1.1234567e5;
-  qDebug(StringNiceNum(zD));
-
-  return 0;
-#endif
-
-#if 0
-  char Zahl1[32] = "12.34e2+j56.7";
-  char Zahl2[32] = "12.56e2";
-  char *p = 0;
-  double z1 = strtod(Zahl1, &p);
-  qDebug("%p -> %g -> %p", &Zahl1[0], z1, p);
-  double z2 = strtod(Zahl2, &p);
-  qDebug("%p -> %g -> %p", &Zahl2[0], z2, p);
-  return 0;
-#endif
-
   // apply default settings
   QucsSettings.x = 0;
   QucsSettings.y = 0;
@@ -373,7 +413,10 @@ int main(int argc, char *argv[])
   a.setFont(QucsSettings.font);
 
   QTranslator tor( 0 );
-  tor.load( QString("qucs_") + QTextCodec::locale(), QucsSettings.LangDir);
+  QString lang = QucsSettings.Language;
+  if(lang.isEmpty())
+    lang = QTextCodec::locale();
+  tor.load( QString("qucs_") + lang, QucsSettings.LangDir);
   a.installTranslator( &tor );
 
   QucsMain = new QucsApp();
