@@ -1,6 +1,6 @@
 /***************************************************************************
-                          main.h  -  description
-                             -------------------
+                                  main.h
+                                 --------
     begin                : Mon May 24  2004
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,6 +21,7 @@
 #include <qfont.h>
 #include <qcolor.h>
 #include <qptrlist.h>
+#include <qstringlist.h>
 
 #include "wire.h"
 #include "node.h"
@@ -40,6 +41,7 @@ struct tQucsSettings {
   QFont font;
   float largeFontSize;
   QColor BGColor;      // background color of view area
+  QString Language;
 
   unsigned int maxUndo;    // size of undo stack
   QString Editor;
@@ -47,6 +49,9 @@ struct tQucsSettings {
   QString BitmapDir;
   QString LangDir;
   QString LibDir;
+
+  // registered filename extensions with program to open the file
+  QStringList FileTypes;
 };
 
 extern tQucsSettings QucsSettings;  // extern because nearly everywhere used
@@ -61,14 +66,10 @@ QString complexDeg (double, double, int Precision=3);
 QString complexRad (double, double, int Precision=3);
 QString StringNum  (double, char form='g', int Precision=3);
 void    str2num    (const QString&, double&, QString&, double&);
+QString num2str    (double);
 QString StringNiceNum(double);
 void    convert2Unicode(QString&);
-
-// just dummies for empty lists
-extern QPtrList<Wire>      SymbolWires;
-extern QPtrList<Node>      SymbolNodes;
-extern QPtrList<Diagram>   SymbolDiags;
-extern QPtrList<Component> SymbolComps;
+QString properName (const QString&);
+bool    VHDL_Time(QString&, const QString&);
 
 #endif
-
