@@ -1,6 +1,6 @@
 /***************************************************************************
-                          graphicline.cpp  -  description
-                             -------------------
+                              graphicline.cpp
+                             -----------------
     begin                : Mon Nov 24 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -86,6 +86,16 @@ Painting* GraphicLine::newOne()
   return new GraphicLine();
 }
 
+// --------------------------------------------------------------------------
+Element* GraphicLine::info(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("Line");
+  BitmapFile = "line";
+
+  if(getNewOne)  return new GraphicLine();
+  return 0;
+}
+
 // --------------------------------------------------------------------------
 bool GraphicLine::load(const QString& s)
 {
