@@ -1,6 +1,6 @@
 /***************************************************************************
-                          id_text.h  -  description
-                             -------------------
+                                id_text.h
+                               -----------
     begin                : Thu Oct 14 2004
     copyright            : (C) 2004 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,10 +21,6 @@
 #include "painting.h"
 
 
-/**
-  *@author Michael Margraf
-  */
-
 class ID_Text : public Painting  {
 public:
   ID_Text(int cx_=0, int cy_=0);
